{
 "cells": [
  {
   "cell_type": "markdown",
   "metadata": {
    "slideshow": {
     "slide_type": "slide"
    }
   },
   "source": [
    "# Requests, The Web, JSON, and APIs"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "slideshow": {
     "slide_type": "slide"
    }
   },
   "source": [
    "# The Web\n",
    "* Client/Server\n",
    "* HTML (Hyper Text Markup Language)\n",
    "* Java Script\n",
    "* JSON (Java Script Object Notation)\n",
    "* The Browser"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "slideshow": {
     "slide_type": "slide"
    }
   },
   "source": [
    "# HTTP, Methods, Reponses\n",
    "* Hyper Text Transfer Protocol\n",
    "* GET, POST, PUT...\n",
    "* Response Codes: 1xx, 2xx, 3xx, 4xx, 5xx\n"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "slideshow": {
     "slide_type": "slide"
    }
   },
   "source": [
    "# GET\n",
    "* The most common method\n",
    "* Used to request data from a specified resource"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "slideshow": {
     "slide_type": "slide"
    }
   },
   "source": [
    "# POST\n",
    "* Method for sending data\n",
    "* Typically used to update or create resources\n",
    "* Is the cause of problems when you try to hit back in your browser\n"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "slideshow": {
     "slide_type": "slide"
    }
   },
   "source": [
    "# Other Methods\n",
    "* PUT: Update resources\n",
    "* DELETE: Delete resources\n",
    "* Still Other Methods: PATCH/OPTION/HEAD Less commonly used"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "slideshow": {
     "slide_type": "slide"
    }
   },
   "source": [
    "# Response Codes\n",
    "* 1xx Informational, uncommon\n",
    "* 200 Success response, most common response\n",
    "* 3xx Redirect, page has moved etc.\n",
    "* 4xx Your problem\n",
    "* 5xx Their problem"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "slideshow": {
     "slide_type": "slide"
    }
   },
   "source": [
    "# Requests\n",
    "* HTTP for Humans\n",
    "* Simple methods for getting, posting, and authenticating with websites"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 1,
   "metadata": {
    "slideshow": {
     "slide_type": "-"
    }
   },
   "outputs": [],
   "source": [
    "import requests"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 2,
   "metadata": {
    "slideshow": {
     "slide_type": "-"
    }
   },
   "outputs": [
    {
     "data": {
      "text/plain": [
       "200"
      ]
     },
     "execution_count": 2,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "google_response = requests.get('http://google.com')\n",
    "google_response.status_code"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 3,
   "metadata": {
    "slideshow": {
     "slide_type": "-"
    }
   },
   "outputs": [
    {
     "data": {
      "text/plain": [
       "12459"
      ]
     },
     "execution_count": 3,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "len(google_response.content)\n",
    "# google_response.content"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "https://www.dictionary.com/browse/biology"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 6,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/plain": [
       "200"
      ]
     },
     "execution_count": 6,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "import os\n",
    "os.environ['http_proxy'] = \"http://proxy.swmed.edu:3128\" \n",
    "os.environ['https_proxy'] = \"https://proxy.swmed.edu:3128\" \n",
    "dictionary_search = requests.get('http://www.dictionary.com/browse/biology')\n",
    "dictionary_search.status_code"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 8,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/plain": [
       "b'<!DOCTYPE html>\\n    <html lang=\"en\" prefix=\"og: http://ogp.me/ns#\">\\n      <head>\\n        \\n  <meta charSet=\"utf-8\">\\n  <meta name=\"description\" content=\"Biology definition, the science of life or living matter in all its forms and phenomena, especially with reference to origin, growth, reproduction, structure, and behavior. See more.\">\\n  <link rel=\"canonical\" href=\"https://www.dictionary.com/browse/biology\">\\n  <link rel=\"preload\" href=\"https://www.dictionary.com/assets/dictionary-font-c864a1ca3bc4a1c7aef16dbbf189ccc1.woff\" as=\"font\" type=\"font/woff\" crossorigin=\"anonymous\">\\n  \\n  <meta property=\"og:title\" content=\"the definition of biology\">\\n  <meta property=\"og:image\" content=\"https://www.dictionary.com/assets/dcom-social-icon-952ee83e140e5bfbd2d4b6c28daa1a8f.png\">\\n  <meta property=\"og:site_name\" content=\"www.dictionary.com\">\\n  <meta property=\"fb:app_id\" content=\"127444090629600\"><meta property=\"fb:admins\" content=\"100000304287730;109125464873\">\\n  <meta name=\"msvalidate.01\" content=\"DF5542D7723770377E9ABFF59AC1DC97\">\\n  <link rel=\"icon\" type=\"image/png\" href=\"https://www.dictionary.com/assets/favicon-1bff2f1b49c077ed504e55c3649f2a4b.png\">\\n  <title>Biology | Define Biology at Dictionary.com</title>\\n  <meta name=\"viewport\" content=\"width=device-width, initial-scale=1.0\">\\n  \\n  <link rel=\"preconnect\" href=\"https://ads.pubmatic.com\">\\n  <link rel=\"preconnect\" href=\"https://www.googletagservices.com\">\\n  <link rel=\"preconnect\" href=\"https://c.amazon-adsystem.com\">\\n  <link rel=\"preconnect\" href=\"https://www.googletagmanager.com\">\\n  <link rel=\"preconnect\" href=\"https://www.google-analytics.com\">\\n  <link rel=\"preconnect\" href=\"https://connect.facebook.net\">\\n\\n        \\n          \\n          <script defer src=\"https://www.dictionary.com/assets/client-cbe18d61.js\"></script>\\n          <script defer src=\"https://www.dictionary.com/assets/standalone-analytics-bd97baaf.js\"></script>\\n          \\n        <!-- Ad integration with callback begins here, must be in head, expects page type to get appropriate configs -->\\n        \\n<script>\\n  /** wrapping ad scripts with adboiler label **/\\n  adboiler: {\\n    \\n\\n    /**---------- Page level ad targeting configs ----------*/\\n    var pageTargeting = {\"tx1\":\"results\",\"tx2\":\"serp_0_n\",\"ptype\":\"content\",\"ld\":\"0\"};\\n\\n    /**---------- Page level ad slot configs ----------*/\\n    var slotConfigs = [{\"placement\":\"dcom-serp-lb-728x90\",\"code\":\"/23219321/iac.dict.dictry.dw/dic/serp_0_n\",\"ad_uuid\":\"728x90_top\",\"sizes\":[[728,90],[970,90],[970,250]],\"targeting\":{\"pos\":\"top\",\"pos2\":\"728x90_1\"}},{\"placement\":\"dcom-serp-a-top-300x250\",\"code\":\"/23219321/iac.dict.dictry.dw/dic/serp_0_n\",\"ad_uuid\":\"300x250_top\",\"sizes\":[[300,250],[300,600]],\"targeting\":{\"pos\":\"top\",\"pos2\":\"300x250_1\"}},{\"placement\":\"dcom-serp-a-mid-300x250\",\"code\":\"/23219321/iac.dict.dictry.dw/dic/serp_0_n\",\"ad_uuid\":\"300x250_mid\",\"sizes\":[[300,250]],\"targeting\":{\"pos\":\"mid\",\"pos2\":\"300x250_2\"}},{\"placement\":\"dcom-serp-bottom-lb-728x90\",\"code\":\"/23219321/iac.dict.dictry.dw/dic/serp_0_n\",\"ad_uuid\":\"728x90_bot\",\"sizes\":[[728,90]],\"targeting\":{\"pos\":\"bot\",\"pos2\":\"728x90_2\"}}];\\n    var slotConfigsDeferred = [];\\n\\n    var googletag = googletag || {};\\n    googletag.cmd = googletag.cmd || [];\\n    var adSlots =  adSlots || {slots:{}, lazySlots:{}};\\n\\n    const setupDFP = function() {\\n      /**---------- Set page level targeting for DFP ----------*/\\n      for (var pageTarget in pageTargeting) {\\n        if (pageTargeting.hasOwnProperty(pageTarget)) {\\n          (function(key, value) {\\n            googletag.cmd.push(function() {\\n              googletag.pubads().setTargeting(key, value);\\n            });\\n          })(pageTarget, pageTargeting[pageTarget]);\\n        }\\n      }\\n\\n      /**---------- Set ad slot level targeting for DFP ----------*/\\n      if (typeof slotConfigs === \"object\") {\\n        slotConfigs.forEach(function(slot, index) {\\n          googletag.cmd.push(function() {\\n            adSlots.slots[slot.placement] = googletag.defineSlot(slot.code, slot.sizes, slot.placement).addService(googletag.pubads());\\n            for (var target in slot.targeting) {\\n              if (slot.targeting.hasOwnProperty(target)) {\\n                adSlots.slots[slot.placement].setTargeting(target, slot.targeting[target]);\\n              }\\n            }\\n          });\\n        });\\n      }\\n\\n      /**---------- Push gpt ad slots to DFP ----------*/\\n      googletag.cmd.push(function() {\\n        googletag.pubads().enableSingleRequest();\\n        googletag.pubads().disableInitialLoad();\\n        googletag.enableServices();\\n        window.dfpReady = true;\\n      });\\n    }\\n\\n    \\n    /**---------- Irene integration ----------*/\\n      var adlerValues;\\n      var detectedDevice = \\'Desktop\\';\\n\\n      if(\\'Mobile\\' === detectedDevice) {\\n        detectedDevice = \\'MobileWeb\\';\\n      }\\n\\n      var setInstrumentationKV = function(status, error) {\\n        slotConfigs.forEach(function(slot) {\\n          slot.targeting.adler_status = status;\\n          if (error) {\\n            slot.targeting.adler_error = error;\\n          }\\n        });\\n      }\\n\\n      var adlerParams = function(slots) {\\n        var r = {};\\n        const geo = \\'US\\';\\n\\n        if(geo === \\'\\') {\\n          setInstrumentationKV(\\'nogeo\\', \\'nogeo\\');\\n        }\\n\\n        slots.forEach(function(slot) {\\n          r[slot.ad_uuid] = {\\n            site: \\'dcom\\',\\n            geo: geo,\\n            platform: detectedDevice,\\n            sizes: slot.sizes,\\n            position: slot.targeting.pos,\\n          }\\n        });\\n\\n        return r;\\n      }\\n\\n      var fallback = function(shouldSetupDFP, event) {\\n        setInstrumentationKV(event.type);\\n        if (shouldSetupDFP) {\\n          setupDFP();\\n        }\\n      }\\n\\n      var injectAdlerValues = function(localSlotConfigs) {\\n        if(adlerValues) {\\n          localSlotConfigs.forEach(function(slot) {\\n            if (!adlerValues[slot.ad_uuid]) {\\n              slot.targeting.adler_status = \\'nofloor\\';\\n            }\\n            else {\\n              slot.targeting.adler = adlerValues[slot.ad_uuid].adler;\\n              slot.targeting.adler_a = adlerValues[slot.ad_uuid].adler_a;\\n              slot.targeting.adler_b = adlerValues[slot.ad_uuid].adler_b;\\n              slot.targeting.adler_status = \\'ok\\';\\n            }\\n          });\\n        }\\n      }\\n\\n      var setAdlerValues = function(rtfAjaxCall, localSlotConfigs) {\\n        try {\\n          adlerValues = JSON.parse(rtfAjaxCall.responseText);\\n        } catch(err) {\\n          setInstrumentationKV(\\'parse\\', err.message);\\n        }\\n        injectAdlerValues(localSlotConfigs);\\n      }\\n\\n      var rtfCallback = function(rtfAjaxCall, localSlotConfigs, shouldSetupDFP) {\\n        setAdlerValues(rtfAjaxCall, localSlotConfigs);\\n        if (shouldSetupDFP) {\\n          setupDFP();\\n        }\\n      }\\n\\n      var callRTF = function(localSlotConfigs, shouldSetupDFP) {\\n        var rtfReq = new XMLHttpRequest();\\n        rtfReq.addEventListener(\"load\", rtfCallback.bind(null, rtfReq, localSlotConfigs, shouldSetupDFP));\\n        rtfReq.addEventListener(\"timeout\", fallback.bind(null, shouldSetupDFP));\\n        rtfReq.addEventListener(\"error\", fallback.bind(null, shouldSetupDFP));\\n        rtfReq.open(\"POST\", \"https://irene.dictionary.com/v1\", true);\\n        rtfReq.timeout = 1000;\\n        rtfReq.send(JSON.stringify(adlerParams(localSlotConfigs)));\\n      }\\n\\n      callRTF(slotConfigs, true);\\n      \\n\\n    /**---------- Pubmatic url ----------*/\\n    const isEU = false;\\n    var url = \"https://ads.pubmatic.com/AdServer/js/pwt/103207/307\";\\n    const setGPTPersonalization = function(personalized) {\\n      googletag.cmd.push(function() {\\n        if (!window.dfpReady) {\\n          setTimeout(setGPTPersonalization, 100, personalized);\\n        }\\n        else {\\n          if (personalized) {\\n            googletag.pubads().setRequestNonPersonalizedAds(0);\\n          }\\n          else {\\n            googletag.pubads().setRequestNonPersonalizedAds(1);\\n          }\\n          googletag.pubads().refresh();\\n        }\\n      });\\n    };\\n    /**---------- extend pageTargeting at runtime ----------*/\\n    pageTargeting.spe = \"n\";\\n    pageTargeting.ref =\\n      window.document.referrer.search(\\n        \"dictionary.com|thesaurus.com|reference.com\"\\n      ) > -1 ? \"organic\" : \"direct\";\\n    pageTargeting.kw = \"\";\\n    pageTargeting.lang = window.navigator.userLanguage || window.navigator.language;\\n    pageTargeting.loc = \"US\";\\n    pageTargeting.dow = new Date().getDay().toString();\\n    pageTargeting.rpv = Math.floor(Math.random() * 100 + 1).toString();\\n    pageTargeting.pv = typeof SCCookie !== \"undefined\" ? SCCookie.getPageViewCount() + \"\" : \"\";\\n    pageTargeting.evince = \"ad\";\\n\\n    /**---------- Pubmatic wrapper and GPT Tag with Callback begins here ----------*/\\n    var apstagSlots = slotConfigs.reduce(function(accumulator, currentValue) {\\n      accumulator.push({\\n        slotID: currentValue.placement,\\n        sizes: currentValue.sizes\\n      });\\n      return accumulator;\\n    }, []);\\n    var PWT = {};\\n\\n    /**---------- PubMatic pwt.js on load callback is used to load GPT ----------*/\\n    PWT.jsLoaded = function() {\\n      /* Notifies OpenWrap that there are some external bidders for which it has to wait before calling DFP. */\\n      window.OWT.registerExternalBidders();\\n      (function() {\\n        var gads = document.createElement(\\'script\\');\\n        gads.src = \\'https://www.googletagservices.com/tag/js/gpt.js\\';\\n        var node = document.getElementsByTagName(\\'script\\')[0];\\n        node.parentNode.insertBefore(gads, node);\\n      })();\\n    };\\n\\n    (function() {\\n      var purl = window.location.href;\\n      var profileVersionId = \\'\\';\\n      if (purl.indexOf(\\'pwtv=\\') > 0) {\\n        var regexp = /pwtv=(.*?)(&|$)/g;\\n        var matches = regexp.exec(purl);\\n        if (matches.length >= 2 && matches[1].length > 0) {\\n          profileVersionId = \\'/\\' + matches[1];\\n        }\\n      }\\n      var wtads = document.createElement(\\'script\\');\\n      wtads.async = true;\\n      wtads.type = \\'text/javascript\\';\\n      wtads.src = url + profileVersionId + \\'/pwt.js\\';\\n      var node = document.getElementsByTagName(\\'script\\')[0];\\n      node.parentNode.insertBefore(wtads, node);\\n    })();\\n\\n    !function(a9, a, p, s, t, A, g) {\\n      if (a[a9]) return;\\n\\n      function q(c, r) {\\n        a[a9]._Q.push([c, r])\\n      }\\n      a[a9] = {\\n        init: function() {\\n          q(\"i\", arguments)\\n        },\\n        fetchBids: function() {\\n          q(\"f\", arguments)\\n        },\\n        setDisplayBids: function() {},\\n        _Q: []\\n      };\\n\\n      A = p.createElement(s);\\n      A.async = !0;\\n      A.src = t;\\n      g = p.getElementsByTagName(s)[0];\\n      g.parentNode.insertBefore(A, g)\\n    }(\"apstag\", window, document, \"script\", \"//c.amazon-adsystem.com/aax2/apstag.js\");\\n\\n    apstag.init({\\n      pubID: \\'3067\\',\\n      adServer: \\'googletag\\',\\n      bidTimeout: 1000\\n    });\\n\\n    apstag.fetchBids({\\n      slots: apstagSlots\\n    }, function(bids) {\\n      /* Callback method that triggers the first DFP request for googletag\\'s disableInitialLoad integration after bids have been set */\\n      googletag.cmd.push(function() {\\n        apstag.setDisplayBids();\\n        window.OWT.notifyExternalBiddingComplete();\\n\\n        /*\\n          Determine IAB consent if necessary, and trigger GPT ad refresh\\n          if consent is provided.\\n        */\\n        if (isEU) {\\n          try {\\n            if (typeof __cmp === \\'function\\') {\\n              __cmp(\"getVendorConsents\", {}, function(c) {\\n                let consent = false;\\n                if (typeof c.purposeConsents === \\'array\\') {\\n                  consent = c.purposeConsents.includes(\\'3:true\\');\\n                } else if (typeof c.purposeConsents === \\'object\\') {\\n                  consent = c.purposeConsents[3];\\n                }\\n                if (consent !== false && consent !== true) consent = false;\\n                // request personalized ads\\n                setGPTPersonalization(consent);\\n              });\\n            } else {\\n              setGPTPersonalization(false);\\n            }\\n          } catch (error) {\\n            console.error(\\'personalization: \\', error);\\n            setGPTPersonalization(false);\\n          }\\n        } else {\\n          setGPTPersonalization(true);\\n        }\\n      });\\n    });\\n  }\\n</script>\\n        <!-- Pubmatic wrapper and GPT Tag ends here -->\\n        <!-- Google Analytics GTM dataLayer starts here -->\\n        \\n      <script type=\\'text/javascript\\'>\\n        window.dataLayer = window.dataLayer || [];\\n        dataLayer.push({\\n          event: \\'pageview\\',\\n          device: \\'Desktop\\',\\n          pageName: \\'undefined\\',\\n          LDid: \\'0\\',\\n          sessionId: null,\\n          browserId: null,\\n        });\\n      </script>\\n      <script>\\n      (function(w, d, s, l, i) {\\n        w[l] = w[l] || [];\\n        w[l].push({ \\'gtm.start\\': new Date().getTime(), event: \\'gtm.js\\' });\\n        var f = d.getElementsByTagName(s)[0],\\n          j = d.createElement(s),\\n          dl = l != \\'dataLayer\\' ? \\'&l=\\' + l : \\'\\';\\n        j.async = true;\\n        j.src = \\'https://www.googletagmanager.com/gtm.js?id=\\' + i + dl;\\n        f.parentNode.insertBefore(j, f);\\n      })(window, document, \\'script\\', \\'dataLayer\\', \\'GTM-TXC5GP\\');\\n      </script>\\n\\n        <!-- Google Analytics GTM dataLayer ends here -->\\n        \\n  <script>\\n    var loadingTimeout = 0;\\n    setTimeout(function stopLoading() {\\n      document.body.classList.remove(\\'init\\');\\n      document.body.classList.add(\\'loaded\\');\\n    }, loadingTimeout)\\n  </script>\\n  <noscript>\\n    <style>\\n      #initial-load-header-loader {\\n        visibility: hidden!important;\\n      }\\n      #initial-load-content {\\n        visibility: visible!important;\\n      }\\n    </style>\\n  </noscript>\\n\\n        <style>@-webkit-keyframes animation-jdx9m6{from{-webkit-transform:translate(-30vw);-ms-transform:translate(-30vw);transform:translate(-30vw);width:30vw;}50%{width:30vw;}70%{width:50vw;}80%{-webkit-transform:translate(50vw);-ms-transform:translate(50vw);transform:translate(50vw);}95%{-webkit-transform:translate(120vw);-ms-transform:translate(120vw);transform:translate(120vw);width:90%;}to{-webkit-transform:translate(140vw);-ms-transform:translate(140vw);transform:translate(140vw);}}@keyframes animation-jdx9m6{from{-webkit-transform:translate(-30vw);-ms-transform:translate(-30vw);transform:translate(-30vw);width:30vw;}50%{width:30vw;}70%{width:50vw;}80%{-webkit-transform:translate(50vw);-ms-transform:translate(50vw);transform:translate(50vw);}95%{-webkit-transform:translate(120vw);-ms-transform:translate(120vw);transform:translate(120vw);width:90%;}to{-webkit-transform:translate(140vw);-ms-transform:translate(140vw);transform:translate(140vw);}}@font-face{font-family:\\'dictionary-fonticon\\';src:url(https://www.dictionary.com/assets/dictionary-font-2f8f4dd423d79b60f7bc58ddcc429053.eot) format(\\'embedded-opentype\\'),url(https://www.dictionary.com/assets/dictionary-font-c864a1ca3bc4a1c7aef16dbbf189ccc1.woff) format(\\'woff\\'),url(https://www.dictionary.com/assets/dictionary-font-0acb1acf427a046a793cc3942f13589e.ttf) format(\\'truetype\\'),url(https://www.dictionary.com/assets/dictionary-font-2ae54d9d76a12012ae17e2dd85d293e9.svg#dictionary-font) format(\\'svg\\');}html{line-height:1.15;-ms-text-size-adjust:100%;-webkit-text-size-adjust:100%;}body{margin:0;}article,aside,footer,header,nav,section{display:block;}h1{font-size:2em;margin:0.67em 0;}figcaption,figure,main{display:block;}figure{margin:1em 40px;}hr{box-sizing:content-box;height:0;overflow:visible;}pre{font-family:monospace,monospace;font-size:1em;}a{background-color:transparent;-webkit-text-decoration-skip:objects;}abbr[title]{border-bottom:none;-webkit-text-decoration:underline;text-decoration:underline;-webkit-text-decoration:underline dotted;text-decoration:underline dotted;}b,strong{font-weight:inherit;}b,strong{font-weight:bolder;}code,kbd,samp{font-family:monospace,monospace;font-size:1em;}dfn{font-style:italic;}mark{background-color:#ff0;color:#000;}small{font-size:80%;}sub,sup{font-size:75%;line-height:0;position:relative;vertical-align:baseline;}sub{bottom:-0.25em;}sup{top:-0.5em;}audio,video{display:inline-block;}audio:not([controls]){display:none;height:0;}img{border-style:none;}svg:not(:root){overflow:hidden;}button,input,optgroup,select,textarea{font-family:sans-serif;font-size:100%;line-height:1.15;margin:0;}button,input{overflow:visible;}button,select{text-transform:none;}button,html [type=\"button\"],[type=\"reset\"],[type=\"submit\"]{-webkit-appearance:button;}button::-moz-focus-inner,[type=\"button\"]::-moz-focus-inner,[type=\"reset\"]::-moz-focus-inner,[type=\"submit\"]::-moz-focus-inner{border-style:none;padding:0;}button:-moz-focusring,[type=\"button\"]:-moz-focusring,[type=\"reset\"]:-moz-focusring,[type=\"submit\"]:-moz-focusring{outline:1px dotted ButtonText;}fieldset{padding:0.35em 0.75em 0.625em;}legend{box-sizing:border-box;color:inherit;display:table;max-width:100%;padding:0;white-space:normal;}progress{display:inline-block;vertical-align:baseline;}textarea{overflow:auto;}[type=\"checkbox\"],[type=\"radio\"]{box-sizing:border-box;padding:0;}[type=\"number\"]::-webkit-inner-spin-button,[type=\"number\"]::-webkit-outer-spin-button{height:auto;}[type=\"search\"]{-webkit-appearance:textfield;outline-offset:-2px;}[type=\"search\"]::-webkit-search-cancel-button,[type=\"search\"]::-webkit-search-decoration{-webkit-appearance:none;}::-webkit-file-upload-button{-webkit-appearance:button;font:inherit;}details,menu{display:block;}summary{display:list-item;}canvas{display:inline-block;}template{display:none;}[hidden]{display:none;}ul,ol,dl{margin:0 auto;padding:0;}button,input,optgroup,select,textarea{font-family:inherit;}html,body{overflow-x:hidden;}body{margin:0;font:14px Verdana,Helvetica,Arial,sans-serif;background-color:white;color:#666666;}body #initial-load-header-loader{visibility:hidden;}body #initial-load-content{visibility:visible;}body.init #initial-load-header-loader{visibility:visible;}body.init #initial-load-content{visibility:hidden;}body .hamburgerMenu-opened.app-isMobile #hamburgerButton-click{margin-left:0;}body .hamburgerMenu-opened #hamburgerButton-click{background-color:#3c7bbe;color:#ffffff;}body .hamburgerMenu-opened #hamburgerButton-click::before{content:\\'\\xee\\xa4\\x84\\';}body .hamburgerMenu-opened .hamburger-overlay{display:block;}a{-webkit-text-decoration:none;text-decoration:none;color:#3c7bbe;}a:hover{-webkit-text-decoration:underline;text-decoration:underline;}.one-click:hover{color:#3c7bbe;cursor:pointer;}.css-yshiao.hamburgerMenu-opened{height:100vh;overflow-y:hidden;}.css-1qktsnw{min-height:calc(100vh - 40px);-webkit-transition:-webkit-transform 0.4s ease;-webkit-transition:transform 0.4s ease;transition:transform 0.4s ease;}@media only screen and (max-width:768px){.css-1qktsnw{min-height:calc(100vh - 81px);}}.hamburgerMenu-opened .css-1qktsnw{-webkit-transform:translate3d(300px,0,0);-ms-transform:translate3d(300px,0,0);transform:translate3d(300px,0,0);}.app-isMobile.hamburgerMenu-opened .css-1qktsnw{-webkit-transform:translate3d(calc(100% - 65px),0,0);-ms-transform:translate3d(calc(100% - 65px),0,0);transform:translate3d(calc(100% - 65px),0,0);}.css-ywz12x{z-index:10001;}.css-14qcrqt{height:40px;overflow:hidden;}.css-rjglq{background:#3c7bbe;display:inline-block;float:left;}.css-cqn0r7{position:absolute;display:none;top:0;left:0;height:100%;width:100%;background-color:rgba(0,0,0,0.6);z-index:4;}.css-151frnk{position:absolute;top:0;left:-300px;width:300px;height:100%;background-color:#3c7bbe;}.css-7wf88h{list-style-type:none;padding:15px 15px 7px;margin:0;}.css-badxzn{font-size:16px;font-style:italic;font-weight:bold;line-height:16px;font-family:Helvetica,Arial,serif;border-top:1px solid #66cef6;}.css-badxzn:first-child{border-top:0;}.css-badxzn:first-child > a{padding-top:0;}.css-badxzn:last-child{border-bottom:1px solid #66cef6;}.css-78n1nc{display:block;color:#f5f5f5;padding:18px 0;-webkit-text-decoration:none;text-decoration:none;}.css-78n1nc:hover{color:#66cef6;-webkit-text-decoration:none;text-decoration:none;cursor:pointer;}.css-1kmzn5i{margin:0;font-family:Verdana,sans-serif;font-size:15px;font-weight:normal;line-height:1.15;list-style-type:none;padding:0 15px 7px;}.css-1kmzn5i > li > a{padding:8px 0 14px;font-style:normal;-webkit-text-decoration:none;text-decoration:none;}.css-1tpwzaq{margin-left:0;font-family:dictionary-fonticon;color:inherit;width:40px;height:40px;cursor:pointer;padding:0;border:none;outline:none;position:relative;display:inline-block;-webkit-font-smoothing:antialiased;background-color:#fff;font-size:24px;line-height:1;z-index:5;}.css-1tpwzaq::before{content:\\'\\xee\\xa4\\x83\\';}.css-1w5d7r9{height:40px;margin:0;padding:0;}.css-1fe7abr{z-index:3;border-right:none;float:left;list-style-type:none;background-color:#f5f5f5;text-align:center;background-color:#3c7bbe;}.css-1fe7abr:last-child{border-right:1px solid #aaa;}.css-akr928{cursor:pointer;display:inline-block;padding:12px 26px;font:16px Helvetica,sans-serif;line-height:18px;font-style:italic;font-weight:bold;-webkit-text-decoration:none;text-decoration:none;color:#666;color:#fff;}@media (max-width:400px){.css-akr928{padding:11px 13px;font-size:14px;}}@media (max-width:318px){.css-akr928{font-size:12px;}}.css-1yyv0n6{z-index:3;border-right:none;float:left;list-style-type:none;background-color:#f5f5f5;text-align:center;}.css-1yyv0n6:last-child{border-right:1px solid #aaa;}.css-1yyv0n6:hover{background-color:#e2e2e2;}.css-1npfjc8{cursor:pointer;display:inline-block;padding:12px 26px;font:16px Helvetica,sans-serif;line-height:18px;font-style:italic;font-weight:bold;-webkit-text-decoration:none;text-decoration:none;color:#666;}@media (max-width:400px){.css-1npfjc8{padding:11px 13px;font-size:14px;}}@media (max-width:318px){.css-1npfjc8{font-size:12px;}}.css-zd7l5y{float:right;padding:1px 14px 1px 22px;margin:8px 0;border-right:1px solid #e2e2e2;line-height:22px;color:#555;font-size:11px;-webkit-text-decoration:none;text-decoration:none;font-weight:400;font-family:Open Sans,sans-serif;-webkit-transition:all 0.15s ease-in-out;transition:all 0.15s ease-in-out;}.css-zd7l5y > span{float:left;width:22px;height:22px;margin-right:8px;font-size:22px;-webkit-text-decoration:none;text-decoration:none;font-family:dictionary-fonticon;}.css-zd7l5y:hover{color:#6cb746;}.css-jna48b::before{content:\\'\\xee\\x98\\x8e\\';}.css-sv8lr1::before{content:\\'\\xee\\x98\\x8d\\';}.css-omrpao{background:#3c7bbe;display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;-webkit-box-pack:left;-webkit-justify-content:left;-ms-flex-pack:left;justify-content:left;left:100px;}.css-15nai5i{padding:15px 15px 18px;height:auto;display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;-webkit-flex-wrap:wrap;-ms-flex-wrap:wrap;flex-wrap:wrap;}@media (min-width:1200px){.css-15nai5i{width:1170px;margin-right:auto;margin-left:auto;}}@media (min-width:992px){.css-15nai5i{width:970px;margin-right:auto;margin-left:auto;}}.css-wwrygl{margin:0 20px 0 0;width:176px;height:40px;}.css-1uhxkf6{padding:8px 2px;background-color:#f8f8f8;display:inline-block;float:left;box-sizing:border-box;position:relative;}.css-1baulvz{display:inline-block;}.css-qwsmke{float:left;cursor:pointer;}.css-omgbl{font-family:\\'dictionary-fonticon\\';speak:none;font-style:normal;font-weight:normal;font-variant:normal;text-transform:none;float:right;padding:1px 3px;color:#555;font-size:25px;line-height:28px;}.css-omgbl:after{content:\\'\\\\e613\\';}.css-1ynlh0h{float:right;min-width:92px;display:block;padding-left:8px;color:#555;font:14px Verdana;line-height:30px;}.css-1dv1kvn{border:0;-webkit-clip:rect(0 0 0 0);clip:rect(0 0 0 0);height:1px;margin:-1px;overflow:hidden;padding:0;position:absolute;width:1px;}.css-ji58t3{float:left;display:block;width:292px;height:30px;padding:0 8px;margin-right:1px;border:1px solid #e2e2e2;min-height:1px;line-height:18px;font-size:18px;color:#666;-webkit-transition:border-color,box-shadow 0.2s,0.2s ease-in-out,ease-in-out;transition:border-color,box-shadow 0.2s,0.2s ease-in-out,ease-in-out;}.css-ji58t3:hover,.css-ji58t3:focus{border-color:#55acee;outline:0;box-shadow:inset 0 1px 1px rgba(0,0,0,0.075),0 0 8px rgba(102,175,233,0.6);}@media (min-width:1200px){.css-ji58t3{width:422px;}}.css-rv4ucl{font-family:\\'dictionary-fonticon\\';speak:none;font-style:normal;font-weight:normal;font-variant:normal;text-transform:none;width:50px;height:30px;cursor:pointer;padding:0;border:0;outline:0;background-color:transparent;float:left;display:inline-block;padding:2px 8px;background:#f8f8f8;color:#3f729b;font-size:24px;color:#55acee;}.css-rv4ucl:before{content:\\'\\\\e614\\';}.css-1jzsm78{margin:38px 0 0 -2px;width:100%;padding:0;background:#fff;z-index:2;cursor:pointer;list-style-type:none;box-shadow:0 2px 3px rgba(50,50,50,0.4);position:absolute;max-height:0px;-webkit-transition:max-height 100ms ease;transition:max-height 100ms ease;overflow:hidden;}.css-afnsia{border-top:1px solid #e2e2e2;padding:10px 8px;}.css-afnsia:hover{background:#f5f5f5;}.css-iry8e{display:block;-webkit-text-decoration:none;text-decoration:none;color:#555;font:14px Verdana,sans-serif;}.css-k2b2qh{z-index:10004;left:-30vw;width:30vw;height:4px;background-color:#9dbde1;-webkit-animation:animation-jdx9m6 2s linear infinite;animation:animation-jdx9m6 2s linear infinite;}.css-13o7eu2{display:block;}.css-d5e8ah{display:block;margin:0 auto;padding:0;}@media (max-width:768px){.css-d5e8ah{display:block;}}@media (min-width:1225px){.css-d5e8ah{width:1200px;}}.css-o2gk28{min-height:90px;padding:20px 0;text-align:center;}.css-dfjnxh{display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;position:relative;min-height:1px;padding:0 15px 15px 15px;width:100%;}@media (max-width:1200px){.css-dfjnxh{width:auto;}}@media (max-width:768px){.css-dfjnxh{display:block;}}.css-11r0tj9{border-top:0;border-bottom:1px solid #d9d9d9;margin:0;}.css-6xt45o{background-color:transparent;text-align:center;}.css-1pny6db{display:inline-block;font-size:18px;font-weight:normal;margin:0 auto 20px;border-bottom:2px solid #3879c0;-webkit-text-decoration:none;text-decoration:none;color:#000;}.css-1pny6db:hover{-webkit-text-decoration:none;text-decoration:none;}.css-2vi8uw{list-style:none;padding-left:0;display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;-webkit-flex-wrap:wrap;-ms-flex-wrap:wrap;flex-wrap:wrap;-webkit-box-pack:justify;-webkit-justify-content:space-between;-ms-flex-pack:justify;justify-content:space-between;}.css-2vi8uw > li{-webkit-flex-basis:24%;-ms-flex-preferred-size:24%;flex-basis:24%;}@media only screen and (max-width:768px){.css-2vi8uw > li{-webkit-flex-basis:49%;-ms-flex-preferred-size:49%;flex-basis:49%;}}.css-105pq9n{text-align:center;min-height:130px;margin-bottom:6px;}.css-105pq9n:last-child{margin-right:0;}.css-u1tqvs{-webkit-text-decoration:none;text-decoration:none;color:#444444;}.css-8atqhb{width:100%;}.css-1fyr8sh{font-size:12px;padding-top:10px;}@media only screen and (max-width:769px){.css-1fyr8sh{font-size:16px;}}.css-19a7eo8{margin-left:30px;display:inline-block;position:relative;min-height:1px;padding:0 15px;width:300px;-webkit-flex:0 0 300px;-ms-flex:0 0 300px;flex:0 0 300px;}@media (max-width:768px){.css-19a7eo8{margin-left:0;display:block;width:auto;}}.css-pb859s{min-height:250px;padding:20px 0;text-align:center;}.css-1rn3crn{background-color:#444;height:148px;}@media only screen and (max-width:769px){.css-1rn3crn{height:282px;}}.css-1tj1foj{width:70%;margin:0 auto;color:#bbb;font-weight:100;font-family:\\'Helvetica\\';font-size:14px;line-height:40px;}@media only screen and (max-width:769px){.css-1tj1foj{width:100%;line-height:30px;text-align:center;}}.css-a50h34{line-height:normal;padding-bottom:22px;}.css-19sw9w4{margin:0;list-style:none;padding-top:20px;padding-left:0px;display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;-webkit-flex-flow:row wrap;-ms-flex-flow:row wrap;flex-flow:row wrap;-webkit-text-decoration:none;text-decoration:none;position:relative;text-align:left;}@media only screen and (max-width:769px){.css-19sw9w4{padding-left:18px;}}.css-1r0i7sq{padding-right:16px;color:#999999;}@media only screen and (min-width:769px){.css-1r0i7sq{float:left;}}.css-603c4d{float:left;padding-right:6px;}@media only screen and (max-width:769px){.css-603c4d{float:right;padding-right:18px;margin-bottom:8px;-webkit-column-fill:balance;column-fill:balance;}}.css-1xa4729{color:#cccccc;-webkit-text-decoration:none;text-decoration:none;}.css-13gnrtg{float:left;padding-right:16px;}@media only screen and (max-width:769px){.css-13gnrtg{float:right;padding-right:18px;margin-bottom:8px;-webkit-column-fill:balance;column-fill:balance;}}.css-13h1p65{display:inline;margin:0;padding:0px;}@media only screen and (min-width:769px){.css-13h1p65{float:right;}}.css-13s85fp{display:inline;position:relative;}.css-16ob2z7{color:#bbb;-webkit-text-decoration:none;text-decoration:none;padding-left:35px;}.css-16ob2z7:hover{color:#fff;-webkit-text-decoration:underline;text-decoration:underline;}@media only screen and (max-width:769px){.css-16ob2z7{padding:5px;display:inline-block;text-align:center;}}.css-k008qs{display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;}.css-1748arg{padding-top:12px;margin-bottom:24px;}.css-1748arg .luna-def-number{font-weight:bold;}.css-1748arg .italic{font-style:italic;}.css-1748arg .luna-pronset .luna-pos{font-style:italic;}.css-1748arg .luna-wud,.css-1748arg .small-caps{font-variant:small-caps;}.css-urzbm0{font-weight:normal;word-break:break-word;display:inline-block;font-size:49px;margin:0 15px 10px 0;line-height:1.7;}@media (max-width:768px){.css-urzbm0{font-size:36px;margin:0 10px 10px 0;}}.css-17dkd7s{border:none;position:relative;top:-10px;font-family:dictionary-fonticon;font-size:25px;color:#3c7bbe;-webkit-text-decoration:none;text-decoration:none;cursor:pointer;}.css-17dkd7s::before{content:\\'\\\\e803\\';}@media (max-width:768px){.css-17dkd7s{top:-2px;}}.css-1khtv86{font-size:20px;color:#c0b5b5;}.css-1khtv86 .bold{font-weight:bold;}.css-1khtv86 .luna-pos{font-style:italic;}@media (max-width:768px){.css-1khtv86{font-size:18px;}}.css-1khtv86::after{content:\\'\\\\0a0\\';}.css-1g5b64m{padding:16px 0;}.css-1fvpz4m{margin-right:32px;outline:none;border:none;padding:0 !important;cursor:pointer;color:#3c7bbe;font-size:15px;background-color:transparent;-webkit-text-decoration:none;text-decoration:none;}.css-1fvpz4m:hover{-webkit-text-decoration:underline;text-decoration:underline;}.css-mtqscf{color:#fcbb45;position:relative;bottom:5px;font-size:15px;-webkit-text-decoration:none;text-decoration:none;}.css-1msjh1x{font-style:italic;}.css-2h6jwx{position:relative;height:auto;padding-bottom:0px;margin-bottom:0px;-webkit-transition:all 0.1s ease;transition:all 0.1s ease;}.css-8lgfcg{height:100%;overflow:hidden;}.css-1sdcacc{margin-bottom:24px;margin-top:24px;}.css-1y60q53{line-height:18px;margin-bottom:11px;}@media (max-width:768px){.css-1y60q53{margin-bottom:2px;}}.css-1pomevn{font-size:20px;font-weight:normal;}.css-zw8qdz{font-size:15px;text-align:left;padding-left:20px;}.css-zw8qdz .superscript{padding-left:2px;font-size:12px;vertical-align:super;}.css-2oywg7{margin-left:12px;margin-bottom:4px;padding-left:8px;}.css-9sn2pa{font-size:15px;line-height:24px;}.css-9sn2pa .luna-example.italic{font-style:italic;color:#c0b5b5;display:block;}.css-9sn2pa .italic{font-style:italic;}.css-9sn2pa .bold{font-weight:bold;}.css-9sn2pa .luna-nickname{font-style:italic;}.css-9sn2pa .luna-nickname::before{content:\\'\"(\\';}.css-9sn2pa .luna-nickname::after{content:\\')\"\\';}.css-9sn2pa .luna-aka{font-style:italic;}.css-9sn2pa .luna-aka::before{content:\\'(\\';}.css-9sn2pa .luna-aka::after{content:\\')\\';}.css-9sn2pa .audio-player{font-family:dictionary-fonticon;font-size:12px;color:#3c7bbe;cursor:pointer;padding:1px;}.css-9sn2pa .audio-player::before{content:\\'\\\\e803\\';}.css-1lfse6c{margin-left:-20px;}.css-hh4f95{margin:20px 0;padding:15px 0;border-top:solid 0.5px #d9d9d9;border-bottom:solid 0.5px #d9d9d9;}.css-grsm00{display:none;position:absolute;bottom:0px;height:100px;background:linear-gradient(rgba(255,255,255,0),white);width:100%;text-align:center;color:white;}.css-6d2nf9{position:relative;outline:none;display:inline-block;top:65px;cursor:pointer;text-align:center;font-weight:bold;font-size:12px;border-radius:2px;padding:8px 32px;border:solid 2px #e6e6e7;background:#ffffff;color:#797979;}.css-54ces9{margin:24px 0 24px 0;}.css-j3k4qp{display:inline-block;line-height:22px;padding-top:12px;font-weight:400;font-size:20px;}.css-1fxfie5{font-size:22px;}@media (max-width:768px){.css-1fxfie5{font-size:18px;margin:0 10px 10px 0;word-break:break-all;word-wrap:break-word;-webkit-hyphens:auto;-moz-hyphens:auto;-ms-hyphens:auto;hyphens:auto;line-height:22px;}}.css-1jci32p{font-size:15px;line-height:28px;margin-bottom:24px;}.css-1jci32p .bold{font-weight:bold;}.css-1jci32p .italic{font-style:italic;}@media (max-width:768px){.css-1jci32p{font-size:15px;}}.css-115kt4v{display:block;font-size:20px;line-height:22px;margin-bottom:12px;}.css-uzg0jd{display:block;font-size:15px;line-height:22px;padding-left:40px;}.css-uzg0jd .bold{font-weight:bold;}@media (max-width:768px){.css-uzg0jd{padding-left:0px;}}.css-1yphgw4{font-size:12px;color:#878787;padding-bottom:35px;line-height:20px;white-space:pre-line;}.css-1an5ojz{padding-bottom:17px;}.css-1wj1ajw{line-height:22px;padding-top:12px;font-weight:400;font-size:20px;}.css-ntz2ga{padding-top:0;display:inline;}.css-16b2ug3{margin:15px 0;}.css-l7r0w2{font-size:20px;font-weight:400;}.css-12sy04c{font-size:18px;line-height:22px;font-weight:400;}.css-o9b79t{list-style:none;}.css-d2znx6{margin-bottom:25px;}.css-it69we{font-size:15px;line-height:22px;font-weight:400;margin:0 0 4px 0;}.css-it69we .italic{font-style:italic;}.css-13aw141{margin-top:6px;width:38px;-webkit-align-self:baseline;-ms-flex-item-align:baseline;align-self:baseline;padding:0 15px 0 0;}.css-1ugobpn{margin:auto;font-size:12px;line-height:20px;}.css-zuqhy{padding:24px 0;color:#666666;font-size:20px;}.css-1nakkwx{margin-bottom:24px;}.css-1nakkwx .italic{font-style:italic;}.css-1nakkwx .bold,.css-1nakkwx .label{font-weight:bold;}.css-i3pbo{margin-bottom:24px;}.css-k59p8l{font-size:15px;line-height:22px;box-sizing:border-box;margin:0 0 17px;}.css-k59p8l .italic{font-style:italic;}.css-utybho{font-size:15px;font-weight:400;margin-bottom:0;}.css-mgww5h{margin:0 0 10px;}.css-1h3udqp{list-style:none;padding-left:0;display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;-webkit-flex-wrap:wrap;-ms-flex-wrap:wrap;flex-wrap:wrap;-webkit-box-pack:justify;-webkit-justify-content:space-between;-ms-flex-pack:justify;justify-content:space-between;}.css-1h3udqp > li{-webkit-flex-basis:49%;-ms-flex-preferred-size:49%;flex-basis:49%;}@media only screen and (max-width:768px){.css-1h3udqp > li{-webkit-flex-basis:49%;-ms-flex-preferred-size:49%;flex-basis:49%;}}.css-1q7njkh{margin-top:10px;}.css-1675y43{padding-bottom:14px;margin:0;font-size:20px;color:#666666;font-weight:normal;}.css-1dqz0ff{border:none;position:relative;margin-right:8px;top:2px;font-family:dictionary-fonticon;font-size:20px;line-height:21px;color:#a19f9c;-webkit-text-decoration:none;text-decoration:none;}.css-1dqz0ff::before{content:\\'\\\\e906\\';}.css-5w0xmi{font-weight:normal;display:inline-block;font-size:36px;margin:0 12px 10px 0;line-height:46px;}.css-gb8pey{-webkit-text-decoration:none;text-decoration:none;}.css-gb8pey:hover{-webkit-text-decoration:none;text-decoration:none;}.css-1upilqn{margin-bottom:12px;}.css-1ok7jrf{list-style:none;padding-left:0;display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;-webkit-flex-wrap:wrap;-ms-flex-wrap:wrap;flex-wrap:wrap;-webkit-box-pack:justify;-webkit-justify-content:space-between;-ms-flex-pack:justify;justify-content:space-between;}.css-1ok7jrf > li{-webkit-flex-basis:100%;-ms-flex-preferred-size:100%;flex-basis:100%;}@media only screen and (max-width:768px){.css-1ok7jrf > li{-webkit-flex-basis:100%;-ms-flex-preferred-size:100%;flex-basis:100%;}}.css-b8kzem{padding-top:12px;}.css-8c7dcs{line-height:24px;font-size:20px;color:#666666;padding-bottom:20px;margin:0;font-weight:normal;}.css-7w6khc{padding-top:20px;}.css-1oucjfz{list-style-type:none;line-height:22px;}.css-139mknr{line-height:31px;padding:6px 0;font-size:22px;}</style>\\n      </head>\\n      <body class=\"init\">\\n        <!-- Google Analytics GTM iframe starts here -->\\n        \\n      <noscript>\\n        <iframe\\n          src=\"https://www.googletagmanager.com/ns.html?id=GTM-TXC5GP\"\\n          height=\"0\"\\n          width=\"0\"\\n          style=\"display:none;visibility:hidden\"\\n        ></iframe>\\n      </noscript>\\n    \\n        <!-- Google Analytics GTM iframe ends here -->\\n        <div id=\"root\"><div data-reactroot=\"\"><div class=\"app-base css-yshiao e1fub8bm0\"><div id=\"base-pw\" class=\"css-1qktsnw e1fub8bm2\"><div class=\"css-ywz12x e11ozc52\"><header><nav aria-label=\"Site Navigation\"><div class=\"css-14qcrqt e1nknobk0\"><div class=\"css-rjglq e1mpvuks0\"><div class=\"hamburger-overlay css-cqn0r7 e1mpvuks1\"></div><nav aria-label=\"Hamburger Menu\" class=\"css-151frnk e1mpvuks3\"><ul class=\"css-7wf88h e1mpvuks5\"><li class=\"css-badxzn e1mpvuks4\"><a id=\"hamburgerMenuDictionarycom\" href=\"https://www.dictionary.com\" data-linkid=\"lxabec\" class=\"css-78n1nc e1mpvuks2\">Dictionary.com</a><ul class=\"css-1kmzn5i e1mpvuks6\"><li><a id=\"hamburgerMenuWotd\" href=\"https://www.dictionary.com/wordoftheday/\" data-linkid=\"1498ik\" class=\"css-78n1nc e1mpvuks2\">Word of the Day</a></li><li><a id=\"hamburgerMenuGames\" href=\"https://www.dictionary.com/fun/crosswordsolver\" data-linkid=\"636f6c\" class=\"css-78n1nc e1mpvuks2\">Crossword Solver</a></li><li><a id=\"hamburgerMenuBlog\" href=\"https://www.dictionary.com/e/\" data-linkid=\"t6ehki\" class=\"css-78n1nc e1mpvuks2\">Everything After Z</a></li></ul></li><li class=\"css-badxzn e1mpvuks4\"><a id=\"hamburgerMenuThesauruscom\" href=\"https://www.thesaurus.com\" data-linkid=\"c1drjk\" class=\"css-78n1nc e1mpvuks2\">Thesaurus.com</a></li></ul></nav><button aria-label=\"Toggle Menu\" id=\"hamburgerButton-click\" class=\"css-1tpwzaq e1mpvuks7\"></button></div><ul class=\"css-1w5d7r9 e1nknobk1\"><li class=\"css-1fe7abr ejn7swr1\"><a href=\"https://www.Dictionary.com\" id=\"\" data-linkid=\"tqks0v\" role=\"link\" class=\"css-akr928 ejn7swr0\">Dictionary.com</a></li><li class=\"css-1yyv0n6 ejn7swr2\"><a href=\"https://www.Thesaurus.com\" id=\"\" data-linkid=\"qxnxzj\" class=\"css-1npfjc8 ejn7swr0\">Thesaurus.com</a></li></ul><a href=\"https://www.dictionary.com/e/apps/\" font-family=\"dictionary-fonticon\" data-linkid=\"dbvvdc\" class=\"css-zd7l5y ebzzift0\"><span class=\"css-jna48b ebzzift1\"></span><span class=\"css-sv8lr1 ebzzift2\"></span>Try Our Apps</a></div></nav><div class=\"css-omrpao e1nfx3j01\"><div class=\"css-15nai5i e1nfx3j02\"><a href=\"https://www.dictionary.com\" data-linkid=\"yg487x\"><img src=\"https://www.dictionary.com/assets/dictionary_logo_white-90c1e2eaf84c6abcb80d08d6eb0b6c60.svg\" alt=\"Dictionary.com\" class=\"css-wwrygl e1nfx3j00\"/></a><div class=\"css-1uhxkf6 e18h4a051\"><form action=\"#\" class=\"css-1baulvz e18h4a053\"><div class=\"css-qwsmke ev3lshj0\"><span class=\"css-omgbl e2cjyp00\"></span><span class=\"css-1ynlh0h ev3lshj1\">definitions</span></div><label for=\"q\" class=\"css-1dv1kvn e1t7bu8t0\">Search</label><input type=\"search\" title=\"Search\" autoComplete=\"off\" autoCapitalize=\"off\" autoCorrect=\"off\" name=\"override_query\" class=\"search-input css-ji58t3 e18h4a054\" id=\"searchbar_input\" value=\"biology\"/><button aria-label=\"Search\" type=\"submit\" id=\"search-submit\" class=\"css-rv4ucl e18h4a052\"></button><ul style=\"max-height:0\" class=\"css-1jzsm78 ep2tsc50\"><li class=\"css-afnsia e18h4a050\"><a data-linkid=\"205vpa\" class=\"css-iry8e ebjrtl60\">synonyms</a></li></ul></form></div></div></div></header><div color=\"#9dbde1\" id=\"initial-load-header-loader\" class=\"css-k2b2qh e11ozc51\"></div></div><div class=\"css-13o7eu2 e11ozc50\"><div id=\"initial-load-content\"><main class=\"css-d5e8ah e1fub8bm3\"><aside class=\"no-collapse css-o2gk28 eanayw60\" id=\"dcom-serp-lb-728x90\"><script>if (window.googletag) {googletag.cmd.push(function() { googletag.display(\\'dcom-serp-lb-728x90\\'); });} else {console.error(\\'googletag not defined, dcom-serp-lb-728x90\\');}</script></aside><section class=\"css-dfjnxh e8xvxkb0\"><section class=\"css-0 e1hj943x0\"><section class=\"css-1748arg e1wu7xq20\"><section class=\"css-0 e1rg2mtf0\"><h1 class=\"css-urzbm0 e1rg2mtf5\">biology</h1><span class=\"audio-wrapper\"><span data-ci-target=\"audio\" class=\"css-17dkd7s e1rg2mtf4\"></span><audio><source src=\"https://static.sfdict.com/audio/lunawav/B03/B0350200.ogg\" type=\"audio/ogg\"/><source src=\"https://static.sfdict.com/audio/B03/B0350200.mp3\" type=\"audio/mpeg\"/></audio></span><div><span class=\"css-1khtv86 e1rg2mtf2\">[bahy-<span class=\"bold\">ol</span>-<span class=\"italic\">uh</span>-jee]</span></div></section><div class=\"css-1g5b64m e4wg2xj0\"><button class=\"hotlinks-button css-1fvpz4m e4wg2xj1\" data-ci-target=\"examples\">Examples</button><button class=\"hotlinks-button css-1fvpz4m e4wg2xj1\" data-ci-target=\"wordOrigin\">Word Origin</button></div><a href=\"https://www.thesaurus.com/browse/biology\" target=\"_blank\" data-linkid=\"oowy0r\" class=\"css-mtqscf e16svm7n1\">See more synonyms for <span class=\"css-1msjh1x e16svm7n2\">biology</span> on Thesaurus.com</a><div class=\"expand-container css-2h6jwx e1iplpfw0\"><div class=\"css-8lgfcg e1iplpfw1\"><section class=\"css-1sdcacc e10vl5dg0\"><header class=\"css-1y60q53 e10vl5dg1\"><span class=\"css-1pomevn e10vl5dg2\"><span class=\"luna-pos\">noun</span></span></header><ol class=\"css-zw8qdz e10vl5dg3\"><li value=\"1\" class=\"css-2oywg7 e10vl5dg5\"><span class=\"one-click-content css-9sn2pa e10vl5dg6\">the science of life or living matter in all its forms and phenomena, especially with reference to origin, growth, reproduction, structure, and behavior.</span></li><li value=\"2\" class=\"css-2oywg7 e10vl5dg5\"><span class=\"one-click-content css-9sn2pa e10vl5dg6\">the living organisms of a region: <span class=\"luna-example italic\">the biology of Pennsylvania.</span></span></li><li value=\"3\" class=\"css-2oywg7 e10vl5dg5\"><span class=\"one-click-content css-9sn2pa e10vl5dg6\">the <a href=\"https://dictionary.com/browse/biological\" class=\"luna-xref\" data-linkid=\"nn1ov4\">biological</a> phenomena characteristic of an organism or a group of organisms: <span class=\"luna-example italic\">She is studying the biology of worms, especially in regard to their reproductive behavior.</span></span></li><div class=\"css-1lfse6c e10vl5dg9\"><section class=\"no-collapse css-hh4f95 e1eb38er0\"><aside class=\"css-6xt45o e1bbcgok0\"><a href=\"https://www.dictionary.com/e/\" data-linkid=\"2azoy5\" class=\"css-1pny6db e1bbcgok2\">Explore Dictionary.com</a><ul class=\"css-2vi8uw e1bbcgok1\"><li class=\"css-105pq9n e1ifcv6o0\"><a href=\"http://www.dictionary.com/e/s/10-weather-words-you-need-to-know/?param=DcomSERP-mid1\" data-linkid=\"b00rn2\" class=\"css-u1tqvs e1ifcv6o1\"><img src=\"//images.ctfassets.net/55tpbg0qcsp4/4Dv5jfCu1G0oA0K2mw62Ci/f990173542acb54b8af9156f20b3f959/weather_words_1000x700.jpg?w=284&amp;h=240\" alt=\"Weather Words You Need to Know\" class=\"css-8atqhb e1ifcv6o3\"/><span class=\"css-1fyr8sh e1ifcv6o2\">Weather Words You Need to Know</span></a></li><li class=\"css-105pq9n e1ifcv6o0\"><a href=\"https://www.dictionary.com/e/video/why-we-love-adding-emoji-to-dictionary/?param=DcomSERP-mid2\" data-linkid=\"ytn3fh\" class=\"css-u1tqvs e1ifcv6o1\"><img src=\"//images.ctfassets.net/55tpbg0qcsp4/4lkNvdcEb62AYAC0y6CQc4/27ccf91ff202a53f227d559dd54778aa/emoji_quotes3.jpg?w=284&amp;h=240\" alt=\"Can You Translate These Famous Phrases From Emoji?\" class=\"css-8atqhb e1ifcv6o3\"/><span class=\"css-1fyr8sh e1ifcv6o2\">Can You Translate These Famous Phrases From Emoji?</span></a></li><li class=\"css-105pq9n e1ifcv6o0\"><a href=\"http://www.dictionary.com/e/s/longest-english-words/?param=DcomSERP-mid3\" data-linkid=\"gdjn7o\" class=\"css-u1tqvs e1ifcv6o1\"><img src=\"//images.ctfassets.net/55tpbg0qcsp4/6Urum7wOdiGMGGQYeiaG6q/cf107f2f179af738b37e42ba83235c72/long_words3.jpg?w=284&amp;h=240\" alt=\"These Are the Longest Words in English\" class=\"css-8atqhb e1ifcv6o3\"/><span class=\"css-1fyr8sh e1ifcv6o2\">These Are the Longest Words in English</span></a></li><li class=\"css-105pq9n e1ifcv6o0\"><a href=\"https://www.dictionary.com/e/s/sad-words/?param=DcomSERP-mid4\" data-linkid=\"mxi818\" class=\"css-u1tqvs e1ifcv6o1\"><img src=\"//images.ctfassets.net/55tpbg0qcsp4/5ln7xDTo6QYiSaEisGcwcU/1b755ef15200d8ca49c9b1813a496dc8/saddest_words_1000x700.jpg?w=284&amp;h=240\" alt=\"These Are the Saddest Phrases in English\" class=\"css-8atqhb e1ifcv6o3\"/><span class=\"css-1fyr8sh e1ifcv6o2\">These Are the Saddest Phrases in English</span></a></li></ul></aside></section></div></ol></section></div><div class=\"expand-button-container css-grsm00 e1iplpfw2\"><button class=\"expand-button css-6d2nf9 e1iplpfw3\">Show More</button></div></div><section class=\"css-54ces9 e16svm7n0\"><h2 id=\"wordOrigin\" class=\"css-j3k4qp e1cxe2lc0\">Origin of <span class=\"css-1fxfie5 e1vvcl3c0\">biology</span></h2><div class=\"one-click-content css-1jci32p e1iz2gwk0\">From the <span class=\"luna-langn\">German</span> word <span class=\"italic\">Biologie,</span> dating back to <span class=\"luna-date\">1805\\xe2\\x80\\x9315.</span> See <a href=\"https://dictionary.com/browse/bio-\" class=\"luna-xref\" data-linkid=\"nn1ov4\">bio-</a>, <a href=\"https://dictionary.com/browse/-logy\" class=\"luna-xref\" data-linkid=\"nn1ov4\">-logy</a></div></section></section><div class=\"css-1yphgw4 ejtq9h60\">Dictionary.com Unabridged\\nBased on the Random House Unabridged Dictionary, \\xc2\\xa9 Random House, Inc. 2018</div><hr class=\"css-11r0tj9 etjs7ll0\"/><div class=\"css-1an5ojz e15p0a5t0\"><h2 class=\"css-1wj1ajw e1cxe2lc2\">Related Words for <!-- -->biology</h2><a href=\"/browse/ecology\" target=\"_blank\" data-linkid=\"ugrcqa\" class=\"css-ntz2ga e15p0a5t1\">ecology</a>, <a href=\"/browse/anthropology\" target=\"_blank\" data-linkid=\"ugrcqa\" class=\"css-ntz2ga e15p0a5t1\">anthropology</a>, <a href=\"/browse/medicine\" target=\"_blank\" data-linkid=\"ugrcqa\" class=\"css-ntz2ga e15p0a5t1\">medicine</a>, <a href=\"/browse/biology\" target=\"_blank\" data-linkid=\"ugrcqa\" class=\"css-ntz2ga e15p0a5t1\">biology</a>, <a href=\"/browse/zoology\" target=\"_blank\" data-linkid=\"ugrcqa\" class=\"css-ntz2ga e15p0a5t1\">zoology</a>, <a href=\"/browse/physics\" target=\"_blank\" data-linkid=\"ugrcqa\" class=\"css-ntz2ga e15p0a5t1\">physics</a>, <a href=\"/browse/division\" target=\"_blank\" data-linkid=\"ugrcqa\" class=\"css-ntz2ga e15p0a5t1\">division</a>, <a href=\"/browse/dissection\" target=\"_blank\" data-linkid=\"ugrcqa\" class=\"css-ntz2ga e15p0a5t1\">dissection</a>, <a href=\"/browse/analysis\" target=\"_blank\" data-linkid=\"ugrcqa\" class=\"css-ntz2ga e15p0a5t1\">analysis</a>, <a href=\"/browse/investigation\" target=\"_blank\" data-linkid=\"ugrcqa\" class=\"css-ntz2ga e15p0a5t1\">investigation</a>, <a href=\"/browse/examination\" target=\"_blank\" data-linkid=\"ugrcqa\" class=\"css-ntz2ga e15p0a5t1\">examination</a>, <a href=\"/browse/diagnosis\" target=\"_blank\" data-linkid=\"ugrcqa\" class=\"css-ntz2ga e15p0a5t1\">diagnosis</a>, <a href=\"/browse/inquiry\" target=\"_blank\" data-linkid=\"ugrcqa\" class=\"css-ntz2ga e15p0a5t1\">inquiry</a>, <a href=\"/browse/cytology\" target=\"_blank\" data-linkid=\"ugrcqa\" class=\"css-ntz2ga e15p0a5t1\">cytology</a>, <a href=\"/browse/genetics\" target=\"_blank\" data-linkid=\"ugrcqa\" class=\"css-ntz2ga e15p0a5t1\">genetics</a>, <a href=\"/browse/etiology\" target=\"_blank\" data-linkid=\"ugrcqa\" class=\"css-ntz2ga e15p0a5t1\">etiology</a>, <a href=\"/browse/histology\" target=\"_blank\" data-linkid=\"ugrcqa\" class=\"css-ntz2ga e15p0a5t1\">histology</a>, <a href=\"/browse/morphology\" target=\"_blank\" data-linkid=\"ugrcqa\" class=\"css-ntz2ga e15p0a5t1\">morphology</a>, <a href=\"/browse/embryology\" target=\"_blank\" data-linkid=\"ugrcqa\" class=\"css-ntz2ga e15p0a5t1\">embryology</a>, <a href=\"/browse/physiology\" target=\"_blank\" data-linkid=\"ugrcqa\" class=\"css-ntz2ga e15p0a5t1\">physiology</a></div><hr class=\"css-11r0tj9 etjs7ll0\"/><section class=\"css-16b2ug3 e15kc6du0\"><h2 id=\"examples\" class=\"css-l7r0w2 e15kc6du3\">Examples from the Web for <!-- -->biology</h2><div data-linkid=\"fboxke\"><h3 class=\"css-12sy04c e15kc6du6\">Contemporary Examples<!-- --> of <!-- -->biology</h3><ul class=\"css-o9b79t e15kc6du4\"><li class=\"css-d2znx6 e15kc6du5\"><p class=\"one-click-content css-it69we e15kc6du7\">Complementarity as conservative Catholics use the term, however, is more than <span class=\"italic\">biology</span>.</p><div class=\"css-k008qs e15kc6du2\"><a href=\"https://thedailybeast.com/?source=dictionary\" rel=\"nofollow\"><img src=\"https://www.dictionary.com/assets/daily_beast_logo-5826abbaebfe092758106390ace3d904.png\" alt=\"The Daily Beast logo\" class=\"css-13aw141 e15kc6du8\"/></a><div><a href=\"http://www.thedailybeast.com/articles/2014/11/19/the-vatican-s-stealth-anti-gay-conference.html?source=dictionary\" rel=\"nofollow\" class=\"css-1ugobpn e15kc6du1\">Is Pope Francis Backpedaling on Gays?</a><p class=\"css-1ugobpn e15kc6du9\">Jay Michaelson</p><p class=\"css-1ugobpn e15kc6du10\">November 19, 2014</p></div></div></li><li class=\"css-d2znx6 e15kc6du5\"><p class=\"one-click-content css-it69we e15kc6du7\">\\xe2\\x80\\x9cIn the long term, I am more worried about <span class=\"italic\">biology</span>,\\xe2\\x80\\x9d he told The Telegraph.</p><div class=\"css-k008qs e15kc6du2\"><a href=\"https://thedailybeast.com/?source=dictionary\" rel=\"nofollow\"><img src=\"https://www.dictionary.com/assets/daily_beast_logo-5826abbaebfe092758106390ace3d904.png\" alt=\"The Daily Beast logo\" class=\"css-13aw141 e15kc6du8\"/></a><div><a href=\"http://www.thedailybeast.com/articles/2014/11/06/the-other-side-of-stephen-hawking-strippers-aliens-and-disturbing-abuse-claims.html?source=dictionary\" rel=\"nofollow\" class=\"css-1ugobpn e15kc6du1\">The Other Side of Stephen Hawking: Strippers, Aliens, and Disturbing Abuse Claims</a><p class=\"css-1ugobpn e15kc6du9\">Marlow Stern</p><p class=\"css-1ugobpn e15kc6du10\">November 6, 2014</p></div></div></li><li class=\"css-d2znx6 e15kc6du5\"><p class=\"one-click-content css-it69we e15kc6du7\">People are starting to recognize that depression must relate to <span class=\"italic\">biology</span>, because who would give up such an outwardly gifted life?</p><div class=\"css-k008qs e15kc6du2\"><a href=\"https://thedailybeast.com/?source=dictionary\" rel=\"nofollow\"><img src=\"https://www.dictionary.com/assets/daily_beast_logo-5826abbaebfe092758106390ace3d904.png\" alt=\"The Daily Beast logo\" class=\"css-13aw141 e15kc6du8\"/></a><div><a href=\"http://www.thedailybeast.com/articles/2014/08/20/we-re-talking-about-depression-all-wrong.html?source=dictionary\" rel=\"nofollow\" class=\"css-1ugobpn e15kc6du1\">We&#x27;re Talking About Depression All Wrong</a><p class=\"css-1ugobpn e15kc6du9\">Jean Kim</p><p class=\"css-1ugobpn e15kc6du10\">August 20, 2014</p></div></div></li><li class=\"css-d2znx6 e15kc6du5\"><p class=\"one-click-content css-it69we e15kc6du7\">Both are graduate students in <span class=\"italic\">biology</span> at the University of Notre Dame.</p><div class=\"css-k008qs e15kc6du2\"><a href=\"https://thedailybeast.com/?source=dictionary\" rel=\"nofollow\"><img src=\"https://www.dictionary.com/assets/daily_beast_logo-5826abbaebfe092758106390ace3d904.png\" alt=\"The Daily Beast logo\" class=\"css-13aw141 e15kc6du8\"/></a><div><a href=\"http://www.thedailybeast.com/articles/2014/08/03/the-daily-beast-s-best-longreads-aug-3-2014.html?source=dictionary\" rel=\"nofollow\" class=\"css-1ugobpn e15kc6du1\">The Daily Beast\\xe2\\x80\\x99s Best Longreads, Aug 3, 2014</a><p class=\"css-1ugobpn e15kc6du9\">The Daily Beast</p><p class=\"css-1ugobpn e15kc6du10\">August 3, 2014</p></div></div></li><li class=\"css-d2znx6 e15kc6du5\"><p class=\"one-click-content css-it69we e15kc6du7\">For example, to build flexible career and promotional tracks which do not conflict with <span class=\"italic\">biology</span>.</p><div class=\"css-k008qs e15kc6du2\"><a href=\"https://thedailybeast.com/?source=dictionary\" rel=\"nofollow\"><img src=\"https://www.dictionary.com/assets/daily_beast_logo-5826abbaebfe092758106390ace3d904.png\" alt=\"The Daily Beast logo\" class=\"css-13aw141 e15kc6du8\"/></a><div><a href=\"http://www.thedailybeast.com/articles/2014/07/19/whither-the-women-s-movement.html?source=dictionary\" rel=\"nofollow\" class=\"css-1ugobpn e15kc6du1\">Whither the Women\\xe2\\x80\\x99s Movement?</a><p class=\"css-1ugobpn e15kc6du9\">Judith Barnett</p><p class=\"css-1ugobpn e15kc6du10\">July 19, 2014</p></div></div></li></ul></div><div data-linkid=\"sl8bq9\"><h3 class=\"css-12sy04c e15kc6du6\">Historical Examples<!-- --> of <!-- -->biology</h3><ul class=\"css-o9b79t e15kc6du4\"><li class=\"css-d2znx6 e15kc6du5\"><p class=\"one-click-content css-it69we e15kc6du7\">They know everything about <span class=\"italic\">biology</span>, but almost nothing about life.</p><div class=\"css-k008qs e15kc6du2\"><div><a href=\"http://www.gutenberg.org/files/9656/9656-h/9656-h.htm\" rel=\"nofollow\" class=\"css-1ugobpn e15kc6du1\">Alarms and Discursions</a><p class=\"css-1ugobpn e15kc6du9\">G. K. Chesterton</p></div></div></li><li class=\"css-d2znx6 e15kc6du5\"><p class=\"one-click-content css-it69we e15kc6du7\">Why this should be so is one of the most profound problems of <span class=\"italic\">biology</span>.</p><div class=\"css-k008qs e15kc6du2\"><div><a href=\"http://www.gutenberg.org/files/29422/29422-h/29422-h.htm\" rel=\"nofollow\" class=\"css-1ugobpn e15kc6du1\">The Meaning of Evolution</a><p class=\"css-1ugobpn e15kc6du9\">Samuel Christian Schmucker</p></div></div></li><li class=\"css-d2znx6 e15kc6du5\"><p class=\"one-click-content css-it69we e15kc6du7\">His progress, and the progress of thousands of other researchers in <span class=\"italic\">biology</span>, must have been watched.</p><div class=\"css-k008qs e15kc6du2\"><div><a href=\"http://www.gutenberg.org/files/29487/29487-h/29487-h.htm\" rel=\"nofollow\" class=\"css-1ugobpn e15kc6du1\">Forever</a><p class=\"css-1ugobpn e15kc6du9\">Robert Sheckley</p></div></div></li><li class=\"css-d2znx6 e15kc6du5\"><p class=\"one-click-content css-it69we e15kc6du7\">What are the general adaptive contributions of <span class=\"italic\">biology</span> to human nature?</p><div class=\"css-k008qs e15kc6du2\"><div><a href=\"http://www.gutenberg.org/files/29604/29604-h/29604-h.htm\" rel=\"nofollow\" class=\"css-1ugobpn e15kc6du1\">College Teaching</a><p class=\"css-1ugobpn e15kc6du9\">Paul Klapper</p></div></div></li><li class=\"css-d2znx6 e15kc6du5\"><p class=\"one-click-content css-it69we e15kc6du7\">What are the results in the individual which <span class=\"italic\">biology</span> should aim to bring to every student?</p><div class=\"css-k008qs e15kc6du2\"><div><a href=\"http://www.gutenberg.org/files/29604/29604-h/29604-h.htm\" rel=\"nofollow\" class=\"css-1ugobpn e15kc6du1\">College Teaching</a><p class=\"css-1ugobpn e15kc6du9\">Paul Klapper</p></div></div></li></ul></div><hr class=\"css-11r0tj9 etjs7ll0\"/></section><section class=\"css-zuqhy e1013k4u0\">British Dictionary definitions for <!-- -->biology</section><section class=\"css-1nakkwx e1n8zibb0\"><section class=\"css-0 e1rg2mtf0\"><h2 class=\"css-urzbm0 e1rg2mtf5\">biology</h2><div></div></section><div class=\"expand-container css-2h6jwx e1iplpfw0\"><div class=\"css-8lgfcg e1iplpfw1\"><section class=\"css-1sdcacc e10vl5dg0\"><header class=\"css-1y60q53 e10vl5dg1\"><span class=\"css-1pomevn e10vl5dg2\"><span class=\"pos\">noun</span></span></header><ol class=\"css-zw8qdz e10vl5dg3\"><li value=\"1\" class=\"css-2oywg7 e10vl5dg5\"><span class=\"one-click-content css-9sn2pa e10vl5dg6\">the study of living organisms, including their structure, functioning, evolution, distribution, and interrelationships</span></li><li value=\"2\" class=\"css-2oywg7 e10vl5dg5\"><span class=\"one-click-content css-9sn2pa e10vl5dg6\">the structure, functioning, etc, of a particular organism or group of organisms</span></li><li value=\"3\" class=\"css-2oywg7 e10vl5dg5\"><span class=\"one-click-content css-9sn2pa e10vl5dg6\">the animal and plant life of a particular region</span></li></ol></section></div><div class=\"expand-button-container css-grsm00 e1iplpfw2\"><button class=\"expand-button css-6d2nf9 e1iplpfw3\">Show More</button></div></div><section class=\"css-54ces9 e16svm7n0\"><span class=\"css-115kt4v e614id60\">Derived Forms</span><span class=\"one-click-content css-uzg0jd e614id61\"><span class=\"headword bold\">biologist</span>, <span class=\"pos\">noun</span></span></section></section><div class=\"css-1yphgw4 ejtq9h60\">Collins English Dictionary - Complete &amp; Unabridged 2012 Digital Edition \\n\\xc2\\xa9 William Collins Sons &amp; Co. Ltd. 1979, 1986 \\xc2\\xa9 HarperCollins \\nPublishers 1998, 2000, 2003, 2005, 2006, 2007, 2009, 2012</div><hr class=\"css-11r0tj9 etjs7ll0\"/><section class=\"css-i3pbo e8i5ajd0\"><h2 class=\"css-1wj1ajw e1cxe2lc2\">Word Origin and History for<!-- --> <span class=\"css-1fxfie5 e1vvcl3c0\">biology</span></h2><section class=\"css-i3pbo e8i5ajd0\"><div><div class=\"expand-container css-2h6jwx e1iplpfw0\"><div class=\"css-8lgfcg e1iplpfw1\"><section class=\"css-k59p8l ehevz040\"><span class=\"css-utybho ehevz045\">n.</span><p class=\"one-click-content css-mgww5h ehevz041\">1819, from Greek <span class=\"italic\">bios</span> \"life\" (see <a href=\"https://dictionary.com/browse/bio-\" class=\"luna-xref\" data-linkid=\"nn1ov4\">bio-</a>) + <a href=\"https://dictionary.com/browse/-logy\" class=\"luna-xref\" data-linkid=\"nn1ov4\">-logy</a>. Suggested 1802 by German naturalist Gottfried Reinhold Treviranus (1776-1837), and introduced as a scientific term that year in French by Lamarck.</p></section></div><div class=\"expand-button-container css-grsm00 e1iplpfw2\"><button class=\"expand-button css-6d2nf9 e1iplpfw3\">Show More</button></div></div></div></section><div class=\"css-1yphgw4 ejtq9h60\">Online Etymology Dictionary, \\xc2\\xa9 2010 Douglas Harper</div><hr class=\"css-11r0tj9 etjs7ll0\"/></section><section class=\"css-i3pbo e8i5ajd0\"><section class=\"css-zuqhy e1013k4u0\">biology<!-- --> in Medicine</section><h2 class=\"css-urzbm0 e1rg2mtf5\">biology</h2><span class=\"css-1khtv86 e1rg2mtf2\">(b\\xc4\\xab-\\xc5\\x8fl<span class=\"rich-text bold\">\\xe2\\x80\\xb2</span>\\xc9\\x99-j\\xc4\\x93)</span><div class=\"expand-container css-2h6jwx e1iplpfw0\"><div class=\"css-8lgfcg e1iplpfw1\"><section class=\"css-1sdcacc e10vl5dg0\"><header class=\"css-1y60q53 e10vl5dg1\"><span class=\"css-1pomevn e10vl5dg2\"><span class=\"pos\">n.</span></span></header><ol class=\"css-zw8qdz e10vl5dg3\"><li class=\"css-2oywg7 e10vl5dg5\"><span class=\"one-click-content css-9sn2pa e10vl5dg6\"><span class=\"tx\">The science of life and of living organisms, including their structure, function, growth, origin, evolution, and distribution. It includes botany and zoology.</span></span></li><li class=\"css-2oywg7 e10vl5dg5\"><span class=\"one-click-content css-9sn2pa e10vl5dg6\"><span class=\"tx\">The life processes or characteristic phenomena of a group or category of living organisms.</span></span></li></ol></section></div><div class=\"expand-button-container css-grsm00 e1iplpfw2\"><button class=\"expand-button css-6d2nf9 e1iplpfw3\">Show More</button></div></div><section class=\"css-54ces9 e16svm7n0\"><span class=\"css-115kt4v e614id60\">Related forms</span><span class=\"one-click-content css-uzg0jd e614id61\"><span class=\"runon\">bi\\xe2\\x80\\xa2ol<span class=\"rich-text bold\">\\xe2\\x80\\xb2</span>o\\xe2\\x80\\xa2gist</span> <span class=\"pos\">n.</span></span></section><div class=\"css-1yphgw4 ejtq9h60\">The American Heritage\\xc2\\xae Stedman&#x27;s Medical Dictionary \\n Copyright \\xc2\\xa9 2002, 2001, 1995 by Houghton Mifflin Company. Published by Houghton Mifflin Company.</div><hr class=\"css-11r0tj9 etjs7ll0\"/></section><section class=\"css-i3pbo e8i5ajd0\"><section class=\"css-zuqhy e1013k4u0\">biology<!-- --> in Science</section><section><section class=\"css-0 e1rg2mtf0\"><h2 class=\"css-urzbm0 e1rg2mtf5\">biology</h2><span class=\"audio-wrapper\"><span data-ci-target=\"audio\" class=\"css-17dkd7s e1rg2mtf4\"></span><audio><source src=\"https://static.sfdict.com/content-assets/science/audio/ogg/B0265500.ogg\" type=\"audio/ogg\"/><source src=\"https://static.sfdict.com/content-assets/science/audio/mp3/B0265500.mp3\" type=\"audio/mpeg\"/><source src=\"https://static.sfdict.com/content-assets/science/audio/wav/B0265500.wav\" type=\"audio/wav\"/></audio></span><div><span class=\"css-1khtv86 e1rg2mtf2\">[b\\xc4\\xab-\\xc5\\x8fl<span class=\"rich-text bold\">\\xe2\\x80\\xb2</span>\\xc9\\x99-j\\xc4\\x93]</span></div></section><div class=\"expand-container css-2h6jwx e1iplpfw0\"><div class=\"css-8lgfcg e1iplpfw1\"><section class=\"css-1sdcacc e10vl5dg0\"><header class=\"css-1y60q53 e10vl5dg1\"><span class=\"css-1pomevn e10vl5dg2\"></span></header><ol class=\"css-zw8qdz e10vl5dg3\"><li class=\"css-2oywg7 e10vl5dg5\"><span class=\"one-click-content css-9sn2pa e10vl5dg6\"><span class=\"definition\"><span class=\"deftx\"><span class=\"tx\">The scientific study of life and of living organisms. Botany, zoology, and ecology are all branches of biology.</span></span></span></span></li></ol></section></div><div class=\"expand-button-container css-grsm00 e1iplpfw2\"><button class=\"expand-button css-6d2nf9 e1iplpfw3\">Show More</button></div></div></section><div class=\"css-1yphgw4 ejtq9h60\">The American Heritage\\xc2\\xae Science Dictionary \\n Copyright \\xc2\\xa9 2011. Published by Houghton Mifflin Harcourt Publishing Company. All rights reserved.</div><hr class=\"css-11r0tj9 etjs7ll0\"/></section><section class=\"css-i3pbo e8i5ajd0\"><section class=\"css-zuqhy e1013k4u0\">biology<!-- --> in Culture</section><section><section class=\"css-0 e1rg2mtf0\"><h2 class=\"css-urzbm0 e1rg2mtf5\">biology</h2><div></div></section><section class=\"css-i3pbo e8i5ajd0\"><div><div class=\"expand-container css-2h6jwx e1iplpfw0\"><div class=\"css-8lgfcg e1iplpfw1\"><section class=\"css-k59p8l ehevz040\"><p class=\"one-click-content css-mgww5h ehevz041\">The study of life and living systems.</p></section></div><div class=\"expand-button-container css-grsm00 e1iplpfw2\"><button class=\"expand-button css-6d2nf9 e1iplpfw3\">Show More</button></div></div></div></section></section><div class=\"css-1yphgw4 ejtq9h60\">The New Dictionary of Cultural Literacy, Third Edition \\nCopyright \\xc2\\xa9 2005 by Houghton Mifflin Harcourt Publishing Company. Published by Houghton Mifflin Harcourt Publishing Company. All rights reserved.</div></section></section><aside class=\"css-19a7eo8 e1su27ci0\"><aside class=\"css-6xt45o e1bbcgok0\"><a href=\"https://www.dictionary.com/e/\" data-linkid=\"lcs15a\" class=\"css-1pny6db e1bbcgok2\">Others Are Reading</a><ul class=\"css-1h3udqp e1bbcgok1\"><li class=\"css-105pq9n e1ifcv6o0\"><a href=\"https://www.dictionary.com/e/mistrust-vs-distrust/?param=DcomSERP-RR1\" data-linkid=\"m9a2e2\" class=\"css-u1tqvs e1ifcv6o1\"><img src=\"//images.ctfassets.net/55tpbg0qcsp4/5CGuTH7Jq8M6seWye2k6w2/38f7aa6e3edf2c39b460788c500d993e/this-or-that_v3_1000x700.jpg?w=284&amp;h=240\" alt=\"We&#x27;re about to solve one of the great mysteries of the English language. Are you ready?\" class=\"css-8atqhb e1ifcv6o3\"/><span class=\"css-1fyr8sh e1ifcv6o2\">We&#x27;re about to solve one of the great mysteries of the English language. Are you ready?</span></a></li><li class=\"css-105pq9n e1ifcv6o0\"><a href=\"https://www.dictionary.com/e/s/umwords/?param=DcomSERP-RR2\" data-linkid=\"r0eap9\" class=\"css-u1tqvs e1ifcv6o1\"><img src=\"//images.ctfassets.net/55tpbg0qcsp4/6XApkF1320sICSogS4ouUg/a63c431dfd27370261d90c1cf66a479d/Avoid_boy_1000x700.jpg?w=284&amp;h=240\" alt=\"Avoid these words. Seriously.\" class=\"css-8atqhb e1ifcv6o3\"/><span class=\"css-1fyr8sh e1ifcv6o2\">Avoid these words. Seriously.</span></a></li></ul></aside><aside class=\"no-collapse css-pb859s eanayw60\" id=\"dcom-serp-a-top-300x250\"><script>if (window.googletag) {googletag.cmd.push(function() { googletag.display(\\'dcom-serp-a-top-300x250\\'); });} else {console.error(\\'googletag not defined, dcom-serp-a-top-300x250\\');}</script></aside><aside class=\"css-1q7njkh e1ywvkmy0\"><h3 class=\"css-1675y43 e1ywvkmy4\"><span class=\"css-1dqz0ff e1ywvkmy1\"></span>Word of the Day</h3><div data-linkid=\"rpilnc\" class=\"css-5w0xmi e1ywvkmy2\"><a href=\"http://www.dictionary.com/wordoftheday/\" class=\"css-gb8pey e1ywvkmy3\">univocal</a></div><span class=\"audio-wrapper\"><span data-ci-target=\"audio\" class=\"css-17dkd7s e1rg2mtf4\"></span><audio><source src=\"https://static.sfdict.com/audio/U00/U0097800.mp3\"/></audio></span></aside><div class=\"css-1upilqn e1su27ci1\"><aside class=\"css-6xt45o e1bbcgok0\"><ul class=\"css-1ok7jrf e1bbcgok1\"><li class=\"css-105pq9n e1ifcv6o0\"><a href=\"https://www.dictionary.com/e/video/people-always-say-wrong/?param=dcomserp-rr3\" data-linkid=\"mw8sx6\" class=\"css-u1tqvs e1ifcv6o1\"><img src=\"//images.ctfassets.net/55tpbg0qcsp4/4vhlY8TonmwOiIe6yeuWyC/e9175e33d87495ec8734d4b669f29950/words-1000x700.jpg?w=284&amp;h=240\" alt=\"Words We Get Wrong: How Many of These Can You Say?\" class=\"css-8atqhb e1ifcv6o3\"/><span class=\"css-1fyr8sh e1ifcv6o2\">Words We Get Wrong: How Many of These Can You Say?</span></a></li></ul></aside></div><aside class=\"css-6xt45o e1bbcgok0\"><ul class=\"css-1ok7jrf e1bbcgok1\"><li class=\"css-105pq9n e1ifcv6o0\"><a href=\"http://www.dictionary.com/e/video/did-you-know-real-people-write-the-dictionary/?param=DcomSERP-RR4\" data-linkid=\"nfcsuc\" class=\"css-u1tqvs e1ifcv6o1\"><img src=\"//images.ctfassets.net/55tpbg0qcsp4/41Y5hDzl6MCwcaaAWoMMkK/624868c1965c24df5c81e0f0be3d9654/AskALexicographer_1000x700.jpg?w=284&amp;h=240\" alt=\"Did You Know Real People Write the Dictionary?\" class=\"css-8atqhb e1ifcv6o3\"/><span class=\"css-1fyr8sh e1ifcv6o2\">Did You Know Real People Write the Dictionary?</span></a></li></ul></aside><aside class=\"no-collapse css-pb859s eanayw60\" id=\"dcom-serp-a-mid-300x250\"><script>if (window.googletag) {googletag.cmd.push(function() { googletag.display(\\'dcom-serp-a-mid-300x250\\'); });} else {console.error(\\'googletag not defined, dcom-serp-a-mid-300x250\\');}</script></aside><div class=\"css-b8kzem e14wda90\"><h3 class=\"css-8c7dcs e14wda92\">Nearby words for <span class=\"css-1fxfie5 e1vvcl3c0\">biology</span></h3><hr class=\"css-11r0tj9 etjs7ll0\"/><ol data-linkid=\"lno2pu\" class=\"css-7w6khc e14wda94\"><li class=\"css-1oucjfz e14wda93\"><a href=\"/browse/biological-vector\">biological vector</a></li><li class=\"css-1oucjfz e14wda93\"><a href=\"/browse/b-w-\">biological warfare</a></li><li class=\"css-1oucjfz e14wda93\"><a href=\"/browse/biologics\">biologics</a></li><li class=\"css-1oucjfz e14wda93\"><a href=\"/browse/biologism\">biologism</a></li><li class=\"css-1oucjfz e14wda93\"><a href=\"/browse/biologist\">biologist</a></li><li class=\"css-1oucjfz e14wda93\"><div class=\"css-139mknr e14wda91\"><a href=\"/browse/biology\"><span class=\"css-1fxfie5 e1vvcl3c0\">biology</span></a></div></li><li class=\"css-1oucjfz e14wda93\"><a href=\"/browse/bioluminescence\">bioluminescence</a></li><li class=\"css-1oucjfz e14wda93\"><a href=\"/browse/bioluminescent\">bioluminescent</a></li><li class=\"css-1oucjfz e14wda93\"><a href=\"/browse/biolysis\">biolysis</a></li><li class=\"css-1oucjfz e14wda93\"><a href=\"/browse/biolytic\">biolytic</a></li><li class=\"css-1oucjfz e14wda93\"><a href=\"/browse/biomagnetism\">biomagnetism</a></li></ol></div></aside></section><aside class=\"no-collapse css-o2gk28 eanayw60\" id=\"dcom-serp-bottom-lb-728x90\"><script>if (window.googletag) {googletag.cmd.push(function() { googletag.display(\\'dcom-serp-bottom-lb-728x90\\'); });} else {console.error(\\'googletag not defined, dcom-serp-bottom-lb-728x90\\');}</script></aside></main></div></div></div><footer class=\"css-1rn3crn esk3ouk0\"><div class=\"css-1tj1foj esk3ouk1\"><div class=\"css-a50h34 esk3ouk5\"><ul class=\"css-19sw9w4 emmj7sa0\"><span class=\"css-1r0i7sq emmj7sa1\">Browse the <!-- -->Dictionary<!-- -->:</span><li class=\"css-603c4d emmj7sa2\"><a href=\"/list/0/1\" class=\"css-1xa4729 emmj7sa3\">#</a></li><li class=\"css-603c4d emmj7sa2\"><a href=\"/list/a/1\" class=\"css-1xa4729 emmj7sa3\">A</a></li><li class=\"css-603c4d emmj7sa2\"><a href=\"/list/b/1\" class=\"css-1xa4729 emmj7sa3\">B</a></li><li class=\"css-603c4d emmj7sa2\"><a href=\"/list/c/1\" class=\"css-1xa4729 emmj7sa3\">C</a></li><li class=\"css-603c4d emmj7sa2\"><a href=\"/list/d/1\" class=\"css-1xa4729 emmj7sa3\">D</a></li><li class=\"css-603c4d emmj7sa2\"><a href=\"/list/e/1\" class=\"css-1xa4729 emmj7sa3\">E</a></li><li class=\"css-603c4d emmj7sa2\"><a href=\"/list/f/1\" class=\"css-1xa4729 emmj7sa3\">F</a></li><li class=\"css-603c4d emmj7sa2\"><a href=\"/list/g/1\" class=\"css-1xa4729 emmj7sa3\">G</a></li><li class=\"css-603c4d emmj7sa2\"><a href=\"/list/h/1\" class=\"css-1xa4729 emmj7sa3\">H</a></li><li class=\"css-603c4d emmj7sa2\"><a href=\"/list/i/1\" class=\"css-1xa4729 emmj7sa3\">I</a></li><li class=\"css-603c4d emmj7sa2\"><a href=\"/list/j/1\" class=\"css-1xa4729 emmj7sa3\">J</a></li><li class=\"css-603c4d emmj7sa2\"><a href=\"/list/k/1\" class=\"css-1xa4729 emmj7sa3\">K</a></li><li class=\"css-603c4d emmj7sa2\"><a href=\"/list/l/1\" class=\"css-1xa4729 emmj7sa3\">L</a></li><li class=\"css-603c4d emmj7sa2\"><a href=\"/list/m/1\" class=\"css-1xa4729 emmj7sa3\">M</a></li><li class=\"css-603c4d emmj7sa2\"><a href=\"/list/n/1\" class=\"css-1xa4729 emmj7sa3\">N</a></li><li class=\"css-603c4d emmj7sa2\"><a href=\"/list/o/1\" class=\"css-1xa4729 emmj7sa3\">O</a></li><li class=\"css-603c4d emmj7sa2\"><a href=\"/list/p/1\" class=\"css-1xa4729 emmj7sa3\">P</a></li><li class=\"css-603c4d emmj7sa2\"><a href=\"/list/q/1\" class=\"css-1xa4729 emmj7sa3\">Q</a></li><li class=\"css-603c4d emmj7sa2\"><a href=\"/list/r/1\" class=\"css-1xa4729 emmj7sa3\">R</a></li><li class=\"css-603c4d emmj7sa2\"><a href=\"/list/s/1\" class=\"css-1xa4729 emmj7sa3\">S</a></li><li class=\"css-603c4d emmj7sa2\"><a href=\"/list/t/1\" class=\"css-1xa4729 emmj7sa3\">T</a></li><li class=\"css-603c4d emmj7sa2\"><a href=\"/list/u/1\" class=\"css-1xa4729 emmj7sa3\">U</a></li><li class=\"css-603c4d emmj7sa2\"><a href=\"/list/v/1\" class=\"css-1xa4729 emmj7sa3\">V</a></li><li class=\"css-603c4d emmj7sa2\"><a href=\"/list/w/1\" class=\"css-1xa4729 emmj7sa3\">W</a></li><li class=\"css-603c4d emmj7sa2\"><a href=\"/list/x/1\" class=\"css-1xa4729 emmj7sa3\">X</a></li><li class=\"css-603c4d emmj7sa2\"><a href=\"/list/y/1\" class=\"css-1xa4729 emmj7sa3\">Y</a></li><li class=\"css-603c4d emmj7sa2\"><a href=\"/list/z/1\" class=\"css-1xa4729 emmj7sa3\">Z</a></li></ul><ul class=\"css-19sw9w4 emmj7sa0\"><span class=\"css-1r0i7sq emmj7sa1\">Browse by Category:</span><li class=\"css-13gnrtg emmj7sa2\"><a href=\"https://www.dictionary.com/e/list/slang/1\" class=\"css-1xa4729 emmj7sa3\">Slang</a></li><li class=\"css-13gnrtg emmj7sa2\"><a href=\"https://www.dictionary.com/e/list/emoji/1\" class=\"css-1xa4729 emmj7sa3\">Emoji</a></li><li class=\"css-13gnrtg emmj7sa2\"><a href=\"https://www.dictionary.com/e/list/acronyms/1\" class=\"css-1xa4729 emmj7sa3\">Acronyms</a></li><li class=\"css-13gnrtg emmj7sa2\"><a href=\"https://www.dictionary.com/e/list/pop-culture/1\" class=\"css-1xa4729 emmj7sa3\">Pop Culture</a></li><li class=\"css-13gnrtg emmj7sa2\"><a href=\"https://www.dictionary.com/e/list/more/1\" class=\"css-1xa4729 emmj7sa3\">More</a></li></ul></div><ul class=\"css-13h1p65 esk3ouk2\"><li class=\"css-13s85fp esk3ouk3\"><a href=\"https://www.dictionary.com/e/about/\" data-linkid=\"gy27eg\" id=\"about-click\" class=\"css-16ob2z7 esk3ouk4\">About</a></li><li class=\"css-13s85fp esk3ouk3\"><a class=\"css-16ob2z7 esk3ouk4\">|</a></li><li class=\"css-13s85fp esk3ouk3\"><a href=\"https://www.dictionary.com/e/terms/\" data-linkid=\"gy27eg\" id=\"termAndPrivacy-click\" class=\"css-16ob2z7 esk3ouk4\">Cookies, Terms, &amp; Privacy</a></li></ul><div>\\xc2\\xa9 2018 Dictionary.com, LLC</div></div></footer></div></div></div>\\n        <script>window.ANALYTICS = {\"siteName\":\"dict\",\"trackURL\":\"https:\\\\u002F\\\\u002Ftrack.dictionary.com\\\\u002Fmain.gif\",\"thesaurusSpanIdUrl\":\"https:\\\\u002F\\\\u002Fspanids.thesaurus.com\\\\u002F\",\"ab\":\"0\",\"platform\":\"Desktop\"};</script>\\n        <script>window.ENV_VARS = {\"dev\":false,\"test\":false,\"prod\":true,\"noReact\":\"true\",\"SERVER_CONTENT_TIMEOUT_DESKTOP\":0,\"CLIENT_CONTENT_TIMEOUT_DESKTOP\":0,\"SERVER_CONTENT_TIMEOUT_MOBILE\":1000,\"CLIENT_CONTENT_TIMEOUT_MOBILE\":1000,\"CLIENT_TRANSITION_MASK_DESKTOP\":false,\"CLIENT_TRANSITION_MASK_MOBILE\":true,\"PROTOCOL\":\"https\",\"TRACKING_URL\":\"https:\\\\u002F\\\\u002Ftrack.dictionary.com\\\\u002Fmain.gif\",\"UPGRADE_INSECURE_REQUESTS\":true,\"THESAURUS_SPANID_URL\":\"https:\\\\u002F\\\\u002Fspanids.thesaurus.com\\\\u002F\",\"TEST_AD_TYPE_TOGGLE\":false,\"DCOM_URL\":\"www.dictionary.com\",\"TCOM_URL\":\"www.thesaurus.com\",\"ALLOW_DISABLED_ADS\":false,\"DCOM_CONTENT_API_ENDPOINT\":\"https:\\\\u002F\\\\u002Fapi-portal.dictionary.com\\\\u002Fdcom\\\\u002FpageData\",\"SPELL_SUGGESTIONS_API_ENDPOINT\":\"https:\\\\u002F\\\\u002Fapi-portal.dictionary.com\\\\u002FspellSuggestions\",\"EDITORIAL_API_ENDPOINT\":\"https:\\\\u002F\\\\u002Feditorial-content-feed.dictionary.com\\\\u002Fdcomserp\",\"WOTD_API_ENDPOINT\":\"https:\\\\u002F\\\\u002Frestcdn.dictionary.com\\\\u002Fv2\\\\u002Fwordoftheday.json?api_key=KgprXEYKVnNSFSZ\",\"EXAMPLE_SENTENCES_API_ENDPOINT\":\"https:\\\\u002F\\\\u002Fapi-portal.dictionary.com\\\\u002FexampleSentencesBySource\",\"NEARBY_WORDS_API_ENDPOINT\":\"https:\\\\u002F\\\\u002Fapi-portal.dictionary.com\\\\u002Fdcom\\\\u002FnearbyWords\",\"RELATED_WORDS_API_ENDPOINT\":\"https:\\\\u002F\\\\u002Fapi-portal.dictionary.com\\\\u002Fdcom\\\\u002Fsynonyms\",\"PUBLIC_ASSETS_URL\":\"https:\\\\u002F\\\\u002Fwww.dictionary.com\\\\u002Fassets\",\"RTF_API_ENDPOINT\":\"https:\\\\u002F\\\\u002Firene.dictionary.com\\\\u002Fv1\",\"SERVER_LOGGING_LEVEL\":\"error\",\"CLIENT_LOGGING_LEVEL\":\"error\",\"API_REQUEST_LOGGING_LEVEL\":\"info\",\"RTF_FEATURE_ENABLED\":\"true\"};</script>\\n        <script>window.INITIAL_STATE = {\"searchData\":{\"searchTerm\":\"biology\",\"pageName\":\"browse\"},\"detectedDevice\":{\"isMobile\":false}};</script>\\n        \\n      </body>\\n    </html>'"
      ]
     },
     "execution_count": 8,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "dictionary_search.content"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 9,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/plain": [
       "151"
      ]
     },
     "execution_count": 9,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "start = dictionary_search.text.find('Biology')\n",
    "start"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 10,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/plain": [
       "323"
      ]
     },
     "execution_count": 10,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "finish = dictionary_search.text.find(' See more')\n",
    "finish"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 11,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/plain": [
       "'Biology definition, the science of life or living matter in all its forms and phenomena, especially with reference to origin, growth, reproduction, structure, and behavior.'"
      ]
     },
     "execution_count": 11,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "definition = dictionary_search.text[start:finish]\n",
    "definition"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 12,
   "metadata": {},
   "outputs": [],
   "source": [
    "def dictionary_search(word):\n",
    "    url = 'https://dictionary.com/browse/' + word\n",
    "    response = requests.get(url)\n",
    "    start = response.text.find(word)\n",
    "    finish = response.text.find(' See more')\n",
    "    definition = response.text[start:finish]\n",
    "    return definition"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 13,
   "metadata": {},
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "Biology definition, the science of life or living matter in all its forms and phenomena, especially with reference to origin, growth, reproduction, structure, and behavior.\n"
     ]
    }
   ],
   "source": [
    "print(dictionary_search('Biology'))"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 14,
   "metadata": {},
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "DNA is encoded in the sequence of the bases and is transcribed as the strands unwind and replicate.\n"
     ]
    }
   ],
   "source": [
    "print(dictionary_search('DNA'))"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 15,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/plain": [
       "b'<!DOCTYPE html>\\n    <html lang=\"en\" prefix=\"og: http://ogp.me/ns#\">\\n      <head>\\n        \\n  <meta charSet=\"utf-8\">\\n  <meta name=\"description\" content=\"Dna definition, deoxyribonucleic acid: an extremely long macromolecule that is the main component of chromosomes and is the material that transfers genetic characteristics in all life forms, constructed of two nucleotide strands coiled around each other in a ladderlike arrangement with the sidepieces composed of alternating phosphate and deoxyribose units and the rungs composed of the purine and pyrimidine bases adenine, guanine, cytosine, and thymine: the genetic information of DNA is encoded in the sequence of the bases and is transcribed as the strands unwind and replicate. See more.\">\\n  <link rel=\"canonical\" href=\"https://www.dictionary.com/browse/dna\">\\n  <link rel=\"preload\" href=\"https://www.dictionary.com/assets/dictionary-font-c864a1ca3bc4a1c7aef16dbbf189ccc1.woff\" as=\"font\" type=\"font/woff\" crossorigin=\"anonymous\">\\n  \\n  <meta property=\"og:title\" content=\"the definition of dna\">\\n  <meta property=\"og:image\" content=\"https://www.dictionary.com/assets/dcom-social-icon-952ee83e140e5bfbd2d4b6c28daa1a8f.png\">\\n  <meta property=\"og:site_name\" content=\"www.dictionary.com\">\\n  <meta property=\"fb:app_id\" content=\"127444090629600\"><meta property=\"fb:admins\" content=\"100000304287730;109125464873\">\\n  <meta name=\"msvalidate.01\" content=\"DF5542D7723770377E9ABFF59AC1DC97\">\\n  <link rel=\"icon\" type=\"image/png\" href=\"https://www.dictionary.com/assets/favicon-1bff2f1b49c077ed504e55c3649f2a4b.png\">\\n  <title>Dna | Define Dna at Dictionary.com</title>\\n  <meta name=\"viewport\" content=\"width=device-width, initial-scale=1.0\">\\n  \\n  <link rel=\"preconnect\" href=\"https://ads.pubmatic.com\">\\n  <link rel=\"preconnect\" href=\"https://www.googletagservices.com\">\\n  <link rel=\"preconnect\" href=\"https://c.amazon-adsystem.com\">\\n  <link rel=\"preconnect\" href=\"https://www.googletagmanager.com\">\\n  <link rel=\"preconnect\" href=\"https://www.google-analytics.com\">\\n  <link rel=\"preconnect\" href=\"https://connect.facebook.net\">\\n\\n        \\n          \\n          <script defer src=\"https://www.dictionary.com/assets/client-cbe18d61.js\"></script>\\n          <script defer src=\"https://www.dictionary.com/assets/standalone-analytics-bd97baaf.js\"></script>\\n          \\n        <!-- Ad integration with callback begins here, must be in head, expects page type to get appropriate configs -->\\n        \\n<script>\\n  /** wrapping ad scripts with adboiler label **/\\n  adboiler: {\\n    \\n\\n    /**---------- Page level ad targeting configs ----------*/\\n    var pageTargeting = {\"tx1\":\"results\",\"tx2\":\"serp_0_n\",\"ptype\":\"content\",\"ld\":\"0\"};\\n\\n    /**---------- Page level ad slot configs ----------*/\\n    var slotConfigs = [{\"placement\":\"dcom-serp-lb-728x90\",\"code\":\"/23219321/iac.dict.dictry.dw/dic/serp_0_n\",\"ad_uuid\":\"728x90_top\",\"sizes\":[[728,90],[970,90],[970,250]],\"targeting\":{\"pos\":\"top\",\"pos2\":\"728x90_1\"}},{\"placement\":\"dcom-serp-a-top-300x250\",\"code\":\"/23219321/iac.dict.dictry.dw/dic/serp_0_n\",\"ad_uuid\":\"300x250_top\",\"sizes\":[[300,250],[300,600]],\"targeting\":{\"pos\":\"top\",\"pos2\":\"300x250_1\"}},{\"placement\":\"dcom-serp-a-mid-300x250\",\"code\":\"/23219321/iac.dict.dictry.dw/dic/serp_0_n\",\"ad_uuid\":\"300x250_mid\",\"sizes\":[[300,250]],\"targeting\":{\"pos\":\"mid\",\"pos2\":\"300x250_2\"}},{\"placement\":\"dcom-serp-bottom-lb-728x90\",\"code\":\"/23219321/iac.dict.dictry.dw/dic/serp_0_n\",\"ad_uuid\":\"728x90_bot\",\"sizes\":[[728,90]],\"targeting\":{\"pos\":\"bot\",\"pos2\":\"728x90_2\"}}];\\n    var slotConfigsDeferred = [];\\n\\n    var googletag = googletag || {};\\n    googletag.cmd = googletag.cmd || [];\\n    var adSlots =  adSlots || {slots:{}, lazySlots:{}};\\n\\n    const setupDFP = function() {\\n      /**---------- Set page level targeting for DFP ----------*/\\n      for (var pageTarget in pageTargeting) {\\n        if (pageTargeting.hasOwnProperty(pageTarget)) {\\n          (function(key, value) {\\n            googletag.cmd.push(function() {\\n              googletag.pubads().setTargeting(key, value);\\n            });\\n          })(pageTarget, pageTargeting[pageTarget]);\\n        }\\n      }\\n\\n      /**---------- Set ad slot level targeting for DFP ----------*/\\n      if (typeof slotConfigs === \"object\") {\\n        slotConfigs.forEach(function(slot, index) {\\n          googletag.cmd.push(function() {\\n            adSlots.slots[slot.placement] = googletag.defineSlot(slot.code, slot.sizes, slot.placement).addService(googletag.pubads());\\n            for (var target in slot.targeting) {\\n              if (slot.targeting.hasOwnProperty(target)) {\\n                adSlots.slots[slot.placement].setTargeting(target, slot.targeting[target]);\\n              }\\n            }\\n          });\\n        });\\n      }\\n\\n      /**---------- Push gpt ad slots to DFP ----------*/\\n      googletag.cmd.push(function() {\\n        googletag.pubads().enableSingleRequest();\\n        googletag.pubads().disableInitialLoad();\\n        googletag.enableServices();\\n        window.dfpReady = true;\\n      });\\n    }\\n\\n    \\n    /**---------- Irene integration ----------*/\\n      var adlerValues;\\n      var detectedDevice = \\'Desktop\\';\\n\\n      if(\\'Mobile\\' === detectedDevice) {\\n        detectedDevice = \\'MobileWeb\\';\\n      }\\n\\n      var setInstrumentationKV = function(status, error) {\\n        slotConfigs.forEach(function(slot) {\\n          slot.targeting.adler_status = status;\\n          if (error) {\\n            slot.targeting.adler_error = error;\\n          }\\n        });\\n      }\\n\\n      var adlerParams = function(slots) {\\n        var r = {};\\n        const geo = \\'US\\';\\n\\n        if(geo === \\'\\') {\\n          setInstrumentationKV(\\'nogeo\\', \\'nogeo\\');\\n        }\\n\\n        slots.forEach(function(slot) {\\n          r[slot.ad_uuid] = {\\n            site: \\'dcom\\',\\n            geo: geo,\\n            platform: detectedDevice,\\n            sizes: slot.sizes,\\n            position: slot.targeting.pos,\\n          }\\n        });\\n\\n        return r;\\n      }\\n\\n      var fallback = function(shouldSetupDFP, event) {\\n        setInstrumentationKV(event.type);\\n        if (shouldSetupDFP) {\\n          setupDFP();\\n        }\\n      }\\n\\n      var injectAdlerValues = function(localSlotConfigs) {\\n        if(adlerValues) {\\n          localSlotConfigs.forEach(function(slot) {\\n            if (!adlerValues[slot.ad_uuid]) {\\n              slot.targeting.adler_status = \\'nofloor\\';\\n            }\\n            else {\\n              slot.targeting.adler = adlerValues[slot.ad_uuid].adler;\\n              slot.targeting.adler_a = adlerValues[slot.ad_uuid].adler_a;\\n              slot.targeting.adler_b = adlerValues[slot.ad_uuid].adler_b;\\n              slot.targeting.adler_status = \\'ok\\';\\n            }\\n          });\\n        }\\n      }\\n\\n      var setAdlerValues = function(rtfAjaxCall, localSlotConfigs) {\\n        try {\\n          adlerValues = JSON.parse(rtfAjaxCall.responseText);\\n        } catch(err) {\\n          setInstrumentationKV(\\'parse\\', err.message);\\n        }\\n        injectAdlerValues(localSlotConfigs);\\n      }\\n\\n      var rtfCallback = function(rtfAjaxCall, localSlotConfigs, shouldSetupDFP) {\\n        setAdlerValues(rtfAjaxCall, localSlotConfigs);\\n        if (shouldSetupDFP) {\\n          setupDFP();\\n        }\\n      }\\n\\n      var callRTF = function(localSlotConfigs, shouldSetupDFP) {\\n        var rtfReq = new XMLHttpRequest();\\n        rtfReq.addEventListener(\"load\", rtfCallback.bind(null, rtfReq, localSlotConfigs, shouldSetupDFP));\\n        rtfReq.addEventListener(\"timeout\", fallback.bind(null, shouldSetupDFP));\\n        rtfReq.addEventListener(\"error\", fallback.bind(null, shouldSetupDFP));\\n        rtfReq.open(\"POST\", \"https://irene.dictionary.com/v1\", true);\\n        rtfReq.timeout = 1000;\\n        rtfReq.send(JSON.stringify(adlerParams(localSlotConfigs)));\\n      }\\n\\n      callRTF(slotConfigs, true);\\n      \\n\\n    /**---------- Pubmatic url ----------*/\\n    const isEU = false;\\n    var url = \"https://ads.pubmatic.com/AdServer/js/pwt/103207/307\";\\n    const setGPTPersonalization = function(personalized) {\\n      googletag.cmd.push(function() {\\n        if (!window.dfpReady) {\\n          setTimeout(setGPTPersonalization, 100, personalized);\\n        }\\n        else {\\n          if (personalized) {\\n            googletag.pubads().setRequestNonPersonalizedAds(0);\\n          }\\n          else {\\n            googletag.pubads().setRequestNonPersonalizedAds(1);\\n          }\\n          googletag.pubads().refresh();\\n        }\\n      });\\n    };\\n    /**---------- extend pageTargeting at runtime ----------*/\\n    pageTargeting.spe = \"n\";\\n    pageTargeting.ref =\\n      window.document.referrer.search(\\n        \"dictionary.com|thesaurus.com|reference.com\"\\n      ) > -1 ? \"organic\" : \"direct\";\\n    pageTargeting.kw = \"\";\\n    pageTargeting.lang = window.navigator.userLanguage || window.navigator.language;\\n    pageTargeting.loc = \"US\";\\n    pageTargeting.dow = new Date().getDay().toString();\\n    pageTargeting.rpv = Math.floor(Math.random() * 100 + 1).toString();\\n    pageTargeting.pv = typeof SCCookie !== \"undefined\" ? SCCookie.getPageViewCount() + \"\" : \"\";\\n    pageTargeting.evince = \"ad\";\\n\\n    /**---------- Pubmatic wrapper and GPT Tag with Callback begins here ----------*/\\n    var apstagSlots = slotConfigs.reduce(function(accumulator, currentValue) {\\n      accumulator.push({\\n        slotID: currentValue.placement,\\n        sizes: currentValue.sizes\\n      });\\n      return accumulator;\\n    }, []);\\n    var PWT = {};\\n\\n    /**---------- PubMatic pwt.js on load callback is used to load GPT ----------*/\\n    PWT.jsLoaded = function() {\\n      /* Notifies OpenWrap that there are some external bidders for which it has to wait before calling DFP. */\\n      window.OWT.registerExternalBidders();\\n      (function() {\\n        var gads = document.createElement(\\'script\\');\\n        gads.src = \\'https://www.googletagservices.com/tag/js/gpt.js\\';\\n        var node = document.getElementsByTagName(\\'script\\')[0];\\n        node.parentNode.insertBefore(gads, node);\\n      })();\\n    };\\n\\n    (function() {\\n      var purl = window.location.href;\\n      var profileVersionId = \\'\\';\\n      if (purl.indexOf(\\'pwtv=\\') > 0) {\\n        var regexp = /pwtv=(.*?)(&|$)/g;\\n        var matches = regexp.exec(purl);\\n        if (matches.length >= 2 && matches[1].length > 0) {\\n          profileVersionId = \\'/\\' + matches[1];\\n        }\\n      }\\n      var wtads = document.createElement(\\'script\\');\\n      wtads.async = true;\\n      wtads.type = \\'text/javascript\\';\\n      wtads.src = url + profileVersionId + \\'/pwt.js\\';\\n      var node = document.getElementsByTagName(\\'script\\')[0];\\n      node.parentNode.insertBefore(wtads, node);\\n    })();\\n\\n    !function(a9, a, p, s, t, A, g) {\\n      if (a[a9]) return;\\n\\n      function q(c, r) {\\n        a[a9]._Q.push([c, r])\\n      }\\n      a[a9] = {\\n        init: function() {\\n          q(\"i\", arguments)\\n        },\\n        fetchBids: function() {\\n          q(\"f\", arguments)\\n        },\\n        setDisplayBids: function() {},\\n        _Q: []\\n      };\\n\\n      A = p.createElement(s);\\n      A.async = !0;\\n      A.src = t;\\n      g = p.getElementsByTagName(s)[0];\\n      g.parentNode.insertBefore(A, g)\\n    }(\"apstag\", window, document, \"script\", \"//c.amazon-adsystem.com/aax2/apstag.js\");\\n\\n    apstag.init({\\n      pubID: \\'3067\\',\\n      adServer: \\'googletag\\',\\n      bidTimeout: 1000\\n    });\\n\\n    apstag.fetchBids({\\n      slots: apstagSlots\\n    }, function(bids) {\\n      /* Callback method that triggers the first DFP request for googletag\\'s disableInitialLoad integration after bids have been set */\\n      googletag.cmd.push(function() {\\n        apstag.setDisplayBids();\\n        window.OWT.notifyExternalBiddingComplete();\\n\\n        /*\\n          Determine IAB consent if necessary, and trigger GPT ad refresh\\n          if consent is provided.\\n        */\\n        if (isEU) {\\n          try {\\n            if (typeof __cmp === \\'function\\') {\\n              __cmp(\"getVendorConsents\", {}, function(c) {\\n                let consent = false;\\n                if (typeof c.purposeConsents === \\'array\\') {\\n                  consent = c.purposeConsents.includes(\\'3:true\\');\\n                } else if (typeof c.purposeConsents === \\'object\\') {\\n                  consent = c.purposeConsents[3];\\n                }\\n                if (consent !== false && consent !== true) consent = false;\\n                // request personalized ads\\n                setGPTPersonalization(consent);\\n              });\\n            } else {\\n              setGPTPersonalization(false);\\n            }\\n          } catch (error) {\\n            console.error(\\'personalization: \\', error);\\n            setGPTPersonalization(false);\\n          }\\n        } else {\\n          setGPTPersonalization(true);\\n        }\\n      });\\n    });\\n  }\\n</script>\\n        <!-- Pubmatic wrapper and GPT Tag ends here -->\\n        <!-- Google Analytics GTM dataLayer starts here -->\\n        \\n      <script type=\\'text/javascript\\'>\\n        window.dataLayer = window.dataLayer || [];\\n        dataLayer.push({\\n          event: \\'pageview\\',\\n          device: \\'Desktop\\',\\n          pageName: \\'undefined\\',\\n          LDid: \\'0\\',\\n          sessionId: null,\\n          browserId: null,\\n        });\\n      </script>\\n      <script>\\n      (function(w, d, s, l, i) {\\n        w[l] = w[l] || [];\\n        w[l].push({ \\'gtm.start\\': new Date().getTime(), event: \\'gtm.js\\' });\\n        var f = d.getElementsByTagName(s)[0],\\n          j = d.createElement(s),\\n          dl = l != \\'dataLayer\\' ? \\'&l=\\' + l : \\'\\';\\n        j.async = true;\\n        j.src = \\'https://www.googletagmanager.com/gtm.js?id=\\' + i + dl;\\n        f.parentNode.insertBefore(j, f);\\n      })(window, document, \\'script\\', \\'dataLayer\\', \\'GTM-TXC5GP\\');\\n      </script>\\n\\n        <!-- Google Analytics GTM dataLayer ends here -->\\n        \\n  <script>\\n    var loadingTimeout = 0;\\n    setTimeout(function stopLoading() {\\n      document.body.classList.remove(\\'init\\');\\n      document.body.classList.add(\\'loaded\\');\\n    }, loadingTimeout)\\n  </script>\\n  <noscript>\\n    <style>\\n      #initial-load-header-loader {\\n        visibility: hidden!important;\\n      }\\n      #initial-load-content {\\n        visibility: visible!important;\\n      }\\n    </style>\\n  </noscript>\\n\\n        <style>@-webkit-keyframes animation-jdx9m6{from{-webkit-transform:translate(-30vw);-ms-transform:translate(-30vw);transform:translate(-30vw);width:30vw;}50%{width:30vw;}70%{width:50vw;}80%{-webkit-transform:translate(50vw);-ms-transform:translate(50vw);transform:translate(50vw);}95%{-webkit-transform:translate(120vw);-ms-transform:translate(120vw);transform:translate(120vw);width:90%;}to{-webkit-transform:translate(140vw);-ms-transform:translate(140vw);transform:translate(140vw);}}@keyframes animation-jdx9m6{from{-webkit-transform:translate(-30vw);-ms-transform:translate(-30vw);transform:translate(-30vw);width:30vw;}50%{width:30vw;}70%{width:50vw;}80%{-webkit-transform:translate(50vw);-ms-transform:translate(50vw);transform:translate(50vw);}95%{-webkit-transform:translate(120vw);-ms-transform:translate(120vw);transform:translate(120vw);width:90%;}to{-webkit-transform:translate(140vw);-ms-transform:translate(140vw);transform:translate(140vw);}}@font-face{font-family:\\'dictionary-fonticon\\';src:url(https://www.dictionary.com/assets/dictionary-font-2f8f4dd423d79b60f7bc58ddcc429053.eot) format(\\'embedded-opentype\\'),url(https://www.dictionary.com/assets/dictionary-font-c864a1ca3bc4a1c7aef16dbbf189ccc1.woff) format(\\'woff\\'),url(https://www.dictionary.com/assets/dictionary-font-0acb1acf427a046a793cc3942f13589e.ttf) format(\\'truetype\\'),url(https://www.dictionary.com/assets/dictionary-font-2ae54d9d76a12012ae17e2dd85d293e9.svg#dictionary-font) format(\\'svg\\');}html{line-height:1.15;-ms-text-size-adjust:100%;-webkit-text-size-adjust:100%;}body{margin:0;}article,aside,footer,header,nav,section{display:block;}h1{font-size:2em;margin:0.67em 0;}figcaption,figure,main{display:block;}figure{margin:1em 40px;}hr{box-sizing:content-box;height:0;overflow:visible;}pre{font-family:monospace,monospace;font-size:1em;}a{background-color:transparent;-webkit-text-decoration-skip:objects;}abbr[title]{border-bottom:none;-webkit-text-decoration:underline;text-decoration:underline;-webkit-text-decoration:underline dotted;text-decoration:underline dotted;}b,strong{font-weight:inherit;}b,strong{font-weight:bolder;}code,kbd,samp{font-family:monospace,monospace;font-size:1em;}dfn{font-style:italic;}mark{background-color:#ff0;color:#000;}small{font-size:80%;}sub,sup{font-size:75%;line-height:0;position:relative;vertical-align:baseline;}sub{bottom:-0.25em;}sup{top:-0.5em;}audio,video{display:inline-block;}audio:not([controls]){display:none;height:0;}img{border-style:none;}svg:not(:root){overflow:hidden;}button,input,optgroup,select,textarea{font-family:sans-serif;font-size:100%;line-height:1.15;margin:0;}button,input{overflow:visible;}button,select{text-transform:none;}button,html [type=\"button\"],[type=\"reset\"],[type=\"submit\"]{-webkit-appearance:button;}button::-moz-focus-inner,[type=\"button\"]::-moz-focus-inner,[type=\"reset\"]::-moz-focus-inner,[type=\"submit\"]::-moz-focus-inner{border-style:none;padding:0;}button:-moz-focusring,[type=\"button\"]:-moz-focusring,[type=\"reset\"]:-moz-focusring,[type=\"submit\"]:-moz-focusring{outline:1px dotted ButtonText;}fieldset{padding:0.35em 0.75em 0.625em;}legend{box-sizing:border-box;color:inherit;display:table;max-width:100%;padding:0;white-space:normal;}progress{display:inline-block;vertical-align:baseline;}textarea{overflow:auto;}[type=\"checkbox\"],[type=\"radio\"]{box-sizing:border-box;padding:0;}[type=\"number\"]::-webkit-inner-spin-button,[type=\"number\"]::-webkit-outer-spin-button{height:auto;}[type=\"search\"]{-webkit-appearance:textfield;outline-offset:-2px;}[type=\"search\"]::-webkit-search-cancel-button,[type=\"search\"]::-webkit-search-decoration{-webkit-appearance:none;}::-webkit-file-upload-button{-webkit-appearance:button;font:inherit;}details,menu{display:block;}summary{display:list-item;}canvas{display:inline-block;}template{display:none;}[hidden]{display:none;}ul,ol,dl{margin:0 auto;padding:0;}button,input,optgroup,select,textarea{font-family:inherit;}html,body{overflow-x:hidden;}body{margin:0;font:14px Verdana,Helvetica,Arial,sans-serif;background-color:white;color:#666666;}body #initial-load-header-loader{visibility:hidden;}body #initial-load-content{visibility:visible;}body.init #initial-load-header-loader{visibility:visible;}body.init #initial-load-content{visibility:hidden;}body .hamburgerMenu-opened.app-isMobile #hamburgerButton-click{margin-left:0;}body .hamburgerMenu-opened #hamburgerButton-click{background-color:#3c7bbe;color:#ffffff;}body .hamburgerMenu-opened #hamburgerButton-click::before{content:\\'\\xee\\xa4\\x84\\';}body .hamburgerMenu-opened .hamburger-overlay{display:block;}a{-webkit-text-decoration:none;text-decoration:none;color:#3c7bbe;}a:hover{-webkit-text-decoration:underline;text-decoration:underline;}.one-click:hover{color:#3c7bbe;cursor:pointer;}.css-yshiao.hamburgerMenu-opened{height:100vh;overflow-y:hidden;}.css-1qktsnw{min-height:calc(100vh - 40px);-webkit-transition:-webkit-transform 0.4s ease;-webkit-transition:transform 0.4s ease;transition:transform 0.4s ease;}@media only screen and (max-width:768px){.css-1qktsnw{min-height:calc(100vh - 81px);}}.hamburgerMenu-opened .css-1qktsnw{-webkit-transform:translate3d(300px,0,0);-ms-transform:translate3d(300px,0,0);transform:translate3d(300px,0,0);}.app-isMobile.hamburgerMenu-opened .css-1qktsnw{-webkit-transform:translate3d(calc(100% - 65px),0,0);-ms-transform:translate3d(calc(100% - 65px),0,0);transform:translate3d(calc(100% - 65px),0,0);}.css-ywz12x{z-index:10001;}.css-14qcrqt{height:40px;overflow:hidden;}.css-rjglq{background:#3c7bbe;display:inline-block;float:left;}.css-cqn0r7{position:absolute;display:none;top:0;left:0;height:100%;width:100%;background-color:rgba(0,0,0,0.6);z-index:4;}.css-151frnk{position:absolute;top:0;left:-300px;width:300px;height:100%;background-color:#3c7bbe;}.css-7wf88h{list-style-type:none;padding:15px 15px 7px;margin:0;}.css-badxzn{font-size:16px;font-style:italic;font-weight:bold;line-height:16px;font-family:Helvetica,Arial,serif;border-top:1px solid #66cef6;}.css-badxzn:first-child{border-top:0;}.css-badxzn:first-child > a{padding-top:0;}.css-badxzn:last-child{border-bottom:1px solid #66cef6;}.css-78n1nc{display:block;color:#f5f5f5;padding:18px 0;-webkit-text-decoration:none;text-decoration:none;}.css-78n1nc:hover{color:#66cef6;-webkit-text-decoration:none;text-decoration:none;cursor:pointer;}.css-1kmzn5i{margin:0;font-family:Verdana,sans-serif;font-size:15px;font-weight:normal;line-height:1.15;list-style-type:none;padding:0 15px 7px;}.css-1kmzn5i > li > a{padding:8px 0 14px;font-style:normal;-webkit-text-decoration:none;text-decoration:none;}.css-1tpwzaq{margin-left:0;font-family:dictionary-fonticon;color:inherit;width:40px;height:40px;cursor:pointer;padding:0;border:none;outline:none;position:relative;display:inline-block;-webkit-font-smoothing:antialiased;background-color:#fff;font-size:24px;line-height:1;z-index:5;}.css-1tpwzaq::before{content:\\'\\xee\\xa4\\x83\\';}.css-1w5d7r9{height:40px;margin:0;padding:0;}.css-1fe7abr{z-index:3;border-right:none;float:left;list-style-type:none;background-color:#f5f5f5;text-align:center;background-color:#3c7bbe;}.css-1fe7abr:last-child{border-right:1px solid #aaa;}.css-akr928{cursor:pointer;display:inline-block;padding:12px 26px;font:16px Helvetica,sans-serif;line-height:18px;font-style:italic;font-weight:bold;-webkit-text-decoration:none;text-decoration:none;color:#666;color:#fff;}@media (max-width:400px){.css-akr928{padding:11px 13px;font-size:14px;}}@media (max-width:318px){.css-akr928{font-size:12px;}}.css-1yyv0n6{z-index:3;border-right:none;float:left;list-style-type:none;background-color:#f5f5f5;text-align:center;}.css-1yyv0n6:last-child{border-right:1px solid #aaa;}.css-1yyv0n6:hover{background-color:#e2e2e2;}.css-1npfjc8{cursor:pointer;display:inline-block;padding:12px 26px;font:16px Helvetica,sans-serif;line-height:18px;font-style:italic;font-weight:bold;-webkit-text-decoration:none;text-decoration:none;color:#666;}@media (max-width:400px){.css-1npfjc8{padding:11px 13px;font-size:14px;}}@media (max-width:318px){.css-1npfjc8{font-size:12px;}}.css-zd7l5y{float:right;padding:1px 14px 1px 22px;margin:8px 0;border-right:1px solid #e2e2e2;line-height:22px;color:#555;font-size:11px;-webkit-text-decoration:none;text-decoration:none;font-weight:400;font-family:Open Sans,sans-serif;-webkit-transition:all 0.15s ease-in-out;transition:all 0.15s ease-in-out;}.css-zd7l5y > span{float:left;width:22px;height:22px;margin-right:8px;font-size:22px;-webkit-text-decoration:none;text-decoration:none;font-family:dictionary-fonticon;}.css-zd7l5y:hover{color:#6cb746;}.css-jna48b::before{content:\\'\\xee\\x98\\x8e\\';}.css-sv8lr1::before{content:\\'\\xee\\x98\\x8d\\';}.css-omrpao{background:#3c7bbe;display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;-webkit-box-pack:left;-webkit-justify-content:left;-ms-flex-pack:left;justify-content:left;left:100px;}.css-15nai5i{padding:15px 15px 18px;height:auto;display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;-webkit-flex-wrap:wrap;-ms-flex-wrap:wrap;flex-wrap:wrap;}@media (min-width:1200px){.css-15nai5i{width:1170px;margin-right:auto;margin-left:auto;}}@media (min-width:992px){.css-15nai5i{width:970px;margin-right:auto;margin-left:auto;}}.css-wwrygl{margin:0 20px 0 0;width:176px;height:40px;}.css-1uhxkf6{padding:8px 2px;background-color:#f8f8f8;display:inline-block;float:left;box-sizing:border-box;position:relative;}.css-1baulvz{display:inline-block;}.css-qwsmke{float:left;cursor:pointer;}.css-omgbl{font-family:\\'dictionary-fonticon\\';speak:none;font-style:normal;font-weight:normal;font-variant:normal;text-transform:none;float:right;padding:1px 3px;color:#555;font-size:25px;line-height:28px;}.css-omgbl:after{content:\\'\\\\e613\\';}.css-1ynlh0h{float:right;min-width:92px;display:block;padding-left:8px;color:#555;font:14px Verdana;line-height:30px;}.css-1dv1kvn{border:0;-webkit-clip:rect(0 0 0 0);clip:rect(0 0 0 0);height:1px;margin:-1px;overflow:hidden;padding:0;position:absolute;width:1px;}.css-ji58t3{float:left;display:block;width:292px;height:30px;padding:0 8px;margin-right:1px;border:1px solid #e2e2e2;min-height:1px;line-height:18px;font-size:18px;color:#666;-webkit-transition:border-color,box-shadow 0.2s,0.2s ease-in-out,ease-in-out;transition:border-color,box-shadow 0.2s,0.2s ease-in-out,ease-in-out;}.css-ji58t3:hover,.css-ji58t3:focus{border-color:#55acee;outline:0;box-shadow:inset 0 1px 1px rgba(0,0,0,0.075),0 0 8px rgba(102,175,233,0.6);}@media (min-width:1200px){.css-ji58t3{width:422px;}}.css-rv4ucl{font-family:\\'dictionary-fonticon\\';speak:none;font-style:normal;font-weight:normal;font-variant:normal;text-transform:none;width:50px;height:30px;cursor:pointer;padding:0;border:0;outline:0;background-color:transparent;float:left;display:inline-block;padding:2px 8px;background:#f8f8f8;color:#3f729b;font-size:24px;color:#55acee;}.css-rv4ucl:before{content:\\'\\\\e614\\';}.css-1jzsm78{margin:38px 0 0 -2px;width:100%;padding:0;background:#fff;z-index:2;cursor:pointer;list-style-type:none;box-shadow:0 2px 3px rgba(50,50,50,0.4);position:absolute;max-height:0px;-webkit-transition:max-height 100ms ease;transition:max-height 100ms ease;overflow:hidden;}.css-afnsia{border-top:1px solid #e2e2e2;padding:10px 8px;}.css-afnsia:hover{background:#f5f5f5;}.css-iry8e{display:block;-webkit-text-decoration:none;text-decoration:none;color:#555;font:14px Verdana,sans-serif;}.css-k2b2qh{z-index:10004;left:-30vw;width:30vw;height:4px;background-color:#9dbde1;-webkit-animation:animation-jdx9m6 2s linear infinite;animation:animation-jdx9m6 2s linear infinite;}.css-13o7eu2{display:block;}.css-d5e8ah{display:block;margin:0 auto;padding:0;}@media (max-width:768px){.css-d5e8ah{display:block;}}@media (min-width:1225px){.css-d5e8ah{width:1200px;}}.css-o2gk28{min-height:90px;padding:20px 0;text-align:center;}.css-dfjnxh{display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;position:relative;min-height:1px;padding:0 15px 15px 15px;width:100%;}@media (max-width:1200px){.css-dfjnxh{width:auto;}}@media (max-width:768px){.css-dfjnxh{display:block;}}.css-11r0tj9{border-top:0;border-bottom:1px solid #d9d9d9;margin:0;}.css-6xt45o{background-color:transparent;text-align:center;}.css-1pny6db{display:inline-block;font-size:18px;font-weight:normal;margin:0 auto 20px;border-bottom:2px solid #3879c0;-webkit-text-decoration:none;text-decoration:none;color:#000;}.css-1pny6db:hover{-webkit-text-decoration:none;text-decoration:none;}.css-2vi8uw{list-style:none;padding-left:0;display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;-webkit-flex-wrap:wrap;-ms-flex-wrap:wrap;flex-wrap:wrap;-webkit-box-pack:justify;-webkit-justify-content:space-between;-ms-flex-pack:justify;justify-content:space-between;}.css-2vi8uw > li{-webkit-flex-basis:24%;-ms-flex-preferred-size:24%;flex-basis:24%;}@media only screen and (max-width:768px){.css-2vi8uw > li{-webkit-flex-basis:49%;-ms-flex-preferred-size:49%;flex-basis:49%;}}.css-105pq9n{text-align:center;min-height:130px;margin-bottom:6px;}.css-105pq9n:last-child{margin-right:0;}.css-u1tqvs{-webkit-text-decoration:none;text-decoration:none;color:#444444;}.css-8atqhb{width:100%;}.css-1fyr8sh{font-size:12px;padding-top:10px;}@media only screen and (max-width:769px){.css-1fyr8sh{font-size:16px;}}.css-19a7eo8{margin-left:30px;display:inline-block;position:relative;min-height:1px;padding:0 15px;width:300px;-webkit-flex:0 0 300px;-ms-flex:0 0 300px;flex:0 0 300px;}@media (max-width:768px){.css-19a7eo8{margin-left:0;display:block;width:auto;}}.css-pb859s{min-height:250px;padding:20px 0;text-align:center;}.css-1rn3crn{background-color:#444;height:148px;}@media only screen and (max-width:769px){.css-1rn3crn{height:282px;}}.css-1tj1foj{width:70%;margin:0 auto;color:#bbb;font-weight:100;font-family:\\'Helvetica\\';font-size:14px;line-height:40px;}@media only screen and (max-width:769px){.css-1tj1foj{width:100%;line-height:30px;text-align:center;}}.css-a50h34{line-height:normal;padding-bottom:22px;}.css-19sw9w4{margin:0;list-style:none;padding-top:20px;padding-left:0px;display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;-webkit-flex-flow:row wrap;-ms-flex-flow:row wrap;flex-flow:row wrap;-webkit-text-decoration:none;text-decoration:none;position:relative;text-align:left;}@media only screen and (max-width:769px){.css-19sw9w4{padding-left:18px;}}.css-1r0i7sq{padding-right:16px;color:#999999;}@media only screen and (min-width:769px){.css-1r0i7sq{float:left;}}.css-603c4d{float:left;padding-right:6px;}@media only screen and (max-width:769px){.css-603c4d{float:right;padding-right:18px;margin-bottom:8px;-webkit-column-fill:balance;column-fill:balance;}}.css-1xa4729{color:#cccccc;-webkit-text-decoration:none;text-decoration:none;}.css-13gnrtg{float:left;padding-right:16px;}@media only screen and (max-width:769px){.css-13gnrtg{float:right;padding-right:18px;margin-bottom:8px;-webkit-column-fill:balance;column-fill:balance;}}.css-13h1p65{display:inline;margin:0;padding:0px;}@media only screen and (min-width:769px){.css-13h1p65{float:right;}}.css-13s85fp{display:inline;position:relative;}.css-16ob2z7{color:#bbb;-webkit-text-decoration:none;text-decoration:none;padding-left:35px;}.css-16ob2z7:hover{color:#fff;-webkit-text-decoration:underline;text-decoration:underline;}@media only screen and (max-width:769px){.css-16ob2z7{padding:5px;display:inline-block;text-align:center;}}.css-1748arg{padding-top:12px;margin-bottom:24px;}.css-1748arg .luna-def-number{font-weight:bold;}.css-1748arg .italic{font-style:italic;}.css-1748arg .luna-pronset .luna-pos{font-style:italic;}.css-1748arg .luna-wud,.css-1748arg .small-caps{font-variant:small-caps;}.css-urzbm0{font-weight:normal;word-break:break-word;display:inline-block;font-size:49px;margin:0 15px 10px 0;line-height:1.7;}@media (max-width:768px){.css-urzbm0{font-size:36px;margin:0 10px 10px 0;}}.css-17dkd7s{border:none;position:relative;top:-10px;font-family:dictionary-fonticon;font-size:25px;color:#3c7bbe;-webkit-text-decoration:none;text-decoration:none;cursor:pointer;}.css-17dkd7s::before{content:\\'\\\\e803\\';}@media (max-width:768px){.css-17dkd7s{top:-2px;}}.css-1khtv86{font-size:20px;color:#c0b5b5;}.css-1khtv86 .bold{font-weight:bold;}.css-1khtv86 .luna-pos{font-style:italic;}@media (max-width:768px){.css-1khtv86{font-size:18px;}}.css-1khtv86::after{content:\\'\\\\0a0\\';}.css-1g5b64m{padding:16px 0;}.css-1fvpz4m{margin-right:32px;outline:none;border:none;padding:0 !important;cursor:pointer;color:#3c7bbe;font-size:15px;background-color:transparent;-webkit-text-decoration:none;text-decoration:none;}.css-1fvpz4m:hover{-webkit-text-decoration:underline;text-decoration:underline;}.css-2h6jwx{position:relative;height:auto;padding-bottom:0px;margin-bottom:0px;-webkit-transition:all 0.1s ease;transition:all 0.1s ease;}.css-8lgfcg{height:100%;overflow:hidden;}.css-1sdcacc{margin-bottom:24px;margin-top:24px;}.css-1y60q53{line-height:18px;margin-bottom:11px;}@media (max-width:768px){.css-1y60q53{margin-bottom:2px;}}.css-1pomevn{font-size:20px;font-weight:normal;}.css-zw8qdz{font-size:15px;text-align:left;padding-left:20px;}.css-zw8qdz .superscript{padding-left:2px;font-size:12px;vertical-align:super;}.css-2oywg7{margin-left:12px;margin-bottom:4px;padding-left:8px;}.css-9sn2pa{font-size:15px;line-height:24px;}.css-9sn2pa .luna-example.italic{font-style:italic;color:#c0b5b5;display:block;}.css-9sn2pa .italic{font-style:italic;}.css-9sn2pa .bold{font-weight:bold;}.css-9sn2pa .luna-nickname{font-style:italic;}.css-9sn2pa .luna-nickname::before{content:\\'\"(\\';}.css-9sn2pa .luna-nickname::after{content:\\')\"\\';}.css-9sn2pa .luna-aka{font-style:italic;}.css-9sn2pa .luna-aka::before{content:\\'(\\';}.css-9sn2pa .luna-aka::after{content:\\')\\';}.css-9sn2pa .audio-player{font-family:dictionary-fonticon;font-size:12px;color:#3c7bbe;cursor:pointer;padding:1px;}.css-9sn2pa .audio-player::before{content:\\'\\\\e803\\';}.css-hh4f95{margin:20px 0;padding:15px 0;border-top:solid 0.5px #d9d9d9;border-bottom:solid 0.5px #d9d9d9;}.css-grsm00{display:none;position:absolute;bottom:0px;height:100px;background:linear-gradient(rgba(255,255,255,0),white);width:100%;text-align:center;color:white;}.css-6d2nf9{position:relative;outline:none;display:inline-block;top:65px;cursor:pointer;text-align:center;font-weight:bold;font-size:12px;border-radius:2px;padding:8px 32px;border:solid 2px #e6e6e7;background:#ffffff;color:#797979;}.css-54ces9{margin:24px 0 24px 0;}.css-j3k4qp{display:inline-block;line-height:22px;padding-top:12px;font-weight:400;font-size:20px;}.css-1fxfie5{font-size:22px;}@media (max-width:768px){.css-1fxfie5{font-size:18px;margin:0 10px 10px 0;word-break:break-all;word-wrap:break-word;-webkit-hyphens:auto;-moz-hyphens:auto;-ms-hyphens:auto;hyphens:auto;line-height:22px;}}.css-1jci32p{font-size:15px;line-height:28px;margin-bottom:24px;}.css-1jci32p .bold{font-weight:bold;}.css-1jci32p .italic{font-style:italic;}@media (max-width:768px){.css-1jci32p{font-size:15px;}}.css-1yphgw4{font-size:12px;color:#878787;padding-bottom:35px;line-height:20px;white-space:pre-line;}.css-1an5ojz{padding-bottom:17px;}.css-1wj1ajw{line-height:22px;padding-top:12px;font-weight:400;font-size:20px;}.css-ntz2ga{padding-top:0;display:inline;}.css-16b2ug3{margin:15px 0;}.css-l7r0w2{font-size:20px;font-weight:400;}.css-12sy04c{font-size:18px;line-height:22px;font-weight:400;}.css-o9b79t{list-style:none;}.css-d2znx6{margin-bottom:25px;}.css-it69we{font-size:15px;line-height:22px;font-weight:400;margin:0 0 4px 0;}.css-it69we .italic{font-style:italic;}.css-k008qs{display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;}.css-1ugobpn{margin:auto;font-size:12px;line-height:20px;}.css-zuqhy{padding:24px 0;color:#666666;font-size:20px;}.css-1nakkwx{margin-bottom:24px;}.css-1nakkwx .italic{font-style:italic;}.css-1nakkwx .bold,.css-1nakkwx .label{font-weight:bold;}.css-1h3udqp{list-style:none;padding-left:0;display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;-webkit-flex-wrap:wrap;-ms-flex-wrap:wrap;flex-wrap:wrap;-webkit-box-pack:justify;-webkit-justify-content:space-between;-ms-flex-pack:justify;justify-content:space-between;}.css-1h3udqp > li{-webkit-flex-basis:49%;-ms-flex-preferred-size:49%;flex-basis:49%;}@media only screen and (max-width:768px){.css-1h3udqp > li{-webkit-flex-basis:49%;-ms-flex-preferred-size:49%;flex-basis:49%;}}.css-1q7njkh{margin-top:10px;}.css-1675y43{padding-bottom:14px;margin:0;font-size:20px;color:#666666;font-weight:normal;}.css-1dqz0ff{border:none;position:relative;margin-right:8px;top:2px;font-family:dictionary-fonticon;font-size:20px;line-height:21px;color:#a19f9c;-webkit-text-decoration:none;text-decoration:none;}.css-1dqz0ff::before{content:\\'\\\\e906\\';}.css-5w0xmi{font-weight:normal;display:inline-block;font-size:36px;margin:0 12px 10px 0;line-height:46px;}.css-gb8pey{-webkit-text-decoration:none;text-decoration:none;}.css-gb8pey:hover{-webkit-text-decoration:none;text-decoration:none;}.css-1upilqn{margin-bottom:12px;}.css-1ok7jrf{list-style:none;padding-left:0;display:-webkit-box;display:-webkit-flex;display:-ms-flexbox;display:flex;-webkit-flex-wrap:wrap;-ms-flex-wrap:wrap;flex-wrap:wrap;-webkit-box-pack:justify;-webkit-justify-content:space-between;-ms-flex-pack:justify;justify-content:space-between;}.css-1ok7jrf > li{-webkit-flex-basis:100%;-ms-flex-preferred-size:100%;flex-basis:100%;}@media only screen and (max-width:768px){.css-1ok7jrf > li{-webkit-flex-basis:100%;-ms-flex-preferred-size:100%;flex-basis:100%;}}.css-i3pbo{margin-bottom:24px;}.css-13aw141{margin-top:6px;width:38px;-webkit-align-self:baseline;-ms-flex-item-align:baseline;align-self:baseline;padding:0 15px 0 0;}.css-k59p8l{font-size:15px;line-height:22px;box-sizing:border-box;margin:0 0 17px;}.css-k59p8l .italic{font-style:italic;}.css-utybho{font-size:15px;font-weight:400;margin-bottom:0;}.css-mgww5h{margin:0 0 10px;}.css-10rk44a{font-size:15px;line-height:24px;}.css-10rk44a .luna-example.italic{font-style:italic;color:#c0b5b5;display:block;}.css-10rk44a .italic{font-style:italic;}.css-10rk44a .bold{font-weight:bold;}.css-10rk44a .luna-nickname{font-style:italic;}.css-10rk44a .luna-nickname::before{content:\\'\"(\\';}.css-10rk44a .luna-nickname::after{content:\\')\"\\';}.css-10rk44a .luna-aka{font-style:italic;}.css-10rk44a .luna-aka::before{content:\\'(\\';}.css-10rk44a .luna-aka::after{content:\\')\\';}.css-10rk44a .audio-player{font-family:dictionary-fonticon;font-size:12px;color:#3c7bbe;cursor:pointer;padding:1px;}.css-10rk44a .audio-player::before{content:\\'\\\\e803\\';}.css-10rk44a::before{content:\\': \\';}</style>\\n      </head>\\n      <body class=\"init\">\\n        <!-- Google Analytics GTM iframe starts here -->\\n        \\n      <noscript>\\n        <iframe\\n          src=\"https://www.googletagmanager.com/ns.html?id=GTM-TXC5GP\"\\n          height=\"0\"\\n          width=\"0\"\\n          style=\"display:none;visibility:hidden\"\\n        ></iframe>\\n      </noscript>\\n    \\n        <!-- Google Analytics GTM iframe ends here -->\\n        <div id=\"root\"><div data-reactroot=\"\"><div class=\"app-base css-yshiao e1fub8bm0\"><div id=\"base-pw\" class=\"css-1qktsnw e1fub8bm2\"><div class=\"css-ywz12x e11ozc52\"><header><nav aria-label=\"Site Navigation\"><div class=\"css-14qcrqt e1nknobk0\"><div class=\"css-rjglq e1mpvuks0\"><div class=\"hamburger-overlay css-cqn0r7 e1mpvuks1\"></div><nav aria-label=\"Hamburger Menu\" class=\"css-151frnk e1mpvuks3\"><ul class=\"css-7wf88h e1mpvuks5\"><li class=\"css-badxzn e1mpvuks4\"><a id=\"hamburgerMenuDictionarycom\" href=\"https://www.dictionary.com\" data-linkid=\"lxabec\" class=\"css-78n1nc e1mpvuks2\">Dictionary.com</a><ul class=\"css-1kmzn5i e1mpvuks6\"><li><a id=\"hamburgerMenuWotd\" href=\"https://www.dictionary.com/wordoftheday/\" data-linkid=\"1498ik\" class=\"css-78n1nc e1mpvuks2\">Word of the Day</a></li><li><a id=\"hamburgerMenuGames\" href=\"https://www.dictionary.com/fun/crosswordsolver\" data-linkid=\"636f6c\" class=\"css-78n1nc e1mpvuks2\">Crossword Solver</a></li><li><a id=\"hamburgerMenuBlog\" href=\"https://www.dictionary.com/e/\" data-linkid=\"t6ehki\" class=\"css-78n1nc e1mpvuks2\">Everything After Z</a></li></ul></li><li class=\"css-badxzn e1mpvuks4\"><a id=\"hamburgerMenuThesauruscom\" href=\"https://www.thesaurus.com\" data-linkid=\"c1drjk\" class=\"css-78n1nc e1mpvuks2\">Thesaurus.com</a></li></ul></nav><button aria-label=\"Toggle Menu\" id=\"hamburgerButton-click\" class=\"css-1tpwzaq e1mpvuks7\"></button></div><ul class=\"css-1w5d7r9 e1nknobk1\"><li class=\"css-1fe7abr ejn7swr1\"><a href=\"https://www.Dictionary.com\" id=\"\" data-linkid=\"tqks0v\" role=\"link\" class=\"css-akr928 ejn7swr0\">Dictionary.com</a></li><li class=\"css-1yyv0n6 ejn7swr2\"><a href=\"https://www.Thesaurus.com\" id=\"\" data-linkid=\"qxnxzj\" class=\"css-1npfjc8 ejn7swr0\">Thesaurus.com</a></li></ul><a href=\"https://www.dictionary.com/e/apps/\" font-family=\"dictionary-fonticon\" data-linkid=\"dbvvdc\" class=\"css-zd7l5y ebzzift0\"><span class=\"css-jna48b ebzzift1\"></span><span class=\"css-sv8lr1 ebzzift2\"></span>Try Our Apps</a></div></nav><div class=\"css-omrpao e1nfx3j01\"><div class=\"css-15nai5i e1nfx3j02\"><a href=\"https://www.dictionary.com\" data-linkid=\"yg487x\"><img src=\"https://www.dictionary.com/assets/dictionary_logo_white-90c1e2eaf84c6abcb80d08d6eb0b6c60.svg\" alt=\"Dictionary.com\" class=\"css-wwrygl e1nfx3j00\"/></a><div class=\"css-1uhxkf6 e18h4a051\"><form action=\"#\" class=\"css-1baulvz e18h4a053\"><div class=\"css-qwsmke ev3lshj0\"><span class=\"css-omgbl e2cjyp00\"></span><span class=\"css-1ynlh0h ev3lshj1\">definitions</span></div><label for=\"q\" class=\"css-1dv1kvn e1t7bu8t0\">Search</label><input type=\"search\" title=\"Search\" autoComplete=\"off\" autoCapitalize=\"off\" autoCorrect=\"off\" name=\"override_query\" class=\"search-input css-ji58t3 e18h4a054\" id=\"searchbar_input\" value=\"dna\"/><button aria-label=\"Search\" type=\"submit\" id=\"search-submit\" class=\"css-rv4ucl e18h4a052\"></button><ul style=\"max-height:0\" class=\"css-1jzsm78 ep2tsc50\"><li class=\"css-afnsia e18h4a050\"><a data-linkid=\"205vpa\" class=\"css-iry8e ebjrtl60\">synonyms</a></li></ul></form></div></div></div></header><div color=\"#9dbde1\" id=\"initial-load-header-loader\" class=\"css-k2b2qh e11ozc51\"></div></div><div class=\"css-13o7eu2 e11ozc50\"><div id=\"initial-load-content\"><main class=\"css-d5e8ah e1fub8bm3\"><aside class=\"no-collapse css-o2gk28 eanayw60\" id=\"dcom-serp-lb-728x90\"><script>if (window.googletag) {googletag.cmd.push(function() { googletag.display(\\'dcom-serp-lb-728x90\\'); });} else {console.error(\\'googletag not defined, dcom-serp-lb-728x90\\');}</script></aside><section class=\"css-dfjnxh e8xvxkb0\"><section class=\"css-0 e1hj943x0\"><section class=\"css-1748arg e1wu7xq20\"><section class=\"css-0 e1rg2mtf0\"><h1 class=\"css-urzbm0 e1rg2mtf5\">DNA</h1><div></div></section><div class=\"css-1g5b64m e4wg2xj0\"><button class=\"hotlinks-button css-1fvpz4m e4wg2xj1\" data-ci-target=\"examples\">Examples</button><button class=\"hotlinks-button css-1fvpz4m e4wg2xj1\" data-ci-target=\"wordOrigin\">Word Origin</button></div><div class=\"expand-container css-2h6jwx e1iplpfw0\"><div class=\"css-8lgfcg e1iplpfw1\"><section class=\"css-1sdcacc e10vl5dg0\"><header class=\"css-1y60q53 e10vl5dg1\"><span class=\"css-1pomevn e10vl5dg2\"></span></header><ol class=\"css-zw8qdz e10vl5dg3\"><li value=\"1\" class=\"css-2oywg7 e10vl5dg5\"><span class=\"one-click-content css-9sn2pa e10vl5dg6\"> <span class=\"luna-labset\"><span class=\"luna-label italic\">Genetics</span></span>. </span><span class=\"one-click-content css-9sn2pa e10vl5dg6\">deoxyribonucleic acid: an extremely long macromolecule that is the main component of chromosomes and is the material that transfers genetic characteristics in all life forms, constructed of two nucleotide strands coiled around each other in a ladderlike arrangement with the sidepieces composed of alternating phosphate and deoxyribose units and the rungs composed of the purine and pyrimidine bases adenine, guanine, cytosine, and thymine: the genetic information of DNA is encoded in the sequence of the bases and is transcribed as the strands unwind and replicate.</span><span class=\"one-click-content css-10rk44a e10vl5dg7\">Compare <a href=\"https://dictionary.com/browse/base-pair\" class=\"luna-xref\" data-linkid=\"nn1ov4\">base pair</a>, <a href=\"https://dictionary.com/browse/gene\" class=\"luna-xref\" data-linkid=\"nn1ov4\">gene</a>, <a href=\"https://dictionary.com/browse/genetic-code\" class=\"luna-xref\" data-linkid=\"nn1ov4\">genetic code</a>, <a href=\"https://dictionary.com/browse/rna\" class=\"luna-xref\" data-linkid=\"nn1ov4\">RNA</a>.</span></li><li value=\"2\" class=\"css-2oywg7 e10vl5dg5\"><span class=\"one-click-content css-9sn2pa e10vl5dg6\">the set of nongenetic traits, qualities, or features that characterize a person or thing: <span class=\"luna-example italic\">Humility is just not in her DNA.</span></span></li></ol></section></div><div class=\"expand-button-container css-grsm00 e1iplpfw2\"><button class=\"expand-button css-6d2nf9 e1iplpfw3\">Show More</button></div></div><section class=\"no-collapse css-hh4f95 e1eb38er0\"><aside class=\"css-6xt45o e1bbcgok0\"><a href=\"https://www.dictionary.com/e/\" data-linkid=\"2azoy5\" class=\"css-1pny6db e1bbcgok2\">Explore Dictionary.com</a><ul class=\"css-2vi8uw e1bbcgok1\"><li class=\"css-105pq9n e1ifcv6o0\"><a href=\"http://www.dictionary.com/e/s/10-weather-words-you-need-to-know/?param=DcomSERP-mid1\" data-linkid=\"b00rn2\" class=\"css-u1tqvs e1ifcv6o1\"><img src=\"//images.ctfassets.net/55tpbg0qcsp4/4Dv5jfCu1G0oA0K2mw62Ci/f990173542acb54b8af9156f20b3f959/weather_words_1000x700.jpg?w=284&amp;h=240\" alt=\"Weather Words You Need to Know\" class=\"css-8atqhb e1ifcv6o3\"/><span class=\"css-1fyr8sh e1ifcv6o2\">Weather Words You Need to Know</span></a></li><li class=\"css-105pq9n e1ifcv6o0\"><a href=\"https://www.dictionary.com/e/video/why-we-love-adding-emoji-to-dictionary/?param=DcomSERP-mid2\" data-linkid=\"ytn3fh\" class=\"css-u1tqvs e1ifcv6o1\"><img src=\"//images.ctfassets.net/55tpbg0qcsp4/4lkNvdcEb62AYAC0y6CQc4/27ccf91ff202a53f227d559dd54778aa/emoji_quotes3.jpg?w=284&amp;h=240\" alt=\"Can You Translate These Famous Phrases From Emoji?\" class=\"css-8atqhb e1ifcv6o3\"/><span class=\"css-1fyr8sh e1ifcv6o2\">Can You Translate These Famous Phrases From Emoji?</span></a></li><li class=\"css-105pq9n e1ifcv6o0\"><a href=\"http://www.dictionary.com/e/s/longest-english-words/?param=DcomSERP-mid3\" data-linkid=\"gdjn7o\" class=\"css-u1tqvs e1ifcv6o1\"><img src=\"//images.ctfassets.net/55tpbg0qcsp4/6Urum7wOdiGMGGQYeiaG6q/cf107f2f179af738b37e42ba83235c72/long_words3.jpg?w=284&amp;h=240\" alt=\"These Are the Longest Words in English\" class=\"css-8atqhb e1ifcv6o3\"/><span class=\"css-1fyr8sh e1ifcv6o2\">These Are the Longest Words in English</span></a></li><li class=\"css-105pq9n e1ifcv6o0\"><a href=\"https://www.dictionary.com/e/s/sad-words/?param=DcomSERP-mid4\" data-linkid=\"mxi818\" class=\"css-u1tqvs e1ifcv6o1\"><img src=\"//images.ctfassets.net/55tpbg0qcsp4/5ln7xDTo6QYiSaEisGcwcU/1b755ef15200d8ca49c9b1813a496dc8/saddest_words_1000x700.jpg?w=284&amp;h=240\" alt=\"These Are the Saddest Phrases in English\" class=\"css-8atqhb e1ifcv6o3\"/><span class=\"css-1fyr8sh e1ifcv6o2\">These Are the Saddest Phrases in English</span></a></li></ul></aside></section><section class=\"css-54ces9 e16svm7n0\"><h2 id=\"wordOrigin\" class=\"css-j3k4qp e1cxe2lc0\">Origin of <span class=\"css-1fxfie5 e1vvcl3c0\">DNA</span></h2><div class=\"one-click-content css-1jci32p e1iz2gwk0\"><span class=\"luna-date\">1930\\xe2\\x80\\x9335;</span> <span class=\"italic\">d(eoxyribo)n(ucleic)</span> <span class=\"italic\">a(cid)</span></div></section></section><div class=\"css-1yphgw4 ejtq9h60\">Dictionary.com Unabridged\\nBased on the Random House Unabridged Dictionary, \\xc2\\xa9 Random House, Inc. 2018</div><hr class=\"css-11r0tj9 etjs7ll0\"/><div class=\"css-1an5ojz e15p0a5t0\"><h2 class=\"css-1wj1ajw e1cxe2lc2\">Related Words for <!-- -->dna</h2><a href=\"/browse/heredity\" target=\"_blank\" data-linkid=\"ugrcqa\" class=\"css-ntz2ga e15p0a5t1\">heredity</a>, <a href=\"/browse/rna\" target=\"_blank\" data-linkid=\"ugrcqa\" class=\"css-ntz2ga e15p0a5t1\">RNA</a>, <a href=\"/browse/gene\" target=\"_blank\" data-linkid=\"ugrcqa\" class=\"css-ntz2ga e15p0a5t1\">gene</a>, <a href=\"/browse/chromosome\" target=\"_blank\" data-linkid=\"ugrcqa\" class=\"css-ntz2ga e15p0a5t1\">chromosome</a></div><hr class=\"css-11r0tj9 etjs7ll0\"/><section class=\"css-16b2ug3 e15kc6du0\"><h2 id=\"examples\" class=\"css-l7r0w2 e15kc6du3\">Examples from the Web for <!-- -->dna</h2><div data-linkid=\"fboxke\"><h3 class=\"css-12sy04c e15kc6du6\">Contemporary Examples<!-- --> of <!-- -->dna</h3><ul class=\"css-o9b79t e15kc6du4\"><li class=\"css-d2znx6 e15kc6du5\"><p class=\"one-click-content css-it69we e15kc6du7\"><span class=\"italic\">DNA</span> tests were used to confirm Albert\\'s status as father in both cases, following protracted legal battles.</p><div class=\"css-k008qs e15kc6du2\"><a href=\"https://thedailybeast.com/?source=dictionary\" rel=\"nofollow\"><img src=\"https://www.dictionary.com/assets/daily_beast_logo-5826abbaebfe092758106390ace3d904.png\" alt=\"The Daily Beast logo\" class=\"css-13aw141 e15kc6du8\"/></a><div><a href=\"http://www.thedailybeast.com/articles/2014/12/10/princess-charlene-gives-birth-to-twins-gabriella-and-jacques.html?source=dictionary\" rel=\"nofollow\" class=\"css-1ugobpn e15kc6du1\">Princess Charlene Gives Birth To Twins Gabriella and Jacques</a><p class=\"css-1ugobpn e15kc6du9\">Tom Sykes</p><p class=\"css-1ugobpn e15kc6du10\">December 10, 2014</p></div></div></li><li class=\"css-d2znx6 e15kc6du5\"><p class=\"one-click-content css-it69we e15kc6du7\">The at-home genetics testing company 23andme, established in 2006, helps people learn more about their \\xe2\\x80\\x9c<span class=\"italic\">DNA</span> relatives.\\xe2\\x80\\x9d</p><div class=\"css-k008qs e15kc6du2\"><a href=\"https://thedailybeast.com/?source=dictionary\" rel=\"nofollow\"><img src=\"https://www.dictionary.com/assets/daily_beast_logo-5826abbaebfe092758106390ace3d904.png\" alt=\"The Daily Beast logo\" class=\"css-13aw141 e15kc6du8\"/></a><div><a href=\"http://www.thedailybeast.com/articles/2014/12/08/nothing-says-i-love-you-like-data.html?source=dictionary\" rel=\"nofollow\" class=\"css-1ugobpn e15kc6du1\">Nothing Says I Love You Like Data</a><p class=\"css-1ugobpn e15kc6du9\">The Daily Beast</p><p class=\"css-1ugobpn e15kc6du10\">December 8, 2014</p></div></div></li><li class=\"css-d2znx6 e15kc6du5\"><p class=\"one-click-content css-it69we e15kc6du7\">The story (and some <span class=\"italic\">DNA</span> evidence) goes, the locals are the descendants of a band of Roman soldiers from 36 B.C.</p><div class=\"css-k008qs e15kc6du2\"><a href=\"https://thedailybeast.com/?source=dictionary\" rel=\"nofollow\"><img src=\"https://www.dictionary.com/assets/daily_beast_logo-5826abbaebfe092758106390ace3d904.png\" alt=\"The Daily Beast logo\" class=\"css-13aw141 e15kc6du8\"/></a><div><a href=\"http://www.thedailybeast.com/articles/2014/12/04/the-chinese-town-descended-from-romans.html?source=dictionary\" rel=\"nofollow\" class=\"css-1ugobpn e15kc6du1\">The Chinese Town Descended From Romans?</a><p class=\"css-1ugobpn e15kc6du9\">Nina Strochlic</p><p class=\"css-1ugobpn e15kc6du10\">December 4, 2014</p></div></div></li><li class=\"css-d2znx6 e15kc6du5\"><p class=\"one-click-content css-it69we e15kc6du7\">Still other media sources are reporting that the <span class=\"italic\">DNA</span> test is awaiting results.</p><div class=\"css-k008qs e15kc6du2\"><a href=\"https://thedailybeast.com/?source=dictionary\" rel=\"nofollow\"><img src=\"https://www.dictionary.com/assets/daily_beast_logo-5826abbaebfe092758106390ace3d904.png\" alt=\"The Daily Beast logo\" class=\"css-13aw141 e15kc6du8\"/></a><div><a href=\"http://www.thedailybeast.com/articles/2014/12/03/mystery-surrounds-the-arrest-of-wife-of-isis-s-top-leader.html?source=dictionary\" rel=\"nofollow\" class=\"css-1ugobpn e15kc6du1\">The ISIS Wife Swap Mystery</a><p class=\"css-1ugobpn e15kc6du9\">Jacob Siegel</p><p class=\"css-1ugobpn e15kc6du10\">December 3, 2014</p></div></div></li><li class=\"css-d2znx6 e15kc6du5\"><p class=\"one-click-content css-it69we e15kc6du7\">The loss of authenticity is equal to loss of the whole site as a cultural resource\\xe2\\x80\\x94its entire <span class=\"italic\">DNA</span> is altered.</p><div class=\"css-k008qs e15kc6du2\"><a href=\"https://thedailybeast.com/?source=dictionary\" rel=\"nofollow\"><img src=\"https://www.dictionary.com/assets/daily_beast_logo-5826abbaebfe092758106390ace3d904.png\" alt=\"The Daily Beast logo\" class=\"css-13aw141 e15kc6du8\"/></a><div><a href=\"http://www.thedailybeast.com/articles/2014/11/16/for-rent-priceless-historic-sites.html?source=dictionary\" rel=\"nofollow\" class=\"css-1ugobpn e15kc6du1\">For Rent: Priceless Historic Sites</a><p class=\"css-1ugobpn e15kc6du9\">Elinor Betesh</p><p class=\"css-1ugobpn e15kc6du10\">November 16, 2014</p></div></div></li></ul></div><div data-linkid=\"sl8bq9\"><h3 class=\"css-12sy04c e15kc6du6\">Historical Examples<!-- --> of <!-- -->dna</h3><ul class=\"css-o9b79t e15kc6du4\"><li class=\"css-d2znx6 e15kc6du5\"><p class=\"one-click-content css-it69we e15kc6du7\">Ruoy xis snisuoc emac ereh yadretsey, <span class=\"italic\">dna</span> dah hcae a eceip fo ekac.</p><div class=\"css-k008qs e15kc6du2\"><div><a href=\"http://www.gutenberg.org/files/42078/42078-h/42078-h.htm\" rel=\"nofollow\" class=\"css-1ugobpn e15kc6du1\">The Letters of Jane Austen</a><p class=\"css-1ugobpn e15kc6du9\">Jane Austen</p></div></div></li><li class=\"css-d2znx6 e15kc6du5\"><p class=\"one-click-content css-it69we e15kc6du7\">Siht si elttil Yssac\\'s yadhtrib, <span class=\"italic\">dna</span> ehs si eerht sraey dlo.</p><div class=\"css-k008qs e15kc6du2\"><div><a href=\"http://www.gutenberg.org/files/42078/42078-h/42078-h.htm\" rel=\"nofollow\" class=\"css-1ugobpn e15kc6du1\">The Letters of Jane Austen</a><p class=\"css-1ugobpn e15kc6du9\">Jane Austen</p></div></div></li><li class=\"css-d2znx6 e15kc6du5\"><p class=\"one-click-content css-it69we e15kc6du7\">The <span class=\"italic\">Dna</span> takes a westerly course towards the Gulf of Riga where it empties near the city of that name.</p><div class=\"css-k008qs e15kc6du2\"><div><a href=\"http://www.gutenberg.org/files/20880/20880-h/20880-h.htm\" rel=\"nofollow\" class=\"css-1ugobpn e15kc6du1\">The Story of Russia</a><p class=\"css-1ugobpn e15kc6du9\">R. Van Bergen, M.A.</p></div></div></li><li class=\"css-d2znx6 e15kc6du5\"><p class=\"one-click-content css-it69we e15kc6du7\">Another bishop sailed up the <span class=\"italic\">Dna</span> with a fleet of twenty-three ships, and in 1200 founded Riga.</p><div class=\"css-k008qs e15kc6du2\"><div><a href=\"http://www.gutenberg.org/files/20880/20880-h/20880-h.htm\" rel=\"nofollow\" class=\"css-1ugobpn e15kc6du1\">The Story of Russia</a><p class=\"css-1ugobpn e15kc6du9\">R. Van Bergen, M.A.</p></div></div></li><li class=\"css-d2znx6 e15kc6du5\"><p class=\"one-click-content css-it69we e15kc6du7\">The cup and foot are of agate, probably specimens of the classic period; the mounting, which dates from the time of <span class=\"italic\">Dna</span>.</p><div class=\"css-k008qs e15kc6du2\"><div><a href=\"http://www.gutenberg.org/files/39602/39602-h/39602-h.htm\" rel=\"nofollow\" class=\"css-1ugobpn e15kc6du1\">The Industrial Arts in Spain</a><p class=\"css-1ugobpn e15kc6du9\">Juan F. Riao</p></div></div></li></ul></div><hr class=\"css-11r0tj9 etjs7ll0\"/></section><section class=\"css-zuqhy e1013k4u0\">British Dictionary definitions for <!-- -->dna</section><section class=\"css-1nakkwx e1n8zibb0\"><section class=\"css-0 e1rg2mtf0\"><h2 class=\"css-urzbm0 e1rg2mtf5\">DNA</h2><div></div></section><div class=\"expand-container css-2h6jwx e1iplpfw0\"><div class=\"css-8lgfcg e1iplpfw1\"><section class=\"css-1sdcacc e10vl5dg0\"><header class=\"css-1y60q53 e10vl5dg1\"><span class=\"css-1pomevn e10vl5dg2\"><span class=\"pos\">noun</span></span></header><ol class=\"css-zw8qdz e10vl5dg3\"><li value=\"1\" class=\"css-2oywg7 e10vl5dg5\"><span class=\"one-click-content css-9sn2pa e10vl5dg6\">deoxyribonucleic acid; a nucleic acid that is the main constituent of the chromosomes of all organisms (except some viruses). The DNA molecule consists of two polynucleotide chains in the form of a double helix, containing phosphate and the sugar deoxyribose and linked by hydrogen bonds between the complementary bases adenine and thymine or cytosine and guanine. DNA is self-replicating, plays a central role in protein synthesis, and is responsible for the transmission of hereditary characteristics from parents to offspring</span><span class=\"one-click-content css-10rk44a e10vl5dg7\">See also <a href=\"https://dictionary.com/browse/genetic-code\" class=\"xref\" data-linkid=\"nn1ov4\">genetic code</a></span></li></ol></section></div><div class=\"expand-button-container css-grsm00 e1iplpfw2\"><button class=\"expand-button css-6d2nf9 e1iplpfw3\">Show More</button></div></div><div class=\"expand-container css-2h6jwx e1iplpfw0\"><div class=\"css-8lgfcg e1iplpfw1\"><section class=\"css-1sdcacc e10vl5dg0\"><header class=\"css-1y60q53 e10vl5dg1\"><span class=\"css-1pomevn e10vl5dg2\"><span class=\"pos\">abbreviation for</span></span></header><ol class=\"css-zw8qdz e10vl5dg3\"><li value=\"2\" class=\"css-2oywg7 e10vl5dg5\"><span class=\"one-click-content css-9sn2pa e10vl5dg6\">did not attend</span></li></ol></section></div><div class=\"expand-button-container css-grsm00 e1iplpfw2\"><button class=\"expand-button css-6d2nf9 e1iplpfw3\">Show More</button></div></div></section><div class=\"css-1yphgw4 ejtq9h60\">Collins English Dictionary - Complete &amp; Unabridged 2012 Digital Edition \\n\\xc2\\xa9 William Collins Sons &amp; Co. Ltd. 1979, 1986 \\xc2\\xa9 HarperCollins \\nPublishers 1998, 2000, 2003, 2005, 2006, 2007, 2009, 2012</div><hr class=\"css-11r0tj9 etjs7ll0\"/><section class=\"css-i3pbo e8i5ajd0\"><h2 class=\"css-1wj1ajw e1cxe2lc2\">Word Origin and History for<!-- --> <span class=\"css-1fxfie5 e1vvcl3c0\">dna</span></h2><section class=\"css-i3pbo e8i5ajd0\"><h2 class=\"css-urzbm0 e1rg2mtf5\">DNA</h2><div><div class=\"expand-container css-2h6jwx e1iplpfw0\"><div class=\"css-8lgfcg e1iplpfw1\"><section class=\"css-k59p8l ehevz040\"><span class=\"css-utybho ehevz045\">n.</span><p class=\"one-click-content css-mgww5h ehevz041\">1944, abbreviation of <span class=\"italic\">d</span>eoxy<span class=\"italic\">r</span>ibonucleic <span class=\"italic\">a</span>cid (1931).</p></section></div><div class=\"expand-button-container css-grsm00 e1iplpfw2\"><button class=\"expand-button css-6d2nf9 e1iplpfw3\">Show More</button></div></div></div></section><div class=\"css-1yphgw4 ejtq9h60\">Online Etymology Dictionary, \\xc2\\xa9 2010 Douglas Harper</div><hr class=\"css-11r0tj9 etjs7ll0\"/></section><section class=\"css-i3pbo e8i5ajd0\"><section class=\"css-zuqhy e1013k4u0\">dna<!-- --> in Medicine</section><h2 class=\"css-urzbm0 e1rg2mtf5\">DNA</h2><span class=\"css-1khtv86 e1rg2mtf2\">(d\\xc4\\x93\\xe2\\x80\\xb2\\xc4\\x95n-\\xc4\\x81<span class=\"rich-text bold\">\\xe2\\x80\\xb2</span>)</span><div class=\"expand-container css-2h6jwx e1iplpfw0\"><div class=\"css-8lgfcg e1iplpfw1\"><section class=\"css-1sdcacc e10vl5dg0\"><header class=\"css-1y60q53 e10vl5dg1\"><span class=\"css-1pomevn e10vl5dg2\"><span class=\"pos\">n.</span></span></header><ol class=\"css-zw8qdz e10vl5dg3\"><li class=\"css-2oywg7 e10vl5dg5\"><span class=\"one-click-content css-9sn2pa e10vl5dg6\"><span class=\"tx\">Deoxyribonucleic acid; a nucleic acid that consists of two long chains of nucleotides twisted together into a double helix and joined by hydrogen bonds between complementary bases adenine and thymine or cytosine and guanine; it carries the cell\\'s genetic information and hereditary characteristics via its nucleotides and their sequence and is capable of self-replication and RNA synthesis.</span></span></li></ol></section></div><div class=\"expand-button-container css-grsm00 e1iplpfw2\"><button class=\"expand-button css-6d2nf9 e1iplpfw3\">Show More</button></div></div><div class=\"css-1yphgw4 ejtq9h60\">The American Heritage\\xc2\\xae Stedman&#x27;s Medical Dictionary \\n Copyright \\xc2\\xa9 2002, 2001, 1995 by Houghton Mifflin Company. Published by Houghton Mifflin Company.</div><hr class=\"css-11r0tj9 etjs7ll0\"/></section><section class=\"css-i3pbo e8i5ajd0\"><section class=\"css-zuqhy e1013k4u0\">dna<!-- --> in Science</section><section><section class=\"css-0 e1rg2mtf0\"><h2 class=\"css-urzbm0 e1rg2mtf5\">DNA</h2><span class=\"audio-wrapper\"><span data-ci-target=\"audio\" class=\"css-17dkd7s e1rg2mtf4\"></span><audio><source src=\"https://static.sfdict.com/content-assets/science/audio/ogg/D0311200.ogg\" type=\"audio/ogg\"/><source src=\"https://static.sfdict.com/content-assets/science/audio/mp3/D0311200.mp3\" type=\"audio/mpeg\"/><source src=\"https://static.sfdict.com/content-assets/science/audio/wav/D0311200.wav\" type=\"audio/wav\"/></audio></span><div><span class=\"css-1khtv86 e1rg2mtf2\">[d\\xc4\\x93\\xe2\\x80\\xb2\\xc4\\x95n-\\xc4\\x81<span class=\"rich-text bold\">\\xe2\\x80\\xb2</span>]</span></div></section><div class=\"expand-container css-2h6jwx e1iplpfw0\"><div class=\"css-8lgfcg e1iplpfw1\"><section class=\"css-1sdcacc e10vl5dg0\"><header class=\"css-1y60q53 e10vl5dg1\"><span class=\"css-1pomevn e10vl5dg2\"></span></header><ol class=\"css-zw8qdz e10vl5dg3\"><li class=\"css-2oywg7 e10vl5dg5\"><span class=\"one-click-content css-9sn2pa e10vl5dg6\"><span class=\"definition\"><span class=\"deftx\"><span class=\"tx\">Short for <span class=\"rich-text italic\">deoxyribonucleic acid.</span> The nucleic acid that is the genetic material determining the makeup of all living cells and many viruses. It consists of two long strands of nucleotides linked together in a structure resembling a ladder twisted into a spiral. In eukaryotic cells, the DNA is contained in the nucleus (where it is bound to proteins known as histones) and in mitochondria and chloroplasts. In the presence of the enzyme DNA polymerase and appropriate nucleotides, DNA can replicate itself. DNA also serves as a template for the synthesis of RNA in the presence of RNA polymerase.</span></span><span class=\"ref ref-comp\"><span class=\"ld\"> Compare </span> <span class=\"kw\">RNA</span>.</span><span class=\"ref ref-n\"><span class=\"ld\"> See Note at </span> <span class=\"kw\">histone</span>.</span></span></span></li></ol></section></div><div class=\"expand-button-container css-grsm00 e1iplpfw2\"><button class=\"expand-button css-6d2nf9 e1iplpfw3\">Show More</button></div></div></section><div class=\"css-1yphgw4 ejtq9h60\">The American Heritage\\xc2\\xae Science Dictionary \\n Copyright \\xc2\\xa9 2011. Published by Houghton Mifflin Harcourt Publishing Company. All rights reserved.</div><hr class=\"css-11r0tj9 etjs7ll0\"/></section><section class=\"css-i3pbo e8i5ajd0\"><section class=\"css-zuqhy e1013k4u0\">dna<!-- --> in Culture</section><section><section class=\"css-0 e1rg2mtf0\"><h2 class=\"css-urzbm0 e1rg2mtf5\">DNA</h2><div></div></section><section class=\"css-i3pbo e8i5ajd0\"><div><div class=\"expand-container css-2h6jwx e1iplpfw0\"><div class=\"css-8lgfcg e1iplpfw1\"><section class=\"css-k59p8l ehevz040\"><p class=\"one-click-content css-mgww5h ehevz041\">The <a href=\"https://dictionary.com/browse/molecule\" class=\"luna-xref\" data-linkid=\"nn1ov4\">molecule</a> that carries genetic information in all living systems (<span class=\"italic\">see</span> <a href=\"https://dictionary.com/browse/genetic-code\" class=\"luna-xref\" data-linkid=\"nn1ov4\">genetic code</a>). The DNA molecule is formed in the shape of a <a href=\"https://dictionary.com/browse/double-helix\" class=\"luna-xref\" data-linkid=\"nn1ov4\">double helix</a> from a great number of smaller molecules (<span class=\"italic\">see</span> <a href=\"https://dictionary.com/browse/nucleotides\" class=\"luna-xref\" data-linkid=\"nn1ov4\">nucleotides</a>). The workings of the DNA molecule provide the most fundamental explanation of the laws of <a href=\"https://dictionary.com/browse/genetics\" class=\"luna-xref\" data-linkid=\"nn1ov4\">genetics</a>.</p><p class=\"one-click-content css-mgww5h ehevz041\">DNA acts in three important way. First, when a <a href=\"https://dictionary.com/browse/cell\" class=\"luna-xref\" data-linkid=\"nn1ov4\">cell</a> divides, the DNA uncoils, and each strand creates a new partner from the surrounding material \\xe2\\x80\\x94 a process called replication. The two cells that result from the cell division have the same DNA as the original (<span class=\"italic\">see</span> <a href=\"https://dictionary.com/browse/mitosis\" class=\"luna-xref\" data-linkid=\"nn1ov4\">mitosis</a>). Second, in <a href=\"https://dictionary.com/browse/sexual-reproduction\" class=\"luna-xref\" data-linkid=\"nn1ov4\">sexual reproduction</a>, each parent contributes one of the two strands in the DNA of the offspring. Third, inside the cell, the DNA governs the production of <a href=\"https://dictionary.com/browse/proteins\" class=\"luna-xref\" data-linkid=\"nn1ov4\">proteins</a> and other molecules essential to cell function.</p></section></div><div class=\"expand-button-container css-grsm00 e1iplpfw2\"><button class=\"expand-button css-6d2nf9 e1iplpfw3\">Show More</button></div></div></div></section></section><div class=\"css-1yphgw4 ejtq9h60\">The New Dictionary of Cultural Literacy, Third Edition \\nCopyright \\xc2\\xa9 2005 by Houghton Mifflin Harcourt Publishing Company. Published by Houghton Mifflin Harcourt Publishing Company. All rights reserved.</div></section></section><aside class=\"css-19a7eo8 e1su27ci0\"><aside class=\"css-6xt45o e1bbcgok0\"><a href=\"https://www.dictionary.com/e/\" data-linkid=\"lcs15a\" class=\"css-1pny6db e1bbcgok2\">Others Are Reading</a><ul class=\"css-1h3udqp e1bbcgok1\"><li class=\"css-105pq9n e1ifcv6o0\"><a href=\"https://www.dictionary.com/e/mistrust-vs-distrust/?param=DcomSERP-RR1\" data-linkid=\"m9a2e2\" class=\"css-u1tqvs e1ifcv6o1\"><img src=\"//images.ctfassets.net/55tpbg0qcsp4/5CGuTH7Jq8M6seWye2k6w2/38f7aa6e3edf2c39b460788c500d993e/this-or-that_v3_1000x700.jpg?w=284&amp;h=240\" alt=\"We&#x27;re about to solve one of the great mysteries of the English language. Are you ready?\" class=\"css-8atqhb e1ifcv6o3\"/><span class=\"css-1fyr8sh e1ifcv6o2\">We&#x27;re about to solve one of the great mysteries of the English language. Are you ready?</span></a></li><li class=\"css-105pq9n e1ifcv6o0\"><a href=\"https://www.dictionary.com/e/s/umwords/?param=DcomSERP-RR2\" data-linkid=\"r0eap9\" class=\"css-u1tqvs e1ifcv6o1\"><img src=\"//images.ctfassets.net/55tpbg0qcsp4/6XApkF1320sICSogS4ouUg/a63c431dfd27370261d90c1cf66a479d/Avoid_boy_1000x700.jpg?w=284&amp;h=240\" alt=\"Avoid these words. Seriously.\" class=\"css-8atqhb e1ifcv6o3\"/><span class=\"css-1fyr8sh e1ifcv6o2\">Avoid these words. Seriously.</span></a></li></ul></aside><aside class=\"no-collapse css-pb859s eanayw60\" id=\"dcom-serp-a-top-300x250\"><script>if (window.googletag) {googletag.cmd.push(function() { googletag.display(\\'dcom-serp-a-top-300x250\\'); });} else {console.error(\\'googletag not defined, dcom-serp-a-top-300x250\\');}</script></aside><aside class=\"css-1q7njkh e1ywvkmy0\"><h3 class=\"css-1675y43 e1ywvkmy4\"><span class=\"css-1dqz0ff e1ywvkmy1\"></span>Word of the Day</h3><div data-linkid=\"rpilnc\" class=\"css-5w0xmi e1ywvkmy2\"><a href=\"http://www.dictionary.com/wordoftheday/\" class=\"css-gb8pey e1ywvkmy3\">univocal</a></div><span class=\"audio-wrapper\"><span data-ci-target=\"audio\" class=\"css-17dkd7s e1rg2mtf4\"></span><audio><source src=\"https://static.sfdict.com/audio/U00/U0097800.mp3\"/></audio></span></aside><div class=\"css-1upilqn e1su27ci1\"><aside class=\"css-6xt45o e1bbcgok0\"><ul class=\"css-1ok7jrf e1bbcgok1\"><li class=\"css-105pq9n e1ifcv6o0\"><a href=\"https://www.dictionary.com/e/video/people-always-say-wrong/?param=dcomserp-rr3\" data-linkid=\"mw8sx6\" class=\"css-u1tqvs e1ifcv6o1\"><img src=\"//images.ctfassets.net/55tpbg0qcsp4/4vhlY8TonmwOiIe6yeuWyC/e9175e33d87495ec8734d4b669f29950/words-1000x700.jpg?w=284&amp;h=240\" alt=\"Words We Get Wrong: How Many of These Can You Say?\" class=\"css-8atqhb e1ifcv6o3\"/><span class=\"css-1fyr8sh e1ifcv6o2\">Words We Get Wrong: How Many of These Can You Say?</span></a></li></ul></aside></div><aside class=\"css-6xt45o e1bbcgok0\"><ul class=\"css-1ok7jrf e1bbcgok1\"><li class=\"css-105pq9n e1ifcv6o0\"><a href=\"http://www.dictionary.com/e/video/did-you-know-real-people-write-the-dictionary/?param=DcomSERP-RR4\" data-linkid=\"nfcsuc\" class=\"css-u1tqvs e1ifcv6o1\"><img src=\"//images.ctfassets.net/55tpbg0qcsp4/41Y5hDzl6MCwcaaAWoMMkK/624868c1965c24df5c81e0f0be3d9654/AskALexicographer_1000x700.jpg?w=284&amp;h=240\" alt=\"Did You Know Real People Write the Dictionary?\" class=\"css-8atqhb e1ifcv6o3\"/><span class=\"css-1fyr8sh e1ifcv6o2\">Did You Know Real People Write the Dictionary?</span></a></li></ul></aside><aside class=\"no-collapse css-pb859s eanayw60\" id=\"dcom-serp-a-mid-300x250\"><script>if (window.googletag) {googletag.cmd.push(function() { googletag.display(\\'dcom-serp-a-mid-300x250\\'); });} else {console.error(\\'googletag not defined, dcom-serp-a-mid-300x250\\');}</script></aside></aside></section><aside class=\"no-collapse css-o2gk28 eanayw60\" id=\"dcom-serp-bottom-lb-728x90\"><script>if (window.googletag) {googletag.cmd.push(function() { googletag.display(\\'dcom-serp-bottom-lb-728x90\\'); });} else {console.error(\\'googletag not defined, dcom-serp-bottom-lb-728x90\\');}</script></aside></main></div></div></div><footer class=\"css-1rn3crn esk3ouk0\"><div class=\"css-1tj1foj esk3ouk1\"><div class=\"css-a50h34 esk3ouk5\"><ul class=\"css-19sw9w4 emmj7sa0\"><span class=\"css-1r0i7sq emmj7sa1\">Browse the <!-- -->Dictionary<!-- -->:</span><li class=\"css-603c4d emmj7sa2\"><a href=\"/list/0/1\" class=\"css-1xa4729 emmj7sa3\">#</a></li><li class=\"css-603c4d emmj7sa2\"><a href=\"/list/a/1\" class=\"css-1xa4729 emmj7sa3\">A</a></li><li class=\"css-603c4d emmj7sa2\"><a href=\"/list/b/1\" class=\"css-1xa4729 emmj7sa3\">B</a></li><li class=\"css-603c4d emmj7sa2\"><a href=\"/list/c/1\" class=\"css-1xa4729 emmj7sa3\">C</a></li><li class=\"css-603c4d emmj7sa2\"><a href=\"/list/d/1\" class=\"css-1xa4729 emmj7sa3\">D</a></li><li class=\"css-603c4d emmj7sa2\"><a href=\"/list/e/1\" class=\"css-1xa4729 emmj7sa3\">E</a></li><li class=\"css-603c4d emmj7sa2\"><a href=\"/list/f/1\" class=\"css-1xa4729 emmj7sa3\">F</a></li><li class=\"css-603c4d emmj7sa2\"><a href=\"/list/g/1\" class=\"css-1xa4729 emmj7sa3\">G</a></li><li class=\"css-603c4d emmj7sa2\"><a href=\"/list/h/1\" class=\"css-1xa4729 emmj7sa3\">H</a></li><li class=\"css-603c4d emmj7sa2\"><a href=\"/list/i/1\" class=\"css-1xa4729 emmj7sa3\">I</a></li><li class=\"css-603c4d emmj7sa2\"><a href=\"/list/j/1\" class=\"css-1xa4729 emmj7sa3\">J</a></li><li class=\"css-603c4d emmj7sa2\"><a href=\"/list/k/1\" class=\"css-1xa4729 emmj7sa3\">K</a></li><li class=\"css-603c4d emmj7sa2\"><a href=\"/list/l/1\" class=\"css-1xa4729 emmj7sa3\">L</a></li><li class=\"css-603c4d emmj7sa2\"><a href=\"/list/m/1\" class=\"css-1xa4729 emmj7sa3\">M</a></li><li class=\"css-603c4d emmj7sa2\"><a href=\"/list/n/1\" class=\"css-1xa4729 emmj7sa3\">N</a></li><li class=\"css-603c4d emmj7sa2\"><a href=\"/list/o/1\" class=\"css-1xa4729 emmj7sa3\">O</a></li><li class=\"css-603c4d emmj7sa2\"><a href=\"/list/p/1\" class=\"css-1xa4729 emmj7sa3\">P</a></li><li class=\"css-603c4d emmj7sa2\"><a href=\"/list/q/1\" class=\"css-1xa4729 emmj7sa3\">Q</a></li><li class=\"css-603c4d emmj7sa2\"><a href=\"/list/r/1\" class=\"css-1xa4729 emmj7sa3\">R</a></li><li class=\"css-603c4d emmj7sa2\"><a href=\"/list/s/1\" class=\"css-1xa4729 emmj7sa3\">S</a></li><li class=\"css-603c4d emmj7sa2\"><a href=\"/list/t/1\" class=\"css-1xa4729 emmj7sa3\">T</a></li><li class=\"css-603c4d emmj7sa2\"><a href=\"/list/u/1\" class=\"css-1xa4729 emmj7sa3\">U</a></li><li class=\"css-603c4d emmj7sa2\"><a href=\"/list/v/1\" class=\"css-1xa4729 emmj7sa3\">V</a></li><li class=\"css-603c4d emmj7sa2\"><a href=\"/list/w/1\" class=\"css-1xa4729 emmj7sa3\">W</a></li><li class=\"css-603c4d emmj7sa2\"><a href=\"/list/x/1\" class=\"css-1xa4729 emmj7sa3\">X</a></li><li class=\"css-603c4d emmj7sa2\"><a href=\"/list/y/1\" class=\"css-1xa4729 emmj7sa3\">Y</a></li><li class=\"css-603c4d emmj7sa2\"><a href=\"/list/z/1\" class=\"css-1xa4729 emmj7sa3\">Z</a></li></ul><ul class=\"css-19sw9w4 emmj7sa0\"><span class=\"css-1r0i7sq emmj7sa1\">Browse by Category:</span><li class=\"css-13gnrtg emmj7sa2\"><a href=\"https://www.dictionary.com/e/list/slang/1\" class=\"css-1xa4729 emmj7sa3\">Slang</a></li><li class=\"css-13gnrtg emmj7sa2\"><a href=\"https://www.dictionary.com/e/list/emoji/1\" class=\"css-1xa4729 emmj7sa3\">Emoji</a></li><li class=\"css-13gnrtg emmj7sa2\"><a href=\"https://www.dictionary.com/e/list/acronyms/1\" class=\"css-1xa4729 emmj7sa3\">Acronyms</a></li><li class=\"css-13gnrtg emmj7sa2\"><a href=\"https://www.dictionary.com/e/list/pop-culture/1\" class=\"css-1xa4729 emmj7sa3\">Pop Culture</a></li><li class=\"css-13gnrtg emmj7sa2\"><a href=\"https://www.dictionary.com/e/list/more/1\" class=\"css-1xa4729 emmj7sa3\">More</a></li></ul></div><ul class=\"css-13h1p65 esk3ouk2\"><li class=\"css-13s85fp esk3ouk3\"><a href=\"https://www.dictionary.com/e/about/\" data-linkid=\"gy27eg\" id=\"about-click\" class=\"css-16ob2z7 esk3ouk4\">About</a></li><li class=\"css-13s85fp esk3ouk3\"><a class=\"css-16ob2z7 esk3ouk4\">|</a></li><li class=\"css-13s85fp esk3ouk3\"><a href=\"https://www.dictionary.com/e/terms/\" data-linkid=\"gy27eg\" id=\"termAndPrivacy-click\" class=\"css-16ob2z7 esk3ouk4\">Cookies, Terms, &amp; Privacy</a></li></ul><div>\\xc2\\xa9 2018 Dictionary.com, LLC</div></div></footer></div></div></div>\\n        <script>window.ANALYTICS = {\"siteName\":\"dict\",\"trackURL\":\"https:\\\\u002F\\\\u002Ftrack.dictionary.com\\\\u002Fmain.gif\",\"thesaurusSpanIdUrl\":\"https:\\\\u002F\\\\u002Fspanids.thesaurus.com\\\\u002F\",\"ab\":\"0\",\"platform\":\"Desktop\"};</script>\\n        <script>window.ENV_VARS = {\"dev\":false,\"test\":false,\"prod\":true,\"noReact\":\"true\",\"SERVER_CONTENT_TIMEOUT_DESKTOP\":0,\"CLIENT_CONTENT_TIMEOUT_DESKTOP\":0,\"SERVER_CONTENT_TIMEOUT_MOBILE\":1000,\"CLIENT_CONTENT_TIMEOUT_MOBILE\":1000,\"CLIENT_TRANSITION_MASK_DESKTOP\":false,\"CLIENT_TRANSITION_MASK_MOBILE\":true,\"PROTOCOL\":\"https\",\"TRACKING_URL\":\"https:\\\\u002F\\\\u002Ftrack.dictionary.com\\\\u002Fmain.gif\",\"UPGRADE_INSECURE_REQUESTS\":true,\"THESAURUS_SPANID_URL\":\"https:\\\\u002F\\\\u002Fspanids.thesaurus.com\\\\u002F\",\"TEST_AD_TYPE_TOGGLE\":false,\"DCOM_URL\":\"www.dictionary.com\",\"TCOM_URL\":\"www.thesaurus.com\",\"ALLOW_DISABLED_ADS\":false,\"DCOM_CONTENT_API_ENDPOINT\":\"https:\\\\u002F\\\\u002Fapi-portal.dictionary.com\\\\u002Fdcom\\\\u002FpageData\",\"SPELL_SUGGESTIONS_API_ENDPOINT\":\"https:\\\\u002F\\\\u002Fapi-portal.dictionary.com\\\\u002FspellSuggestions\",\"EDITORIAL_API_ENDPOINT\":\"https:\\\\u002F\\\\u002Feditorial-content-feed.dictionary.com\\\\u002Fdcomserp\",\"WOTD_API_ENDPOINT\":\"https:\\\\u002F\\\\u002Frestcdn.dictionary.com\\\\u002Fv2\\\\u002Fwordoftheday.json?api_key=KgprXEYKVnNSFSZ\",\"EXAMPLE_SENTENCES_API_ENDPOINT\":\"https:\\\\u002F\\\\u002Fapi-portal.dictionary.com\\\\u002FexampleSentencesBySource\",\"NEARBY_WORDS_API_ENDPOINT\":\"https:\\\\u002F\\\\u002Fapi-portal.dictionary.com\\\\u002Fdcom\\\\u002FnearbyWords\",\"RELATED_WORDS_API_ENDPOINT\":\"https:\\\\u002F\\\\u002Fapi-portal.dictionary.com\\\\u002Fdcom\\\\u002Fsynonyms\",\"PUBLIC_ASSETS_URL\":\"https:\\\\u002F\\\\u002Fwww.dictionary.com\\\\u002Fassets\",\"RTF_API_ENDPOINT\":\"https:\\\\u002F\\\\u002Firene.dictionary.com\\\\u002Fv1\",\"SERVER_LOGGING_LEVEL\":\"error\",\"CLIENT_LOGGING_LEVEL\":\"error\",\"API_REQUEST_LOGGING_LEVEL\":\"info\",\"RTF_FEATURE_ENABLED\":\"true\"};</script>\\n        <script>window.INITIAL_STATE = {\"searchData\":{\"searchTerm\":\"dna\",\"pageName\":\"browse\"},\"detectedDevice\":{\"isMobile\":false}};</script>\\n        \\n      </body>\\n    </html>'"
      ]
     },
     "execution_count": 15,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "dna_search = requests.get('https://dictionary.com/browse/DNA')\n",
    "dna_search.content"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 16,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/plain": [
       "''"
      ]
     },
     "execution_count": 16,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "dictionary_search('biology')"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 17,
   "metadata": {},
   "outputs": [],
   "source": [
    "# Perhaps we can fix it\n",
    "def dictionary_search(word):\n",
    "    url = 'https://dictionary.com/browse/' + word\n",
    "    response = requests.get(url)\n",
    "    start = response.text.find(word)\n",
    "    finish = response.text.find(' See more')\n",
    "    definition = response.text[start:finish]\n",
    "    return definition"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 18,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/plain": [
       "''"
      ]
     },
     "execution_count": 18,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "dictionary_search('DNA')\n",
    "dictionary_search('biology')"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "slideshow": {
     "slide_type": "slide"
    }
   },
   "source": [
    "# API\n",
    "* Application Programming Interface\n",
    "* Web API\n",
    "* XML/JSON\n",
    "* Much easier to use than scraping"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "# JSON\n",
    "* Java Script Object Notation\n",
    "* Similar to Python dictionaries\n",
    "* Key/Value store\n",
    "* Incredibly common data interchange format on the web and elsewhere"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 19,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/plain": [
       "'{\"gene_name\": \"BRAF\"}'"
      ]
     },
     "execution_count": 19,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "import json\n",
    "data = {'gene_name': 'BRAF'}\n",
    "json.dumps(data)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 20,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/plain": [
       "'{\"gene_name\": \"BRAF\", \"patient_count\": 3}'"
      ]
     },
     "execution_count": 20,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "data['patient_count'] = 3\n",
    "json.dumps(data)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 21,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/plain": [
       "'{\"gene_name\": \"BRAF\", \"patient_count\": 3, \"is_alive\": true}'"
      ]
     },
     "execution_count": 21,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "data['is_alive'] = True\n",
    "json.dumps(data)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 22,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/plain": [
       "'{\"gene_name\": \"BRAF\", \"patient_count\": 3, \"is_alive\": true, \"phone_number\": null}'"
      ]
     },
     "execution_count": 22,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "data['phone_number'] = None\n",
    "json.dumps(data)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 23,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/plain": [
       "'{\"gene_name\": \"BRAF\", \"patient_count\": 3, \"is_alive\": true, \"phone_number\": null, \"more_data\": {}}'"
      ]
     },
     "execution_count": 23,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "data['more_data'] = {}\n",
    "json.dumps(data)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 24,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/plain": [
       "'[{\"gene_name\": \"BRAF\", \"patient_count\": 3, \"is_alive\": true, \"phone_number\": null, \"more_data\": {}}, 1]'"
      ]
     },
     "execution_count": 24,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "data_table = [data, 1]\n",
    "json.dumps(data_table)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 25,
   "metadata": {},
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "{'gene_name': 'BRAF'}\n"
     ]
    },
    {
     "data": {
      "text/plain": [
       "dict"
      ]
     },
     "execution_count": 25,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "input_data = json.loads('{\"gene_name\": \"BRAF\"}')\n",
    "print(input_data)\n",
    "type(input_data)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "https://mygene.info"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 26,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/plain": [
       "{'max_score': 435.33853,\n",
       " 'took': 11,\n",
       " 'total': 386,\n",
       " 'hits': [{'_id': '673',\n",
       "   '_score': 435.33853,\n",
       "   'entrezgene': '673',\n",
       "   'name': 'B-Raf proto-oncogene, serine/threonine kinase',\n",
       "   'symbol': 'BRAF',\n",
       "   'taxid': 9606},\n",
       "  {'_id': '109880',\n",
       "   '_score': 358.14212,\n",
       "   'entrezgene': '109880',\n",
       "   'name': 'Braf transforming gene',\n",
       "   'symbol': 'Braf',\n",
       "   'taxid': 10090},\n",
       "  {'_id': '114486',\n",
       "   '_score': 309.06714,\n",
       "   'entrezgene': '114486',\n",
       "   'name': 'B-Raf proto-oncogene, serine/threonine kinase',\n",
       "   'symbol': 'Braf',\n",
       "   'taxid': 10116},\n",
       "  {'_id': '112945628',\n",
       "   '_score': 285.43057,\n",
       "   'entrezgene': '112945628',\n",
       "   'name': 'B-Raf proto-oncogene, serine/threonine kinase',\n",
       "   'symbol': 'BRAF',\n",
       "   'taxid': 30464},\n",
       "  {'_id': '109296160',\n",
       "   '_score': 285.43057,\n",
       "   'entrezgene': '109296160',\n",
       "   'name': 'B-Raf proto-oncogene, serine/threonine kinase',\n",
       "   'symbol': 'BRAF',\n",
       "   'taxid': 94835},\n",
       "  {'_id': '103769301',\n",
       "   '_score': 285.43057,\n",
       "   'entrezgene': '103769301',\n",
       "   'name': 'B-Raf proto-oncogene, serine/threonine kinase',\n",
       "   'symbol': 'BRAF',\n",
       "   'taxid': 57421},\n",
       "  {'_id': '100219601',\n",
       "   '_score': 285.43057,\n",
       "   'entrezgene': '100219601',\n",
       "   'name': 'B-Raf proto-oncogene, serine/threonine kinase',\n",
       "   'symbol': 'BRAF',\n",
       "   'taxid': 59729},\n",
       "  {'_id': '104629609',\n",
       "   '_score': 285.43057,\n",
       "   'entrezgene': '104629609',\n",
       "   'name': 'B-Raf proto-oncogene, serine/threonine kinase',\n",
       "   'symbol': 'BRAF',\n",
       "   'taxid': 100784},\n",
       "  {'_id': '110394457',\n",
       "   '_score': 285.43057,\n",
       "   'entrezgene': '110394457',\n",
       "   'name': 'B-Raf proto-oncogene, serine/threonine kinase',\n",
       "   'symbol': 'BRAF',\n",
       "   'taxid': 8996},\n",
       "  {'_id': '100934801',\n",
       "   '_score': 285.43057,\n",
       "   'entrezgene': '100934801',\n",
       "   'name': 'B-Raf proto-oncogene, serine/threonine kinase',\n",
       "   'symbol': 'BRAF',\n",
       "   'taxid': 9305}]}"
      ]
     },
     "execution_count": 26,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "query = {'q': 'BRAF'}\n",
    "response = requests.get('http://mygene.info/v3/query', params=query)\n",
    "braf_data = response.json()\n",
    "braf_data"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 27,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/plain": [
       "[{'_id': '673',\n",
       "  '_score': 435.33853,\n",
       "  'entrezgene': '673',\n",
       "  'name': 'B-Raf proto-oncogene, serine/threonine kinase',\n",
       "  'symbol': 'BRAF',\n",
       "  'taxid': 9606},\n",
       " {'_id': '109880',\n",
       "  '_score': 358.14212,\n",
       "  'entrezgene': '109880',\n",
       "  'name': 'Braf transforming gene',\n",
       "  'symbol': 'Braf',\n",
       "  'taxid': 10090},\n",
       " {'_id': '114486',\n",
       "  '_score': 309.06714,\n",
       "  'entrezgene': '114486',\n",
       "  'name': 'B-Raf proto-oncogene, serine/threonine kinase',\n",
       "  'symbol': 'Braf',\n",
       "  'taxid': 10116},\n",
       " {'_id': '112945628',\n",
       "  '_score': 285.43057,\n",
       "  'entrezgene': '112945628',\n",
       "  'name': 'B-Raf proto-oncogene, serine/threonine kinase',\n",
       "  'symbol': 'BRAF',\n",
       "  'taxid': 30464},\n",
       " {'_id': '109296160',\n",
       "  '_score': 285.43057,\n",
       "  'entrezgene': '109296160',\n",
       "  'name': 'B-Raf proto-oncogene, serine/threonine kinase',\n",
       "  'symbol': 'BRAF',\n",
       "  'taxid': 94835},\n",
       " {'_id': '103769301',\n",
       "  '_score': 285.43057,\n",
       "  'entrezgene': '103769301',\n",
       "  'name': 'B-Raf proto-oncogene, serine/threonine kinase',\n",
       "  'symbol': 'BRAF',\n",
       "  'taxid': 57421},\n",
       " {'_id': '100219601',\n",
       "  '_score': 285.43057,\n",
       "  'entrezgene': '100219601',\n",
       "  'name': 'B-Raf proto-oncogene, serine/threonine kinase',\n",
       "  'symbol': 'BRAF',\n",
       "  'taxid': 59729},\n",
       " {'_id': '104629609',\n",
       "  '_score': 285.43057,\n",
       "  'entrezgene': '104629609',\n",
       "  'name': 'B-Raf proto-oncogene, serine/threonine kinase',\n",
       "  'symbol': 'BRAF',\n",
       "  'taxid': 100784},\n",
       " {'_id': '110394457',\n",
       "  '_score': 285.43057,\n",
       "  'entrezgene': '110394457',\n",
       "  'name': 'B-Raf proto-oncogene, serine/threonine kinase',\n",
       "  'symbol': 'BRAF',\n",
       "  'taxid': 8996},\n",
       " {'_id': '100934801',\n",
       "  '_score': 285.43057,\n",
       "  'entrezgene': '100934801',\n",
       "  'name': 'B-Raf proto-oncogene, serine/threonine kinase',\n",
       "  'symbol': 'BRAF',\n",
       "  'taxid': 9305}]"
      ]
     },
     "execution_count": 27,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "braf_data['hits']"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 28,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/plain": [
       "'673'"
      ]
     },
     "execution_count": 28,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "braf_id = braf_data['hits'][0]['_id']\n",
    "braf_id"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 29,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/plain": [
       "{'HGNC': '1097',\n",
       " 'MIM': '164757',\n",
       " 'Vega': 'OTTHUMG00000157457',\n",
       " '_id': '673',\n",
       " '_score': 12.80121,\n",
       " 'accession': {'genomic': ['AC006006.2',\n",
       "   'AC006344.2',\n",
       "   'AC006347.2',\n",
       "   'AC079339.5',\n",
       "   'CH236950.1',\n",
       "   'CH471070.1',\n",
       "   'EU600171.1',\n",
       "   'HB432546.1',\n",
       "   'HC464558.1',\n",
       "   'HM459603.1',\n",
       "   'HQ224878.1',\n",
       "   'KF481581.1',\n",
       "   'KT584890.1',\n",
       "   'KY769663.1',\n",
       "   'KY769664.1',\n",
       "   'KY769665.1',\n",
       "   'KY769666.1',\n",
       "   'KY769667.1',\n",
       "   'KY769668.1',\n",
       "   'NC_000007.14',\n",
       "   'NG_007873.3',\n",
       "   'X65187.1'],\n",
       "  'protein': ['AAA35609.2',\n",
       "   'AAA96495.1',\n",
       "   'AAD15551.1',\n",
       "   'AAD43193.1',\n",
       "   'AAI01758.1',\n",
       "   'AAI12080.1',\n",
       "   'AAS00359.1',\n",
       "   'ACD11489.1',\n",
       "   'ADN43065.1',\n",
       "   'ADQ00186.1',\n",
       "   'ADX94397.1',\n",
       "   'AIE38317.1',\n",
       "   'ARR27440.1',\n",
       "   'ARR27441.1',\n",
       "   'ARR27442.1',\n",
       "   'ARR27443.1',\n",
       "   'ARR27444.1',\n",
       "   'ARR27445.1',\n",
       "   'CAA46301.1',\n",
       "   'CAB81553.1',\n",
       "   'CAZ68014.1',\n",
       "   'CBK51920.1',\n",
       "   'EAL24023.1',\n",
       "   'EAW83964.1',\n",
       "   'EAW83965.1',\n",
       "   'NP_001341538.1',\n",
       "   'NP_004324.2',\n",
       "   'P15056.4',\n",
       "   'XP_016868047.1',\n",
       "   'XP_016868048.1'],\n",
       "  'rna': ['AA252358.1',\n",
       "   'AA834931.1',\n",
       "   'AA975673.1',\n",
       "   'AI203435.1',\n",
       "   'AJ276310.1',\n",
       "   'AK054801.1',\n",
       "   'AK094023.1',\n",
       "   'AK098095.1',\n",
       "   'AK124257.1',\n",
       "   'AK314346.1',\n",
       "   'AW971583.1',\n",
       "   'BC038966.1',\n",
       "   'BC101757.1',\n",
       "   'BC112079.1',\n",
       "   'BM263585.1',\n",
       "   'DB454480.1',\n",
       "   'DN996440.1',\n",
       "   'HM437233.1',\n",
       "   'M21001.1',\n",
       "   'M95712.2',\n",
       "   'NM_001354609.1',\n",
       "   'NM_004333.5',\n",
       "   'NR_148928.1',\n",
       "   'XM_017012558.1',\n",
       "   'XM_017012559.1',\n",
       "   'XR_001744857.1',\n",
       "   'XR_001744858.1'],\n",
       "  'translation': [{'protein': 'AAA35609.2', 'rna': 'M95712.2'},\n",
       "   {'protein': 'AAA96495.1', 'rna': 'M21001.1'},\n",
       "   {'protein': 'XP_016868048.1', 'rna': 'XM_017012559.1'},\n",
       "   {'protein': 'ADN43065.1', 'rna': 'HM437233.1'},\n",
       "   {'protein': 'AAI01758.1', 'rna': 'BC101757.1'},\n",
       "   {'protein': 'NP_001341538.1', 'rna': 'NM_001354609.1'},\n",
       "   {'protein': 'XP_016868047.1', 'rna': 'XM_017012558.1'},\n",
       "   {'protein': 'CAB81553.1', 'rna': 'AJ276310.1'},\n",
       "   {'protein': 'AAI12080.1', 'rna': 'BC112079.1'},\n",
       "   {'protein': 'NP_004324.2', 'rna': 'NM_004333.5'}]},\n",
       " 'alias': ['B-RAF1', 'B-raf', 'BRAF1', 'NS7', 'RAFB1'],\n",
       " 'ec': '2.7.11.1',\n",
       " 'ensembl': {'gene': 'ENSG00000157764',\n",
       "  'protein': ['ENSP00000288602',\n",
       "   'ENSP00000418033',\n",
       "   'ENSP00000419060',\n",
       "   'ENSP00000420119',\n",
       "   'ENSP00000493543',\n",
       "   'ENSP00000493678',\n",
       "   'ENSP00000493783',\n",
       "   'ENSP00000494784',\n",
       "   'ENSP00000495132',\n",
       "   'ENSP00000495858',\n",
       "   'ENSP00000496776'],\n",
       "  'transcript': ['ENST00000288602',\n",
       "   'ENST00000469930',\n",
       "   'ENST00000479537',\n",
       "   'ENST00000496384',\n",
       "   'ENST00000497784',\n",
       "   'ENST00000642228',\n",
       "   'ENST00000642272',\n",
       "   'ENST00000642808',\n",
       "   'ENST00000642875',\n",
       "   'ENST00000643356',\n",
       "   'ENST00000643790',\n",
       "   'ENST00000644120',\n",
       "   'ENST00000644650',\n",
       "   'ENST00000644905',\n",
       "   'ENST00000644969',\n",
       "   'ENST00000645443',\n",
       "   'ENST00000646334',\n",
       "   'ENST00000646427',\n",
       "   'ENST00000646730',\n",
       "   'ENST00000646891',\n",
       "   'ENST00000647434'],\n",
       "  'translation': [{'protein': 'ENSP00000419060', 'rna': 'ENST00000496384'},\n",
       "   {'protein': 'ENSP00000496776', 'rna': 'ENST00000644969'},\n",
       "   {'protein': 'ENSP00000493543', 'rna': 'ENST00000646891'},\n",
       "   {'protein': 'ENSP00000493678', 'rna': 'ENST00000642228'},\n",
       "   {'protein': 'ENSP00000288602', 'rna': 'ENST00000288602'},\n",
       "   {'protein': 'ENSP00000494784', 'rna': 'ENST00000646730'},\n",
       "   {'protein': 'ENSP00000418033', 'rna': 'ENST00000479537'},\n",
       "   {'protein': 'ENSP00000495132', 'rna': 'ENST00000647434'},\n",
       "   {'protein': 'ENSP00000493783', 'rna': 'ENST00000644650'},\n",
       "   {'protein': 'ENSP00000420119', 'rna': 'ENST00000497784'},\n",
       "   {'protein': 'ENSP00000495858', 'rna': 'ENST00000469930'}],\n",
       "  'type_of_gene': 'protein_coding'},\n",
       " 'entrezgene': '673',\n",
       " 'exac': {'all': {'exp_lof': 38.7898242736,\n",
       "   'exp_mis': 222.804792623,\n",
       "   'exp_syn': 91.8960727685,\n",
       "   'lof_z': 5.85138231407808,\n",
       "   'mis_z': 3.99133872234548,\n",
       "   'mu_lof': 2.88380412169e-06,\n",
       "   'mu_mis': 2.2184090402e-05,\n",
       "   'mu_syn': 9.8889618129e-06,\n",
       "   'n_lof': 2.0,\n",
       "   'n_mis': 101.0,\n",
       "   'n_syn': 92.0,\n",
       "   'p_li': 0.999978196041997,\n",
       "   'p_null': 3.88216441101404e-14,\n",
       "   'p_rec': 2.18039579639691e-05,\n",
       "   'syn_z': -0.00672112442056413},\n",
       "  'bp': 2301,\n",
       "  'cds_end': 140624503,\n",
       "  'cds_start': 140434396,\n",
       "  'n_exons': 18,\n",
       "  'nonpsych': {'exp_lof': 34.7601572454,\n",
       "   'exp_mis': 201.311466134,\n",
       "   'exp_syn': 82.8264394585,\n",
       "   'lof_z': 5.62361517113138,\n",
       "   'mis_z': 4.02811051726418,\n",
       "   'mu_lof': 2.88380412169e-06,\n",
       "   'mu_mis': 2.2184090402e-05,\n",
       "   'mu_syn': 9.8889618129e-06,\n",
       "   'n_lof': 1.0,\n",
       "   'n_mis': 88.0,\n",
       "   'n_syn': 82.0,\n",
       "   'p_li': 0.999983482649624,\n",
       "   'p_null': 1.18961221524589e-13,\n",
       "   'p_rec': 1.65173502566583e-05,\n",
       "   'syn_z': 0.057172913417909},\n",
       "  'nontcga': {'exp_lof': 35.6526822996,\n",
       "   'exp_mis': 204.94646599,\n",
       "   'exp_syn': 84.5104358173,\n",
       "   'lof_z': 5.55974482036514,\n",
       "   'mis_z': 4.03503314525409,\n",
       "   'mu_lof': 2.88380412169e-06,\n",
       "   'mu_mis': 2.2184090402e-05,\n",
       "   'mu_syn': 9.8889618129e-06,\n",
       "   'n_lof': 2.0,\n",
       "   'n_mis': 89.0,\n",
       "   'n_syn': 81.0,\n",
       "   'p_li': 0.999932334264256,\n",
       "   'p_null': 6.11297736772402e-13,\n",
       "   'p_rec': 6.76657351324938e-05,\n",
       "   'syn_z': 0.241784586564238},\n",
       "  'transcript': 'ENST00000288602.6'},\n",
       " 'exons': [{'cdsend': 140924703,\n",
       "   'cdsstart': 140726493,\n",
       "   'chr': '7',\n",
       "   'position': [[140719326, 140726516],\n",
       "    [140734616, 140734770],\n",
       "    [140739811, 140739946],\n",
       "    [140749286, 140749418],\n",
       "    [140753274, 140753393],\n",
       "    [140754186, 140754233],\n",
       "    [140776911, 140777088],\n",
       "    [140777990, 140778075],\n",
       "    [140781575, 140781693],\n",
       "    [140783020, 140783157],\n",
       "    [140787547, 140787584],\n",
       "    [140794307, 140794467],\n",
       "    [140800361, 140800481],\n",
       "    [140801411, 140801560],\n",
       "    [140807959, 140808062],\n",
       "    [140808891, 140808995],\n",
       "    [140834608, 140834872],\n",
       "    [140850110, 140850212],\n",
       "    [140924565, 140924928]],\n",
       "   'strand': -1,\n",
       "   'transcript': 'NM_001354609',\n",
       "   'txend': 140924928,\n",
       "   'txstart': 140719326},\n",
       "  {'cdsend': 140924703,\n",
       "   'cdsstart': 140734596,\n",
       "   'chr': '7',\n",
       "   'position': [[140732563, 140734770],\n",
       "    [140739811, 140739946],\n",
       "    [140749286, 140749418],\n",
       "    [140753274, 140753393],\n",
       "    [140754186, 140754233],\n",
       "    [140776911, 140777088],\n",
       "    [140777990, 140778075],\n",
       "    [140781575, 140781693],\n",
       "    [140783020, 140783157],\n",
       "    [140787547, 140787584],\n",
       "    [140794307, 140794467],\n",
       "    [140800361, 140800481],\n",
       "    [140801411, 140801560],\n",
       "    [140807959, 140808062],\n",
       "    [140808891, 140808995],\n",
       "    [140834608, 140834872],\n",
       "    [140850110, 140850212],\n",
       "    [140924565, 140924928]],\n",
       "   'strand': -1,\n",
       "   'transcript': 'NM_004333',\n",
       "   'txend': 140924928,\n",
       "   'txstart': 140732563},\n",
       "  {'cdsend': 140924928,\n",
       "   'cdsstart': 140924928,\n",
       "   'chr': '7',\n",
       "   'position': [[140732563, 140734770],\n",
       "    [140739811, 140739946],\n",
       "    [140749286, 140749418],\n",
       "    [140753274, 140754233],\n",
       "    [140776911, 140777088],\n",
       "    [140777990, 140778075],\n",
       "    [140781575, 140781693],\n",
       "    [140783020, 140783157],\n",
       "    [140787547, 140787584],\n",
       "    [140794307, 140794467],\n",
       "    [140800361, 140800481],\n",
       "    [140801411, 140801560],\n",
       "    [140807959, 140808062],\n",
       "    [140808236, 140808316],\n",
       "    [140808891, 140808995],\n",
       "    [140834608, 140834872],\n",
       "    [140850110, 140850212],\n",
       "    [140924565, 140924928]],\n",
       "   'strand': -1,\n",
       "   'transcript': 'NR_148928',\n",
       "   'txend': 140924928,\n",
       "   'txstart': 140732563}],\n",
       " 'exons_hg19': [{'cdsend': 140624503,\n",
       "   'cdsstart': 140426293,\n",
       "   'chr': '7',\n",
       "   'position': [[140419126, 140426316],\n",
       "    [140434416, 140434570],\n",
       "    [140439611, 140439746],\n",
       "    [140449086, 140449218],\n",
       "    [140453074, 140453193],\n",
       "    [140453986, 140454033],\n",
       "    [140476711, 140476888],\n",
       "    [140477790, 140477875],\n",
       "    [140481375, 140481493],\n",
       "    [140482820, 140482957],\n",
       "    [140487347, 140487384],\n",
       "    [140494107, 140494267],\n",
       "    [140500161, 140500281],\n",
       "    [140501211, 140501360],\n",
       "    [140507759, 140507862],\n",
       "    [140508691, 140508795],\n",
       "    [140534408, 140534672],\n",
       "    [140549910, 140550012],\n",
       "    [140624365, 140624728]],\n",
       "   'strand': -1,\n",
       "   'transcript': 'NM_001354609',\n",
       "   'txend': 140624728,\n",
       "   'txstart': 140419126},\n",
       "  {'cdsend': 140624503,\n",
       "   'cdsstart': 140434396,\n",
       "   'chr': '7',\n",
       "   'position': [[140432363, 140434570],\n",
       "    [140439611, 140439746],\n",
       "    [140449086, 140449218],\n",
       "    [140453074, 140453193],\n",
       "    [140453986, 140454033],\n",
       "    [140476711, 140476888],\n",
       "    [140477790, 140477875],\n",
       "    [140481375, 140481493],\n",
       "    [140482820, 140482957],\n",
       "    [140487347, 140487384],\n",
       "    [140494107, 140494267],\n",
       "    [140500161, 140500281],\n",
       "    [140501211, 140501360],\n",
       "    [140507759, 140507862],\n",
       "    [140508691, 140508795],\n",
       "    [140534408, 140534672],\n",
       "    [140549910, 140550012],\n",
       "    [140624365, 140624728]],\n",
       "   'strand': -1,\n",
       "   'transcript': 'NM_004333',\n",
       "   'txend': 140624728,\n",
       "   'txstart': 140432363},\n",
       "  {'cdsend': 140624728,\n",
       "   'cdsstart': 140624728,\n",
       "   'chr': '7',\n",
       "   'position': [[140432363, 140434570],\n",
       "    [140439611, 140439746],\n",
       "    [140449086, 140449218],\n",
       "    [140453074, 140454033],\n",
       "    [140476711, 140476888],\n",
       "    [140477790, 140477875],\n",
       "    [140481375, 140481493],\n",
       "    [140482820, 140482957],\n",
       "    [140487347, 140487384],\n",
       "    [140494107, 140494267],\n",
       "    [140500161, 140500281],\n",
       "    [140501211, 140501360],\n",
       "    [140507759, 140507862],\n",
       "    [140508036, 140508116],\n",
       "    [140508691, 140508795],\n",
       "    [140534408, 140534672],\n",
       "    [140549910, 140550012],\n",
       "    [140624365, 140624728]],\n",
       "   'strand': -1,\n",
       "   'transcript': 'NR_148928',\n",
       "   'txend': 140624728,\n",
       "   'txstart': 140432363}],\n",
       " 'generif': [{'pubmed': 8621729, 'text': 'MEK1 interacts with B-Raf.'},\n",
       "  {'pubmed': 12068308,\n",
       "   'text': 'somatic missense mutations in 66% of malignant melanomas and at lower frequency in a wide range of human cancers'},\n",
       "  {'pubmed': 12198537,\n",
       "   'text': 'BRAF mutations in colorectal cancers occur only in tumours that do not carry mutations in a RAS gene known as KRAS, and BRAF mutation is linked to the proficiency of these tumours in repairing mismatched bases in DNA'},\n",
       "  {'pubmed': 12447372, 'text': 'High frequency of BRAF mutations in nevi'},\n",
       "  {'pubmed': 12619120,\n",
       "   'text': 'The V599E BRAF mutation appears to be a somatic mutation associated with melanoma development and/or progression in a proportion of affected individuals.'},\n",
       "  {'pubmed': 12644542,\n",
       "   'text': 'results demonstrate that the mutational status of BRAF and KRAS is distinctly different among histologic types of ovarian serous carcinoma, occurring most frequently in invasive micropapillary serous carcinomas and its precursors, serous borderline tumors'},\n",
       "  {'pubmed': 12670889,\n",
       "   'text': 'High prevalence of BRAF mutations in thyroid cancer is genetic evidence for constitutive activation of the RET/PTC-RAS-BRAF signaling pathway in papillary thyroid carcinoma.'},\n",
       "  {'pubmed': 12697856,\n",
       "   'text': 'activating BRAF mutations may be an important event in the development of papillary thyroid cancer'},\n",
       "  {'pubmed': 12753285,\n",
       "   'text': 'cAMP activates ERK and increases proliferation of autosomal dominant polycystic kindey epithelial cells through the sequential phosphorylation of PKA, B-Raf and MAPK in a pathway separate from the classical receptor tyrosine kinase cascade'},\n",
       "  {'pubmed': 12778069,\n",
       "   'text': 'gene is mutated in skin melanoma, but not in uveal melanomas'},\n",
       "  {'pubmed': 12810628,\n",
       "   'text': '13 germline BRAF variants, 4 of which were silent mutations in coding regions & 9 nucleotide substitutions in introns, were found in melanoma patients and melanoma family, but none appeared statistically likely to be a melanoma susceptibility gene.'},\n",
       "  {'pubmed': 12821662,\n",
       "   'text': 'B-raf is involved in adhesion-independent ERK1/2 signaling in melanocytes'},\n",
       "  {'pubmed': 12824225,\n",
       "   'text': 'Data suggest that BRAF T1796A activating mutation is not common in primary uveal melanoma.'},\n",
       "  {'pubmed': 12855697,\n",
       "   'text': 'B-Raf has a role in extracellular signal-regulated kinase (ERK) signaling in T cells and prevents antigen-presenting cell-induced anergy'},\n",
       "  {'pubmed': 12879021,\n",
       "   'text': 'BRAF has a role in in squamous cell carcinoma of the head and neck through uncommon mutations'},\n",
       "  {'pubmed': 12881714,\n",
       "   'text': 'The BRAF(V599E) mutation appears to be an alternative event to RET/PTC rearrangement rather than to RAS mutations, which are rare in PTC. BRAF(V599E) may represent an alternative pathway to oncogenic MAPK activation in PTCs without RET/PTC activation.'},\n",
       "  {'pubmed': 12893203,\n",
       "   'text': 'Mucinous ovarian cancers without a KRAS mutation have not sustained alternative activation of this signaling pathway through mutation of the BRAF oncogene.'},\n",
       "  {'pubmed': 12917419,\n",
       "   'text': '3 cell lines derived from human choroidal melanoma express B-Raf containing the V599E mutation and showed a 10-fold increase in endogenous B-RafV599E kinase activity and a constitutive activation of the MEK/ERK pathway that is independent of Ras'},\n",
       "  {'pubmed': 12931219,\n",
       "   'text': 'Mutations are not detectable in plasma cell leukemia and multiple myeloma.'},\n",
       "  {'pubmed': 12970315,\n",
       "   'text': 'mutation of BRAF gene could be a potentially useful marker of prognosis of patients with advanced thyroid cancers'},\n",
       "  {'pubmed': 14501284,\n",
       "   'text': 'Our findings of a high frequency of BRAF mutations at codon 599 in benign melanocytic lesions of the skin indicate that this mutation is not sufficient by itself for malignant transformation.'},\n",
       "  {'pubmed': 14507635,\n",
       "   'text': 'Both BRAF and FBXW7 mutations functionally activate kinase effectors important in pancreatic cancer and extend potential options for therapeutic targeting of kinases in treatment of phenotypically distinct pancreatic adenocarcinoma subsets.'},\n",
       "  {'pubmed': 14513361,\n",
       "   'text': 'BRAF mutations, which are present in a variety of other human cancers, do not seem to be involved in gastric cancer development'},\n",
       "  {'pubmed': 14522897,\n",
       "   'text': 'Uceal melanomas arise independent of oncogenic BRAF and NRAS mutations.'},\n",
       "  {'pubmed': 14534542,\n",
       "   'text': 'BRAF mutations were seen in stomach neoplasms.'},\n",
       "  {'pubmed': 14602780,\n",
       "   'text': 'BRAF mutations are restricted to papillary carcinomas and poorly differentiated and anaplastic carcinomas arising from papillary carcinomas'},\n",
       "  {'pubmed': 14612909,\n",
       "   'text': 'BRAF is occasionally mutated in NHL, and BRAF mutation may contribute to tumor development in some NHLs'},\n",
       "  {'pubmed': 14618633,\n",
       "   'text': 'None of the cases of gastric cancer showed braf mutations'},\n",
       "  {'pubmed': 14639609,\n",
       "   'text': 'Mutations of BRAF are associated with extensive hMLH1 promoter methylation in sporadic colorectal carcinomas'},\n",
       "  {'pubmed': 14668801,\n",
       "   'text': 'Missense mutation is marker of colonic but not gastric cancer.'},\n",
       "  {'pubmed': 14688025,\n",
       "   'text': 'Mutations were found in exon 15 in colorectal adenocarcinoma.'},\n",
       "  {'pubmed': 14691295,\n",
       "   'text': 'Our data indicate that BRAF gene mutations are rare to absent events in uveal melanoma of humans.'},\n",
       "  {'pubmed': 14695152,\n",
       "   'text': 'NRAS and BRAF mutations arise early during melanoma pathogenesis and are preserved throughout tumor progression'},\n",
       "  {'pubmed': 14695993,\n",
       "   'text': 'BRAF mutations are associated with proximal colon tumors with mismatch repair deficiency and MLH1 hypermethylation.'},\n",
       "  {'pubmed': 14719068,\n",
       "   'text': 'New enriched PCR-RFLP assay for detecting mutations of BRAF codon 599 mutation in pleural mesotheliomas.'},\n",
       "  {'pubmed': 14722037,\n",
       "   'text': 'Observational study of genotype prevalence and gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 14724583,\n",
       "   'text': \"RAS or BRAF mutations are detected in about 32% of all Barrett's adenocarcinomas; the disruption of the Raf/MEK/ERK (MAPK) kinase pathway is a frequent but also early event in the development of Barrett's adenocarcinoma\"},\n",
       "  {'pubmed': 14734469,\n",
       "   'text': 'BRAF mutations are frequently present in sporadic colorectal cancer with methylated hMLH1'},\n",
       "  {'pubmed': 14961576,\n",
       "   'text': 'Mutations in BRAF gene is associated with malignant melanomas'},\n",
       "  {'pubmed': 14966563,\n",
       "   'text': 'These studies identify isoprenylcysteine carboxyl methyltransferase as a potential target for reducing the growth of K-Ras- and B-Raf-induced malignancies.'},\n",
       "  {'pubmed': 15001635,\n",
       "   'text': 'The lack or low prevalence of BRAF mutation in other thyroid neoplasms is consistent with the notion that other previously defined genetic alterations on the same signaling pathway are sufficient to cause tumorigenesis in most thyroid neoplasms.'},\n",
       "  {'pubmed': 15009714,\n",
       "   'text': 'possible cooperation between BRAF activation and PTEN loss in melanoma development.'},\n",
       "  {'pubmed': 15009715,\n",
       "   'text': 'mutations in the BRAF gene and to some extent in the N-ras gene represent early somatic events that occur in melanocytic nevi'},\n",
       "  {'pubmed': 15014028,\n",
       "   'text': 'BRAF mutation may be acquired during development of metastasis but is not a significant factor for primary melanoma development and disease outcome.'},\n",
       "  {'pubmed': 15077125,\n",
       "   'text': 'ovarian serous cystadenomas do not contain mutations in either BRAF or KRAS genes'},\n",
       "  {'pubmed': 15104286,\n",
       "   'text': 'These results suggest that the BRAF mutation is unlikely to be involved in gastric carcinogenesis.'},\n",
       "  {'pubmed': 15126572,\n",
       "   'text': 'BRAF(V599E) is more common genetic alteration found to date in adult sporadic papillary thyroid carcinomas (PTCs). It is unique for this thyroid cancer histotype, and it might drive the development of PTCs of classic papillary subtype.'},\n",
       "  {'pubmed': 15140228,\n",
       "   'text': 'The finding of tandem mutations in thin melanomas makes it more likely that they arise as a simultaneous rather than sequential event.'},\n",
       "  {'pubmed': 15145515,\n",
       "   'text': 'Radiation-induced tumors have a low prevalence of BRAF point mutations and high prevalence of RET/PTC rearrangements'},\n",
       "  {'pubmed': 15150271,\n",
       "   'text': 'B-Raf kinase activity regulation by tuberin and Rheb is mammalian target of rapamycin (mTOR)-independent'},\n",
       "  {'pubmed': 15161700,\n",
       "   'text': 'mucosal melanomas of the head and neck do not frequently harbor an activating mutation of BRAF'},\n",
       "  {'pubmed': 15179189,\n",
       "   'text': 'in contrast to cutaneous melanoma, BRAF does not appear to be involved in the pathogenesis of uveal melanoma'},\n",
       "  {'pubmed': 15186612,\n",
       "   'text': 'BRAF mutations are rather rare in solitary cold adenomas and adenomatous nodules and do not explain the molecular etiology of ras mutation-negative cold thyroid nodules.'},\n",
       "  {'pubmed': 15191558,\n",
       "   'text': 'activation of this gene may be one of the early events in the pathogenesis of some melanomas.'},\n",
       "  {'pubmed': 15263001,\n",
       "   'text': 'B-Raf and ERK are activated by cyclic AMP after calcium restriction'},\n",
       "  {'pubmed': 15273715, 'text': 'mutated in papillary thyroid cancer.'},\n",
       "  {'pubmed': 15277467,\n",
       "   'text': 'In this study, this BRAF mutation was demonstrated in some conjunctival melanoma tissue samples, suggesting that some conjunctival melanomas may share biological features in common with cutaneous melanoma.'},\n",
       "  {'pubmed': 15313890,\n",
       "   'text': 'Data suggest that SPRY2, an inhibitor of ERK signaling, may be bypassed in melanoma cells either by down-regulation of its expression in WT BRAF cells, or by the presence of the BRAF mutation.'},\n",
       "  {'pubmed': 15330192,\n",
       "   'text': 'Mutations within the BRAF gene are useful markers for the differential diagnosis between Spitz nevus and malignant melanoma.'},\n",
       "  {'pubmed': 15331929,\n",
       "   'text': 'we found 19 cases (38%) to harbor somatic B-raf exon 15 mutations.'},\n",
       "  {'pubmed': 15339934,\n",
       "   'text': 'Data provide evidence that B-Raf is a positive regulator of T cell receptor-mediated sustained ERK activation, which is required for NFAT activation and the full production of IL-2.'},\n",
       "  {'pubmed': 15373778,\n",
       "   'text': 'BRAF(V599E) mutation is seven times higher in lesions with structural changes and 13 times higher in growing lesions as compared with lesions without changes'},\n",
       "  {'pubmed': 15488754,\n",
       "   'text': 'REVIEW: our understanding of B-RAF as an oncogene and of its role in cancer'},\n",
       "  {'pubmed': 15489648,\n",
       "   'text': 'Mutations of BRAF or KRAS oncogenes are early events in the serrated polyp neoplasia pathway. CpG island methylation plays a role in serrated polyp progression to colorectal carcinoma.'},\n",
       "  {'pubmed': 15538400,\n",
       "   'text': 'mutated in childhood acute lymphoblastic leukemia.'},\n",
       "  {'pubmed': 15577314,\n",
       "   'text': 'BRAF mutations are associated with conjunctival neoplasms'},\n",
       "  {'pubmed': 15630448,\n",
       "   'text': 'AKAP9-BRAF fusion was preferentially found in radiation-induced papillary carcinomas developing after a short latency, whereas BRAF point mutations were absent in this group'},\n",
       "  {'pubmed': 15632082,\n",
       "   'text': 'Data suggest that Rit is involved in a novel pathway of neuronal development and regeneration by coupling specific trophic factor signals to sustained activation of the B-Raf/ERK and p38 MAP kinase cascades.'},\n",
       "  {'pubmed': 15653554,\n",
       "   'text': 'a novel Ras-independent ERK1/2 activation system in which p110gamma/Raf-1/MEK1/2 and PKA/B-Raf/MEK1/2 cooperate to activate ERK1/2.'},\n",
       "  {'pubmed': 15702478,\n",
       "   'text': 'We found mutations in p53, K-ras, and BRAF genes in 35%, 30%, and 4% of tumors, respectively, and observed a minimal or no co-presence of these gene alterations.'},\n",
       "  {'pubmed': 15705790,\n",
       "   'text': 'KSHV-infected cell lines expressed higher levels of B-Raf and VEGF-A; B-Raf-induced VEGF-A expression was demonstrated to be sufficient to enhance tubule formation in endothelial cells'},\n",
       "  {'pubmed': 15710605,\n",
       "   'text': 'autoinhibition was negatively regulated by acidic substitutions at phosphorylation sites within the activation loop'},\n",
       "  {'pubmed': 15765445,\n",
       "   'text': 'Mutations in the BRAF protooncogene (V599E)may be an alternative pathway of tumorigenesis of familial colorectal cancer.'},\n",
       "  {'pubmed': 15782118,\n",
       "   'text': 'BRAF mutations proved to be absent in tumors from hereditary nonpolyposis colorectal cancer syndrome (HNPCC) families with germline mutations in the MMR genes MLH1 and MSH2.'},\n",
       "  {'pubmed': 15791479,\n",
       "   'text': 'The data of this study suggest that activating mutations of B-RAF are not a frequent event in gliomas; nevertheless, when present they are associated with high-grade malignant lesions.'},\n",
       "  {'pubmed': 15791648,\n",
       "   'text': 'B-raf mutations surrounding Thr439 found in human cancers are unlikely to contribute to increased oncogenic properties of B-raf'},\n",
       "  {'pubmed': 15824163,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 15842051,\n",
       "   'text': 'These results suggest that BRAF mutations do not have a role in tumorigenesis of neuroendocrine gastroenteropancreatic tumors.'},\n",
       "  {'pubmed': 15880523,\n",
       "   'text': 'Anaplastic thyroid carcinomas which are derived from papillary carcinomas are due to BRAF and p53 mutations'},\n",
       "  {'pubmed': 15904951,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 15935100,\n",
       "   'text': 'B-raf V599E and V599K oncogenic mutations are likely to affect melanocyte-specific pathways controlling proliferation and differentiation'},\n",
       "  {'pubmed': 15968271,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 15968271,\n",
       "   'text': 'The increasing frequency of BRAF mutations as a function of age could help account for the well documented but poorly understood observation that age is a relevant prognostic indicator for patients with papillary thyroid carcinoma.'},\n",
       "  {'pubmed': 15980887,\n",
       "   'text': 'BRAF mutation occurs later in thyroid tumor progression and is restricted mainly to papillary thyroid carcinoma and anaplastic thyroid carcinoma'},\n",
       "  {'pubmed': 15994075,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 15998781,\n",
       "   'text': 'Role of BRAF mutation in facilitating metastasis and progression of papillary thyroid cancer in lymph nodes.'},\n",
       "  {'pubmed': 16007166,\n",
       "   'text': 'determination of mutation specific gene expression profiles in papillary thyroid carcinoma'},\n",
       "  {'pubmed': 16007203,\n",
       "   'text': 'Single-cell clones with efficient knockdown of (V 600 E)B-RAF could be propagated in the presence of basic fibroblast growth factor but underwent apoptosis or senescence-like growth arrest upon withdrawal of this growth factor'},\n",
       "  {'pubmed': 16015629,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 16024606,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 16079850,\n",
       "   'text': 'sustained BRAF(V600E) expression in human melanocytes induces cell cycle arrest, which is accompanied by the induction of both p16(INK4a) and senescence-associated acidic beta-galactosidase (SA-beta-Gal) activity, a commonly used senescence marker'},\n",
       "  {'pubmed': 16096377,\n",
       "   'text': 'BRAF mutation in melanoma is most likely to occur prior to the development of metastatic disease'},\n",
       "  {'pubmed': 16098042,\n",
       "   'text': 'Although BRAF and NRAS mutations are likely to be important for the initiation and maintenance of some melanomas, other factors might be more significant for proliferation and prognosis in subgroups of aggressive melanoma'},\n",
       "  {'pubmed': 16098042,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 16123397,\n",
       "   'text': 'The results showed that conjunctival nevi, similar to skin nevi, have a high frequency of oncogenic BRAF mutations.'},\n",
       "  {'pubmed': 16129781,\n",
       "   'text': 'These data suggest that MITF is an anti-proliferation factor that is down-regulated by B-RAF signaling and that this is a crucial event for the progression of melanomas that harbor oncogenic B-RAF.'},\n",
       "  {'pubmed': 16143028,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 16144912,\n",
       "   'text': 'Mutations of the BRAF gene are partly involved in the malignant transformation of the endometrium.'},\n",
       "  {'pubmed': 16144912,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 16172610,\n",
       "   'text': 'selective reduction in catalytic activity and expression of B-Raf but not Raf-1 suggest that B-Raf may be playing an important role in altered ERK signaling in brain of suicide subjects, and thus in the pathophysiology of suicide'},\n",
       "  {'pubmed': 16174717,\n",
       "   'text': 'In patients with papillary thyroid cancer, BRAF mutation is associated with poorer clinicopathological outcomes and independently predicts recurrence.'},\n",
       "  {'pubmed': 16174717,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 16179867,\n",
       "   'text': 'As the BRAF oncogene is frequently found to be mutated in human cutaneous melanomas, it may constitute a risk factor for melanoma formation within CMN and DMN.'},\n",
       "  {'pubmed': 16179870,\n",
       "   'text': 'The oncogenic B-raf mutations V599E and V599K, as early events in melanocyte transformation, persist throughout metastasis with important prognostic implications.'},\n",
       "  {'pubmed': 16181240,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 16181547,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 16199894,\n",
       "   'text': 'copy number gain may represent another mechanism of BRAF activation in thyroid tumors'},\n",
       "  {'pubmed': 16268813,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 16354196,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 16354196,\n",
       "   'text': 'The estimated proportion of attributable risk of melanoma due to variants in BRAF is 1.6%, but the burden of disease associated with this variant is greater than that associated with the major melanoma locus (CDKN2A) which has a risk of 0.2%.'},\n",
       "  {'pubmed': 16354586,\n",
       "   'text': 'Mutation and elevated expression of BRAF is associated with the development of testicular germ cell tumors'},\n",
       "  {'pubmed': 16361694,\n",
       "   'text': 'The authors have developed and run a high-throughput screen to find inhibitors of V600E BRAF using an enzyme cascade assay in which oncogenic BRAF activates MEK1, which in turn activates ERK2, which then phosphorylates the transcription factor ELK1.'},\n",
       "  {'pubmed': 16364920,\n",
       "   'text': 'Data suggest that B-RAF activates C-RAF through a mechanism involving 14-3-3 mediated heterooligomerization and C-RAF transphosphorylation.'},\n",
       "  {'pubmed': 16371460,\n",
       "   'text': 'V600E B-Raf requires the Hsp90 chaperone for stability and is degraded in response to Hsp90 inhibitors.'},\n",
       "  {'pubmed': 16373964,\n",
       "   'text': 'activating mutations of PDGFR-alpha, c-kit and B-RAF are absent in gliosarcomas'},\n",
       "  {'pubmed': 16376942,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 16376942,\n",
       "   'text': 'V599E BRAF mutation was uncommon in Japanese lung cancer.'},\n",
       "  {'pubmed': 16382052,\n",
       "   'text': 'aberrant B-Raf activity in angiomyolipomas leads to abnormal cellular differentiation and migration [review]'},\n",
       "  {'pubmed': 16397024,\n",
       "   'text': 'Observational study of genotype prevalence. (HuGE Navigator)'},\n",
       "  {'pubmed': 16413100,\n",
       "   'text': 'The most frequent B-RAF gene alterations are not involved in prostate carcinogenesis'},\n",
       "  {'pubmed': 16417232,\n",
       "   'text': 'BRAF mutation does not seem to be sufficient to produce MAPK activation in melanocytic nevi.'},\n",
       "  {'pubmed': 16424035,\n",
       "   'text': 'gain-of-function BRAF signaling is strongly associated with in vivo tumorigenicity'},\n",
       "  {'pubmed': 16439621,\n",
       "   'text': 'findings demonstrate that heterogeneous de novo missense mutations in three genes within the mitogen-activated protein kinase pathway, BRAF, MEK1 and MEK2 cause cardio-facio-cutaneous syndrome'},\n",
       "  {'pubmed': 16452469,\n",
       "   'text': 'wild-type B-Raf-mediated ERK1/2 activation plays a major role in proliferation and transformation of uveal melanocytes; Raf-1 is not involved in this activation'},\n",
       "  {'pubmed': 16452550,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 16462768,\n",
       "   'text': 'NRAS and BRAF activating mutations can coexist in the same melanoma, but are mutually exclusive at the single-cell level'},\n",
       "  {'pubmed': 16474404,\n",
       "   'text': 'Cardio-facio-cutaneous (CFC) syndrome involves dysregulation of the RAS-RAF-ERK pathway.'},\n",
       "  {'pubmed': 16487015,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 16537381,\n",
       "   'text': 'Merlin and MLK3 can interact in situ and merlin can disrupt the interactions between B-Raf and Raf-1 or those between MLK3 and either B-Raf or Raf-1.'},\n",
       "  {'pubmed': 16547495,\n",
       "   'text': 'Melanoma cells require either B-RAF or phosphoinositide-3 kinase activation for protection from anoikis.'},\n",
       "  {'pubmed': 16601293,\n",
       "   'text': 'BRAF V600E is associated with a high risk of recurrence and less differentiated papillary thyroid carcinoma due to the impairment of Na+/I- targeting to the membrane'},\n",
       "  {'pubmed': 16601293,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 16618717,\n",
       "   'text': 'Observational study of gene-environment interaction and pharmacogenomic / toxicogenomic. (HuGE Navigator)'},\n",
       "  {'pubmed': 16687919,\n",
       "   'text': 'Observational study of genotype prevalence. (HuGE Navigator)'},\n",
       "  {'pubmed': 16691193,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 16691193,\n",
       "   'text': 'UV light is not necessarily required for the acquisition of the BRAF(V600E) mutation, and non-mutagenic effects of UV light to melanocytes may be more important in the nevogenesis'},\n",
       "  {'pubmed': 16721785,\n",
       "   'text': 'BRAF mutations are as uncommon as KRAS mutations in prostate adenocarcinoma'},\n",
       "  {'pubmed': 16728573,\n",
       "   'text': 'B-RAF (V600E) was confirmed to be associated with the papillary growth pattern, but not with poorer differentiated papillary thyroid carcinoma variants.'},\n",
       "  {'pubmed': 16728573,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 16773193,\n",
       "   'text': 'among 23 melanomas located at body sites with chronic UV exposure, only a single tumour harboured the B-raf V599E mutation which was a significantly lower frequency in comparison to melanomas from sun-protected body sites'},\n",
       "  {'pubmed': 16786134,\n",
       "   'text': 'a BRAFT1799A mutation may have a role in poor differentiation of thyroid carcinoma'},\n",
       "  {'pubmed': 16799476,\n",
       "   'text': 'A subset of Spitz nevi, some with atypical histologic features, possess BRAF mutations. The BRAF mutational status does not separate all Spitz nevi from spitzoid melanomas and non-Spitz types of melanocytic proliferations, contrary to previous reports.'},\n",
       "  {'pubmed': 16803888,\n",
       "   'text': 'Rheb has a central role in the regulation of the Ras/B-Raf/C-Raf/MEK signaling network'},\n",
       "  {'pubmed': 16804544,\n",
       "   'text': 'CpG island methylator phenotype-positive colorectal tumors represent a distinct subset, encompassing almost all cases of tumors with BRAF mutation'},\n",
       "  {'pubmed': 16809487,\n",
       "   'text': 'findings show that MC1R variants are strongly associated with BRAF mutations in non-chronic sun-induced damage melanomas; in this subtype, risk for melanoma associated with MC1R is due to increase in risk of developing melanomas with BRAF mutations'},\n",
       "  {'pubmed': 16845322,\n",
       "   'text': 'BRAF mutation is associated with melanoma and melanocytic nevi.'},\n",
       "  {'pubmed': 16858395,\n",
       "   'text': 'Thus, we propose that the hitherto unidentified function of the B-Raf amino-terminal region is to mediate calcium-dependent activation of B-Raf and the following MEK activation, which may occur in the absence of Ras activation.'},\n",
       "  {'pubmed': 16858683,\n",
       "   'text': 'Aberrant methylation and hence silencing of TIMP3, SLC5A8, DAPK and RARbeta2, in association with BRAF mutation, may be an important step in PTC tumorigenesis and progression.'},\n",
       "  {'pubmed': 16879389,\n",
       "   'text': 'BRAF mutation was frequent in hyperplastic polyps (67%) and sessile serrated adenomas (81%).'},\n",
       "  {'pubmed': 16912199,\n",
       "   'text': 'B-RAF has been identified as the most mutated gene in invasive cells and therefore an attractive therapeutic target in melanoma.'},\n",
       "  {'pubmed': 16918136,\n",
       "   'text': 'BRAF mutations are associated with colorectal cancers'},\n",
       "  {'pubmed': 16918957,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 16924241,\n",
       "   'text': 'Expression of p27Kip1 in melanoma is regulated by B-RAF at the mRNA level and via B-RAF control of Cks1/Skp2-mediated proteolysis.'},\n",
       "  {'pubmed': 16932278,\n",
       "   'text': 'Single nucleotide polymorphism found exclusively in papillary thyroid carcinoma.'},\n",
       "  {'pubmed': 16937524,\n",
       "   'text': 'BRAF, K-ras and BAT26 are expressed in colorectal polyps and stool'},\n",
       "  {'pubmed': 16937524,\n",
       "   'text': 'BRAF, K-ras and BAT26 are expressed in colorectal polyps and stool [BAT26]'},\n",
       "  {'pubmed': 16946010, 'text': 'Braf mutations in thyroid tumorigenesis.'},\n",
       "  {'pubmed': 16953233,\n",
       "   'text': 'Concomitant KRAS and BRAF mutations increased along progression of MSS colorectal cancer, suggesting that activation of both genes is likely to harbour a synergistic effect'},\n",
       "  {'pubmed': 16959844,\n",
       "   'text': 'BRAFV600E activates not only MAPK but also NF-kappaB signaling pathway in human thyroid cancer cells, leading to an acquisition of apoptotic resistance and promotion of invasion.'},\n",
       "  {'pubmed': 16960555,\n",
       "   'text': 'Expression of active mutants of B-Raf induces fibronectin.'},\n",
       "  {'pubmed': 16964379,\n",
       "   'text': 'Extracellular signal-regulated kinase-3 (ERK3/MAPK6) is highly expressed in response to BRAF signaling.'},\n",
       "  {'pubmed': 16973828,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 16987295,\n",
       "   'text': 'BRAF T1976A mutation is present at high frequency in benign naevi such as Spitz and Reed.'},\n",
       "  {'pubmed': 17001349,\n",
       "   'text': 'data support a model in which mutational activation of BRAF in human melanomas contributes to constitutive induction of NF-kappaB activity and to increased survival of melanoma cells'},\n",
       "  {'pubmed': 17018604,\n",
       "   'text': 'Normally, BRAF alone is responsible for signaling to MEK. However, when RAS is mutated in melanoma, melanocytes switch their signaling from BRAF to CRAF.'},\n",
       "  {'pubmed': 17044028,\n",
       "   'text': 'Activating BRAF mutation is associated with papillary thyroid carcinoma'},\n",
       "  {'pubmed': 17060774,\n",
       "   'text': 'BRAF mutation remained a significant prognostic factor for lymph node metastasis (odds ratio = 10.8, 95% confidence interval, 3.5-34.0, P < 0.0001).'},\n",
       "  {'pubmed': 17074813,\n",
       "   'text': 'phosphorylation on both S365 and S429 participate in the differential regulation of B-Raf isoforms through distinct mechanisms'},\n",
       "  {'pubmed': 17097223,\n",
       "   'text': 'data provide evidence that oncogenic properties of BRAF contribute to the tumorigenesis of intraductal papillary mucinous neoplasm/carcinoma (IPMN/IPMC), but at a lower frequency than KRAS'},\n",
       "  {'pubmed': 17119056,\n",
       "   'text': 'BRAF-V600E mutations are mainly involved in colorectal cancer families characterized by an increased risk of other common malignancies'},\n",
       "  {'pubmed': 17119447,\n",
       "   'text': 'Association with preexisting nevi and pronounced infiltration of lymphocytes was significantly higher in BRAF mutated melanoma tumours'},\n",
       "  {'pubmed': 17148775,\n",
       "   'text': 'Observational study of gene-disease association and gene-environment interaction. (HuGE Navigator)'},\n",
       "  {'pubmed': 17148775,\n",
       "   'text': 'Previously identified associations between smoking and colon cancer, whether microsatellite unstable or stable, appear to be explained by the association of smoking with BRAF mutation.'},\n",
       "  {'pubmed': 17159915,\n",
       "   'text': 'BRAF(T1799A) mutation is associated with a lower rate of tumor proliferation.'},\n",
       "  {'pubmed': 17159915,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 17170014,\n",
       "   'text': 'RASSF1A methylation was observed in a high frequency in endometrioid endometrial carcinoma whereas K-ras and B-raf mutations were observed in a low frequency'},\n",
       "  {'pubmed': 17179987,\n",
       "   'text': 'The role for BRAF activation in thyroid cancer development and establishing the potential therapeutic efficacy of BRAF-targeted agents in patients with thyroid cancerwill be reviewed.'},\n",
       "  {'pubmed': 17186541,\n",
       "   'text': 'BRAF mutation is associated with thyroid carcinogenesis'},\n",
       "  {'pubmed': 17186541,\n",
       "   'text': 'Observational study of gene-disease association and gene-environment interaction. (HuGE Navigator)'},\n",
       "  {'pubmed': 17195912,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 17195912,\n",
       "   'text': 'there is a subgroup of colorectal carcinomas which develop via the microsatellite instability pathway that carry an alteration of the BRAF gene'},\n",
       "  {'pubmed': 17199737,\n",
       "   'text': 'Absence of association between BRAF mutation and activation of MAPK pathway in papillary thyroid carcinoma suggests the presence of mechanisms that downregulate MAPK activation.'},\n",
       "  {'pubmed': 17227125,\n",
       "   'text': 'Copy gain of PDGFB occurs in a subset of tumors showing no evidence of mutated BRAF or rearranged ret, suggesting that copy gain of PDGFB may underlie the increased expression of platelet-derived growth factor described recently in the literature.'},\n",
       "  {'pubmed': 17270239,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 17297294,\n",
       "   'text': 'characterization of the T1799-1801del and A1799-1816ins BRAF mutations in papillary thyroid cancer; the two new mutations resulted in constitutive activation of the BRAF kinase and caused NIH3T3 cell transformation'},\n",
       "  {'pubmed': 17302867,\n",
       "   'text': 'Overexpression of B-Raf mRNA and protein may be a feature of nonfunctioning pituitary adenomas, highlighting overactivity of the Ras-B-Raf-MAP kinase pathway in these tumors.'},\n",
       "  {'pubmed': 17309670,\n",
       "   'text': 'BRAF gene plays a \"gatekeeper\" role but does not act as a predisposition gene in the development of low-grade ovarian serous carcinomas'},\n",
       "  {'pubmed': 17309670,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 17312306,\n",
       "   'text': 'Observational study of genetic testing. (HuGE Navigator)'},\n",
       "  {'pubmed': 17315191,\n",
       "   'text': 'BRAFV600E represents a detectable marker in the plasma/serum from melanoma patients for monitoring but not diagnostic purposes'},\n",
       "  {'pubmed': 17318013,\n",
       "   'text': 'B-RAF mutations are a rare event in pituitary tumorigenesis.'},\n",
       "  {'pubmed': 17355635,\n",
       "   'text': 'The aim of this study was to identify the effect that BRAF oncogene has on post-transcriptional regulation in papillary thyroid carcinoma by using microRNA analysis.'},\n",
       "  {'pubmed': 17360030,\n",
       "   'text': 'findings show that RASSF1A hypermethylation and KRAS mutations and BRAF mutations are inversely correlated and play an important role in the development of cervical adenocarcinomas'},\n",
       "  {'pubmed': 17366577,\n",
       "   'text': 'mutational analysis of KRAS, BRAF, and MAP2K1/2 in 56 patients with CFC syndrome; comparison of the genotype-phenotype correlation of CFC with that of Costello syndrome suggest a significant clinical overlap but not genotype overlap.'},\n",
       "  {'pubmed': 17387744,\n",
       "   'text': 'BRAF(V600E) mutation is identified in a subset of cutaneous metastases from papillary thyroid carcinomas'},\n",
       "  {'pubmed': 17393356,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 17393356,\n",
       "   'text': 'data suggest that BRAF mutations might be present less frequently than KRAS mutations in Greek patients with colorectal carcinomas'},\n",
       "  {'pubmed': 17440063,\n",
       "   'text': 'finding of a strong association between BRAF mutations and serrated histology in hyperplastic aberrant crypt foci supports the idea that these lesions are an early, sentinel, or a potentially initiating step on the serrated pathway to colorectal carcinoma'},\n",
       "  {'pubmed': 17453004,\n",
       "   'text': 'BRAF V600E mutation was occasionally observed in anaplastic carcinomas with papillary carcinoma.'},\n",
       "  {'pubmed': 17453358,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 17454879,\n",
       "   'text': 'MSI is rare in UC-related neoplasia as well as non-neoplastic lesions, and does not contribute to the development of dysplasia.'},\n",
       "  {'pubmed': 17464312,\n",
       "   'text': 'prevalence of BRAF mutation and RET/PTC were determined in diffuse sclerosing variant of papillary thyroid carcinoma; none of the cases showed a BRAF mutation'},\n",
       "  {'pubmed': 17483702,\n",
       "   'text': 'Molecular diagnosis and careful observations should be considered in children with Cardio-facio-cutaneous syndrome because they have germline mutations in BRAF and might develop malignancy.'},\n",
       "  {'pubmed': 17487277,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 17487504,\n",
       "   'text': 'c-kit expression is not alternative to BRAF and/or KRAS activation.'},\n",
       "  {'pubmed': 17488796,\n",
       "   'text': 'BRAF V600E mutation in PTCs is associated with reduced expression of key genes involved in iodine metabolism'},\n",
       "  {'pubmed': 17507627,\n",
       "   'text': 'Observational study of gene-disease association and gene-environment interaction. (HuGE Navigator)'},\n",
       "  {'pubmed': 17507627,\n",
       "   'text': 'data indicate that both early-life UV exposure and nevus propensity contribute to occurrence of BRAF+ melanoma, whereas nevus propensity and later-life sun exposure influence the occurrence of NRAS+ melanoma'},\n",
       "  {'pubmed': 17516929,\n",
       "   'text': 'analysis of a BRAF mutation-associated gene expression signature in melanoma'},\n",
       "  {'pubmed': 17518771,\n",
       "   'text': 'low rate of RAS-RAF mutations (2/22, 9.1%) observed in Spitz melanocytic nevi suggests that these lesions harbor as yet undetected activating mutations in other components of the RAS-RAF-MEK-ERK-MAPK pathway'},\n",
       "  {'pubmed': 17520704,\n",
       "   'text': 'Meta-analysis of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 17520704,\n",
       "   'text': 'frequency of the BRAF mutation and the associations between BRAF mutation and clinicopathologic parameters in papillary thyroid carcinoma were evaluated by meta-analysis'},\n",
       "  {'pubmed': 17525723,\n",
       "   'text': 'T1790A BRAF mutation (L597Q) in childhood acute lymphoblastic leukemia is a functional oncogene'},\n",
       "  {'pubmed': 17535994,\n",
       "   'text': 'The heterogeneous distribution of BRAF mutations suggests that discrete tumor foci in multifocal PTC may occur as independent tumors.'},\n",
       "  {'pubmed': 17542667,\n",
       "   'text': 'Presence of BRAF V600E in very early stages of papillary thyroid carcinoma.'},\n",
       "  {'pubmed': 17548320,\n",
       "   'text': 'influence of B-RAF-specific RNA interference on the proliferation and apoptosis of gastric cancer BGC823 cell line'},\n",
       "  {'pubmed': 17566669,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 17566669,\n",
       "   'text': 'We conclude that screening for BRAF 15 exon mutation is an efficient tool in the diagnostic strategy for HNPCC'},\n",
       "  {'pubmed': 17635919,\n",
       "   'text': 'In contrast to C-RAF that requires farnesylated H-Ras, cytosolic B-RAF associates effectively and with significantly higher affinity with both farnesylated and nonfarnesylated H-Ras.'},\n",
       "  {'pubmed': 17663506,\n",
       "   'text': 'KLF6 and p53 mutations are involved in the development of nonpolypoid colorectal carcinoma, whereas K-ras and B-raf mutations are not'},\n",
       "  {'pubmed': 17671688,\n",
       "   'text': 'PPARbeta/delta has a role in growth of RAF-induced lung adenomas'},\n",
       "  {'pubmed': 17685465,\n",
       "   'text': 'BRAF V600E mutation in papillary carcinoma of the thyroid may facilitate tumor cell growth and progression once seeded in the lymph nodes.'},\n",
       "  {'pubmed': 17693984,\n",
       "   'text': 'Observational study of genotype prevalence, gene-disease association, and genetic testing. (HuGE Navigator)'},\n",
       "  {'pubmed': 17693984,\n",
       "   'text': 'There was no coexistence of BRAF (V600E) mutation in papillary thyroid carcinoma.'},\n",
       "  {'pubmed': 17696195,\n",
       "   'text': 'data showed differences in gene expression between nevi with and without the V600E BRAF mutation. Moreover, nevi with mutations showed over-expression of genes involved in melanocytic senescence and cell cycle inhibition'},\n",
       "  {'pubmed': 17699719,\n",
       "   'text': 'RNA interference and pharmacologic approaches were used to assess the role of B-Raf activation in the growth of human melanomas and additionally determined if a similar role for mutant B-Raf is seen for colorectal carcinoma cell lines.'},\n",
       "  {'pubmed': 17704260,\n",
       "   'text': '5 unreported mutations (T241P, Q262R, G464R, E501V, N581K) were found in cardio-facio-cutaneous syndrome. A hotspot in exon 6 at Q257 was found.'},\n",
       "  {'pubmed': 17714762,\n",
       "   'text': 'diffuse expression of wild-type and/or mutant B-Raf may be involved in the tumorigenic process'},\n",
       "  {'pubmed': 17717450,\n",
       "   'text': 'BRAF V600E mutation is primarily present in conventional papillary thyroid cancer; it is associated with an aggressive tumor phenotype and higher risk of recurrent and persistent disease in patients with conventional papillary thyroid cancer'},\n",
       "  {'pubmed': 17717450,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 17721188,\n",
       "   'text': 'Develompment of malignant strumo ovarii with papillary thyroid carcinoma features is associated with BRAF mutations.'},\n",
       "  {'pubmed': 17727338,\n",
       "   'text': 'BRAF(V600E) mutation detected on fine-needle aspiration biopsy specimens, more than RET/PTC rearrangements, is highly specific for papillary thyroid carcinoma.'},\n",
       "  {'pubmed': 17785355,\n",
       "   'text': 'BRAF V600E mutation is associated with high-risk papillary thyroid carcinoma'},\n",
       "  {'pubmed': 17785355,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 17786355,\n",
       "   'text': 'BRAFV600E mutations were found in 41.2% of the papillary thyroid carcinomas'},\n",
       "  {'pubmed': 17854396,\n",
       "   'text': 'Papillary thyroid cancers with no 131I uptake had a high frequency of BRAF mutations.'},\n",
       "  {'pubmed': 17878251,\n",
       "   'text': 'MEK inhibition is cytostatic in papillary thyroid cancer and anaplastic thyroid cancer cells bearing a BRAF mutation'},\n",
       "  {'pubmed': 17911174,\n",
       "   'text': 'effects of a MEK inhibitor, CI-1040, on thyroid cancer cells, some of which, particularly cell proliferation and tumor growth, seemed to be BRAF mutation or RAS mutation selective'},\n",
       "  {'pubmed': 17914558,\n",
       "   'text': 'BRAF mutation is associated as early as the hyperplastic polyp stage followed by microsatellite instability at the carcinoma stage'},\n",
       "  {'pubmed': 17924122,\n",
       "   'text': 'Examined associations between BRAF mutations, morphology, and apoptosis in early colorectal cancer.'},\n",
       "  {'pubmed': 17940185,\n",
       "   'text': 'BRAF mutation represents a novel indicator of the progression and aggressiveness of papillary thyroid cancer (Review)'},\n",
       "  {'pubmed': 17942568,\n",
       "   'text': 'BRAF interacts with PLCepsilon1 in nephrotic syndrome type 3. Both proteins are coexpressed and colocalize in developing and mature glomerular podocytes.'},\n",
       "  {'pubmed': 17962436,\n",
       "   'text': 'In this small study, the T1799A BRAF mutation was identified in almost half of the iris melanoma tissues samples examined. This finding suggests that there may be genetic as well as clinical differences between iris and posterior uveal melanomas.'},\n",
       "  {'pubmed': 17972530,\n",
       "   'text': 'These results suggest that papillary thyroid carcinomas with BRAF (V600E) mutation are more aggressive than those with wildtype BRAF.'},\n",
       "  {'pubmed': 18000091,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 18008004,\n",
       "   'text': 'mutation of N-RAS or B-RAF, signature genetic lesions present in most MMs, potently induced the expression of cell-surface CD200, a repressor of DC function.'},\n",
       "  {'pubmed': 18024410,\n",
       "   'text': 'no BRAF mutations identified in 65 screened JMML patients; this gene is unlikely to play a role in the pathogenesis of JMML.'},\n",
       "  {'pubmed': 18032947,\n",
       "   'text': 'The BRAF mutation is common in melanomas, but variation in rates across melanoma subtypes points to a complex interplay between BRAF activation and other factors (eg, sun exposure).'},\n",
       "  {'pubmed': 18042262,\n",
       "   'text': 'the results of HRAS, BRAF and MAP2K1/2 mutation screening in a large cohort of patients with CS and CFC'},\n",
       "  {'pubmed': 18045960,\n",
       "   'text': 'Detection of BRAF improves the diagnosis in fine-needle biopsy with cytological findings suspicious for papillary thyroid carcinoma.'},\n",
       "  {'pubmed': 18045987,\n",
       "   'text': 'These results identify Rnd3 as a regulator of cross talk between the RAF/MEK/ERK and Rho/ROCK signaling pathways, and a key contributor to oncogene-mediated reorganization of the actin cytoskeleton and focal adhesions.'},\n",
       "  {'pubmed': 18060073,\n",
       "   'text': 'BRAF and MEK1/2 mutations may be more common than anticipated in ovarian cancer which could have important implications for treatment of patients with this disease and suggests potential new therapeutic avenues'},\n",
       "  {'pubmed': 18061181,\n",
       "   'text': 'Observational study of genetic testing. (HuGE Navigator)'},\n",
       "  {'pubmed': 18070147,\n",
       "   'text': \"BRAF(V600E)'alone' does not represent a marker for poor outcome\"},\n",
       "  {'pubmed': 18071315,\n",
       "   'text': 'B-Raf(V600E) signaling deregulates the mitotic spindle checkpoint through stabilizing Mps1 levels in melanoma cells.'},\n",
       "  {'pubmed': 18098337,\n",
       "   'text': 'BRAF provides proliferation and survival signals in MSI colorectal carcinoma cells displaying BRAF(V600E) but not KRAS mutations.'},\n",
       "  {'pubmed': 18172070,\n",
       "   'text': 'Because of the very sensitive pyrophosphorolysis-activated polymerization (PAP)technology, B-RAF mutations were found in cell lines and primary uveal melanomas.'},\n",
       "  {'pubmed': 18199160,\n",
       "   'text': 'A worse clinical outcome was found for CIMP-high, microsatellite stable colorectal cancer with KRAS/BRAF mutation but not for those lacking KRAS/BRAF mutation.'},\n",
       "  {'pubmed': 18224685,\n",
       "   'text': 'Observational study of gene-disease association and gene-gene interaction. (HuGE Navigator)'},\n",
       "  {'pubmed': 18226854,\n",
       "   'text': 'frequency of the occurrence of BRAF mutation and/or RET/PTC in H4-PTEN positive tumors was extremely high (75%) in papillary thyroid carcinoma'},\n",
       "  {'pubmed': 18227705,\n",
       "   'text': 'BRAF mutation is not associated with cutaneous melanoma'},\n",
       "  {'pubmed': 18228248,\n",
       "   'text': 'Important signalling role in T cell development.'},\n",
       "  {'pubmed': 18235983,\n",
       "   'text': 'Follicular histotypes of oncocytic thyroid carcinomas do not carry BRAF mutations'},\n",
       "  {'pubmed': 18246127,\n",
       "   'text': 'Mutant B-RAF mediates resistance to anoikis via Bad and Bim.'},\n",
       "  {'pubmed': 18267069,\n",
       "   'text': 'A genome-wide RNA-interference screening to identify genes required for an activated BRAF oncogene to block proliferation of fibroblasts and melanocytes revealed that a IGFBP7, has a central role in BRAF-mediated senescence and apoptosis.'},\n",
       "  {'pubmed': 18310286,\n",
       "   'text': 'BRAF T1799A mutation is associated with aggressive pathological outcomes of papillary thyroid cancer'},\n",
       "  {'pubmed': 18310287,\n",
       "   'text': 'BRAF(V600E) mutation is asscoiated with papillary thyroid cancer'},\n",
       "  {'pubmed': 18310288,\n",
       "   'text': 'BRAF-V600E mutation is associated with familial non-medullary thyroid carcinoma'},\n",
       "  {'pubmed': 18323787,\n",
       "   'text': 'Mitogen-activated protein kinase (MAPK) activity is subject to regulation even in BRAF/NRAS mutant melanoma cells and that high MAPK pathway signaling may be important only in distinct subsets of tumor cells.'},\n",
       "  {'pubmed': 18329792,\n",
       "   'text': 'RKIP could play an important role in the down-regulation of wild-type BRAF, serving thus as an endogenous inhibitor of the MAPK pathway in nasal polyps and their adjacent turbinate mucosa.'},\n",
       "  {'pubmed': 18337114,\n",
       "   'text': 'BRAF mutation testing of papillary thyroid carcinoma might improve the diagnosis, prognostic stratification and treatment of these tumors.'},\n",
       "  {'pubmed': 18343945,\n",
       "   'text': 'Our data provide evidence that PIK3CA and BRAF contribute to the tumorigenesis of IPMN/IPMC, but at a lower frequency than KRAS.'},\n",
       "  {'pubmed': 18368129,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 18368129,\n",
       "   'text': 'This study confirms that the known MC1R-melanoma risk association is confined to subjects whose melanomas harbor BRAF mutations.'},\n",
       "  {'pubmed': 18375819,\n",
       "   'text': 'BRAF mutation is associated with disease stabilization in melanoma'},\n",
       "  {'pubmed': 18381570,\n",
       "   'text': 'Thyroid cancers with BRAF mutation are preferentially sensitive to MEK inhibitors.'},\n",
       "  {'pubmed': 18382358,\n",
       "   'text': 'Detecting BRAF mutation by pyrosequencing is more sensitive, faster, and less expensive than direct DNA sequencing.'},\n",
       "  {'pubmed': 18383861,\n",
       "   'text': 'K-RAS and BRAF mutations are a frequent genetic event in our samples of sporadic papillary and medullary thyroid carcinoma.'},\n",
       "  {'pubmed': 18383861,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 18397470,\n",
       "   'text': 'is commonly activated by somatic point mutation, it may provide possible diagnostic and therapeutic targets in human malignant tumors.'},\n",
       "  {'pubmed': 18398503,\n",
       "   'text': 'Results implicate aberrant activation of the MAPK pathway due to gene duplication or mutation of BRAF as a molecular mechanism of pathogenesis in low-grade astrocytomas and suggest inhibition of the MAPK pathway as a potential treatment.'},\n",
       "  {'pubmed': 18402768,\n",
       "   'text': 'Aberrant BRAF and INK4A functionally interact to promote growth and survival of melanoma cells.'},\n",
       "  {'pubmed': 18408659,\n",
       "   'text': 'in melanocytic lesions, BRAF(V600E) mutation can affect a subset of the cells and is associated with the type and quantity of sun exposure'},\n",
       "  {'pubmed': 18413255,\n",
       "   'text': 'study describes the biochemical characterization of novel BRAF and MEK germline mutations in cardio-facio-cutaneous syndrome'},\n",
       "  {'pubmed': 18434602,\n",
       "   'text': 'Cdk1/cyclin B has a role in regulating B-raf activation at mitosis'},\n",
       "  {'pubmed': 18435933,\n",
       "   'text': 'CpG island methylator phenotype in colorectal neoplasms may result from activating mutations in either BRAF or KRAS.'},\n",
       "  {'pubmed': 18451171,\n",
       "   'text': 'Akt3 and mutant V600E B-Raf cooperate to promote early melanoma development.'},\n",
       "  {'pubmed': 18458053,\n",
       "   'text': 'oncogenic BRAF inhibition can have a different effect on cell fate depending on the cellular type'},\n",
       "  {'pubmed': 18470905,\n",
       "   'text': 'aberrant methylation of the hMLH1 gene may play a role in BRAF mutation-promoted thyroid tumorigenesis'},\n",
       "  {'pubmed': 18509003,\n",
       "   'text': 'study revealed a significant correlation of BRAFV600E mutation with a lower expression of both sodium iodide symporter and thyroperoxidase in papillary thyroid cancer'},\n",
       "  {'pubmed': 18509361,\n",
       "   'text': 'Shorter overall survival in primary melanoma was associated with the presence of ulceration and BRAF exon 15 mutations, as well as the absence of nuclear activation of Akt and of cytoplasmic activation of ERK.'},\n",
       "  {'pubmed': 18517279,\n",
       "   'text': 'BRAF mutations in colorectal cancer microsatellite-stable cases are associated with high levels of chromosomal instability that are likely responsible for the adverse outcomes in these cases'},\n",
       "  {'pubmed': 18519771,\n",
       "   'text': 'a significant relationship in overall survival in colon cancer patients with defective DNA mismatch repair and the presence of a specific mutation in BRAF (V600E)'},\n",
       "  {'pubmed': 18532874,\n",
       "   'text': 'Compared to melanomas without BRAF mutations, melanomas with BRAF mutations showed statistically significantly higher degrees of intraepidermal scatter of melanocytes, and a higher proportion of melanocytes arranged in nests.'},\n",
       "  {'pubmed': 18567582,\n",
       "   'text': 'the scaffold protein IQGAP1 couples Ca(2+) and calmodulin signaling to B-Raf function'},\n",
       "  {'pubmed': 18592405,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 18594528,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 18602919,\n",
       "   'text': 'Rac1b and B-Raf(V600E) functionally cooperate to sustain colorectal cell viability and suggest they constitute an alternative survival pathway to oncogenic K-Ras'},\n",
       "  {'pubmed': 18615679,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 18615679,\n",
       "   'text': 'V600E BRAF mutation is associated with imatinib-resistant gastrointestinal stromal tumors'},\n",
       "  {'pubmed': 18615680,\n",
       "   'text': 'MLH1 methylation and BRAF mutations are associated with microsatellite unstable colon tumors'},\n",
       "  {'pubmed': 18615680,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 18621636,\n",
       "   'text': 'Observational study of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)'},\n",
       "  {'pubmed': 18628356,\n",
       "   'text': 'The frequencies of LOHs of 17q21, 17p13, 10q23, and 22q13 were higher in tumors with lymph node metastasis, suggesting that these LOHs may be important in increased lymph node metastasis.'},\n",
       "  {'pubmed': 18628431,\n",
       "   'text': 'People of southern European origin had lower risk of colorectal cancers with CIMP and BRAF mutation than people of Anglo-Celtic origin, which may in part be due to genetic factors that are less common in people of southern European origin.'},\n",
       "  {'pubmed': 18628967,\n",
       "   'text': 'BRAF regulates melanoma proliferation through the lineage specific factor MITF'},\n",
       "  {'pubmed': 18632627,\n",
       "   'text': 'co-overexpression of KIT/CDK4 is a potential mechanism of oncogenic transformation in some BRAF/NRAS wild-type melanomas'},\n",
       "  {'pubmed': 18636014,\n",
       "   'text': 'lung adenocarcinoma of mixed type with a high incidence of papillary and lepidic growth may be worthwhile investigating for BRAF-V600E mutation as more genetically oriented drug therapies emerge.'},\n",
       "  {'pubmed': 18650848,\n",
       "   'text': 'hyperactivation of the MAPK pathway following activation of an inducible form of oncogenic C-Raf induces a senescence-like proliferation arrest in B-Raf mutant melanoma cells'},\n",
       "  {'pubmed': 18668139,\n",
       "   'text': \"N-RAS(Q61K) and B-RAF(V600E) contribute to melanoma's resistance to apoptosis in part by downregulating Bim expression\"},\n",
       "  {'pubmed': 18669866,\n",
       "   'text': 'Observational study of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)'},\n",
       "  {'pubmed': 18676742,\n",
       "   'text': 'CST6, CXCL14, DHRS3, and SPP1 are regulated by BRAF signaling and may play a role in papillary thyroid carcinoma pathogenesis'},\n",
       "  {'pubmed': 18676756,\n",
       "   'text': 'Observational study of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)'},\n",
       "  {'pubmed': 18682506,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 18682506,\n",
       "   'text': 'The BRAF(V600E) mutation was demonstrated to be a poor prognostic factor independent from other clinicopathological features.'},\n",
       "  {'pubmed': 18697864,\n",
       "   'text': 'Identification and functional characterization of a novel T599I-VKSR(600-603)del BRAF mutation in a patient with follicular variant papillary thyroid carcinoma.'},\n",
       "  {'pubmed': 18710471,\n",
       "   'text': 'There is a higher frequency of the BRAF(V600E) mutation in papillary thyroid carcinomas than in normal thyroid tissue.'},\n",
       "  {'pubmed': 18715233,\n",
       "   'text': 'These data suggest that regulation of BIM expression by BRAF-->MEK-->ERK signaling is one mechanism by which oncogenic BRAF(V600E) can influence the aberrant physiology of melanoma cells.'},\n",
       "  {'pubmed': 18716556,\n",
       "   'text': 'focal gains at chromosome 7q34 and increased BRAF-MEK-ERK signaling are common findings in sporadic pilocytic astrocytomas'},\n",
       "  {'pubmed': 18718023,\n",
       "   'text': 'presence of the BRAF (V600E) mutation,the incidence of microsatellite instability high colorectal cancer in populations based study.'},\n",
       "  {'pubmed': 18757341,\n",
       "   'text': 'KRAS and BRAF mutations can impair response to anti-EGFR therapy for colorectal neoplasms'},\n",
       "  {'pubmed': 18757433,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 18759827,\n",
       "   'text': 'Observational study of genetic testing. (HuGE Navigator)'},\n",
       "  {'pubmed': 18778891,\n",
       "   'text': 'BRAF mutation is associated with the CpG island methylator phenotype in colorectal cancer from young patients'},\n",
       "  {'pubmed': 18778891,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 18782444,\n",
       "   'text': 'BRAF, KRAS and PIK3CA mutations occur prior to malignant transformation demonstrating that these oncogenic alterations are primary genetic events in colorectal carcinogenesis'},\n",
       "  {'pubmed': 18782444,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 18787396,\n",
       "   'text': 'These data implicates a mitotic role for B-Raf in regulating spindle formation and the spindle checkpoint in human somatic cells.'},\n",
       "  {'pubmed': 18794094,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 18794803,\n",
       "   'text': 'study identified a group of melanomas with low-activity BRAF mutations (G469E- and D594G) that are reliant upon CRAF-mediated survival activity'},\n",
       "  {'pubmed': 18798261,\n",
       "   'text': 'BRAF mutation occurs independently of CpG island methylator phenotype and MSI in all types of serrated polyps and may serve as a marker of serrated pathway of colorectal carcinogenesis'},\n",
       "  {'pubmed': 18806830,\n",
       "   'text': 'study concludes a single endogenous BRAF(V600E) allele is sufficient to repress BIM & prevent death from growth factor withdrawal; colorectal cancer cells with V600E mutations are addicted to the ERK1/2 pathway for repression of BIM'},\n",
       "  {'pubmed': 18832519,\n",
       "   'text': 'CIMP-high appears to be an independent predictor of a low colon cancer-specific mortality, while BRAF mutation is associated with a high colon cancer-specific mortality.'},\n",
       "  {'pubmed': 18834226,\n",
       "   'text': 'With at least 3 markers methylated, new CIMP-positive colorectal cancers were closely associated with proximal tumor location, low frequency of KRAS mutation, and high frequency of BRAF mutation.'},\n",
       "  {'pubmed': 18840924,\n",
       "   'text': 'BRAF(V600E) mutation may play some roles in local carcinoma development, there is no evidence that BRAF(V600E) mutation significantly reflects the aggressive characteristics and poor prognosis of patients with papillary carcinoma in Japan.'},\n",
       "  {'pubmed': 18840924,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 18945298,\n",
       "   'text': 'BRAF V600E appeared to be the most commonly mutated gene in both the melanocytic aggregate (seven of 18, 39%) and the melanoma (four of 18, 22%)'},\n",
       "  {'pubmed': 18946221,\n",
       "   'text': 'Hereditary pancreatitis patients with PRSS1 mutations also had mutations in BRAF and KRAS2.'},\n",
       "  {'pubmed': 18953432,\n",
       "   'text': 'study shows high expression of p16(INK4a) or the absence of activated B-RAF correlates with in vivo response of melanoma to cytotoxic drugs'},\n",
       "  {'pubmed': 18974108,\n",
       "   'text': 'rearrangement, which was not observed in a series of 244 higher-grade astrocytomas, results in an in-frame fusion gene incorporating the kinase domain of the BRAF oncogene'},\n",
       "  {'pubmed': 18980976,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 18985043,\n",
       "   'text': 'the T1799A BRAF mutation is present in a proportion of posterior uveal melanomas but within these tumours the distribution of the mutation is heterogeneous.'},\n",
       "  {'pubmed': 18987552,\n",
       "   'text': 'BRAF mutations may not play an important role in the oncogenesis or therapy of prostate adenocarcinoma'},\n",
       "  {'pubmed': 18992635,\n",
       "   'text': '8% of sporadic colorectal tumors in this study harbor mutation in the BRAF gene.'},\n",
       "  {'pubmed': 18992635,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 19001320,\n",
       "   'text': 'Observational study of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)'},\n",
       "  {'pubmed': 19001320,\n",
       "   'text': 'Wild-type BRAF is required for response to panitumumab or cetuximab in metastatic colorectal cancer.'},\n",
       "  {'pubmed': 19003996,\n",
       "   'text': 'BRAF-V600E mutation is uncommon in endocrine tumors other than thyroid papillary carcinomas'},\n",
       "  {'pubmed': 19012001,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 19012001,\n",
       "   'text': 'The result showed that the mutation rate of PIK3CA in nasopharyngeal carcinomas (n = 73) was 9.6%, whereas both BRAF (n = 65) and RAS (n = 45) were wild type in every specimen with adequate DNA for analysis.'},\n",
       "  {'pubmed': 19014278,\n",
       "   'text': 'In Korean patients with papillary thyroid carcinoma, the BRAFV600E mutation is associated with a lower frequency of background Hashimoto thyroiditis and a high frequency of lymph node metastasis.'},\n",
       "  {'pubmed': 19014278,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 19016743,\n",
       "   'text': 'Reverse transcription polymerase chain reaction-based sequencing revealed a fusion product between KIAA1549 and BRAF in pediatric low-grade astrocytomas'},\n",
       "  {'pubmed': 19018267,\n",
       "   'text': 'Observational study of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)'},\n",
       "  {'pubmed': 19018267,\n",
       "   'text': 'ovarian cancer patients with KRAS or BRAF mutations may benefit from CI-1040 treatment'},\n",
       "  {'pubmed': 19026650,\n",
       "   'text': 'Observational study of genetic testing. (HuGE Navigator)'},\n",
       "  {'pubmed': 19033861,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 19034577,\n",
       "   'text': 'BRAF(V600E) mutation is assocciated with aggressive papillary thyroid microcarcinoma.'},\n",
       "  {'pubmed': 19034577,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 19037234,\n",
       "   'text': 'NRAS and BRAF mutations increase from the radial to the vertical growth phase in cutaneous melanoma'},\n",
       "  {'pubmed': 19064572,\n",
       "   'text': 'Observational study and meta-analysis of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 19079609,\n",
       "   'text': 'Genetic extinction of BRAF(V600E) in established prostate tumors did not lead to tumor regression, indicating that while sufficient to initiate development of invasive prostate adenocarcinoma, BRAF(V600E) is not required for its maintenance.'},\n",
       "  {'pubmed': 19087308,\n",
       "   'text': 'G12D mutation may be more likely selected in a BRAF mutated context'},\n",
       "  {'pubmed': 19098310,\n",
       "   'text': 'ERK activation was induced by PKD2 overexpression via B-Raf signaling, providing a possible molecular mechanism of cystogenesis'},\n",
       "  {'pubmed': 19107232,\n",
       "   'text': 'BRAF pseudogene activation may play a role in thyroid tumor development.'},\n",
       "  {'pubmed': 19126563,\n",
       "   'text': 'Sessile serrated adenomas are encountered commonly in routine endoscopy practice and the histological diagnosis correlates strongly with the presence of BRAF mutation.'},\n",
       "  {'pubmed': 19127559,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 19133693,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 19142971,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 19147753,\n",
       "   'text': 'BRAF and RET/PTC dual mutations are associated with recurrent papillary thyroid carcinoma'},\n",
       "  {'pubmed': 19147753,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 19152441,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 19159571,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 19164452,\n",
       "   'text': 'MLH1-hypermethylated tumors harbor fewer APC and KRAS mutations and more BRAF mutations, suggesting that they develop distinctly from an MGMT methylator pathway.'},\n",
       "  {'pubmed': 19178815,\n",
       "   'text': 'Mutations are absent or rare in the kinase domain of B-RAF in Japanese head and neck squamous cell carcinoma.'},\n",
       "  {'pubmed': 19178815,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 19190079,\n",
       "   'text': 'Mutation in BRAF is associated with adrenocortical carcinomas.'},\n",
       "  {'pubmed': 19190105,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 19190129,\n",
       "   'text': 'Distinct BRAF (V600E) and KRAS mutations in high microsatellite instability sporadic colorectal cancer in African Americans.'},\n",
       "  {'pubmed': 19190129,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 19194051,\n",
       "   'text': 'Expression levels of fibronectin, vimentin and CITED1 were positively correlated with those of BRAFV600E, suggesting pathophysiological links between activated BRAF and overexpression of these genes.'},\n",
       "  {'pubmed': 19200582,\n",
       "   'text': '(novel) mutation in the activation kinase domain of the BRAF (A598V), this mutation led to the up-regulation of the BRAF kinase activity and its downstream signaling factors.'},\n",
       "  {'pubmed': 19206169,\n",
       "   'text': 'Findings provide evidence for a wide phenotypic diversity associated with mutations affecting BRAF, and occurrence of a clinical continuum associated with these molecular lesions.'},\n",
       "  {'pubmed': 19207009,\n",
       "   'text': 'the presence of the braf protein mutation increases prohibitin promoter activity and therefore potentially mediates effects of this mutation on the behavior of BRAF protein'},\n",
       "  {'pubmed': 19208736,\n",
       "   'text': 'BRAFT1799A mutation or RET/PTC rearrangement, mainly corresponding to follicular variants, maintain a thyroid differentiation expression level close to that of normal tissue.'},\n",
       "  {'pubmed': 19226609,\n",
       "   'text': 'BRAF* melanomas appear to be associated with a specific profile of DNA copy number aberrations that is distinct from those found in NRAS* and BRAF/NRAS(wt/wt) tumors.'},\n",
       "  {'pubmed': 19237633,\n",
       "   'text': 'Observational study of gene-disease association and gene-gene interaction. (HuGE Navigator)'},\n",
       "  {'pubmed': 19240718,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 19255327,\n",
       "   'text': 'Clinical trial of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)'},\n",
       "  {'pubmed': 19274086,\n",
       "   'text': 'oncogenic BRAF(V600E) induces the uncoupling of LKB1-AMPKalpha complexes providing at the same time a possible mechanism in cell proliferation that engages cell growth and cell division in response to mitogenic stimuli'},\n",
       "  {'pubmed': 19276360,\n",
       "   'text': 'GDC-0879-mediated efficacy was associated strictly with BRAF(V600E) status, MEK inhibition also attenuated proliferation and tumor growth of cell lines expressing wild-type BRAF.'},\n",
       "  {'pubmed': 19282104,\n",
       "   'text': 'study of KRAS/BRAF mutation status in a large and well-documented cohort of primary and metastatic renal cell carcinoma'},\n",
       "  {'pubmed': 19289622,\n",
       "   'text': 'Observational study of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)'},\n",
       "  {'pubmed': 19289622,\n",
       "   'text': 'a correlation between a gene mutation--BRAF V600E--and cisplatin resistance in nonseminomatous germ cell tumors.'},\n",
       "  {'pubmed': 19342899,\n",
       "   'text': 'Both BRAF and RKIP expression levels exhibit a decrease from normal skin tissue and actinic keratosis, going to squamous cell carcinoma.'},\n",
       "  {'pubmed': 19344998,\n",
       "   'text': 'In BRAF mutated colorectal carcinoma cells quercetin, luteolin and ursolic acid decreased Akt phosphorylation'},\n",
       "  {'pubmed': 19351817,\n",
       "   'text': 'Observational study of gene-disease association and gene-environment interaction. (HuGE Navigator)'},\n",
       "  {'pubmed': 19355825,\n",
       "   'text': 'BRAF(V600E) is associated some of the aggressive clinicopathological features of papillary thyroid carcinoma including younger age at diagnosis, larger tumor size, and classic histological type, as well as also extrathyroidal invasion.'},\n",
       "  {'pubmed': 19355825,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 19358278,\n",
       "   'text': 'Observational study of gene-disease association and gene-environment interaction. (HuGE Navigator)'},\n",
       "  {'pubmed': 19362540,\n",
       "   'text': 'Targets of phosphorylation by B-Raf signaling are investigated in melanoma.'},\n",
       "  {'pubmed': 19369630,\n",
       "   'text': 'K-ras, EGFR, and BRAF mutations are disproportionately seen in adenocarcinomas of lung with a dominant micropapillary growth pattern compared with conventional adenocarcinoma in our institutional experience.'},\n",
       "  {'pubmed': 19369630,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 19370505,\n",
       "   'text': 'BRAF V600E mutation was significantly found in papillary thyroid carcinoma.'},\n",
       "  {'pubmed': 19370505,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 19372556,\n",
       "   'text': 'Mutation in BRAF is associated with ERK1/2 activation and MEK1/2 inhibitor therapy in colorectal cancer.'},\n",
       "  {'pubmed': 19378335,\n",
       "   'text': 'proliferation of cells harboring mutations in B-Raf, but not K-Ras, is exquisitely sensitive inhibition of the MAPK pathway'},\n",
       "  {'pubmed': 19383313,\n",
       "   'text': 'REVIEW summarizes the literature on NRAS and BRAF activating mutations in melanoma tumors with respect to available data on histogenetic classification as well as body site and presumed UV-exposure.'},\n",
       "  {'pubmed': 19383316,\n",
       "   'text': 'The genes whose expression is associated with BRAF mutations are not simply restricted to the MAPK/ERK signaling but also converge to enhanced immune responsiveness, cell motility and melanosomes processing involved in the adaptative UV response'},\n",
       "  {'pubmed': 19389934,\n",
       "   'text': 'a subpopulation of melanocytes possesses the ability to survive BRAF(V600E)-induced senescence'},\n",
       "  {'pubmed': 19393416,\n",
       "   'text': 'B-RAF mutation was found to be significantly higher in papillary carcinomas when compared to follicular variant of papillary thyroid carcinomas (55.6% vs 14.3%, P = 0.05).'},\n",
       "  {'pubmed': 19393416,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 19398955,\n",
       "   'text': 'The murine model of mutant BRAF-induced melanoma formation provides an important tool for identifying further genetic alterations that cooperates with BRAF and that may be useful in enhancing susceptibility to BRAF-targeted therapeutics in melanoma.'},\n",
       "  {'pubmed': 19404844,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 19404844,\n",
       "   'text': 'elevated pERK expression occurs in urothelial carcinoma in the absence of B-Raf mutations and is not correlated with FGFR3 over-expression'},\n",
       "  {'pubmed': 19404918,\n",
       "   'text': 'Investigated BRAF mutations in 30 bladder tumors. Detected two tumor specimens bearing two different mutations, both of which were found in exon 15. One sample showed the T1799A (V600E) and the other the G1798T (V600L) mutation.'},\n",
       "  {'pubmed': 19404918,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 19414674,\n",
       "   'text': 'Observational study of gene-disease association and genetic testing. (HuGE Navigator)'},\n",
       "  {'pubmed': 19415957,\n",
       "   'text': 'The T1799A BRAF mutation does not appear to play a role in the tumorigenesis of the cribriform-morular variant of papillary carcinoma.'},\n",
       "  {'pubmed': 19416762,\n",
       "   'text': 'Novel BRAF mutation in a patient with LEOPARD syndrome and normal intelligence is reported.'},\n",
       "  {'pubmed': 19424571,\n",
       "   'text': 'BRAF V600E mutation is not the target gene for abnormal DNA mismatch repair in patients with sporadic endometrial cancer.'},\n",
       "  {'pubmed': 19424639,\n",
       "   'text': \"Report efficient molecular screening of Lynch syndrome by specific 3' promoter methylation of the MLH1 or BRAF mutation in colorectal cancer with high-frequency microsatellite instability.\"},\n",
       "  {'pubmed': 19430562,\n",
       "   'text': 'Mutations in BRAF were found 10% patients in the low-grade carcinoma group, however, they were not found in the high-grade carcinoma group. KRAS and BRAF mutations were mutually exclusive, and both mutations were observed in 40%.'},\n",
       "  {'pubmed': 19430562,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 19440799,\n",
       "   'text': 'oncogenic properties of KRAS and BRAF but not NRAS, HRAS, and PIK3CA contribute to the tumorigenesis of periampullary and ampullary tumors'},\n",
       "  {'pubmed': 19461239,\n",
       "   'text': 'mismatch repair deficiency is not a crucial event for BRAF mutation in melanocytic tumors'},\n",
       "  {'pubmed': 19464601,\n",
       "   'text': 'The RAS/RAF/MEK/ERK signaling pathway has emerged as a major player in the induction and maintenance of melanoma, particularly the protein kinase BRAF, mutated in approximately 44% of melanoma cases. Review.'},\n",
       "  {'pubmed': 19474002,\n",
       "   'text': 'data confirm that KRAS and BRAF mutations do occur in the same cell and that BRAF V600E mutation is associated with CIMP+ status.'},\n",
       "  {'pubmed': 19483722,\n",
       "   'text': 'B-Raf/MKK/ERK provides a permissive environment for melanoma genesis by modulating plexin B1.'},\n",
       "  {'pubmed': 19487299,\n",
       "   'text': 'If BRAF is mutated in the primary thyroid neoplasm, it is likely that the metastases will harbor the defect.'},\n",
       "  {'pubmed': 19487299,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 19492075,\n",
       "   'text': 'Targeting NRAS alone or both BRAF and CRAF in combination or both BRAF and PIK3CA together showed delay in tumor growth.'},\n",
       "  {'pubmed': 19498322,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 19498322,\n",
       "   'text': 'Results show that activating BRAF somatic mutations may be occasionally found in advanced adrenocortical carcinomas, while CTNNB1 activating mutations are early and common events in adrenal tumorigenesis.'},\n",
       "  {'pubmed': 19504446,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 19534622,\n",
       "   'text': 'CTNNB1 and BRAF mutations may have roles in the cribriform-morular variant of papillary thyroid carcinoma'},\n",
       "  {'pubmed': 19534623,\n",
       "   'text': 'BRAF V600E may have a role in development of papillary thyroid carcinoma'},\n",
       "  {'pubmed': 19543740,\n",
       "   'text': 'Pilocytic astrocytomas had BRAF fusions in 70% of cases but not IDH1 or IDH2 mutations. Diffuse astrocytomas had IDH1 mutations in 76% of cases but not IDH2 mutations or BRAF fusions. Analysis of BRAF and IDH1 separates pilocytic from diffuse astrocytoma.'},\n",
       "  {'pubmed': 19547661,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 19551857,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 19561230,\n",
       "   'text': 'BRAF mutations represent an alternative molecular pathway in the early tumorigenesis of a subset of KIT/PDGFRA wild-type GISTs and are per se not associated with a high risk of malignancy.'},\n",
       "  {'pubmed': 19561230,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 19571295,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 19571295,\n",
       "   'text': 'study concludes that a BRAF mutation is a negative prognostic marker in patients with metastatic colorectal cancer'},\n",
       "  {'pubmed': 19571709,\n",
       "   'text': 'BRAF mutated tumors occurred with a much greater frequency in proximal colon tumors than in either distal colon or rectal tumors'},\n",
       "  {'pubmed': 19571821,\n",
       "   'text': 'We observed no association between germline MC1R status and somatic BRAF mutations in melanomas'},\n",
       "  {'pubmed': 19574281,\n",
       "   'text': 'BRAF V600E mutation analysis can significantly improve FNAB diagnostic accuracy.'},\n",
       "  {'pubmed': 19584155,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 19584155,\n",
       "   'text': 'Results suggest that the mutations of EGFR, KRAS, BRAF between primary tumors and corresponding lymph node metastases should be considered whenever mutations are used for the selection of patients for EGFR-directed tyrosine kinase inhibitor therapy.'},\n",
       "  {'pubmed': 19603018,\n",
       "   'text': 'Assessing KRAS and BRAF mutations might help optimising the selection of the candidate metastatic colorectal cancer patients to receive anti-EGFR moAbs.'},\n",
       "  {'pubmed': 19603018,\n",
       "   'text': 'Observational study of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)'},\n",
       "  {'pubmed': 19603024,\n",
       "   'text': 'BRAF (P=0.01) mutations predicted reduced progress free survival in response to cetuximab salvage therapy in patients with metastatic colorectal cancer .'},\n",
       "  {'pubmed': 19603024,\n",
       "   'text': 'Observational study of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)'},\n",
       "  {'pubmed': 19624312,\n",
       "   'text': 'Mutated BRAF is a target in metastatic melanomas'},\n",
       "  {'pubmed': 19626635,\n",
       "   'text': 'In this study, 28 matched tumor and serum samples obtained from patients with both benign and malignant thyroid disorders were analyzed for BRAF mutation.'},\n",
       "  {'pubmed': 19626635,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 19628078,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 19633643,\n",
       "   'text': 'Characterization of candidate gene copy number alterations in the 11q13 region along with BRAF and NRAS mutations in human melanoma.'},\n",
       "  {'pubmed': 19637313,\n",
       "   'text': 'strong inter-relation between DR4 AND DR5 overexpression and presence of oncogenic KRAS/ BRAF mutations in colon cancer.'},\n",
       "  {'pubmed': 19638574,\n",
       "   'text': 'Sorafenib inhibits NSCLC cell growth by targeting B-RAF in cells with wild-type KRAS and C-RAF in those with mutant KRAS.'},\n",
       "  {'pubmed': 19644722,\n",
       "   'text': 'BRAFV600E mutation is associated with papillary thyroid carcinoma.'},\n",
       "  {'pubmed': 19652585,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 19659611,\n",
       "   'text': 'simultaneous depletion of both MITF and BRAF(V600E) significantly inhibited melanoma growth even for the melanoma cell lines resistant to MITF depletion'},\n",
       "  {'pubmed': 19667985,\n",
       "   'text': 'Studies indicate that in pilocytic astrocytomas, the BRAF fusion gene has been identified as a specific and frequent event leading to potentially targetable mitogen-activated protein kinase pathway activation.'},\n",
       "  {'pubmed': 19669908,\n",
       "   'text': 'Observational study of gene-disease association and DATA ERROR. (HuGE Navigator)'},\n",
       "  {'pubmed': 19679016,\n",
       "   'text': 'Studies indicate that drugs are effective in targeting essential molecular pathways of BRAF, PTEN, Akt and mammalian target of rapamycin.'},\n",
       "  {'pubmed': 19679059,\n",
       "   'text': 'Mutations in BRAF protein is associated with Colorectal Carcinoma.'},\n",
       "  {'pubmed': 19679059,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 19681119,\n",
       "   'text': 'Investigated the prevalence of PTPN11, HRAS, KRAS, NRAS, BRAF, MEK1, and MEK2 mutations in a relatively large cohort of primary embryonal Rhabdomyosarcoma (RMS) tumors. No mutation was observed in BRAF and MEK genes.'},\n",
       "  {'pubmed': 19682280,\n",
       "   'text': 'This study provides a basis for understanding the molecular processes that are regulated by (V600E)BRAF/MEK signalling in melanoma cells.'},\n",
       "  {'pubmed': 19686742,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 19690147,\n",
       "   'text': 'a dual mechanism that affects the Sprouty2/B-Raf interaction: Sprouty phosphorylation and B-Raf conformation'},\n",
       "  {'pubmed': 19693938,\n",
       "   'text': 'Whenever necessary BRAF testing may be performed on the residual samples of thyroid nodules, without interfering with routine cytology.'},\n",
       "  {'pubmed': 19704056,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 19710001,\n",
       "   'text': 'The BRAF(V600E) mutation can be used as a potential prognostic factor in PTMC patients in a BRAF(V600E)-prevalent area.'},\n",
       "  {'pubmed': 19710016,\n",
       "   'text': 'DGKeta acts as a novel critical regulatory component of the Ras/B-Raf/C-Raf/MEK/ERK signaling cascade via a previously unidentified mechanism.'},\n",
       "  {'pubmed': 19718661,\n",
       "   'text': 'analysis of the effect on the Ras/Raf signaling pathway of post-translational modifications of neurofibromin'},\n",
       "  {'pubmed': 19724843,\n",
       "   'text': 'This article focuses on reviewing the impact of the BRAFV600E mutation in the tumorigenesis of Papillary thyroid carcinoma'},\n",
       "  {'pubmed': 19725049,\n",
       "   'text': 'EPAC-mediated cellular effects require activation of the B-Raf/ERK and mTOR signaling cascades'},\n",
       "  {'pubmed': 19735675,\n",
       "   'text': 'Insights into the molecular function of the inactivating mutations of B-Raf involving the DFG motif.'},\n",
       "  {'pubmed': 19738388,\n",
       "   'text': 'Observational study of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)'},\n",
       "  {'pubmed': 19738460,\n",
       "   'text': 'Papillary carcinomas of the thyroid with papillary growth and areas of follicular growth have a high frequency of BRAF mutations.'},\n",
       "  {'pubmed': 19745699,\n",
       "   'text': 'Beta-catenin nuclear labeling is a common feature of sessile serrated adenomas and correlates with early neoplastic progression after BRAF activation.'},\n",
       "  {'pubmed': 19752400,\n",
       "   'text': 'The polyclonality of BRAF mutations in acquired melanocytic nevi suggests that mutation of BRAF may not be an initial event in melanocyte transformation.'},\n",
       "  {'pubmed': 19759551,\n",
       "   'text': 'analysis of coexisting NRAS and BRAF mutations in primary familial melanomas with specific CDKN2A germline alterations'},\n",
       "  {'pubmed': 19765726,\n",
       "   'text': 'Observational study of gene-disease association and gene-gene interaction. (HuGE Navigator)'},\n",
       "  {'pubmed': 19794125,\n",
       "   'text': 'As predicted from the genomic organization at this locus, 22 of 36 patients with sporadic pilocytic astrocytomas and B-Raf gene rearrangement also exhibit corresponding homeodomain interacting protein kinase-2 (HIPK2) gene amplification.'},\n",
       "  {'pubmed': 19826477,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 19829302,\n",
       "   'text': 'data argues against obligatory downregulation in IGFBP7 expression in BRAF mutated melanoma cells'},\n",
       "  {'pubmed': 19850689,\n",
       "   'text': 'BRAF(T1799A) can be detected in the blood of papillary thyroid carcinoma patients with residual or metastatic disease and may provide diagnostic information'},\n",
       "  {'pubmed': 19850689,\n",
       "   'text': 'Observational study of genetic testing. (HuGE Navigator)'},\n",
       "  {'pubmed': 19855373,\n",
       "   'text': 'BRAF V600E mutations were seen in 83% of proximal and 74% of distal hyperplastic colonic polyps'},\n",
       "  {'pubmed': 19861538,\n",
       "   'text': 'BRAFV600E oncogene induces transforming growth factor beta secretion leading to sodium iodide symporter repression and increased malignancy in thyroid cancer.'},\n",
       "  {'pubmed': 19861964,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 19861964,\n",
       "   'text': 'These data demonstrate the feasibility of BRAF mutation detection in cfDNA of patients with advanced melanoma. Future studies should aim to incorporate BRAF mutation testing in cfDNA to further validate this biomarker for patient selection.'},\n",
       "  {'pubmed': 19878585,\n",
       "   'text': 'Suppression of BRAF gene expression inhibited cell proliferation in cells with BRAF(V600E) mutation.'},\n",
       "  {'pubmed': 19880519,\n",
       "   'text': 'Hyperactivation of BRAF-MEK signaling activates MAP2 expression in melanoma cells by two independent mechanisms, promoter demethylation or down-regulation of neuronal transcription repressor HES1.'},\n",
       "  {'pubmed': 19881948,\n",
       "   'text': 'BRAF and KRAS oncogenes have different transforming capability in colon cancer'},\n",
       "  {'pubmed': 19883729,\n",
       "   'text': 'The knowledge of BRAF mutation status can facilitate more accurate risk stratification and better decision making at various steps in the management of papillary thyroid cancer.'},\n",
       "  {'pubmed': 19884549,\n",
       "   'text': 'Clinical trial of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)'},\n",
       "  {'pubmed': 19884549,\n",
       "   'text': 'KRAS and BRAF mutations in advanced colorectal cancer are associated with poor prognosis but do not preclude benefit from oxaliplatin or irinotecan.'},\n",
       "  {'pubmed': 19884556,\n",
       "   'text': 'BRAF status, EGFR amplification, and cytoplasmic expression of PTEN were associated with outcome measures in KRAS wild-type patients treated with a cetuximab-based regimen.'},\n",
       "  {'pubmed': 19884556,\n",
       "   'text': 'Observational study of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)'},\n",
       "  {'pubmed': 19893451,\n",
       "   'text': 'Study identified the previously reported pathogenic mutation of NTRK3 in a KRAS/BRAF wild-type tumor and 2 somatic mutations in the Src family of kinases (YES1 and LYN) that would be expected to cause structural changes.'},\n",
       "  {'pubmed': 19903786,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 19908233,\n",
       "   'text': 'BRAF gene mutation is associated with colorectal cancer.'},\n",
       "  {'pubmed': 19908233,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 19913317,\n",
       "   'text': 'BRAF mutations are not relevant for rectal carcinogenesis'},\n",
       "  {'pubmed': 19913317,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 19917255,\n",
       "   'text': 'Data show that melanoma cells expressing B-Raf(V600E) display a reduced C-Raf:B-Raf ratio, and further suppression of C-Raf increases MAPK activation and proliferation.'},\n",
       "  {'pubmed': 19919630,\n",
       "   'text': 'The BRAF V600E mutational status appears to be of limited diagnostic utility in distinguishing genital naevi that exhibit atypia from those that do not.'},\n",
       "  {'pubmed': 19919912,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 19935791,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 19955937,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 19955937,\n",
       "   'text': 'v-Raf murine sarcoma viral oncogene mutations are common in ovarian serous bordeline tumors.'},\n",
       "  {'pubmed': 19956635,\n",
       "   'text': 'Uncategorized study of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)'},\n",
       "  {'pubmed': 19958951,\n",
       "   'text': 'clinical, cytologic, and pathologic parameters of 106 consecutive surgically treated patients with BRAF-positive PTC were compared with a concurrent cohort of 100 patients with BRAF-negative PTC (papillary thyroid carcinoma)'},\n",
       "  {'pubmed': 19959686,\n",
       "   'text': '2-fold increased risk of BRAF V600E colonic tumor mutation was observed in current and former cigarette smokers homozygous for the OGG1 polymorphism'},\n",
       "  {'pubmed': 19960590,\n",
       "   'text': 'BRAF T1796A mutation was identified in 27% of papillary thyroid cancer samples and its identification may be used to determine this risk factor of the development of papillary thyroid cancer.'},\n",
       "  {'pubmed': 19960590,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 20008640,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 20009493,\n",
       "   'text': 'BRAFV600E mutation is associated with high-risk clinicopathological characteristics of papillary thyroid carcinoma and worse prognosis of patients'},\n",
       "  {'pubmed': 20009493,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 20012784,\n",
       "   'text': 'Screening for BRAF, RET, KRAS, NRAS, and HRAS mutations, as well as RET-PTC1 and RET-PTC3 rearrangements, was performed on cases of Hashimoto thyroiditis with a dominant nodule'},\n",
       "  {'pubmed': 20023270,\n",
       "   'text': 'BRAF V600E detection in the tumor does not induce a higher expression of the B-raf protein or the preferential activation of the p42/44 mitogen-activated protein kinase (MAPK) signaling pathway compared with GISTs without the BRAF mutation.'},\n",
       "  {'pubmed': 20027224,\n",
       "   'text': 'CpG island methylator phenotype (CIMP)-specific inactivation of BRAF(V600E)-induced senescence and apoptosis pathways by IGFBP7 DNA hypermethylation might create a favorable context for the acquisition of BRAF(V600E) in CIMP+ colorectal cancer.'},\n",
       "  {'pubmed': 20043015,\n",
       "   'text': 'Observational study of gene-disease association and gene-gene interaction. (HuGE Navigator)'},\n",
       "  {'pubmed': 20043015,\n",
       "   'text': 'no support for MC1R variants with BRAF mutation for melanoma risk'},\n",
       "  {'pubmed': 20044755,\n",
       "   'text': 'BRAF gene rearrangements were more common in cerebellar pilocytic astrocytoma than non-cerebellar tumors; clinical outcome was independent of BRAF status'},\n",
       "  {'pubmed': 20049644,\n",
       "   'text': 'BRAF mutations only in metastases is not associated with resistance to anti-EGFR treatment in primary colorectal tumors.'},\n",
       "  {'pubmed': 20049644,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 20051945,\n",
       "   'text': 'Observational study of genetic testing. (HuGE Navigator)'},\n",
       "  {'pubmed': 20068183,\n",
       "   'text': 'BRAF(V600E) mutation seems to define a subset of malignant astrocytomas in children, in which there is frequent concomitant homozygous deletion of CDKN2A (five of seven cases).'},\n",
       "  {'pubmed': 20098682,\n",
       "   'text': 'Observational study of genetic testing. (HuGE Navigator)'},\n",
       "  {'pubmed': 20118768,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 20140953,\n",
       "   'text': 'Formalin-fixed primary melanomas from relapsed and nonrelapsed patients were sequenced for common BRAF and NRAS mutations. BRAF/NRAS mutations were detected in 77% of relapsers and 58% of nonrelapsers and did not predict ulceration or mitotic rate.'},\n",
       "  {'pubmed': 20146801,\n",
       "   'text': 'Data demonstrate a signaling loop between B-Raf activation and p73 function, and suggest that low expression of TAp73 in colorectal cancer cell lines with mutated B-Raf may lead to lack of response to oxaliplatin/cetuximab.'},\n",
       "  {'pubmed': 20156809,\n",
       "   'text': 'BRAF activating mutations are a major genetic alteration in this histologic group of pediatric low-grade brain tumors.'},\n",
       "  {'pubmed': 20162668,\n",
       "   'text': 'Observational study of gene-disease association and gene-gene interaction. (HuGE Navigator)'},\n",
       "  {'pubmed': 20162668,\n",
       "   'text': 'With MSI, specific KRAS and BRAF mutations, 3 distinct prognostic subgroups were observed: patients with (i) KRAS mutation G12D, G12V or BRAFmutation, (ii) KRAS/BRAFwild-type or KRAS G13D mutations in MSS/MSI-L and (iii) MSI-H and KRAS G13D mutations.'},\n",
       "  {'pubmed': 20177422,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 20182446,\n",
       "   'text': 'High oncogenic BRAF levels trigger autophagy, which may have a role in melanoma tumor progression.'},\n",
       "  {'pubmed': 20186801,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 20187782,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 20200438,\n",
       "   'text': 'Observational study of gene-disease association and gene-environment interaction. (HuGE Navigator)'},\n",
       "  {'pubmed': 20200438,\n",
       "   'text': 'we measured the prevalence and epidemiologic correlates of the BRAF V600E somatic mutation in cases collected as a part of a population-based case-control study of colorectal cancer in northern Israel.'},\n",
       "  {'pubmed': 20230995,\n",
       "   'text': 'pathogenesis of papillary thyroid cancer , and the clinical implications of BRAF(V600E) mutation in the diagnosis, prognosis and potential targeted therapeutic strategies for thyroid cancer [review]'},\n",
       "  {'pubmed': 20233436,\n",
       "   'text': 'data support the model of BRAF and K-ras mutations arising in distinct colorectal cancer subsets associated with different clinicopathological and dietary factors, acting as mutually exclusive mechanisms of activation of the same signalling pathway'},\n",
       "  {'pubmed': 20234366,\n",
       "   'text': 'Observational study of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)'},\n",
       "  {'pubmed': 20300843,\n",
       "   'text': 'BRAF mutation is not associated with interval cancers but is a marker of poor prognosis, particularly in microsatellite stable cancers.'},\n",
       "  {'pubmed': 20300843,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 20302979,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 20303012,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 20303012,\n",
       "   'text': 'Our study suggests that mutations of KRAS, not BRAF, may play a role in the pathogenesis of prostate carcinoma in Chinese patients.'},\n",
       "  {'pubmed': 20305537,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 20332228,\n",
       "   'text': 'Studies show FOXD3 is suppressed by B-RAF, uncover a novel role and mechanism for FOXD3 as a negative cell cycle regulator, and have implications for the repression of melanocytic lineage cells.'},\n",
       "  {'pubmed': 20351680, 'text': 'Mutated in melanoma.'},\n",
       "  {'pubmed': 20379614,\n",
       "   'text': 'Clinical trial of gene-disease association and gene-environment interaction. (HuGE Navigator)'},\n",
       "  {'pubmed': 20381121,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 20406109,\n",
       "   'text': 'The miR-146b expression levels in papillary thyroid carcinoma with BRAF mutation were significantly higher than those without this mutation'},\n",
       "  {'pubmed': 20407018,\n",
       "   'text': 'Activated Raf-1 induces focal adhesion kinase expression and regulates neuroendocrine and metastatic phenotypes in gastrointestinal carcinoid cell line BON.'},\n",
       "  {'pubmed': 20410389,\n",
       "   'text': 'thyroid carcinoma with the BRAF(V600E) mutation tends to be taller than wide and is not associated with the presence of calcifications on ultrasound.'},\n",
       "  {'pubmed': 20413299,\n",
       "   'text': 'Observational study of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)'},\n",
       "  {'pubmed': 20444249,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 20445557,\n",
       "   'text': 'B-RAF(V600E) can protect melanocytes from anoikis independently of cell cycle inhibition'},\n",
       "  {'pubmed': 20453000,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 20454969,\n",
       "   'text': 'This study identified an exceptionally high frequency of KIAA1549-BRAF fusions in pilocytic astrocytoma.'},\n",
       "  {'pubmed': 20460314,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 20460314,\n",
       "   'text': 'These data demonstrate a high prevalence of B-RAF mutations in the present study population, underscoring the possibility of strong regional differences.'},\n",
       "  {'pubmed': 20473281,\n",
       "   'text': 'Hypoxia-inducible factor-1alpha is expressed in papillary thyroid carcinomas and is regulated not only by hypoxia but also by BRAF(V600E)-mediated signaling pathway.'},\n",
       "  {'pubmed': 20473281,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 20478260,\n",
       "   'text': 'Study concludes that the secreted protein IGFBP7 is dispensable for B-RAF(V600E)-induced senescence in human melanocytes.'},\n",
       "  {'pubmed': 20485284,\n",
       "   'text': 'BRAF V600E mutations are associated with MSI-H status and cyclin D1 overexpression and characterize a subgroup of patients with poor prognosis.'},\n",
       "  {'pubmed': 20485284,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 20489114,\n",
       "   'text': 'Observational study of genetic testing. (HuGE Navigator)'},\n",
       "  {'pubmed': 20495538,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 20496269,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 20498063,\n",
       "   'text': 'Knockdown of B-Raf(V600E) resulted in thrombospondin-1 down-regulation and a reduction of adhesion and migration/invasion of human thyroid cancer cells.'},\n",
       "  {'pubmed': 20501503,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 20501503,\n",
       "   'text': 'The V600E BRAF mutation confers a worse prognosis to stage II and stage III colon cancer patients independently of disease stage and therapy.'},\n",
       "  {'pubmed': 20501689,\n",
       "   'text': 'Observational study of gene-disease association and genetic testing. (HuGE Navigator)'},\n",
       "  {'pubmed': 20514492,\n",
       "   'text': 'BRAF mutation may be used a biomarker for the selection of patients with colorectal cancer patients who might benefit from anti-egf receptor monoclonal antibodies.'},\n",
       "  {'pubmed': 20514492,\n",
       "   'text': 'Meta-analysis of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)'},\n",
       "  {'pubmed': 20519626,\n",
       "   'text': 'Studies identified the oncogenic BRAF V600E mutation in 35 of 61 archived specimens (57%).'},\n",
       "  {'pubmed': 20526288,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 20526288,\n",
       "   'text': 'The BRAF 1799T>A mutation was found in 5 of 19 (26%) of infiltrative follicular variant of papillary thyroid carcinomas and in none of the encapsulated carcinomas'},\n",
       "  {'pubmed': 20543023,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 20563851,\n",
       "   'text': 'HER2, but not EGFR gene amplification, is frequently observed in KRAS and BRAF wild type colorectal cancer patients'},\n",
       "  {'pubmed': 20563851,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 20569675,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 20569675,\n",
       "   'text': 'reports the low frequency of PIK3CA and B-RAF mutations in astrocytomas, despite the presence of activated ERK and AKT proteins'},\n",
       "  {'pubmed': 20570909,\n",
       "   'text': 'Incidence of cancer in FDRs of index CRC patients with the p.V600E BRAF mutation may be explained by a genetic predisposition to develop cancer through the serrated pathway of colorectal carcinogenesis.'},\n",
       "  {'pubmed': 20570909,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 20571907,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 20571907,\n",
       "   'text': 'PIK3CA mutations may have a role in KRAS and BRAF wild type colorectal cancer'},\n",
       "  {'pubmed': 20573852,\n",
       "   'text': 'BRAF mutational status of metastases is not required when the primary tumour is BRAF wild type.'},\n",
       "  {'pubmed': 20576522,\n",
       "   'text': 'allele specific Taqman-based real-time PCR assay allows the sensitive, accurate and reliable measurement of BRAF(V600E) mutated DNA in plasma'},\n",
       "  {'pubmed': 20591910,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 20605766,\n",
       "   'text': 'in melanomas activation of the MAPK pathway can occur through signaling pathways operating independently of BRAF T1799A'},\n",
       "  {'pubmed': 20607849,\n",
       "   'text': 'V600E BRAF mutation is not associated with seminoma.'},\n",
       "  {'pubmed': 20616366,\n",
       "   'text': 'Using traditional PCR and direct sequencing, we found KRAS mutations in 47 (40%) patients and BRAF(V600E) in 10 (8.5%)'},\n",
       "  {'pubmed': 20619739,\n",
       "   'text': 'if KRAS is not mutated, assessing BRAF, NRAS, and PIK3CA exon 20 mutations (in that order) gives additional information about the efficacy of cetuximab plus chemotherapy in metastatic colorectal cancer.'},\n",
       "  {'pubmed': 20627194,\n",
       "   'text': 'PCR is practically applicable to KRAS/BRAF genotyping using small amounts of biopsied colorectal tumor cells.'},\n",
       "  {'pubmed': 20631031,\n",
       "   'text': 'No significant difference in BRAF alterations was found between pT1 tumors and thyroid capsule invasion and pT3 tumors.'},\n",
       "  {'pubmed': 20631031,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 20635392,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 20640859,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 20645028,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 20645028,\n",
       "   'text': 'samples of metastatic colorectal cancer were tested for the presence of the seven most common mutations in the KRAS gene and the V600E mutation in the BRAF gene'},\n",
       "  {'pubmed': 20647301,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 20647317,\n",
       "   'text': 'Findings delineate how mutant B-RAF protects melanoma cells from apoptosis and provide insight into possible resistance mechanisms to B-RAF inhibitors.'},\n",
       "  {'pubmed': 20652941,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 20670148,\n",
       "   'text': 'Traditional DNA sequencing and the somewhat more-sensitive pyrosequencing method can detect multiple alternative BRAF mutations.'},\n",
       "  {'pubmed': 20679909,\n",
       "   'text': 'Mutant Braf can be detected in RNA from mixed populations with as few as 0.1% Braf(V600E) mutant cells.'},\n",
       "  {'pubmed': 20689758,\n",
       "   'text': 'PLX4032 has robust activity in BRAF mutated melanoma.'},\n",
       "  {'pubmed': 20702649,\n",
       "   'text': 'Observational study of gene-disease association and gene-gene interaction. (HuGE Navigator)'},\n",
       "  {'pubmed': 20703476,\n",
       "   'text': 'Observational study of genetic testing. (HuGE Navigator)'},\n",
       "  {'pubmed': 20720566,\n",
       "   'text': 'Observational study of gene-disease association and gene-gene interaction. (HuGE Navigator)'},\n",
       "  {'pubmed': 20720566,\n",
       "   'text': 'association between MC1 receptor germline variation and BRAF/NRAS mutations in melanoma'},\n",
       "  {'pubmed': 20736745,\n",
       "   'text': 'Observational study of gene-disease association and gene-gene interaction. (HuGE Navigator)'},\n",
       "  {'pubmed': 20802181,\n",
       "   'text': 'BRAF mutation is rare in advanced-stage low-grade ovarian serous carcinomas.'},\n",
       "  {'pubmed': 20802181,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 20807807,\n",
       "   'text': 'Mutant protein kinase elicits significant therapeutic responses in mutant BRAF-driven human melanoma xenografts.'},\n",
       "  {'pubmed': 20813562,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 20813562,\n",
       "   'text': 'first report implicating BRAF mutation in OSCC. study supports that mutations in the BRAF gene makes at least a minor contribution to OSCC tumorigenesis.'},\n",
       "  {'pubmed': 20837233,\n",
       "   'text': 'BRAF mutation detection in fine needle biopsy may be an adjunct tool for preoperative didagnosis of papillary thyroid carcinoma.'},\n",
       "  {'pubmed': 20840674,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 20840674,\n",
       "   'text': 'RET rearrangements and BRAF mutation in undifferentiated thyroid carcinomas having papillary carcinoma components'},\n",
       "  {'pubmed': 20843808,\n",
       "   'text': 'A BRAF aberrant splice variant with an intact kinase domain and partial loss of the N-terminal autoinhibitory domain was identified in fibroblasts from an additional patient, and fibroblast proliferation was inhibited by BRAF-specific siRNA.'},\n",
       "  {'pubmed': 20853079,\n",
       "   'text': 'reduced RKIP mRNA levels and the elevated levels of B-RAF in pT1, grade III tumors vs. normal tissue, corroborate that these genes are involved in the pathogenesis of urinary bladder cancer.'},\n",
       "  {'pubmed': 20857202,\n",
       "   'text': 'BRAF V600E mutation is associated with lack of response in wild-type KRAS metastatic colorectal cancer treated with anti-EGFR monoclonal antibodies.'},\n",
       "  {'pubmed': 20860430,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 20881644,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 20944096,\n",
       "   'text': 'Determination of the BRAF mutation and the growth fraction of melanomas may add a prognostic value.'},\n",
       "  {'pubmed': 20944096,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 20945104,\n",
       "   'text': 'BRAF(V600E) mutation is associated with thyroid nodules.'},\n",
       "  {'pubmed': 20945104,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 20947270,\n",
       "   'text': 'In the present series, no BRAF mutation was detected. The presence of KRAS mutations and loss of PTEN expression were not associated with impaired response to cetuximab-based chemoradiotherapy and 3-year disease free survival.'},\n",
       "  {'pubmed': 20947270,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 20950194,\n",
       "   'text': 'BRAF is mutated in a low percentage of follicular variant of papillary thyroid carcinoma, and most of these mutated cases are suspicious or positive on fine-needle aspiration.'},\n",
       "  {'pubmed': 20953721,\n",
       "   'text': 'BRAF mutation is associated with papillary thyroid microcarcinoma.'},\n",
       "  {'pubmed': 20955560,\n",
       "   'text': 'Anti-BRAF autoantibodies from RA patients preferentially recognize one BRAF peptide: P2'},\n",
       "  {'pubmed': 20959481,\n",
       "   'text': 'Braf mutation is associated with basal and treatment-induced regulation of the PI3K-AKT pathway as a critical regulator of AZD6244 sensitivity in cutaneous melanoma.'},\n",
       "  {'pubmed': 20962618,\n",
       "   'text': 'Describe benign serrated colorectal fibroblastic polyps/intramucosal perineuriomas are true mixed epithelial-stromal polyps (hybrid hyperplastic polyp/mucosal perineurioma) with frequent BRAF mutations.'},\n",
       "  {'pubmed': 20975100,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 20979647,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 21048031,\n",
       "   'text': 'Observational study of gene-disease association and gene-environment interaction. (HuGE Navigator)'},\n",
       "  {'pubmed': 21049459,\n",
       "   'text': 'Although many studies document BRAF mutation as a prognostic factor in PTC our results underline that it is too early to consider it as a routine clinical predictive factor.'},\n",
       "  {'pubmed': 21049459,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 21051183,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 21051183,\n",
       "   'text': 'findings indicate that somatic mutations in KRAS and PIK3CA but not BRAF oncogenes are closely associated with the development of cholangiocarcinoma in Chinese population'},\n",
       "  {'pubmed': 21068756,\n",
       "   'text': 'The dermoscopical and histopathological patterns of nevi correlate with the frequency of BRAF mutations.'},\n",
       "  {'pubmed': 21076620,\n",
       "   'text': 'Data show that BRAF knockdown led to suppression of the expression of the GABPbeta, which involved in regulating HPR1 promoter activity.'},\n",
       "  {'pubmed': 21098728,\n",
       "   'text': 'BRAF gene amplification can promote acquired resistance to MEK inhibitors in cancer cells harboring the BRAF V600E mutation.'},\n",
       "  {'pubmed': 21102258,\n",
       "   'text': 'Mutations of EGFR, BRAF, and KRAS in adenocarcinoma were mutually exclusive and inversely correlated with RASSF1A methylation'},\n",
       "  {'pubmed': 21102416,\n",
       "   'text': 'We show a strong association between concordant methylation of >/= 3 of five 3p22 genes with the CpG island methylator phenotype and the BRAF V600E mutation.'},\n",
       "  {'pubmed': 21103049,\n",
       "   'text': 'Data show that among 181 CRC patients, stratified by microsatellite instability status, DNA sequence changes were identified in KRAS (32%), BRAF (16%), PIK3CA (4%), PTEN (14%) and TP53 (51%).'},\n",
       "  {'pubmed': 21107320,\n",
       "   'text': 'identification of MAP3K8 (the gene encoding COT/Tpl2) as a MAPK pathway agonist that drives resistance to RAF inhibition in B-RAF(V600E) cell lines'},\n",
       "  {'pubmed': 21107323,\n",
       "   'text': 'melanomas escape B-RAF(V600E) targeting not through secondary B-RAF(V600E) mutations but via receptor tyrosine kinase (RTK)-mediated activation of alternative survival pathway(s) or activated RAS-mediated reactivation of the MAPK pathway'},\n",
       "  {'pubmed': 21129611,\n",
       "   'text': 'It therefore appears that BRAF mutations may play a strong negative prognostic role and only a slight role in resistance to anti-EGFR Abs.'},\n",
       "  {'pubmed': 21131919,\n",
       "   'text': 'Primary esophageal melanomas of Caucasian patients harbor mutations of c-Kit, KRAS and BRAF in varied frequencies.'},\n",
       "  {'pubmed': 21134544,\n",
       "   'text': 'BRAF mutation in papillary thyroid carcinoma is associated with an increased risk of palpable nodal recurrence and the need for reoperative surgery.'},\n",
       "  {'pubmed': 21134562,\n",
       "   'text': 'BRAF mutations activate the mitogen-activated protein kinase pathway and confer an aggressive thyroid cancer phenotype.'},\n",
       "  {'pubmed': 21161938,\n",
       "   'text': 'KRAS mutations arise more frequently than BRAF mutations in Moroccan patients with colorectal carcinomas.'},\n",
       "  {'pubmed': 21166657,\n",
       "   'text': 'The BRAF mutation was frequently detected in patients with superficial spreading melanoma (OR=2.021; P<0.001) and in melanomas arising in nonchronic sun-damaged skin (OR=2.043; P=0.001).'},\n",
       "  {'pubmed': 21167555,\n",
       "   'text': 'concluded that follicular variant of papillary thyroid carcinoma differs from conventional papillary thyroid carcinoma in the rate of BRAF mutation'},\n",
       "  {'pubmed': 21176117,\n",
       "   'text': 'These results show that melanoma cell phenotype is an important factor in MAPK pathway inhibition response, as invasive phenotype cell response is dependent on BRAF mutation status.'},\n",
       "  {'pubmed': 21185263,\n",
       "   'text': 'this study has confirmed that the BRAF(T1799A) mutation confers cancer cells sensitivity to PLX4032 and demonstrated its specific potential as an effective and BRAF(T1799A) mutation-selective therapeutic agent for thyroid cancer.'},\n",
       "  {'pubmed': 21190184,\n",
       "   'text': 'B-Raf(insT) and B-Raf(V600E) , but not B-Raf(wt) , provoke drastic morphological alterations in human astrocytes.'},\n",
       "  {'pubmed': 21203559,\n",
       "   'text': 'BRAF alternative splicing is differentially regulated in human and mouse. BRAF exon 9b is required for learning and memory associated with the hippocampus.'},\n",
       "  {'pubmed': 21215707,\n",
       "   'text': 'In melanoma cells, oncogenic (V600E) BRAF signaling downregulates PDE5A through the transcription factor BRN2, leading to increased cGMP and Ca2+ and the induction of invasion through increased cell contractility.'},\n",
       "  {'pubmed': 21223556,\n",
       "   'text': 'B-Raf signaling has a key function in the altered expression of contractile receptors in the cerebrovasculature.'},\n",
       "  {'pubmed': 21223812,\n",
       "   'text': 'The high expression of activated ERK is not caused by BRAF gene mutation in nasal mucosa malignant melanomas.'},\n",
       "  {'pubmed': 21224857,\n",
       "   'text': 'Acquisition of a BRAF mutation is not a founder event, but may be one of the multiple clonal events in melanoma development, which is selected for during the progression.'},\n",
       "  {'pubmed': 21239517,\n",
       "   'text': 'We found that performing BRAF(V600E) mutation analysis on the fine-needle aspiration biopsy specimens was of great help to make a therapeutic decision for thyroid nodules when the fine-needle aspiration biopsy results were equivocal'},\n",
       "  {'pubmed': 21249150,\n",
       "   'text': 'the oncogenic effect of BRAF(V600E) is associated with the inhibition of MST1 tumor suppressor pathways, and the activity of RASSF1A-MST1-FoxO3 pathways determines the phenotypes of BRAF(V600E) tumors.'},\n",
       "  {'pubmed': 21263251,\n",
       "   'text': 'These findings suggest that BRAF mutations may be associated with the pathogenesis of sessile serrated colorectal adenomas.'},\n",
       "  {'pubmed': 21270111,\n",
       "   'text': 'Findings suggest inhibition of autophagy in combination with ER stress-inducing agents may represent a means by which to harness autophagy for the therapeutic benefit of B-RAF wild-type melanoma.'},\n",
       "  {'pubmed': 21274671,\n",
       "   'text': 'B-Raf mutations, microsatellite instability and p53 protein expression is not associated with sporadic basal cell carcinomas.'},\n",
       "  {'pubmed': 21274720,\n",
       "   'text': 'The analysis of BRAF V600E mutation in 1,320 nervous system tumors reveals high mutation frequencies in pleomorphic xanthoastrocytoma, ganglioglioma and extra-cerebellar pilocytic astrocytoma.'},\n",
       "  {'pubmed': 21285991,\n",
       "   'text': 'Presence of mutated BRAF is one of the most powerful prognostic factors for advanced and recurrent CRC'},\n",
       "  {'pubmed': 21289333,\n",
       "   'text': '803 metastatic colorectal cancer samples studied for KRAS exon 2 and BRAF exon 15 mutations; BRAF mutated samples were characterized for mismatch repair function; 344 tumours were mutated -34 involving BRAF mutations (8 of microsatellite instability type)'},\n",
       "  {'pubmed': 21303778,\n",
       "   'text': 'Ras/Raf/MAPK and RhoA/ROCKII signalling pathways are abnormally activated in eutopic endometrial stromal cells of patients with endometriosis'},\n",
       "  {'pubmed': 21305640,\n",
       "   'text': '78 colorectal tumor samples were mutant for BRAF.'},\n",
       "  {'pubmed': 21307665,\n",
       "   'text': 'analysis of gallbladder carcinomas, gallbladder adenomas, and high-grade dysplastic lesions for the BRAF and the KRAS mutations'},\n",
       "  {'pubmed': 21317202,\n",
       "   'text': 'Findings suggest that inhibition of Raf-MEK-Erk pathway might offer a novel therapeutic strategy in neuroendocrine tumors'},\n",
       "  {'pubmed': 21317224,\n",
       "   'text': 'Studies showed that siRNA knockdown of BIM significantly blunted the apoptotic response in PTEN+ melanoma cells.'},\n",
       "  {'pubmed': 21317286,\n",
       "   'text': 'identified BAD serine 134 to be strongly involved in survival signaling of B-RAF-V600E-containing tumor cells and found that phosphorylation of BAD at this residue is critical for efficient proliferation in these cells.'},\n",
       "  {'pubmed': 21321384,\n",
       "   'text': 'identifying downstream events from the BRAFV600E/ERK1/2 pathway will eventually identify novel biomarkers that can be used to correlate with disease outcome and overall survival.'},\n",
       "  {'pubmed': 21324100,\n",
       "   'text': 'Data show that BRAF-mutated melanomas occur in a younger age group on skin without marked solar elastosis and less frequently affect the head and neck area, compared to melanomas without BRAF mutations.'},\n",
       "  {'pubmed': 21326296,\n",
       "   'text': 'BRAF mutations have a smaller role in the carcinogenesis of malignant melanoma in Chinese Han than in Western patients.'},\n",
       "  {'pubmed': 21332555,\n",
       "   'text': 'BRAF mutations were rare in colorectal laterally-spreading tumors.'},\n",
       "  {'pubmed': 21343559,\n",
       "   'text': 'The presence of mutant BRAF had no impact on the disease-free interval from diagnosis of first-ever melanoma to first distant metastasis; however, it may have impacted survival thereafter.'},\n",
       "  {'pubmed': 21345796,\n",
       "   'text': 'B-Raf associates with and stimulates NHE1 activity and that B-Raf(V600E) also increases NHE1 activity that raises intracellular pH.'},\n",
       "  {'pubmed': 21351275,\n",
       "   'text': 'BRAF mutation is associated with selective inhibition of thyroid cancer cells by the novel MEK inhibitor RDEA119 and genetic-potentiated synergism with the mTOR inhibitor temsirolimus'},\n",
       "  {'pubmed': 21356389,\n",
       "   'text': 'IDH1 mutation works with other oncogenic mutations and could contribute to the metastasis in melanoma.'},\n",
       "  {'pubmed': 21362156,\n",
       "   'text': 'Regulation of NR4A nuclear receptor expression by oncogenic BRAF in melanoma cells.'},\n",
       "  {'pubmed': 21383284,\n",
       "   'text': 'BRAF mutational status yielded no useful prognostic information in predicting recurrence and benefits from adjuvant chemotherapy in colorectal cancer.'},\n",
       "  {'pubmed': 21383288,\n",
       "   'text': 'Thus, MEK1(C121S) or functionally similar mutations are predicted to confer drug resistance of neoplasms to combined MEK/RAF inhibition.'},\n",
       "  {'pubmed': 21383698,\n",
       "   'text': 'tumor initiation by oncogenic BRAF renders thyroid cells susceptible to TGFbeta-induced epithelial-mesenchymal transition, through a MAPK-dependent process'},\n",
       "  {'pubmed': 21390154,\n",
       "   'text': 'K-ras gene mutation is a common event in Chinese colorectal cancer (CRC) patients, but may not be a prognostic factor in CRC , while BRAF is rarely mutated in Chinese CRC patients.'},\n",
       "  {'pubmed': 21408138,\n",
       "   'text': 'Allele-specific qPCR assays for the most frequent activating mutations in EGFR, KRAS, BRAF and PIK3CA in tumor-positive fine needle cytological aspirates were compared against histological material of primary tumors.'},\n",
       "  {'pubmed': 21412762,\n",
       "   'text': 'BRAF mutation is associated with papillary thyroid cancer.'},\n",
       "  {'pubmed': 21424126,\n",
       "   'text': 'study suggested that both KRAS and BRAF mutations are exclusive, but KRAS and PIK3CA mutations are coexistent'},\n",
       "  {'pubmed': 21424530,\n",
       "   'text': 'This study demonistrated that the role of RAF kinase fusions as a central oncogenic mechanism in the development of pilocytic astrocytoma.'},\n",
       "  {'pubmed': 21426297,\n",
       "   'text': 'Mutations at the position V600 of BRAF were described in approximately 8% of all solid tumors, including 50% of melanomas, 30 to 70% of papillary thyroid carcinomas and 5 to 8% of colorectal adenocarcinomas.'},\n",
       "  {'pubmed': 21427714,\n",
       "   'text': 'There were no significant differences in the frequency of BRAF mutations among lesions exhibiting the hyperplastic, adenomatous, or mixed patterns.'},\n",
       "  {'pubmed': 21430505,\n",
       "   'text': 'The presence of the BRAF(V600E) mutation may play different roles between medium and giant CMNs in melanocytic tumorigenesis.'},\n",
       "  {'pubmed': 21431280,\n",
       "   'text': 'BRAF T1799A mutation may be an early and essential carcinogenic event in nearly all Korean papillary thyroid carcinomas'},\n",
       "  {'pubmed': 21441079,\n",
       "   'text': 'In papilary thyroid carcinoma, the BRAFT1799A mutation is associated with age over 60 & a tumor size of 1cm or greater, but not with other clinicopathological characteristics, tumor recurrence or persistence.'},\n",
       "  {'pubmed': 21441910,\n",
       "   'text': \"KSR interacts with a regulatory Raf molecule in cis to induce a conformational switch of MEK, facilitating MEK's phosphorylation by a separate catalytic Raf molecule in trans\"},\n",
       "  {'pubmed': 21447798,\n",
       "   'text': 'Amplification of the driving oncogene, KRAS or BRAF, underpins acquired resistance to MEK1/2 inhibitors in colorectal cancer cells.'},\n",
       "  {'pubmed': 21451543,\n",
       "   'text': 'Activated BRAF promotes melanoma cell growth by matrix metalloproteinase-1'},\n",
       "  {'pubmed': 21455633,\n",
       "   'text': 'No V600E mutation was identified in the BRAF gene in any sample.'},\n",
       "  {'pubmed': 21456008,\n",
       "   'text': 'the impact of BRAF mutation and microsatellite instability on prognosis in metastatic colorectal cancer'},\n",
       "  {'pubmed': 21457162,\n",
       "   'text': 'BRAF mutations are specific for serrated adenocarcinoma and identify a subset of serrated adenocarcinomas with gene methylation and a tendency for MSI-H'},\n",
       "  {'pubmed': 21479234,\n",
       "   'text': 'BRAF V600E mutations are common in the majority of pleomorphic xanthoastrocytoma.'},\n",
       "  {'pubmed': 21483104,\n",
       "   'text': 'Heterogeneity of KRAS and BRAF mutation status intra-tumorally in colorectal cancer was assessed.'},\n",
       "  {'pubmed': 21498916,\n",
       "   'text': 'findings support the notion that BRAF(V600E), which can be detected preoperatively in papillary thyroid carcinoma fine-needle aspiration biopsy material, has a potential to contribute to patients stratification into high- and low-risk groups.'},\n",
       "  {'pubmed': 21512141,\n",
       "   'text': 'Mutated BRAF is detected in approximately 45% of papillary thyroid carcinomas (PTC).'},\n",
       "  {'pubmed': 21514245,\n",
       "   'text': 'Ablation of B-Raf had no significant effect on development of K-Ras oncogene-driven non-small cell lung carcinoma.'},\n",
       "  {'pubmed': 21553007,\n",
       "   'text': 'BRAF mutations, but not KRAS mutations, were associated with a worse outcome in Chinese colorectal cancer patients.'},\n",
       "  {'pubmed': 21557216,\n",
       "   'text': 'MSS/BRAF mutant cancers were more commonly proximal (38/54, 70.3%).'},\n",
       "  {'pubmed': 21570823,\n",
       "   'text': 'Analysis showed that blood samples with PCR evidence for CMC were heterogeneous for BRAF status under limiting-dilution conditions, suggestive of heterogeneity of CMC'},\n",
       "  {'pubmed': 21577205,\n",
       "   'text': 'Studies indicate that Raf kinases are excellent molecular targets for anticancer therapy.'},\n",
       "  {'pubmed': 21587258,\n",
       "   'text': 'Wnt5a methylation was strongly associated with tumour microsatellite instability tumours after adjustment for age, sex, and tumour location and with BRAF V600E mutation, a marker of CpG island methylator phenotype'},\n",
       "  {'pubmed': 21594703,\n",
       "   'text': 'BRAF V600E mutation is associated with recurrent papillary thyroid cancer.'},\n",
       "  {'pubmed': 21636552,\n",
       "   'text': 'introduction of constitutively active BRAF V600E into human cortical stem and progenitor cells initially promotes clonogenic growth in soft agar but ultimately results in dramatically reduced proliferation and arrested growth of the culture.'},\n",
       "  {'pubmed': 21653734,\n",
       "   'text': 'Compared with BRAF-wt papillary thyroid cancer, those harboring BRAF(V600E) exhibit downregulated VEGFA, VEGFR, and PDGFRbeta expression, suggesting presence of BRAF mutation does not imply stronger response to drugs targeting VEGF and PDGFB signal pathways.'},\n",
       "  {'pubmed': 21663470,\n",
       "   'text': 'The BRAF V600E mutation was present in all patients with hairy-cell leukemia who were evaluated.'},\n",
       "  {'pubmed': 21681432,\n",
       "   'text': 'The BRAF V600E mutation did not show association with clinical or molecular characteristics of colorectal cancer.'},\n",
       "  {'pubmed': 21693616,\n",
       "   'text': 'Eight of 16 primary tumor samples and 4 of 6 metastatic samples showed BRAF V600E gene mutations and no copy number changes were associated exclusively with metastatic cancer'},\n",
       "  {'pubmed': 21696415,\n",
       "   'text': 'The frequency of BRAF-KIAA1549 fusion transcripts is significantly lower in adult patients with pilocytic astrocytoma.'},\n",
       "  {'pubmed': 21705440,\n",
       "   'text': 'MEK1(F129L) mutation also strengthened binding to c-Raf, suggesting an underlying mechanism of higher intrinsic kinase activity'},\n",
       "  {'pubmed': 21707687,\n",
       "   'text': 'The application of BRAF(V600E) mutation analysis in US-guided FNAB can improve the diagnostic accuracy of thyroid nodules.'},\n",
       "  {'pubmed': 21716161,\n",
       "   'text': 'We describe a new mutation of BRAF, T599dup, in a case of anaplastic thyroid carcinoma with tall cell papillary thyroid carcinomas component.'},\n",
       "  {'pubmed': 21725359,\n",
       "   'text': 'identified concurrent mutational inactivation of the PTEN and RB1 tumor suppressors as a mechanism for loss of BRAF/MEK dependence in melanomas harboring (V600E)BRAF mutations'},\n",
       "  {'pubmed': 21750338,\n",
       "   'text': 'BRAF mutation of papillary thyroid carcinoma may have differential predictive values for LN metastasis, according to tumor size.'},\n",
       "  {'pubmed': 21774961,\n",
       "   'text': 'BRAF(V600E) mutation analysis using residual liquid-based preparation cytologic samples is, therefore, a powerful additional diagnostic tool for diagnosis of papillary thyroid carcinoma.'},\n",
       "  {'pubmed': 21788131,\n",
       "   'text': 'Patients with mutations in BRAF or NRAS gene are frequently present with ulceration, and mutation in BRAF or NRAS gene is indicator for poor prognosis.'},\n",
       "  {'pubmed': 21796448,\n",
       "   'text': 'Importance of infiltrative growth pattern and invasiveness over presence of BRAF mutation in classic and follicular variant papillary thyroid carcinoma for development of nodal metastases.'},\n",
       "  {'pubmed': 21803329,\n",
       "   'text': 'BRAF mutation is not indicative for predicting papillary thyroid cancer prognosis.'},\n",
       "  {'pubmed': 21825258,\n",
       "   'text': 'study reports that V600E and non-V600E BRAF mutations affect different patients with non-small-cell lung cancer; V600E mutations are significantly associated with female sex and represent a negative prognostic factor'},\n",
       "  {'pubmed': 21826673,\n",
       "   'text': 'BRAF mutations and llelic loss of susceptibility loci are associated with familial non-medullary thyroid cancer.'},\n",
       "  {'pubmed': 21835307,\n",
       "   'text': 'The BRAF/MEK/ERK pathway is upregulated in progressive retinal arterial macroaneurysm patients, caused by mutation in IGFBP7.'},\n",
       "  {'pubmed': 21863388,\n",
       "   'text': 'Braf mutation in metastatic melanoma treated with BRAF inhibitor vemurafenib.'},\n",
       "  {'pubmed': 21871821,\n",
       "   'text': 'Genetic analysis revealed individual heterozygous mutations in the KRAS (phenotype of CFC/Noonan syndrome) and BRAF genes (phenotype of CFC syndrome)'},\n",
       "  {'pubmed': 21875464,\n",
       "   'text': 'BRAF V600E mutation has a significant correlation with papillary thyroid carcinomas.'},\n",
       "  {'pubmed': 21882184,\n",
       "   'text': 'the BRAF(V600E) mutation should be considered as a poor prognostic marker in papillary thyroid cancer (Meta-Analysis)'},\n",
       "  {'pubmed': 21900390,\n",
       "   'text': 'Studies indicate that BRAF V600E mutation initiates follicular cell transformation.'},\n",
       "  {'pubmed': 21901162,\n",
       "   'text': 'In sporadic colorectal tumourspatients, the most frequently mutated gene was APC (68.9% of tumours), followed by KRAS (31.1%), TP53 (27.2%), BRAF (8.7%) and CTNNB1 (1.9%).'},\n",
       "  {'pubmed': 21903858,\n",
       "   'text': 'BRAF(V600E) causes upregulation of TIMP-1 via NF-kappaB. TIMP-1 binds then its surface receptor CD63, leading eventually to Akt activation, which in turn confers antiapoptotic behavior and promotion of cell invasion.'},\n",
       "  {'pubmed': 21906875,\n",
       "   'text': 'BRAF mutations are of pathogenetic significance in wild type gastrointestinal stromal tumors.'},\n",
       "  {'pubmed': 21909080,\n",
       "   'text': \"CXCR4 expression and BRAF mutation status could cooperatively induce and promote a more aggressive phenotype in papillary thyroid carcinoma through several pathways and specifically increase the tumors' spread outside of the thyroid gland.\"},\n",
       "  {'pubmed': 21915661,\n",
       "   'text': 'Aberrant CIMP was detected in 16% of chromosomal instable tumors and in 44% of both microsatellite instable and microsatellite and chromosomally stable carcinomas'},\n",
       "  {'pubmed': 21936566,\n",
       "   'text': 'this novel B-Raf fusion protein (SND-1 was identified as the B-Raf fusion partner) presents a novel target with potential clinical implications in the treatment of patients resistant to c-Met inhibitors.'},\n",
       "  {'pubmed': 21937738,\n",
       "   'text': 'A prominent epigenetic mechanism through which BRAF V600E can promote papillary thyroid cancer tumorigenesis by altering the methylation and hence the expression of numerous important genes.'},\n",
       "  {'pubmed': 21943101,\n",
       "   'text': 'BRAF mutation V600E significantly induces cell migration and invasion properties in vitro in colon cancer cells'},\n",
       "  {'pubmed': 21948220,\n",
       "   'text': 'In malignant FNABs in papillary thyroid carcinoma, BRAF(V600E) mutation was significantly associated with presence of extra-thyroidal extension and metastases after surgery.'},\n",
       "  {'pubmed': 22006538,\n",
       "   'text': 'DNA methylation of each marker was quantified using combined bisulfite restriction analysis (COBRA) and analyzed along with various genetic factors associated with CRC [the BRAF and KRAS mutations, MLH1 methylation and microsatellite instability'},\n",
       "  {'pubmed': 22012135,\n",
       "   'text': 'An integrated approach combining both VE1 mutant protein immunohistochemistry and genetic analysis may increase the diagnostic accuracy of BRAF mutation analysis.'},\n",
       "  {'pubmed': 22027477,\n",
       "   'text': 'Postmenopausal hormone therapy was associated with borderline statistically significant risk reductions for BRAF-wildtype tumours among women with prolonged exposure to Postmenopausal hormone therapy.'},\n",
       "  {'pubmed': 22028477,\n",
       "   'text': 'BRAF V600E mutation is associated with hairy cell leukemia and B-cell neoplasms'},\n",
       "  {'pubmed': 22033631,\n",
       "   'text': 'high prevalence of BRAF (V600E) mutation is associated with synchronous bilateral papillary thyroid carcinoma.'},\n",
       "  {'pubmed': 22038996,\n",
       "   'text': 'Results support evaluation of BRAF(V600E)-specific inhibitors for treating BRAF(V600E) malignant astrocytomas (MA) patients.'},\n",
       "  {'pubmed': 22039425,\n",
       "   'text': 'study examined the clinical characteristics and outcomes of patients with mutant BRAF advanced cancer; conclude that BRAF appears to be a druggable mutation that also defines subgroups of patients with phenotypic overlap, albeit with differences that correlate with histology or site of mutation'},\n",
       "  {'pubmed': 22043994,\n",
       "   'text': 'This article reviewes the spectrum of KRAS/BRAF genotype and the impact of KRAS/BRAF mutations on the clinicopathological features and prognosis of patients with colorectal cancer. [review]'},\n",
       "  {'pubmed': 22065586,\n",
       "   'text': 'Ras induces DR5 expression through co-activation of ERK/RSK and JNK signaling pathways'},\n",
       "  {'pubmed': 22072557,\n",
       "   'text': 'BRAF V600E mutation is associated with hairy cell leukemia and other mature B-cell neoplasms'},\n",
       "  {'pubmed': 22072743,\n",
       "   'text': 'BAG3 protein sustains anaplastic thyroid tumor growth in vitro and in vivo. The underlying molecular mechanism appears to rely on BAG3 binding to BRAF, thus protecting it from proteasome-dependent degradation.'},\n",
       "  {'pubmed': 22105174,\n",
       "   'text': 'Murine thyroid tumors carrying the human BRAF(V600E) mutations are exquisitely dependent on the oncoprotein for viability.'},\n",
       "  {'pubmed': 22105775,\n",
       "   'text': 'BRAF (V600E) is a prevalent genetic alteration in adult sporadic papillary thyroid carcinoma in Indian cohort and it may be responsible for the progression of its classic variant.'},\n",
       "  {'pubmed': 22114137,\n",
       "   'text': 'Overall, no difference existed in microsatellite instability or BRAF mutation frequencies between African Americans and Caucasians with colorectal neoplasms.'},\n",
       "  {'pubmed': 22133769,\n",
       "   'text': 'BRAF mutations are associated with hairy cell leukemia and related lymphoproliferative disorders.'},\n",
       "  {'pubmed': 22136270,\n",
       "   'text': 'Case Report: describe case of follicular thyroid carcinoma with BRAF mutation.'},\n",
       "  {'pubmed': 22137342,\n",
       "   'text': 'thieno[2,3-d]pyrimidines are B-Raf inhibitors'},\n",
       "  {'pubmed': 22145942,\n",
       "   'text': 'Pyrosequencing of BRAF V600E in routine samples of hairy cell leukaemia identifies CD5+ variant hairy cell leukaemia that lacks V600E.'},\n",
       "  {'pubmed': 22147429,\n",
       "   'text': 'V600E mutation of the BRAF gene reported to be associated with poor prognosis of germ cell tumors in adults prognostic biomarkers cannot necessarily be transferred from one age group to the other.'},\n",
       "  {'pubmed': 22147942,\n",
       "   'text': 'BRAF mutation is associated with inferior survival in stage III colon cancer.'},\n",
       "  {'pubmed': 22150560,\n",
       "   'text': 'papillary thyroid cancers in young patients display a low prevalence of the already identified oncogenic alterations; the increasing prevalence with age is mainly due to V600E BRAF mutation'},\n",
       "  {'pubmed': 22156467,\n",
       "   'text': 'The BRAF V600E mutation is associated with a higher pathological stage at surgery and a higher rate of recurrence.'},\n",
       "  {'pubmed': 22156468,\n",
       "   'text': 'BRAF mutations enhance the predictability of malignancy in thyroid follicular lesions of undetermined significance.'},\n",
       "  {'pubmed': 22157687,\n",
       "   'text': 'BRAF and KRAS mutations were observed in six (46.2%) and four (30.3%) filiform serrated adenomaS, respectively.'},\n",
       "  {'pubmed': 22170714,\n",
       "   'text': 'BRAF mutation in papillary thyroid carcinoma is a later subclonal event, its intratumoral heterogeneity may hamper the efficacy of targeted pharmacotherapy, and its association with a more aggressive disease should be reevaluated.'},\n",
       "  {'pubmed': 22174938,\n",
       "   'text': 'The antibody response against the catalytic domain of BRAF is not specific for rheumatoid arthritis.'},\n",
       "  {'pubmed': 22178589,\n",
       "   'text': 'Report mutations in KRAS, EGFR, and BRAF in cholangiocarcinoma and identify therapeutic targets for tyrosine kinase inhibitors.'},\n",
       "  {'pubmed': 22180495,\n",
       "   'text': 'Findings suggest that the BRAF inhibitor vemurafenib in combination with standard-of-care or novel targeted therapies may lead to enhanced and sustained clinical antitumor efficacy in CRCs harboring the BRAF(V600E) mutation.'},\n",
       "  {'pubmed': 22189819,\n",
       "   'text': 'Aberrant gene methylation driven by BRAF(V600E) altered expression of the DNA methyltransferase 1 and histone methyltransferase EZH2 profoundly.'},\n",
       "  {'pubmed': 22190222,\n",
       "   'text': 'The BRAF(V600E) mutation was associated with high-risk clinicopathologic characteristics in patients with papillary thyroid cancer (PTC). The BRAF(V600E) mutation may be a potential prognostic factor in PTC patients.'},\n",
       "  {'pubmed': 22190283,\n",
       "   'text': 'B-Raf gene mutation primarily occurs at two loci--the exon 11 glycine loop and the activation area of exon 15--in surgically resected specimens of hepatocellular carcinoma patients.'},\n",
       "  {'pubmed': 22194995,\n",
       "   'text': 'These data support a model where the continuous regenerative process initiated by oncogenic B-RAF-driven alveolar disruption provides a tumor-promoting environment associated with chronic inflammation.'},\n",
       "  {'pubmed': 22199277,\n",
       "   'text': 'RET mutations may have a role in medullary thyroid carcinoma, while BRAF, AKT1, and CTNNB1 do not; the role of HRAS, KRAS, and NRAS mutations are not determined'},\n",
       "  {'pubmed': 22199339,\n",
       "   'text': 'analysis of BRAF gene mutations in non-small cell lung cancer'},\n",
       "  {'pubmed': 22203991,\n",
       "   'text': 'These results provide a functional link between oncogenic BRAF and angiogenesis.'},\n",
       "  {'pubmed': 22210186,\n",
       "   'text': 'Patients with microsatellite instability tumor phenotype had favorable prognosis, but in those with the V600E BRAF mutation higher recurrence rate was observed.'},\n",
       "  {'pubmed': 22210875,\n",
       "   'text': 'Our results suggest that HCLv and IGHV4-34(+) HCLs have a different pathogenesis than HCLc and that a significant minority of other HCLc are also wild-type for BRAF V600.'},\n",
       "  {'pubmed': 22214007,\n",
       "   'text': 'Although it constitutes a poor prognostic factor in colorectal cancer, it is not conclusive if it interferes with a poor therapeutic effect when cetuximab is used.[review]'},\n",
       "  {'pubmed': 22227015,\n",
       "   'text': 'The findings show mutant BRAF-induced oncogenic stress manifests itself by DNA damage and growth arrest by activating the pCHK2-p53-p21 pathway.It also confers tumor-promoting phenotypes such as the up-regulation of GLUT1 and enhances glucose metabolism.'},\n",
       "  {'pubmed': 22228154,\n",
       "   'text': 'In patients with colorectal adenocarcinoma, there were significant differences between BRAF wild-type and mutant tumors in age, female sex, proximal tumor location, frequency of microsatellite instability, and survival.'},\n",
       "  {'pubmed': 22230299,\n",
       "   'text': 'One chronic lymphocytic leukaemia patient and one patient with B-prolymphocytic leukaemia were found to harbour the BRAF V600E mutation'},\n",
       "  {'pubmed': 22233696,\n",
       "   'text': 'Sessile serrated adenomas are precursors of sporadic colorectal cancers with microsatellite instability.Identified a novel surface microstructure, the Type II open-shape pit pattern (Type II-O), which was specific to SSAs with BRAF mutation and CIMP.'},\n",
       "  {'pubmed': 22235286,\n",
       "   'text': 'evidence for heterogeneity of the BRAF(V600E) mutation within individual melanoma tumor specimens'},\n",
       "  {'pubmed': 22245873,\n",
       "   'text': 'No BRAF mutations were found in colon adenocarcinomas from renal transplant recipients.'},\n",
       "  {'pubmed': 22246856,\n",
       "   'text': 'BRAF V600E mutation in low and intermediate grade lymphomas is associated with frequent occurrence in hairy cell leukaemia.'},\n",
       "  {'pubmed': 22249628,\n",
       "   'text': 'None of the molecular marker mutations that were analyzed in this study, including the BRAF mutation, predicted lymph node metastasis in classic papillary thyroid carcinoma.'},\n",
       "  {'pubmed': 22250191,\n",
       "   'text': 'During therapy with selective BRAF inhibitors, panniculitis with arthralgia represents a new adverse effect that can require dose reduction.'},\n",
       "  {'pubmed': 22258409,\n",
       "   'text': 'Mutational activation of both BRAF and PIK3CA genes does contribute to hepatocellular tumorigenesis at somatic level in Southern Italian population.'},\n",
       "  {'pubmed': 22282465,\n",
       "   'text': 'In naive GISTs carrying activating mutations in KIT or PDGFRA a concomitant activating mutation was detected in KRAS (5%) or BRAF (about 2%) genes. I'},\n",
       "  {'pubmed': 22287190,\n",
       "   'text': 'BRAF mutation is associated with colorectal serrated adenocarcinoma.'},\n",
       "  {'pubmed': 22294102,\n",
       "   'text': 'No hotspot mutations in Braf were found in oral squamous cell carcinoma in a Greek population.'},\n",
       "  {'pubmed': 22314188,\n",
       "   'text': 'Colon adenocarcinomas with BRAF mutations have morphologic characteristics distinct from those with KRAS mutations and BRAF-mutated proximal colonic adenocarcinomas with proficient DNA mismatch repair have an aggressive clinical course.'},\n",
       "  {'pubmed': 22317764,\n",
       "   'text': 'Data indicate that 266 (76.2%) tumors harbored EGFR mutations, 16 (4.6%) HER2 mutations, 15 (4.3%) EML4-ALK fusions, 7 (2.0%) KRAS mutations, and 2 (0.6%) BRAF mutations.'},\n",
       "  {'pubmed': 22317887,\n",
       "   'text': 'Report of oncogenic BRAF/KRAS mutations in sporadic glomus tumors.'},\n",
       "  {'pubmed': 22331186,\n",
       "   'text': 'BRAFmut as a useful marker in hairy cell leukemia.'},\n",
       "  {'pubmed': 22331825,\n",
       "   'text': 'BRAF mutation is an independent prognostic biomarker for colorectal liver metastasectomy.'},\n",
       "  {'pubmed': 22335197,\n",
       "   'text': 'BRAF V600E mutation-positive papillary thyroid carcinomas (PTCs) displayed infiltrative growth, stromal fibrosis, psammoma bodies, plump eosinophilic tumour cells, and classic fully developed nuclear features of PTC.'},\n",
       "  {'pubmed': 22339435,\n",
       "   'text': 'Data suggest that the BRAF V600E mutation does not seem to play a role in myeloid malignant transformation.'},\n",
       "  {'pubmed': 22358007,\n",
       "   'text': '(BRAF(V600E))detected in 141/170 malignant thyroid nodules (82.9%) (140 PTCs and one follicular variant of PTC). BRAF status not associated with US features with the exception of a negative relation between BRAF(V600E) and an irregular shape (p = 0.004).'},\n",
       "  {'pubmed': 22361037,\n",
       "   'text': 'This is the first reported study of the relationship between CK20/CK7 immunophenotype, BRAF mutations and microsatellite status in colorectal carcinomas'},\n",
       "  {'pubmed': 22367297,\n",
       "   'text': 'A distinct subset of atypical Spitz tumors is characterized by BRAF mutation and loss of BAP1 expression.'},\n",
       "  {'pubmed': 22368298,\n",
       "   'text': \"review demonstrates that tumour BRAF V600E mutation, and MLH1 promoter 'C region' methylation specifically, are strong predictors of negative MMR mutation status[review]\"},\n",
       "  {'pubmed': 22374786,\n",
       "   'text': 'The presence of activating GNAS mutations, in association with KRAS or BRAF mutations, is a characteristic genetic feature of colorectal villous adenoma.'},\n",
       "  {'pubmed': 22376079,\n",
       "   'text': 'evidence presented that ERK activation occurs in a K-ras or B-raf -independent manner in the majority of primary colon cancer cases; B-raf mutations are not associated with mismatch-repair deficiency through loss of hMLH1 or hMSH2 expression'},\n",
       "  {'pubmed': 22376167,\n",
       "   'text': 'The V600E BRAF mutation in papillary thyroid carcinomas may contribute to the initiation of the glycolytic phenotype and confers growth advantages in cancer'},\n",
       "  {'pubmed': 22382362,\n",
       "   'text': 'Eleven patients displayed Durable Disease Control (DDC) of which 55% had BRAF-V600E mutation positive tumors and 45% did not.'},\n",
       "  {'pubmed': 22393095,\n",
       "   'text': 'Patient diagnosed with colon cancer shows poor prognosis with BRAF genetic mutation.'},\n",
       "  {'pubmed': 22395615,\n",
       "   'text': 'findings show (V600E)B-RAF copy-number gain as a mechanism of acquired B-RAF inhibitor resistance in 4 out of 20 patients treated with B-RAF inhibitor'},\n",
       "  {'pubmed': 22398042,\n",
       "   'text': 'In a cohort of Indian patients with ulcerative colitis, with or without neoplasia, none showed the BRAF mutation.'},\n",
       "  {'pubmed': 22417847,\n",
       "   'text': 'we have analyzed the prevalence of somatic mutations in the FGFR3, PIK3CA, AKT1, KRAS, HRAS, and BRAF genes in bladder cancers'},\n",
       "  {'pubmed': 22426079,\n",
       "   'text': 'Data indicate that TaqMan(R) Mutation Detection assay is an important technology to consider in the field of mutation detection for KRAS, BRAF and EGFR point mutation screening.'},\n",
       "  {'pubmed': 22426956,\n",
       "   'text': 'genetic association studies in population in Turkey: Data suggest that a mutation in BRAF (V600E; found in 39.45% of patients) is associated with aggressiveness of papillary thyroid neoplasms; lymph node metastasis increases when mutation is present.'},\n",
       "  {'pubmed': 22427190,\n",
       "   'text': 'Investigation the prevalence of mutations in the BRAF gene and its correlation with demographic characteristics, tumor location and stage in 100 colorectal carcinoma patients from India.'},\n",
       "  {'pubmed': 22429583,\n",
       "   'text': 'Article reviews the current understanding of BRAF gene, its structure, expression, and signal pathway in non-small cell lung cancer. [Review]'},\n",
       "  {'pubmed': 22430133,\n",
       "   'text': 'The prevalence of EGFR, KRAS, BRAF and PIK3CA somatic mutations in 861 randomly selected Chinese patients with non-small cell lung cancer'},\n",
       "  {'pubmed': 22430208,\n",
       "   'text': 'We propose that , and that persistent phosphorylation of Mps1 through BRAF(V600E) signaling is a key event in disrupting the control of centrosome duplication and chromosome stability that may contribute to tumorigenesis.'},\n",
       "  {'pubmed': 22430215,\n",
       "   'text': 'expression of these oncogenes markedly stimulated ERK1/2 activities and morphologically transformed IECs. Importantly however'},\n",
       "  {'pubmed': 22431777,\n",
       "   'text': 'Effective use of PDT in the treatment of BRAF inhibitor-associated KAs and SCCs.'},\n",
       "  {'pubmed': 22431868,\n",
       "   'text': 'EFVPTC 1 patient BRAFV600E mutation, NVPTC 2 patients, FVPTC 2 patients.'},\n",
       "  {'pubmed': 22435913,\n",
       "   'text': 'analysis of a patient with pancreatic metastasis arising from a BRAF(V600E)-positive papillary thyroid cancer [case report]'},\n",
       "  {'pubmed': 22451557,\n",
       "   'text': 'The BRAF(V600E) mutation analysis from FNA specimens for calcified thyroid nodules may be performed for a greater negative predictive value and unveil the malignancy in 25% of indeterminate or nondiagnostic cytology.'},\n",
       "  {'pubmed': 22456166,\n",
       "   'text': 'Report marked differences in the genetic pattern of the BRAF or NRAS mutated and wild-type melanoma subgroups.'},\n",
       "  {'pubmed': 22459936,\n",
       "   'text': 'BRAF mutations play a limited role in the development of sinonasal cancer.'},\n",
       "  {'pubmed': 22471241,\n",
       "   'text': 'Out of 1041 Korean patients with papillary thyroid carcinoma, 0.4% had rare types of BRAF mutation and three new somatic mutations were identified'},\n",
       "  {'pubmed': 22471666,\n",
       "   'text': 'An update on malignancies displaying high frequencies of BRAF mutations and the mechanisms underlying the side effects and drug resistance phenomena associated with Raf inhibitors.'},\n",
       "  {'pubmed': 22488961,\n",
       "   'text': 'prevalence of the BRAF(V600E) mutation increased with increased tumor size'},\n",
       "  {'pubmed': 22492957, 'text': 'BRAF V600E is associated with gliomas.'},\n",
       "  {'pubmed': 22498935,\n",
       "   'text': 'No BRAF V600E mutations were indentified in this study of patients with endometrial cancer.'},\n",
       "  {'pubmed': 22500044,\n",
       "   'text': 'Highly sensitive and specific molecular assays such as MEMO sequencing are optimal for detecting the BRAF mutations in thyroid FNAC because these techniques can detect PTC that might be missed by cytology or less sensitive molecular assays.'},\n",
       "  {'pubmed': 22506009,\n",
       "   'text': 'The (600DLAT)B-RAF and (V600E)B-RAF mutations were found enriched in DNA and mRNA from the CD1a+ fraction of granuloma.'},\n",
       "  {'pubmed': 22508706,\n",
       "   'text': 'The analysis of BRAF mutations by pyrosequencing is useful to refine the risk stratification of patients with papillary thyroid carcinoma.'},\n",
       "  {'pubmed': 22510757,\n",
       "   'text': 'Patients with serrated polyposis syndrome referred to genetics clinics had a pan-colonic disease with a high polyp burden and a high rate of BRAF mutation.'},\n",
       "  {'pubmed': 22510884,\n",
       "   'text': 'It was shown that the dimer interface within the kinase domain plays a pivotal role for the activity of B-Raf and several of its gain-of-function mutants.'},\n",
       "  {'pubmed': 22514085,\n",
       "   'text': 'The tumor with T1799A BRAF mutation and tumor sizes of 2 cm or more were clinicopathologic parameters associated with lower STAT1 activity.'},\n",
       "  {'pubmed': 22515292,\n",
       "   'text': 'BRAF V600E is common in patients with low-risk papillary thyroid carcinoma but does not predict recurrence.'},\n",
       "  {'pubmed': 22515520,\n",
       "   'text': 'Mutation BRAF transforms cells through cross talk with developmental pathways Hedgehog and Wnt, as well as by deregulation of colorectal cancer related kinase pathways.'},\n",
       "  {'pubmed': 22516966,\n",
       "   'text': 'Report upregulation of Bim and the splicing factor SRp55 in melanoma cells from patients treated with selective BRAF inhibitors.'},\n",
       "  {'pubmed': 22522845,\n",
       "   'text': 'In signet ring cell carcinoma, BRAF V600E mutation adversely affects survival in microsatellite-stable tumors, but not in high-level microsatellite-unstable tumor'},\n",
       "  {'pubmed': 22531127,\n",
       "   'text': 'study concludes that generally, overweight increases the risk of colorectal cancer; taller individuals have an increased risk of developing a tumour with a BRAF mutation or microsatellite instability'},\n",
       "  {'pubmed': 22531170,\n",
       "   'text': 'Demonstrate that BRAF V600E mutation-specific antibody can be used in immunohistochemical diagnosis of hairy cell leukemia.'},\n",
       "  {'pubmed': 22534474,\n",
       "   'text': 'BRAF and KIT mutations have been found in Japanese melanoma patients.'},\n",
       "  {'pubmed': 22535154,\n",
       "   'text': 'study shows there are clinically and biologically distinct subtypes of BRAF-mutant metastatic melanoma, defined by genotype, with distinct etiology and behavior; cumulative sun-induced damage in primary cutaneous melanoma and older age are associated with V600K BRAF mutations;it establishes prevalence of the BRAF mutation by age-decade'},\n",
       "  {'pubmed': 22535974,\n",
       "   'text': 'The diagnostic sensitivity for thyroid cancer is significantly increased by BRAF V600E mutation analysis, indicating that the screening for BRAF mutation in FNAB samples has a relevant diagnostic potential.'},\n",
       "  {'pubmed': 22549559,\n",
       "   'text': 'Recurrent/persistent PTC in the central compartment typically harbors the BRAF mutation'},\n",
       "  {'pubmed': 22549727,\n",
       "   'text': 'abrogation of BRAFV600E-induced senescence contributes to melanomagenesis.'},\n",
       "  {'pubmed': 22549934,\n",
       "   'text': 'The mTOR pathway could be a good target to enhance therapy effects in certain types of thyroid carcinoma, namely in those harboring the BRAF(V600E) mutation.'},\n",
       "  {'pubmed': 22568401,\n",
       "   'text': 'These results suggest that low-grade diffuse gliomas with 1p/19q loss have frequent BRAF gains'},\n",
       "  {'pubmed': 22579930,\n",
       "   'text': 'KRAS, BRAF, and PIK3CA mutations in colorectal cancer have sustained prevalence rate in the Taiwanese population.'},\n",
       "  {'pubmed': 22581800,\n",
       "   'text': 'BRAF regulates expression of long noncoding RNAs in melanocytes and melanoma cells'},\n",
       "  {'pubmed': 22586484,\n",
       "   'text': 'In the present study, we did not find any significant correlations between KRAS, BRAF and PIK3CA mutations and the loss of PTEN expression and various clinicopathological features in Chinese patients with colorectal cancer.'},\n",
       "  {'pubmed': 22591444,\n",
       "   'text': 'Our results suggest that in a small fraction of diffuse gliomas, KIAA1549-BRAF fusion gene and BRAF(v600E) mutation may be responsible for deregulation of the Ras-RAF-ERK signaling pathway'},\n",
       "  {'pubmed': 22592144,\n",
       "   'text': 'Immunohistochemical detection of the mutated V600E BRAF protein in papillary thyroid carcinoma may facilitate mutational analysis in the clinical setting.'},\n",
       "  {'pubmed': 22614711,\n",
       "   'text': 'BRAF p.Val600Lys mutations were present at a relatively high frequency in the cohort of metastatic melanoma patients (27/183, 15%)'},\n",
       "  {'pubmed': 22614978,\n",
       "   'text': 'BRAF/NRAS mutations were identified in 58% of primary melanomas (43% BRAF; 15% NRAS)'},\n",
       "  {'pubmed': 22628551,\n",
       "   'text': 'Data show that RNF149 (RING finger protein 149) interacts with wild-type BRAF.'},\n",
       "  {'pubmed': 22639828,\n",
       "   'text': 'Data suggest that BRAF V600E mutation may not be widespread in hematologic malignancies, excluding hairy-cell leukemia (HCL).'},\n",
       "  {'pubmed': 22649091,\n",
       "   'text': \"Patient's BRAF mutation was likely responsible for his tumor's marked response to dasatinib, suggesting that tumors bearing kinase-impaired BRAF mutations may be exquisitely sensitive to dasatinib.\"},\n",
       "  {'pubmed': 22681706,\n",
       "   'text': 'BRAFV600E mutation is associated with lymph node metastasis in multiple papillary thyroid carcinoma.'},\n",
       "  {'pubmed': 22684223,\n",
       "   'text': 'The presence of BRAF mutations in these adenomatous precursors to colon cancer suggests that they represent sessile serrated adenomas with complete cytologic dysplasia.'},\n",
       "  {'pubmed': 22694820,\n",
       "   'text': 'In papillary thyroid cancer, significant correlations between the methylation status of four genes (TIMP3, RASSF1A, RARbeta2 and DCC) and the V600E BRAF mutation were found.'},\n",
       "  {'pubmed': 22699145,\n",
       "   'text': 'Data indicate that 14% with pancreatic ductal adenocarcinomas (PDACs) and 7% ampullary adenocarcinomas (A-ACs) had mutations in both KRAS and BRAF.'},\n",
       "  {'pubmed': 22702340,\n",
       "   'text': 'In papillary thyroid carcinoma BRAFV600E is associated with increased expression of the urokinase plasminogen activator and its cognate receptor, but not with disease-free interval.'},\n",
       "  {'pubmed': 22705994,\n",
       "   'text': 'Hairy cell leukemia cell lines expressing annexin A1 and displaying B-cell receptor signals characteristic of primary tumor cells lack the signature BRAF mutation to reveal unrepresentative origins.'},\n",
       "  {'pubmed': 22706026,\n",
       "   'text': 'The combined effects of EGFR downregulation, ligand competition, and immune effector function conspire to inhibit tumor growth in xenograft models of cetuximab-resistant BRAF and KRAS mutant cancers.'},\n",
       "  {'pubmed': 22727996,\n",
       "   'text': 'BRAF V600E mutations are present in approximately 90% of all kidney metanephric adenoma cases, serving as a potential valuable diagnostic tool in the differential diagnosis.'},\n",
       "  {'pubmed': 22730329,\n",
       "   'text': 'Reactivation of mitogen-activated protein kinase (MAPK) pathway by FGF receptor 3 (FGFR3)/Ras mediates resistance to vemurafenib in human B-RAF V600E mutant melanoma.'},\n",
       "  {'pubmed': 22732794,\n",
       "   'text': 'BRAF V600E mutation revealed a strong association with specific histological variants of papillary thyroid carcinoma.'},\n",
       "  {'pubmed': 22740704,\n",
       "   'text': 'These results clearly prove that the BRAFV600E mutation is not associated with the development of distant metastases or fatal outcome in papillary thyroid carcinoma'},\n",
       "  {'pubmed': 22742884,\n",
       "   'text': 'Vemurafenib is effective for advanced melanomas expressing the BRAF V600E mutations [review]'},\n",
       "  {'pubmed': 22743296,\n",
       "   'text': 'BRAF V600E mutation is associated with response to vemurafenib in lung adenocarcinoma.'},\n",
       "  {'pubmed': 22751131,\n",
       "   'text': 'B-Raf/MKK/ERK controls key aspects of cancer cell behavior and gene expression by modulating a network of miRNAs with cross-regulatory functions.'},\n",
       "  {'pubmed': 22752848,\n",
       "   'text': 'study reports a novel complex BRAF mutation identified in 4/492 Japanese papillary thyroid carcinoma(PTC) cases; findings suggest the BRAF(V600delinsYM)mutation, is a gain-of-function mutation and plays an important role in PTC development'},\n",
       "  {'pubmed': 22767446,\n",
       "   'text': 'study found a relatively higher B-Raf serine/threonine-protein kinase (BRAF)(V600E) mutation rate in classical type papillary thyroid carcinomas than in other similar studies'},\n",
       "  {'pubmed': 22770943,\n",
       "   'text': 'BRAF mRNA expression may help to identify PTC among thyroid nodules independently of the presence of BRAFV600E mutation.'},\n",
       "  {'pubmed': 22772867,\n",
       "   'text': 'BRAF (V600) mutations are are associated with melanomas.'},\n",
       "  {'pubmed': 22773810,\n",
       "   'text': 'Lung cancers with acquired resistance to EGFR inhibitors occasionally harbor BRAF gene mutations but lack mutations in KRAS, NRAS, or MEK1.'},\n",
       "  {'pubmed': 22797077,\n",
       "   'text': 'RSK regulates activated BRAF signalling to mTORC1 and promotes melanoma growth'},\n",
       "  {'pubmed': 22798288,\n",
       "   'text': 'Data show clinical significance to BRAF(L597) mutations in melanoma.'},\n",
       "  {'pubmed': 22798500,\n",
       "   'text': 'In CRC patients treated with cetuximab, activating mutation signatures for BRAF (58 genes) were developed.'},\n",
       "  {'pubmed': 22799316,\n",
       "   'text': 'Preoperative BRAF mutation was a predictive factor for occult contralateral papillary thyroid microcarcinoma presence.'},\n",
       "  {'pubmed': 22809251,\n",
       "   'text': 'As has been reported in other common types of melanoma, V600 BRAF mutation is the most common mutation of those tested in spindle cell melanoma. NRAS or KIT mutation appears to be rare, if not completely absent.'},\n",
       "  {'pubmed': 22814862,\n",
       "   'text': 'we found no cases of Rosette-forming glioneuronal tumors of the fourth ventricle showing KIAA1549-BRAF gene fusion or BRAF (V600E) mutation'},\n",
       "  {'pubmed': 22820187,\n",
       "   'text': 'these results link epigenetic genes to methylation and suppression of tumor suppressor genes as a mechanism involved in BRAFV600E-promoted melanoma tumorigenesis and uncover a novel molecular signature that predicts a poor prognosis of melanoma.'},\n",
       "  {'pubmed': 22820660,\n",
       "   'text': 'No BRAF V600E mutations were detected in nonserous epithelial ovarian tumors.'},\n",
       "  {'pubmed': 22824468,\n",
       "   'text': 'Single Nucleotide Polymorphisms in BRAF gene is associated with diseases.'},\n",
       "  {'pubmed': 22826122,\n",
       "   'text': 'It was concluded that extracellular kinase-mediated up-regulation of c-myc by K-Ras or B-Raf oncogenes disrupts the establishment of apical/basolateral polarity in colon epithelial cells independently of its effect on proliferation.'},\n",
       "  {'pubmed': 22826437,\n",
       "   'text': 'RAF1(D486N), as well as other kinase-impaired RAF1 mutants, showed increased heterodimerization with BRAF, which was necessary and sufficient to promote increased MEK/ERK activation.'},\n",
       "  {'pubmed': 22833462,\n",
       "   'text': 'Investigated BRAF and RAF1 alterations in Chinese prostate cancer.Found BRAF truncated in five of 200 informative Chinese cases & RAF1 was truncated in three of 204 informative cases and genomic rearrangements were correlated w/high Gleason scores.'},\n",
       "  {'pubmed': 22850568,\n",
       "   'text': 'This study reveals a novel mechanism of immune suppression sensitive to BRAF(V600E) inhibition, and indicates that clinical blockade of IL-1 may benefit patients'},\n",
       "  {'pubmed': 22858857,\n",
       "   'text': 'A review summarizes the role of the BRAF V600E mutation in the development and progression of thyroid cancer.'},\n",
       "  {'pubmed': 22859608,\n",
       "   'text': 'BRAFV600E mutation is associated with Langerhans cell histiocytosis.'},\n",
       "  {'pubmed': 22863493,\n",
       "   'text': 'The BRAFV600E occurs exclusively in papillary thyroid carcinoma and papillary carcinoma-derived anaplastic cancer, rising as a specific diagnostic marker for this tumor when identified in cytological / histological exams'},\n",
       "  {'pubmed': 22870241,\n",
       "   'text': 'High-throughput genotyping in metastatic esophageal squamous cell carcinoma identifies phosphoinositide-3-kinase and BRAF mutations.'},\n",
       "  {'pubmed': 22876591,\n",
       "   'text': 'Cardio-facio-cutaneous syndrome is caused by heterogeneous mutations in BRAF gene.'},\n",
       "  {'pubmed': 22879539,\n",
       "   'text': 'High prevalence of BRAF V600E mutations is associated with Erdheim-Chester disease but not in other non-Langerhans cell histiocytoses.'},\n",
       "  {'pubmed': 22880048,\n",
       "   'text': 'This study reveals a novel molecular mechanism underlying the regulation of feedback loops between the MAPK and AKT pathways.'},\n",
       "  {'pubmed': 22887810,\n",
       "   'text': 'A K601E BRAF mutation is associated with papillary thyroid carcinoma.'},\n",
       "  {'pubmed': 22892521,\n",
       "   'text': 'The results of this study supported an important role for BRAF duplication and MAPK pathway activation in gliomas of the optic nerve proper.'},\n",
       "  {'pubmed': 22898351,\n",
       "   'text': 'MSI status, KRAS and BRAF mutation rates varied remarkably among the colonic carcinoma subsites irrespective of right- and left-sided origin.'},\n",
       "  {'pubmed': 22899730,\n",
       "   'text': 'The presence of a BRAF c.1799T>A (p.V600E) mutation is associated with significantly poorer prognosis after colorectal cancer diagnosis among subgroups of patients.'},\n",
       "  {'pubmed': 22912864,\n",
       "   'text': 'Data indicate that mutation frequency in malanoma patients was found witih BRAF(V600) in 51%, NRAS in 19%, PI3K pathway in 41% and PTEN in 22%.'},\n",
       "  {'pubmed': 22918165,\n",
       "   'text': 'BRAF(V600E) mutation is an early event in thyroid carcinogenesis, and is associated with distinctive morphology and aggressive features even in papillary thyroid microcarcinomas'},\n",
       "  {'pubmed': 22926515,\n",
       "   'text': 'ARAF seems to stabilize BRAF:CRAF complexes in cells treated with RAF inhibitors and thereby regulate cell signaling in a subtle manner to ensure signaling efficiency'},\n",
       "  {'pubmed': 22930283,\n",
       "   'text': 'BRAF mutation is associated with early stage disease and improved outcome in patients with low-grade serous ovarian cancer.'},\n",
       "  {'pubmed': 22931913,\n",
       "   'text': 'We conclude that the presence of BRAF mutation, NRAS mutation, and the absence of an immune-related expressed gene profile predict poor outcome in melanoma patients with macroscopic stage III disease.'},\n",
       "  {'pubmed': 22932786,\n",
       "   'text': 'Thus, in this meta-analysis, the BRAF mutation in PTC was significantly associated with PTC recurrence, lymph node metastasis, extrathyroidal extension, and advanced stage AJCC III/IV.'},\n",
       "  {'pubmed': 22938585,\n",
       "   'text': 'Data indicate that KRAS, BRAF, PIK3CA, and AKT1 mutations can be rapidly and accurately detected for cancer diagnosis.'},\n",
       "  {'pubmed': 22941165,\n",
       "   'text': 'The BRAF V600E mutation is the only independent predictor of compartment lymph node metastasis in papillary thyroid carcinoma.'},\n",
       "  {'pubmed': 22946697,\n",
       "   'text': 'Data indicate that of the 32 cardio-facio-cutaneous syndrome (CFC) patients, 28 (88%) had a known mutation in a gene that is causative for CFC, including BRAF (n = 21), MEK1 (n = 2), MEK2 (n = 4), and KRAS (n = 1).'},\n",
       "  {'pubmed': 22972589,\n",
       "   'text': 'Higher response rates and longer time to progression were observed with selumetinib-containing regimens in patients who had melanoma that harbored a BRAF mutation.'},\n",
       "  {'pubmed': 22973979,\n",
       "   'text': 'found a significantly increased risk of papillary thyroid carcinoma attributed to the SNP variants rs17161747, rs1042179, and rs3748093 for those with a family history of cancer, for smokers, and for both those of age <45 years and nondrinkers'},\n",
       "  {'pubmed': 22996177,\n",
       "   'text': 'This report is the first to identify the rare, variant BRAF V600D mutation in LCH, and provides support for constitutively activated BRAF oncogene-induced cell senescence as a mechanism of regression in congenital, benign LCH.'},\n",
       "  {'pubmed': 23009221,\n",
       "   'text': 'consistent with previous studies, it was concluded that the incidence of BRAF V600E mutation in adult acute lymphoblastic leukemia, if any, is extremely infrequent'},\n",
       "  {'pubmed': 23010278,\n",
       "   'text': 'B-RAF upregulates SGLT1 activity, an effect requiring vesicle insertion into the cell membrane.'},\n",
       "  {'pubmed': 23010994,\n",
       "   'text': 'BRAF mutation is suggested to be poor prognostic factors in CRLM.'},\n",
       "  {'pubmed': 23014346,\n",
       "   'text': 'Braf mutation status is not significantly associated with poor survival for melanoma in Koreans.'},\n",
       "  {'pubmed': 23021375,\n",
       "   'text': 'EGFR and downstream genetic alterations in KRAS/BRAF and PI3K/AKT pathways have roles in colorectal cancer and treatment [review]'},\n",
       "  {'pubmed': 23026937,\n",
       "   'text': 'Immunohistochemistry is highly sensitive and specific for the detection of V600E BRAF mutation in melanoma.'},\n",
       "  {'pubmed': 23033302,\n",
       "   'text': 'the spectrum and frequency distribution of the identified KRAS and BRAF mutations in Serbian patient with colorectal cancer are in good accordance with literature data.'},\n",
       "  {'pubmed': 23036672,\n",
       "   'text': 'We describe 3 patients with BRAF V600E mutation metastatic melanoma in whom treatment with vemurafenib resulted in prompt extracranial disease response but progression of metastatic disease in the brain.'},\n",
       "  {'pubmed': 23039341,\n",
       "   'text': 'Studied the cytotoxicity and anti-tumour activity of novel MEK inhibitor, E6201, in a panel of melanoma cell lines. Most melanoma cell lines were sensitive or hypersensitive to E6201; the sensitivity correlated with wildtype PTEN and mutant BRAF status.'},\n",
       "  {'pubmed': 23041829,\n",
       "   'text': 'Findings support the potential use of immunohistochemistry as an ancillary screening tool to assess the BRAFV600E mutation status in primary cutaneous melanoma.'},\n",
       "  {'pubmed': 23051629,\n",
       "   'text': 'Increased BRAF mutation with age along with the lack of a UVR magnitude-BRAF mutation association suggests that duration of exposure rather than UVR exposure dose is the more likely link to acquiring mutations in melanocytic nevi.'},\n",
       "  {'pubmed': 23055340,\n",
       "   'text': 'KRAS and BRAF mutations are infrequent or absent, respectively in Intestinal-type sinonasal adenocarcinoma'},\n",
       "  {'pubmed': 23055546,\n",
       "   'text': 'BRAF mutation was associated with lymph node metastases (LNM), advanced stage, extrathyroidal extension, tumor size, male gender, multifocality, absence of capsule, classic PTC, and tall-cell variant papillary thyroid cancer.'},\n",
       "  {'pubmed': 23056577,\n",
       "   'text': 'A systematic review and meta-analysis revealed that BRAF mutation is an absolute risk factor for patient survival in colorectal cancer and melanoma.'},\n",
       "  {'pubmed': 23062653,\n",
       "   'text': 'BRAF mutation was not found to be significantly associated with lymph node metastasis in patients with papillary thyroid cancer'},\n",
       "  {'pubmed': 23066120,\n",
       "   'text': 'The BRAF(V600E) mutation was demonstrated to be a poor prognostic factor for the persistence of the disease independent from other clinical-pathological features in low-risk intrathyroid papillary thyroid carcinoma patients.'},\n",
       "  {'pubmed': 23069257,\n",
       "   'text': 'Histopathologic changes suggesting prolapsed rectal mucosa should take precedence over BRAF results in diagnosing sessile serrated adenomas in the rectum.'},\n",
       "  {'pubmed': 23088640,\n",
       "   'text': 'analysis suggests that BRAF mutations occur at a low frequency in chronic lymphocytic leukemia'},\n",
       "  {'pubmed': 23095503,\n",
       "   'text': 'Desmoplastic malignant melanoma: a study of ten cases and status of BRAF mutation.'},\n",
       "  {'pubmed': 23096133,\n",
       "   'text': 'BRAF mutation is associated with pleomorphic xanthoastrocytomas with anaplastic features.'},\n",
       "  {'pubmed': 23096702,\n",
       "   'text': 'We found that NRAS-mutant melanomas were significantly more likely from older patients and BRAF-mutant melanomas were more frequent in melanomas from the trunk.'},\n",
       "  {'pubmed': 23098991,\n",
       "   'text': 'Studied differential miRNA expression in metastatic colorectal cancer by microarrays from primary tumors of 33 patients who had wild-type KRAS/BRAF and third- to sixth-line anti-EGFRmAb treatment, with/without irinotecan.'},\n",
       "  {'pubmed': 23110075,\n",
       "   'text': 'Study demonstrates that chromosomal instability commonly occurs in advanced BRAF mutant/MSS colorectal cancers where it may contribute to poorer survival, and further highlights molecular similarities occurring between these and BRAF wild type cancers.'},\n",
       "  {'pubmed': 23125007,\n",
       "   'text': 'One hundred and ten patients (51%) were identified who were potentially nonresponders to anti-EGFR therapy:  13/117 (11.1%) had the V600E BRAF mutation.'},\n",
       "  {'pubmed': 23132792,\n",
       "   'text': 'BRAFV600E mutation is associated with cervical lymph node metastasis and recurrence in papillary thyroid cancer.'},\n",
       "  {'pubmed': 23138171,\n",
       "   'text': 'Clinical characteristics of colorectal cancer with the V600E BRAF mutation.'},\n",
       "  {'pubmed': 23153455,\n",
       "   'text': 'These findings indicate that ABCG2 confers resistance to vemurafenib in A375 cells, suggesting involvement of this transporter in acquired resistance to vemurafenib.'},\n",
       "  {'pubmed': 23157614,\n",
       "   'text': 'Data indicate that the presence of the BRAF V600E mutation was more frequent in women, but this gender difference was not statistically significant.'},\n",
       "  {'pubmed': 23157823,\n",
       "   'text': 'In Chinese colorectal carcinoma patients, BRAF mutation is associated with tumor differentiation and primary tumor sites.'},\n",
       "  {'pubmed': 23157824,\n",
       "   'text': 'Codon 12, 13 in KRAS gene and codon 600 in BRAF gene are the most common mutation points in Chinese colorectal cancer. KRAS and BRAF mutations are mutually exclusive. KRAS and BRAF gene mutation is higher in females than that in males.'},\n",
       "  {'pubmed': 23158172,\n",
       "   'text': 'BRAF mutational status is predictive of papillary thyroid carcinoma recurrence'},\n",
       "  {'pubmed': 23159116,\n",
       "   'text': 'V600E point mutation was identified in the BRAF gene in 3 intramucosal nevi and in 2 melanomas. Only 1 blue nevus harbored the GNAQ209 mutation'},\n",
       "  {'pubmed': 23161556,\n",
       "   'text': 'BRAF mutation as a new serum marker for papillary thyroid carcinomas were not detectable in patientts diagnosed with thyroid neoplasms.'},\n",
       "  {'pubmed': 23161722,\n",
       "   'text': 'data confirm that among lymphoproliferative disorders, BRAF V600E mutation is restricted to hairy cell leukemia (HCL); no mutations were identified in variant HCL, NMZL, ENMZL, PTLD, PTCL, ALCL, or LGL proliferations'},\n",
       "  {'pubmed': 23163107,\n",
       "   'text': 'The BRAF(V600E) mutation might be associated with a more aggressive phenotype and a poor prognosis in classic variant of papillary thyroid carcinomas.'},\n",
       "  {'pubmed': 23179992,\n",
       "   'text': 'BRAF (V600E) mutation is associated with papillary thyroid carcinomas.'},\n",
       "  {'pubmed': 23188063,\n",
       "   'text': 'BRAF mutations were correlated with poor overall survival in the full patient cohort'},\n",
       "  {'pubmed': 23190154,\n",
       "   'text': 'Our findings suggest that RAS pathway activation due to BRAF V600E and KRAS mutations is an important event in a subset of peripheral nerve sheath tumours not related to neurofibromatosis'},\n",
       "  {'pubmed': 23190890,\n",
       "   'text': 'Oncogenic B-RAF(V600E) signaling induces the T-Box3 transcriptional repressor to repress E-cadherin and enhance melanoma cell invasion.'},\n",
       "  {'pubmed': 23192464,\n",
       "   'text': 'Aim of this work is to provide a detailed comparison of clinical-pathologic features between well-differentiated and poorly differentiated tumors according to their BRAF and RASSF1A status.'},\n",
       "  {'pubmed': 23192956,\n",
       "   'text': 'BRAF (V600E) mutation is associated with papillary thyroid microcarcinoma.'},\n",
       "  {'pubmed': 23203004,\n",
       "   'text': 'BRAF (V600E) is non-associated with Gal-3 expression, whereas it is associated with cytoplasmatic localization of p27kip1 and higher CK19 expression in papillary thyroid carcinoma.'},\n",
       "  {'pubmed': 23207070,\n",
       "   'text': 'The present study revealed that ESCC of Brazilian patients do not present mutations in hot spots of EGFR, K-RAS and BRAF and only a minor proportion present overexpression of EGFR or HER2.'},\n",
       "  {'pubmed': 23208503,\n",
       "   'text': 'results suggest that mutant B-RAF signaling downregulates Tiam1/Rac activity resulting in an increase in N-cadherin levels and a decrease in E-cadherin levels and ultimately enhanced invasion'},\n",
       "  {'pubmed': 23224067,\n",
       "   'text': 'Mutations affecting BRAF, EGFR, PIK3CA, and KRAS are not associated with sporadic vestibular schwannomas.'},\n",
       "  {'pubmed': 23235345,\n",
       "   'text': 'the BRAF V600E mutation is not pathobiologically relevant in primary central nervous system lymphoma'},\n",
       "  {'pubmed': 23237741,\n",
       "   'text': 'Patients with V600R BRAF mutations can be treated successfully with oral BRAF inhibitors.'},\n",
       "  {'pubmed': 23242808,\n",
       "   'text': 'Data indicate that BRAF and EGF receptor or SRC family kinase inhibition blocked proliferation and invasion of the resistant tumors.'},\n",
       "  {'pubmed': 23246082,\n",
       "   'text': 'the role of BRAF mutations in melanoma and colorectal cancer, focusing on similarities and differences of BRAF mutations (Review)'},\n",
       "  {'pubmed': 23253715,\n",
       "   'text': 'The status of BRAF(V600E) mutation was more frequent in multifocal PTC patients with lymph node metastasis and diagnosis at later age.'},\n",
       "  {'pubmed': 23263826,\n",
       "   'text': 'we deduce that in the absence of mutation activation, B-Raf overexpression or downregulation is a protective event, since it delays the development of both malignant and benign thyroid tumors.'},\n",
       "  {'pubmed': 23274581,\n",
       "   'text': 'BRAF mutation is associated with esophageal squamous cell carcinoma.'},\n",
       "  {'pubmed': 23280049,\n",
       "   'text': 'Preoperative mutation screening for BRAF(V600E) does not meaningfully improve risk stratification and is unlikely to alter the initial management of patients with indeterminate nodules.'},\n",
       "  {'pubmed': 23287985,\n",
       "   'text': 'Pulmonary Langerhans cell histiocytosis appears to be a clonal proliferation that may or may not have BRAF V600E mutations.'},\n",
       "  {'pubmed': 23290787,\n",
       "   'text': 'Studies indicate that BRAF mutations are identified in 40-50% of patients with melanoma, and treatment with either of two BRAF inhibitors (vemurafenib, dabrafenib) or the MEK inhibitor trametinib is associated with improved clinical benefit.'},\n",
       "  {'pubmed': 23297805,\n",
       "   'text': 'No point mutations were identified in BRAF codon Val600Glu in the studied colorectal adenocarcinomas in the Turkish population.'},\n",
       "  {'pubmed': 23307859,\n",
       "   'text': 'High BRAF is associated with metastatic melanoma.'},\n",
       "  {'pubmed': 23310942,\n",
       "   'text': 'This study shows that BRAF mutation occurs in Nigerian colorectal cancers.'},\n",
       "  {'pubmed': 23317446,\n",
       "   'text': 'Results demonstrated the action of Dabrafenib and the inhibition of MAPK pathway in melanoma cell lines carrying BRAFV600D/R mutations; these results could be helpful to enlarge the number of patients who may benefit of a more effective targeted treatment'},\n",
       "  {'pubmed': 23324583,\n",
       "   'text': 'BRAF mutations is associated with colorectal cancer.'},\n",
       "  {'pubmed': 23334329,\n",
       "   'text': 'Human neural crest progenitor cells are susceptible to BRAF(V600E)-induced transformation.'},\n",
       "  {'pubmed': 23343956,\n",
       "   'text': 'no association with BRAF-V600E mutation in gastroeosophageal tumors'},\n",
       "  {'pubmed': 23349307,\n",
       "   'text': 'Data indicate that besides confirming the constant presence of BRAF-V600E in all patients with hairy cell leukemia, phospho-ERK1/ERK2 expression was observed.'},\n",
       "  {'pubmed': 23352452,\n",
       "   'text': 'Ras pathway activation via EGF treatment induced strong binding between B-Raf and C-Raf and a low level of binding between B-Raf and A-Raf.'},\n",
       "  {'pubmed': 23354951,\n",
       "   'text': 'Alternative splicing of exons 14, 15, 15b, 16b and 16c occurs in a considerable fraction of BRAF mRNA in normal colon and colorectal cancer cells and is independent of the V600E mutational status of the parental allele.'},\n",
       "  {'pubmed': 23355004,\n",
       "   'text': 'The detected Merkel cell polyomavirus prevalence in non-small cell lung cancer in combination with the deregulated expression of BRAF and Bcl-2 genes suggests that these events are likely to contribute to the pathogenesis of non-small cell lung cancer.'},\n",
       "  {'pubmed': 23359496,\n",
       "   'text': 'Kidins220 is a novel T-cell receptor (TCR)-interacting protein that couples B-Raf to the TCR. Kidins220 is mandatory for sustained Erk signaling and is crucial for TCR-mediated T cell activation.'},\n",
       "  {'pubmed': 23370429,\n",
       "   'text': 'This is the first report of BRAF V600E mutation in endometrial cancer, indicating that it may contribute to tumorigenesis of endometrial cancer, although at a low frequency compared with KRAS mutations.'},\n",
       "  {'pubmed': 23370668,\n",
       "   'text': 'study suggests that highly aggressive papillary thyroid microcarcinoma may arise in a subset of patients with BRAF(V600E) mutation and tumors greater than 5 mm; multivariate analysis showed that tumor recurrence was not associated with BRAF(V600E)mutation'},\n",
       "  ...],\n",
       " 'genomic_pos': {'chr': '7',\n",
       "  'end': 140924928,\n",
       "  'ensemblgene': 'ENSG00000157764',\n",
       "  'start': 140719327,\n",
       "  'strand': -1},\n",
       " 'genomic_pos_hg19': {'chr': '7',\n",
       "  'end': 140624564,\n",
       "  'start': 140419127,\n",
       "  'strand': -1},\n",
       " 'go': {'BP': [{'evidence': 'IBA',\n",
       "    'gocategory': 'BP',\n",
       "    'id': 'GO:0000165',\n",
       "    'pubmed': 21873635,\n",
       "    'term': 'MAPK cascade'},\n",
       "   {'evidence': 'TAS',\n",
       "    'gocategory': 'BP',\n",
       "    'id': 'GO:0000165',\n",
       "    'term': 'MAPK cascade'},\n",
       "   {'evidence': 'IEA',\n",
       "    'gocategory': 'BP',\n",
       "    'id': 'GO:0000186',\n",
       "    'term': 'activation of MAPKK activity'},\n",
       "   {'evidence': 'IEA',\n",
       "    'gocategory': 'BP',\n",
       "    'id': 'GO:0002318',\n",
       "    'term': 'myeloid progenitor cell differentiation'},\n",
       "   {'evidence': 'IDA',\n",
       "    'gocategory': 'BP',\n",
       "    'id': 'GO:0006468',\n",
       "    'pubmed': 17563371,\n",
       "    'term': 'protein phosphorylation'},\n",
       "   {'evidence': 'IEA',\n",
       "    'gocategory': 'BP',\n",
       "    'id': 'GO:0008542',\n",
       "    'term': 'visual learning'},\n",
       "   {'evidence': 'TAS',\n",
       "    'gocategory': 'BP',\n",
       "    'id': 'GO:0009887',\n",
       "    'pubmed': 9207797,\n",
       "    'term': 'animal organ morphogenesis'},\n",
       "   {'evidence': 'IMP',\n",
       "    'gocategory': 'BP',\n",
       "    'id': 'GO:0010628',\n",
       "    'pubmed': 22065586,\n",
       "    'term': 'positive regulation of gene expression'},\n",
       "   {'evidence': 'IEA',\n",
       "    'gocategory': 'BP',\n",
       "    'id': 'GO:0010764',\n",
       "    'term': 'negative regulation of fibroblast migration'},\n",
       "   {'evidence': 'IDA',\n",
       "    'gocategory': 'BP',\n",
       "    'id': 'GO:0010828',\n",
       "    'pubmed': 23010278,\n",
       "    'term': 'positive regulation of glucose transmembrane transport'},\n",
       "   {'evidence': 'IEA',\n",
       "    'gocategory': 'BP',\n",
       "    'id': 'GO:0030878',\n",
       "    'term': 'thyroid gland development'},\n",
       "   {'evidence': 'IDA',\n",
       "    'gocategory': 'BP',\n",
       "    'id': 'GO:0033138',\n",
       "    'pubmed': 19667065,\n",
       "    'term': 'positive regulation of peptidyl-serine phosphorylation'},\n",
       "   {'evidence': 'IEA',\n",
       "    'gocategory': 'BP',\n",
       "    'id': 'GO:0035019',\n",
       "    'term': 'somatic stem cell population maintenance'},\n",
       "   {'evidence': 'IEA',\n",
       "    'gocategory': 'BP',\n",
       "    'id': 'GO:0035690',\n",
       "    'term': 'cellular response to drug'},\n",
       "   {'evidence': 'IEA',\n",
       "    'gocategory': 'BP',\n",
       "    'id': 'GO:0042127',\n",
       "    'term': 'regulation of cell proliferation'},\n",
       "   {'evidence': 'IDA',\n",
       "    'gocategory': 'BP',\n",
       "    'id': 'GO:0043066',\n",
       "    'pubmed': 19667065,\n",
       "    'term': 'negative regulation of apoptotic process'},\n",
       "   {'evidence': 'IEA',\n",
       "    'gocategory': 'BP',\n",
       "    'id': 'GO:0043367',\n",
       "    'term': 'CD4-positive, alpha-beta T cell differentiation'},\n",
       "   {'evidence': 'IEA',\n",
       "    'gocategory': 'BP',\n",
       "    'id': 'GO:0043369',\n",
       "    'term': 'CD4-positive or CD8-positive, alpha-beta T cell lineage commitment'},\n",
       "   {'evidence': 'IEA',\n",
       "    'gocategory': 'BP',\n",
       "    'id': 'GO:0043434',\n",
       "    'term': 'response to peptide hormone'},\n",
       "   {'evidence': 'IEA',\n",
       "    'gocategory': 'BP',\n",
       "    'id': 'GO:0043524',\n",
       "    'term': 'negative regulation of neuron apoptotic process'},\n",
       "   {'evidence': 'IEA',\n",
       "    'gocategory': 'BP',\n",
       "    'id': 'GO:0045580',\n",
       "    'term': 'regulation of T cell differentiation'},\n",
       "   {'evidence': 'IEA',\n",
       "    'gocategory': 'BP',\n",
       "    'id': 'GO:0048538',\n",
       "    'term': 'thymus development'},\n",
       "   {'evidence': 'IEA',\n",
       "    'gocategory': 'BP',\n",
       "    'id': 'GO:0048680',\n",
       "    'term': 'positive regulation of axon regeneration'},\n",
       "   {'evidence': 'IEA',\n",
       "    'gocategory': 'BP',\n",
       "    'id': 'GO:0050772',\n",
       "    'term': 'positive regulation of axonogenesis'},\n",
       "   {'evidence': 'IEA',\n",
       "    'gocategory': 'BP',\n",
       "    'id': 'GO:0050852',\n",
       "    'term': 'T cell receptor signaling pathway'},\n",
       "   {'evidence': 'IEA',\n",
       "    'gocategory': 'BP',\n",
       "    'id': 'GO:0051291',\n",
       "    'term': 'protein heterooligomerization'},\n",
       "   {'evidence': 'IEA',\n",
       "    'gocategory': 'BP',\n",
       "    'id': 'GO:0051496',\n",
       "    'term': 'positive regulation of stress fiber assembly'},\n",
       "   {'evidence': 'IEA',\n",
       "    'gocategory': 'BP',\n",
       "    'id': 'GO:0051591',\n",
       "    'term': 'response to cAMP'},\n",
       "   {'evidence': 'IEA',\n",
       "    'gocategory': 'BP',\n",
       "    'id': 'GO:0060291',\n",
       "    'term': 'long-term synaptic potentiation'},\n",
       "   {'evidence': 'IEA',\n",
       "    'gocategory': 'BP',\n",
       "    'id': 'GO:0060323',\n",
       "    'term': 'head morphogenesis'},\n",
       "   {'evidence': 'IEA',\n",
       "    'gocategory': 'BP',\n",
       "    'id': 'GO:0060324',\n",
       "    'term': 'face development'},\n",
       "   {'evidence': 'IDA',\n",
       "    'gocategory': 'BP',\n",
       "    'id': 'GO:0070374',\n",
       "    'pubmed': 22065586,\n",
       "    'term': 'positive regulation of ERK1 and ERK2 cascade'},\n",
       "   {'evidence': 'IMP',\n",
       "    'gocategory': 'BP',\n",
       "    'id': 'GO:0070413',\n",
       "    'pubmed': 9837904,\n",
       "    'term': 'trehalose metabolism in response to stress'},\n",
       "   {'evidence': 'IDA',\n",
       "    'gocategory': 'BP',\n",
       "    'id': 'GO:0071277',\n",
       "    'pubmed': 18567582,\n",
       "    'term': 'cellular response to calcium ion'},\n",
       "   {'evidence': 'IDA',\n",
       "    'gocategory': 'BP',\n",
       "    'id': 'GO:0090150',\n",
       "    'pubmed': 23010278,\n",
       "    'term': 'establishment of protein localization to membrane'},\n",
       "   {'evidence': 'IEA',\n",
       "    'gocategory': 'BP',\n",
       "    'id': 'GO:1900026',\n",
       "    'term': 'positive regulation of substrate adhesion-dependent cell spreading'},\n",
       "   {'evidence': 'IEA',\n",
       "    'gocategory': 'BP',\n",
       "    'id': 'GO:1990090',\n",
       "    'term': 'cellular response to nerve growth factor stimulus'},\n",
       "   {'evidence': 'IEA',\n",
       "    'gocategory': 'BP',\n",
       "    'id': 'GO:2000301',\n",
       "    'term': 'negative regulation of synaptic vesicle exocytosis'},\n",
       "   {'evidence': 'IEA',\n",
       "    'gocategory': 'BP',\n",
       "    'id': 'GO:2000352',\n",
       "    'term': 'negative regulation of endothelial cell apoptotic process'}],\n",
       "  'CC': [{'evidence': 'IEA',\n",
       "    'gocategory': 'CC',\n",
       "    'id': 'GO:0005634',\n",
       "    'term': 'nucleus'},\n",
       "   {'evidence': 'IBA',\n",
       "    'gocategory': 'CC',\n",
       "    'id': 'GO:0005739',\n",
       "    'pubmed': 21873635,\n",
       "    'term': 'mitochondrion'},\n",
       "   {'evidence': 'IBA',\n",
       "    'gocategory': 'CC',\n",
       "    'id': 'GO:0005829',\n",
       "    'pubmed': 21873635,\n",
       "    'term': 'cytosol'},\n",
       "   {'evidence': 'IDA',\n",
       "    'gocategory': 'CC',\n",
       "    'id': 'GO:0005829',\n",
       "    'term': 'cytosol'},\n",
       "   {'evidence': 'TAS',\n",
       "    'gocategory': 'CC',\n",
       "    'id': 'GO:0005829',\n",
       "    'term': 'cytosol'},\n",
       "   {'evidence': 'IBA',\n",
       "    'gocategory': 'CC',\n",
       "    'id': 'GO:0005886',\n",
       "    'pubmed': 21873635,\n",
       "    'term': 'plasma membrane'},\n",
       "   {'evidence': 'TAS',\n",
       "    'gocategory': 'CC',\n",
       "    'id': 'GO:0005886',\n",
       "    'term': 'plasma membrane'},\n",
       "   {'evidence': 'IEA',\n",
       "    'gocategory': 'CC',\n",
       "    'id': 'GO:0043005',\n",
       "    'term': 'neuron projection'},\n",
       "   {'evidence': 'IDA',\n",
       "    'gocategory': 'CC',\n",
       "    'id': 'GO:0043231',\n",
       "    'term': 'intracellular membrane-bounded organelle'},\n",
       "   {'evidence': 'IEA',\n",
       "    'gocategory': 'CC',\n",
       "    'id': 'GO:0044297',\n",
       "    'term': 'cell body'}],\n",
       "  'MF': [{'category': 'MF',\n",
       "    'evidence': 'IDA',\n",
       "    'id': 'GO:0004672',\n",
       "    'pubmed': 17563371,\n",
       "    'term': 'protein kinase activity'},\n",
       "   {'category': 'MF',\n",
       "    'evidence': 'IBA',\n",
       "    'id': 'GO:0004674',\n",
       "    'pubmed': 21873635,\n",
       "    'term': 'protein serine/threonine kinase activity'},\n",
       "   {'category': 'MF',\n",
       "    'evidence': 'IDA',\n",
       "    'id': 'GO:0004674',\n",
       "    'pubmed': 19667065,\n",
       "    'term': 'protein serine/threonine kinase activity'},\n",
       "   {'category': 'MF',\n",
       "    'evidence': 'IEA',\n",
       "    'id': 'GO:0004709',\n",
       "    'term': 'MAP kinase kinase kinase activity'},\n",
       "   {'category': 'MF',\n",
       "    'evidence': 'IDA',\n",
       "    'id': 'GO:0005509',\n",
       "    'pubmed': 18567582,\n",
       "    'term': 'calcium ion binding'},\n",
       "   {'category': 'MF',\n",
       "    'evidence': 'IPI',\n",
       "    'id': 'GO:0005515',\n",
       "    'pubmed': [12620389,\n",
       "     15161933,\n",
       "     16810323,\n",
       "     16888650,\n",
       "     17380122,\n",
       "     17563371,\n",
       "     17979178,\n",
       "     18567582,\n",
       "     20130576,\n",
       "     20141835,\n",
       "     21441910,\n",
       "     21478863,\n",
       "     22169110,\n",
       "     22510884,\n",
       "     22939624,\n",
       "     23153539,\n",
       "     23680146,\n",
       "     23934108,\n",
       "     24255178,\n",
       "     24441586,\n",
       "     24746704,\n",
       "     25155755,\n",
       "     25241761,\n",
       "     25437913,\n",
       "     25600339,\n",
       "     26165597,\n",
       "     26466569,\n",
       "     26496610,\n",
       "     27353360],\n",
       "    'term': 'protein binding'},\n",
       "   {'category': 'MF',\n",
       "    'evidence': 'IEA',\n",
       "    'id': 'GO:0005524',\n",
       "    'term': 'ATP binding'},\n",
       "   {'category': 'MF',\n",
       "    'evidence': 'IPI',\n",
       "    'id': 'GO:0031267',\n",
       "    'pubmed': 12194967,\n",
       "    'qualifier': 'NOT',\n",
       "    'term': 'small GTPase binding'},\n",
       "   {'category': 'MF',\n",
       "    'evidence': 'IEA',\n",
       "    'id': 'GO:0031434',\n",
       "    'term': 'mitogen-activated protein kinase kinase binding'},\n",
       "   {'category': 'MF',\n",
       "    'evidence': 'IPI',\n",
       "    'id': 'GO:0042802',\n",
       "    'pubmed': [16858395, 19727074, 22169110, 22510884, 25155755, 25437913],\n",
       "    'term': 'identical protein binding'},\n",
       "   {'category': 'MF',\n",
       "    'evidence': 'IEA',\n",
       "    'id': 'GO:0046982',\n",
       "    'term': 'protein heterodimerization activity'}]},\n",
       " 'homologene': {'genes': [[6239, 177436],\n",
       "   [7165, 1278538],\n",
       "   [7227, 31221],\n",
       "   [7955, 403065],\n",
       "   [8364, 779570],\n",
       "   [9031, 396239],\n",
       "   [9544, 693554],\n",
       "   [9598, 463781],\n",
       "   [9606, 673],\n",
       "   [9615, 475526],\n",
       "   [9913, 536051],\n",
       "   [10090, 109880],\n",
       "   [10116, 114486]],\n",
       "  'id': 3197},\n",
       " 'interpro': [{'desc': 'Protein kinase domain',\n",
       "   'id': 'IPR000719',\n",
       "   'short_desc': 'Prot_kinase_dom'},\n",
       "  {'desc': 'Serine-threonine/tyrosine-protein kinase, catalytic domain',\n",
       "   'id': 'IPR001245',\n",
       "   'short_desc': 'Ser-Thr/Tyr_kinase_cat_dom'},\n",
       "  {'desc': 'Protein kinase C-like, phorbol ester/diacylglycerol-binding domain',\n",
       "   'id': 'IPR002219',\n",
       "   'short_desc': 'PE/DAG-bd'},\n",
       "  {'desc': 'Raf-like Ras-binding', 'id': 'IPR003116', 'short_desc': 'RBD_dom'},\n",
       "  {'desc': 'Serine/threonine-protein kinase, active site',\n",
       "   'id': 'IPR008271',\n",
       "   'short_desc': 'Ser/Thr_kinase_AS'},\n",
       "  {'desc': 'Protein kinase-like domain superfamily',\n",
       "   'id': 'IPR011009',\n",
       "   'short_desc': 'Kinase-like_dom_sf'},\n",
       "  {'desc': 'Protein kinase, ATP binding site',\n",
       "   'id': 'IPR017441',\n",
       "   'short_desc': 'Protein_kinase_ATP_BS'},\n",
       "  {'desc': 'Diacylglycerol/phorbol-ester binding',\n",
       "   'id': 'IPR020454',\n",
       "   'short_desc': 'DAG/PE-bd'},\n",
       "  {'desc': 'Ubiquitin-like domain superfamily',\n",
       "   'id': 'IPR029071',\n",
       "   'short_desc': 'Ubiquitin-like_domsf'}],\n",
       " 'ipi': 'IPI00303797',\n",
       " 'map_location': '7q34',\n",
       " 'name': 'B-Raf proto-oncogene, serine/threonine kinase',\n",
       " 'other_names': ['94 kDa B-raf protein',\n",
       "  'B-Raf proto-oncogene serine/threonine-protein kinase (p94)',\n",
       "  'B-Raf serine/threonine-protein',\n",
       "  'murine sarcoma viral (v-raf) oncogene homolog B1',\n",
       "  'proto-oncogene B-Raf',\n",
       "  'serine/threonine-protein kinase B-raf',\n",
       "  'v-raf murine sarcoma viral oncogene homolog B',\n",
       "  'v-raf murine sarcoma viral oncogene homolog B1'],\n",
       " 'pantherdb': {'HGNC': '1097',\n",
       "  'ortholog': [{'MGI': '88190',\n",
       "    'ortholog_type': 'LDO',\n",
       "    'panther_family': 'PTHR44329',\n",
       "    'taxid': 10090,\n",
       "    'uniprot_kb': 'P28028'},\n",
       "   {'RGD': '619908',\n",
       "    'ortholog_type': 'LDO',\n",
       "    'panther_family': 'PTHR44329',\n",
       "    'taxid': 10116,\n",
       "    'uniprot_kb': 'F1M9C3'},\n",
       "   {'Ensembl': 'ENSGALG00000012865',\n",
       "    'ortholog_type': 'LDO',\n",
       "    'panther_family': 'PTHR44329',\n",
       "    'taxid': 9031,\n",
       "    'uniprot_kb': 'Q04982'},\n",
       "   {'ZFIN': 'ZDB-GENE-040805-1',\n",
       "    'ortholog_type': 'LDO',\n",
       "    'panther_family': 'PTHR44329',\n",
       "    'taxid': 7955,\n",
       "    'uniprot_kb': 'Q1LYG2'},\n",
       "   {'WormBase': 'WBGene00003030',\n",
       "    'ortholog_type': 'LDO',\n",
       "    'panther_family': 'PTHR44329',\n",
       "    'taxid': 6239,\n",
       "    'uniprot_kb': 'Q07292'},\n",
       "   {'FlyBase': 'FBgn0003079',\n",
       "    'ortholog_type': 'LDO',\n",
       "    'panther_family': 'PTHR44329',\n",
       "    'taxid': 7227,\n",
       "    'uniprot_kb': 'P11346'},\n",
       "   {'HGNC': '42952',\n",
       "    'ortholog_type': 'P',\n",
       "    'panther_family': 'PTHR44329',\n",
       "    'taxid': 9606,\n",
       "    'uniprot_kb': 'V9GXZ4'},\n",
       "   {'HGNC': '26617',\n",
       "    'ortholog_type': 'P',\n",
       "    'panther_family': 'PTHR44329',\n",
       "    'taxid': 9606,\n",
       "    'uniprot_kb': 'Q8NB16'},\n",
       "   {'HGNC': '6850',\n",
       "    'ortholog_type': 'P',\n",
       "    'panther_family': 'PTHR44329',\n",
       "    'taxid': 9606,\n",
       "    'uniprot_kb': 'Q16584'},\n",
       "   {'HGNC': '10019',\n",
       "    'ortholog_type': 'P',\n",
       "    'panther_family': 'PTHR44329',\n",
       "    'taxid': 9606,\n",
       "    'uniprot_kb': 'Q13546'},\n",
       "   {'HGNC': '10020',\n",
       "    'ortholog_type': 'P',\n",
       "    'panther_family': 'PTHR44329',\n",
       "    'taxid': 9606,\n",
       "    'uniprot_kb': 'O43353'},\n",
       "   {'HGNC': '6851',\n",
       "    'ortholog_type': 'P',\n",
       "    'panther_family': 'PTHR44329',\n",
       "    'taxid': 9606,\n",
       "    'uniprot_kb': 'Q12852'},\n",
       "   {'HGNC': '6849',\n",
       "    'ortholog_type': 'P',\n",
       "    'panther_family': 'PTHR44329',\n",
       "    'taxid': 9606,\n",
       "    'uniprot_kb': 'Q02779'},\n",
       "   {'HGNC': '6852',\n",
       "    'ortholog_type': 'P',\n",
       "    'panther_family': 'PTHR44329',\n",
       "    'taxid': 9606,\n",
       "    'uniprot_kb': 'O43283'},\n",
       "   {'HGNC': '6861',\n",
       "    'ortholog_type': 'P',\n",
       "    'panther_family': 'PTHR44329',\n",
       "    'taxid': 9606,\n",
       "    'uniprot_kb': 'P80192'},\n",
       "   {'dictyBase': 'DDB_G0273445',\n",
       "    'ortholog_type': 'LDO',\n",
       "    'panther_family': 'PTHR44329',\n",
       "    'taxid': 352472,\n",
       "    'uniprot_kb': 'Q86AT8'},\n",
       "   {'dictyBase': 'DDB_G0278909',\n",
       "    'ortholog_type': 'O',\n",
       "    'panther_family': 'PTHR44329',\n",
       "    'taxid': 352472,\n",
       "    'uniprot_kb': 'Q54XI9'},\n",
       "   {'dictyBase': 'DDB_G0289555',\n",
       "    'ortholog_type': 'O',\n",
       "    'panther_family': 'PTHR44329',\n",
       "    'taxid': 352472,\n",
       "    'uniprot_kb': 'Q54HC6'},\n",
       "   {'dictyBase': 'DDB_G0278535',\n",
       "    'ortholog_type': 'O',\n",
       "    'panther_family': 'PTHR44329',\n",
       "    'taxid': 352472,\n",
       "    'uniprot_kb': 'Q54XX5'},\n",
       "   {'TAIR': 'AT4G24480',\n",
       "    'ortholog_type': 'O',\n",
       "    'panther_family': 'PTHR44329',\n",
       "    'taxid': 3702,\n",
       "    'uniprot_kb': 'F4JQX7'},\n",
       "   {'TAIR': 'AT5G03730',\n",
       "    'ortholog_type': 'O',\n",
       "    'panther_family': 'PTHR44329',\n",
       "    'taxid': 3702,\n",
       "    'uniprot_kb': 'Q05609'}],\n",
       "  'uniprot_kb': 'P15056'},\n",
       " 'pathway': {'kegg': [{'id': 'hsa04010',\n",
       "    'name': 'MAPK signaling pathway - Homo sapiens (human)'},\n",
       "   {'id': 'hsa04012', 'name': 'ErbB signaling pathway - Homo sapiens (human)'},\n",
       "   {'id': 'hsa04015', 'name': 'Rap1 signaling pathway - Homo sapiens (human)'},\n",
       "   {'id': 'hsa04024', 'name': 'cAMP signaling pathway - Homo sapiens (human)'},\n",
       "   {'id': 'hsa04062',\n",
       "    'name': 'Chemokine signaling pathway - Homo sapiens (human)'},\n",
       "   {'id': 'hsa04068', 'name': 'FoxO signaling pathway - Homo sapiens (human)'},\n",
       "   {'id': 'hsa04150', 'name': 'mTOR signaling pathway - Homo sapiens (human)'},\n",
       "   {'id': 'hsa04270',\n",
       "    'name': 'Vascular smooth muscle contraction - Homo sapiens (human)'},\n",
       "   {'id': 'hsa04510', 'name': 'Focal adhesion - Homo sapiens (human)'},\n",
       "   {'id': 'hsa04650',\n",
       "    'name': 'Natural killer cell mediated cytotoxicity - Homo sapiens (human)'},\n",
       "   {'id': 'hsa04720', 'name': 'Long-term potentiation - Homo sapiens (human)'},\n",
       "   {'id': 'hsa04722',\n",
       "    'name': 'Neurotrophin signaling pathway - Homo sapiens (human)'},\n",
       "   {'id': 'hsa04726', 'name': 'Serotonergic synapse - Homo sapiens (human)'},\n",
       "   {'id': 'hsa04730', 'name': 'Long-term depression - Homo sapiens (human)'},\n",
       "   {'id': 'hsa04810',\n",
       "    'name': 'Regulation of actin cytoskeleton - Homo sapiens (human)'},\n",
       "   {'id': 'hsa04910',\n",
       "    'name': 'Insulin signaling pathway - Homo sapiens (human)'},\n",
       "   {'id': 'hsa04914',\n",
       "    'name': 'Progesterone-mediated oocyte maturation - Homo sapiens (human)'},\n",
       "   {'id': 'hsa04934', 'name': 'Cushing,s syndrome - Homo sapiens (human)'},\n",
       "   {'id': 'hsa05034', 'name': 'Alcoholism - Homo sapiens (human)'},\n",
       "   {'id': 'hsa05160', 'name': 'Hepatitis C - Homo sapiens (human)'},\n",
       "   {'id': 'hsa05200', 'name': 'Pathways in cancer - Homo sapiens (human)'},\n",
       "   {'id': 'hsa05205',\n",
       "    'name': 'Proteoglycans in cancer - Homo sapiens (human)'},\n",
       "   {'id': 'hsa05210', 'name': 'Colorectal cancer - Homo sapiens (human)'},\n",
       "   {'id': 'hsa05211', 'name': 'Renal cell carcinoma - Homo sapiens (human)'},\n",
       "   {'id': 'hsa05212', 'name': 'Pancreatic cancer - Homo sapiens (human)'},\n",
       "   {'id': 'hsa05213', 'name': 'Endometrial cancer - Homo sapiens (human)'},\n",
       "   {'id': 'hsa05214', 'name': 'Glioma - Homo sapiens (human)'},\n",
       "   {'id': 'hsa05215', 'name': 'Prostate cancer - Homo sapiens (human)'},\n",
       "   {'id': 'hsa05216', 'name': 'Thyroid cancer - Homo sapiens (human)'},\n",
       "   {'id': 'hsa05218', 'name': 'Melanoma - Homo sapiens (human)'},\n",
       "   {'id': 'hsa05219', 'name': 'Bladder cancer - Homo sapiens (human)'},\n",
       "   {'id': 'hsa05220',\n",
       "    'name': 'Chronic myeloid leukemia - Homo sapiens (human)'},\n",
       "   {'id': 'hsa05221', 'name': 'Acute myeloid leukemia - Homo sapiens (human)'},\n",
       "   {'id': 'hsa05223',\n",
       "    'name': 'Non-small cell lung cancer - Homo sapiens (human)'},\n",
       "   {'id': 'hsa05224', 'name': 'Breast cancer - Homo sapiens (human)'},\n",
       "   {'id': 'hsa05225',\n",
       "    'name': 'Hepatocellular carcinoma - Homo sapiens (human)'},\n",
       "   {'id': 'hsa05226', 'name': 'Gastric cancer - Homo sapiens (human)'}],\n",
       "  'netpath': {'id': 'Pathway_EGFR1', 'name': 'EGFR1'},\n",
       "  'pharmgkb': [{'id': 'PA165959425', 'name': 'Pathway_PA165959425'},\n",
       "   {'id': 'PA165959584', 'name': 'Sorafenib Pharmacodynamics'},\n",
       "   {'id': 'PA165980050', 'name': 'Vemurafenib Pathway, Pharmacodynamics'},\n",
       "   {'id': 'PA165980050', 'name': 'update your name in edit mode'}],\n",
       "  'pid': [{'id': 'cd8tcrdownstreampathway',\n",
       "    'name': 'Downstream signaling in na&#xef;ve CD8+ T cells'},\n",
       "   {'id': 'cdc42_pathway', 'name': 'CDC42 signaling events'},\n",
       "   {'id': 'erbb1_downstream_pathway', 'name': 'ErbB1 downstream signaling'},\n",
       "   {'id': 'fak_pathway',\n",
       "    'name': 'Signaling events mediated by focal adhesion kinase'},\n",
       "   {'id': 'mapktrkpathway',\n",
       "    'name': 'Trk receptor signaling mediated by the MAPK pathway'},\n",
       "   {'id': 'mtor_4pathway', 'name': 'mTOR signaling pathway'},\n",
       "   {'id': 'pdgfrbpathway', 'name': 'PDGFR-beta signaling pathway'},\n",
       "   {'id': 'tcrraspathway', 'name': 'Ras signaling in the CD4+ TCR pathway'},\n",
       "   {'id': 'vegfr1_2_pathway',\n",
       "    'name': 'Signaling events mediated by VEGFR1 and VEGFR2'}],\n",
       "  'reactome': [{'id': 'R-HSA-112314',\n",
       "    'name': 'Neurotransmitter receptors and postsynaptic signal transmission'},\n",
       "   {'id': 'R-HSA-112315', 'name': 'Transmission across Chemical Synapses'},\n",
       "   {'id': 'R-HSA-112316', 'name': 'Neuronal System'},\n",
       "   {'id': 'R-HSA-1295596', 'name': 'Spry regulation of FGF signaling'},\n",
       "   {'id': 'R-HSA-162582', 'name': 'Signal Transduction'},\n",
       "   {'id': 'R-HSA-162582', 'name': 'Signal Transduction'},\n",
       "   {'id': 'R-HSA-1643685', 'name': 'Disease'},\n",
       "   {'id': 'R-HSA-166520', 'name': 'Signaling by NTRKs'},\n",
       "   {'id': 'R-HSA-169893', 'name': 'Prolonged ERK activation events'},\n",
       "   {'id': 'R-HSA-170968', 'name': 'Frs2-mediated activation'},\n",
       "   {'id': 'R-HSA-170984', 'name': 'ARMS-mediated activation'},\n",
       "   {'id': 'R-HSA-187037', 'name': 'Signaling by NTRK1 (TRKA)'},\n",
       "   {'id': 'R-HSA-187687', 'name': 'Signalling to ERKs'},\n",
       "   {'id': 'R-HSA-187706', 'name': 'Signalling to p38 via RIT and RIN'},\n",
       "   {'id': 'R-HSA-190236', 'name': 'Signaling by FGFR'},\n",
       "   {'id': 'R-HSA-438064', 'name': 'Post NMDA receptor activation events'},\n",
       "   {'id': 'R-HSA-442742',\n",
       "    'name': 'CREB phosphorylation through the activation of Ras'},\n",
       "   {'id': 'R-HSA-442755',\n",
       "    'name': 'Activation of NMDA receptors and postsynaptic events'},\n",
       "   {'id': 'R-HSA-5654726', 'name': 'Negative regulation of FGFR1 signaling'},\n",
       "   {'id': 'R-HSA-5654727', 'name': 'Negative regulation of FGFR2 signaling'},\n",
       "   {'id': 'R-HSA-5654732', 'name': 'Negative regulation of FGFR3 signaling'},\n",
       "   {'id': 'R-HSA-5654733', 'name': 'Negative regulation of FGFR4 signaling'},\n",
       "   {'id': 'R-HSA-5654736', 'name': 'Signaling by FGFR1'},\n",
       "   {'id': 'R-HSA-5654738', 'name': 'Signaling by FGFR2'},\n",
       "   {'id': 'R-HSA-5654741', 'name': 'Signaling by FGFR3'},\n",
       "   {'id': 'R-HSA-5654743', 'name': 'Signaling by FGFR4'},\n",
       "   {'id': 'R-HSA-5663202', 'name': 'Diseases of signal transduction'},\n",
       "   {'id': 'R-HSA-5673000', 'name': 'RAF activation'},\n",
       "   {'id': 'R-HSA-5673001', 'name': 'RAF/MAP kinase cascade'},\n",
       "   {'id': 'R-HSA-5674135', 'name': 'MAP2K and MAPK activation'},\n",
       "   {'id': 'R-HSA-5674499',\n",
       "    'name': 'Negative feedback regulation of MAPK pathway'},\n",
       "   {'id': 'R-HSA-5675221', 'name': 'Negative regulation of MAPK pathway'},\n",
       "   {'id': 'R-HSA-5683057', 'name': 'MAPK family signaling cascades'},\n",
       "   {'id': 'R-HSA-5684996', 'name': 'MAPK1/MAPK3 signaling'},\n",
       "   {'id': 'R-HSA-6802946',\n",
       "    'name': 'Signaling by moderate kinase activity BRAF mutants'},\n",
       "   {'id': 'R-HSA-6802948',\n",
       "    'name': 'Signaling by high-kinase activity BRAF mutants'},\n",
       "   {'id': 'R-HSA-6802949', 'name': 'Signaling by RAS mutants'},\n",
       "   {'id': 'R-HSA-6802952', 'name': 'Signaling by BRAF and RAF fusions'},\n",
       "   {'id': 'R-HSA-6802955',\n",
       "    'name': 'Paradoxical activation of RAF signaling by kinase inactive BRAF'},\n",
       "   {'id': 'R-HSA-6802957', 'name': 'Oncogenic MAPK signaling'},\n",
       "   {'id': 'R-HSA-9006934', 'name': 'Signaling by Receptor Tyrosine Kinases'},\n",
       "   {'id': 'R-HSA-9006934', 'name': 'Signaling by Receptor Tyrosine Kinases'}],\n",
       "  'smpdb': [{'id': 'SMP00320',\n",
       "    'name': 'Intracellular Signalling Through Adenosine Receptor A2a and Adenosine'},\n",
       "   {'id': 'SMP00321',\n",
       "    'name': 'Intracellular Signalling Through Adenosine Receptor A2b and Adenosine'}],\n",
       "  'wikipathways': [{'id': 'WP185', 'name': 'Integrin-mediated Cell Adhesion'},\n",
       "   {'id': 'WP2032',\n",
       "    'name': 'Human Thyroid Stimulating Hormone (TSH) signaling pathway'},\n",
       "   {'id': 'WP2261', 'name': 'Signaling Pathways in Glioblastoma'},\n",
       "   {'id': 'WP23', 'name': 'B Cell Receptor Signaling Pathway'},\n",
       "   {'id': 'WP2355',\n",
       "    'name': 'Corticotropin-releasing hormone signaling pathway'},\n",
       "   {'id': 'WP2512', 'name': 'Integrated Lung Cancer Pathway'},\n",
       "   {'id': 'WP2571', 'name': 'Polycystic Kidney Disease Pathway'},\n",
       "   {'id': 'WP2828', 'name': 'Bladder Cancer'},\n",
       "   {'id': 'WP306', 'name': 'Focal Adhesion'},\n",
       "   {'id': 'WP3676', 'name': 'BDNF-TrkB Signaling'},\n",
       "   {'id': 'WP382', 'name': 'MAPK Signaling Pathway'},\n",
       "   {'id': 'WP3929', 'name': 'Chemokine signaling pathway'},\n",
       "   {'id': 'WP3931', 'name': 'ESC Pluripotency Pathways'},\n",
       "   {'id': 'WP4155', 'name': 'Endometrial cancer'},\n",
       "   {'id': 'WP4205', 'name': 'MET in type 1 papillary renal cell carcinoma'},\n",
       "   {'id': 'WP4216',\n",
       "    'name': 'Chromosomal and microsatellite instability in colorectal cancer'},\n",
       "   {'id': 'WP422', 'name': 'MAPK Cascade'},\n",
       "   {'id': 'WP437', 'name': 'EGF-EGFR Signaling Pathway'},\n",
       "   {'id': 'WP51', 'name': 'Regulation of Actin Cytoskeleton'},\n",
       "   {'id': 'WP615', 'name': 'Senescence and Autophagy in Cancer'},\n",
       "   {'id': 'WP712', 'name': 'Estrogen signaling pathway'},\n",
       "   {'id': 'WP722', 'name': 'Serotonin HTR1 Group and FOS Pathway'},\n",
       "   {'id': 'WP734', 'name': 'Serotonin Receptor 4-6-7 and NR3C Signaling'}]},\n",
       " 'pdb': ['1UWH',\n",
       "  '1UWJ',\n",
       "  '2FB8',\n",
       "  '2L05',\n",
       "  '3C4C',\n",
       "  '3D4Q',\n",
       "  '3IDP',\n",
       "  '3II5',\n",
       "  '3NY5',\n",
       "  '3OG7',\n",
       "  '3PPJ',\n",
       "  '3PPK',\n",
       "  '3PRF',\n",
       "  '3PRI',\n",
       "  '3PSB',\n",
       "  '3PSD',\n",
       "  '3Q4C',\n",
       "  '3Q96',\n",
       "  '3SKC',\n",
       "  '3TV4',\n",
       "  '3TV6',\n",
       "  '4CQE',\n",
       "  '4DBN',\n",
       "  '4E26',\n",
       "  '4E4X',\n",
       "  '4EHE',\n",
       "  '4EHG',\n",
       "  '4FC0',\n",
       "  '4FK3',\n",
       "  '4G9C',\n",
       "  '4G9R',\n",
       "  '4H58',\n",
       "  '4JVG',\n",
       "  '4KSP',\n",
       "  '4KSQ',\n",
       "  '4MBJ',\n",
       "  '4MNE',\n",
       "  '4MNF',\n",
       "  '4PP7',\n",
       "  '4R5Y',\n",
       "  '4RZV',\n",
       "  '4RZW',\n",
       "  '4WO5',\n",
       "  '4XV1',\n",
       "  '4XV2',\n",
       "  '4XV3',\n",
       "  '4XV9',\n",
       "  '4YHT',\n",
       "  '5C9C',\n",
       "  '5CSW',\n",
       "  '5CSX',\n",
       "  '5CT7',\n",
       "  '5FD2',\n",
       "  '5HI2',\n",
       "  '5HID',\n",
       "  '5HIE',\n",
       "  '5ITA',\n",
       "  '5J17',\n",
       "  '5J18',\n",
       "  '5J2R',\n",
       "  '5JRQ',\n",
       "  '5JSM',\n",
       "  '5JT2',\n",
       "  '5VAL',\n",
       "  '5VAM',\n",
       "  '5VR3',\n",
       "  '5VYK',\n",
       "  '6B8U',\n",
       "  '6CAD'],\n",
       " 'pfam': ['PF00130', 'PF02196', 'PF07714'],\n",
       " 'pharmgkb': 'PA25408',\n",
       " 'pharos': {'target_id': 1932},\n",
       " 'pir': 'A57977',\n",
       " 'prosite': ['PS50011', 'PS50081', 'PS50898'],\n",
       " 'reagent': {'GNF_Qia_hs-genome_v1_siRNA': [{'id': 'GNF246467',\n",
       "    'relationship': 'is'},\n",
       "   {'id': 'GNF246468', 'relationship': 'is'},\n",
       "   {'id': 'GNF246469', 'relationship': 'is'},\n",
       "   {'id': 'GNF246470', 'relationship': 'is'}],\n",
       "  'GNF_hs-Origene': [{'id': 'GNF033097', 'relationship': 'similar to'},\n",
       "   {'id': 'GNF036220', 'relationship': 'is'},\n",
       "   {'id': 'GNF046927', 'relationship': 'weakly similar to'}],\n",
       "  'GNF_hs-druggable_lenti-shRNA': [{'id': 'GNF092340', 'relationship': 'is'},\n",
       "   {'id': 'GNF092341', 'relationship': 'is'},\n",
       "   {'id': 'GNF092342', 'relationship': 'is'}],\n",
       "  'GNF_hs-druggable_plasmid-shRNA': [{'id': 'GNF051312', 'relationship': 'is'},\n",
       "   {'id': 'GNF056078', 'relationship': 'is'},\n",
       "   {'id': 'GNF060793', 'relationship': 'is'}],\n",
       "  'GNF_hs-druggable_siRNA': [{'id': 'GNF067889', 'relationship': 'is'},\n",
       "   {'id': 'GNF067890', 'relationship': 'is'}],\n",
       "  'GNF_hs-pkinase_IDT-siRNA': [{'id': 'GNF165248', 'relationship': 'is'},\n",
       "   {'id': 'GNF165249', 'relationship': 'is'},\n",
       "   {'id': 'GNF165250', 'relationship': 'is'},\n",
       "   {'id': 'GNF165251', 'relationship': 'is'}],\n",
       "  'GNF_mm+hs-MGC': {'id': 'GNF279495', 'relationship': 'is'},\n",
       "  'Invitrogen_IVTHSSIPKv2': [{'id': 'GNF324655', 'relationship': 'is'},\n",
       "   {'id': 'GNF324656', 'relationship': 'is'}],\n",
       "  'NIBRI_hs-Secretome_pDEST': {'id': 'GNF339157', 'relationship': 'is'},\n",
       "  'NOVART_hs-genome_siRNA': [{'id': 'GNF092847', 'relationship': 'is'},\n",
       "   {'id': 'GNF132545', 'relationship': 'is'}]},\n",
       " 'refseq': {'genomic': ['NC_000007.14', 'NG_007873.3'],\n",
       "  'protein': ['NP_001341538.1',\n",
       "   'NP_004324.2',\n",
       "   'XP_016868047.1',\n",
       "   'XP_016868048.1'],\n",
       "  'rna': ['NM_001354609.1',\n",
       "   'NM_004333.5',\n",
       "   'NR_148928.1',\n",
       "   'XM_017012558.1',\n",
       "   'XM_017012559.1',\n",
       "   'XR_001744857.1',\n",
       "   'XR_001744858.1'],\n",
       "  'translation': [{'protein': 'XP_016868047.1', 'rna': 'XM_017012558.1'},\n",
       "   {'protein': 'XP_016868048.1', 'rna': 'XM_017012559.1'},\n",
       "   {'protein': 'NP_001341538.1', 'rna': 'NM_001354609.1'},\n",
       "   {'protein': 'NP_004324.2', 'rna': 'NM_004333.5'}]},\n",
       " 'reporter': {'HG-U133_Plus_2': ['206044_s_at',\n",
       "   '226391_at',\n",
       "   '236402_at',\n",
       "   '243829_at'],\n",
       "  'HG-U95Av2': ['1654_at', '40306_at'],\n",
       "  'HG-U95B': '55694_at',\n",
       "  'HTA-2_0': ['TC07001926.hg.1', 'TC07001927.hg.1', 'TC07003197.hg.1'],\n",
       "  'HuEx-1_0': ['2320411', '3076340', '3982172'],\n",
       "  'HuGene-1_1': ['7897745', '8143417'],\n",
       "  'HuGene-2_1': ['16659054', '17063631']},\n",
       " 'summary': 'This gene encodes a protein belonging to the RAF family of serine/threonine protein kinases. This protein plays a role in regulating the MAP kinase/ERK signaling pathway, which affects cell division, differentiation, and secretion. Mutations in this gene, most commonly the V600E mutation, are the most frequently identified cancer-causing mutations in melanoma, and have been identified in various other cancers as well, including non-Hodgkin lymphoma, colorectal cancer, thyroid carcinoma, non-small cell lung carcinoma, hairy cell leukemia and adenocarcinoma of lung. Mutations in this gene are also associated with cardiofaciocutaneous, Noonan, and Costello syndromes, which exhibit overlapping phenotypes. A pseudogene of this gene has been identified on the X chromosome. [provided by RefSeq, Aug 2017].',\n",
       " 'symbol': 'BRAF',\n",
       " 'taxid': 9606,\n",
       " 'type_of_gene': 'protein-coding',\n",
       " 'umls': {'cui': 'C0812241'},\n",
       " 'unigene': ['Hs.550061', 'Hs.324250', 'Hs.600998', 'Hs.659507', 'Hs.684552'],\n",
       " 'uniprot': {'Swiss-Prot': 'P15056',\n",
       "  'TrEMBL': ['H7C4S5',\n",
       "   'A0A2R8Y8E0',\n",
       "   'A0A2U3TZI2',\n",
       "   'A0A2R8Y492',\n",
       "   'A0A2R8Y467',\n",
       "   'H7C560',\n",
       "   'A0A2R8Y679',\n",
       "   'A0A2R8YES9',\n",
       "   'H7C5K3',\n",
       "   'A0A2R8YDP5']},\n",
       " 'wikipedia': {'url_stub': 'BRAF (gene)'}}"
      ]
     },
     "execution_count": 29,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "braf_response = requests.get('http://mygene.info/v3/gene/' + braf_id)\n",
    "braf_response.json()"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 30,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/plain": [
       "'This gene encodes a protein belonging to the RAF family of serine/threonine protein kinases. This protein plays a role in regulating the MAP kinase/ERK signaling pathway, which affects cell division, differentiation, and secretion. Mutations in this gene, most commonly the V600E mutation, are the most frequently identified cancer-causing mutations in melanoma, and have been identified in various other cancers as well, including non-Hodgkin lymphoma, colorectal cancer, thyroid carcinoma, non-small cell lung carcinoma, hairy cell leukemia and adenocarcinoma of lung. Mutations in this gene are also associated with cardiofaciocutaneous, Noonan, and Costello syndromes, which exhibit overlapping phenotypes. A pseudogene of this gene has been identified on the X chromosome. [provided by RefSeq, Aug 2017].'"
      ]
     },
     "execution_count": 30,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "braf_info = braf_response.json()\n",
    "braf_info['summary']"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 31,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/plain": [
       "[{'query': '673',\n",
       "  'HGNC': '1097',\n",
       "  'MIM': '164757',\n",
       "  'Vega': 'OTTHUMG00000157457',\n",
       "  '_id': '673',\n",
       "  '_score': 20.348886,\n",
       "  'accession': {'genomic': ['AC006006.2',\n",
       "    'AC006344.2',\n",
       "    'AC006347.2',\n",
       "    'AC079339.5',\n",
       "    'CH236950.1',\n",
       "    'CH471070.1',\n",
       "    'EU600171.1',\n",
       "    'HB432546.1',\n",
       "    'HC464558.1',\n",
       "    'HM459603.1',\n",
       "    'HQ224878.1',\n",
       "    'KF481581.1',\n",
       "    'KT584890.1',\n",
       "    'KY769663.1',\n",
       "    'KY769664.1',\n",
       "    'KY769665.1',\n",
       "    'KY769666.1',\n",
       "    'KY769667.1',\n",
       "    'KY769668.1',\n",
       "    'NC_000007.14',\n",
       "    'NG_007873.3',\n",
       "    'X65187.1'],\n",
       "   'protein': ['AAA35609.2',\n",
       "    'AAA96495.1',\n",
       "    'AAD15551.1',\n",
       "    'AAD43193.1',\n",
       "    'AAI01758.1',\n",
       "    'AAI12080.1',\n",
       "    'AAS00359.1',\n",
       "    'ACD11489.1',\n",
       "    'ADN43065.1',\n",
       "    'ADQ00186.1',\n",
       "    'ADX94397.1',\n",
       "    'AIE38317.1',\n",
       "    'ARR27440.1',\n",
       "    'ARR27441.1',\n",
       "    'ARR27442.1',\n",
       "    'ARR27443.1',\n",
       "    'ARR27444.1',\n",
       "    'ARR27445.1',\n",
       "    'CAA46301.1',\n",
       "    'CAB81553.1',\n",
       "    'CAZ68014.1',\n",
       "    'CBK51920.1',\n",
       "    'EAL24023.1',\n",
       "    'EAW83964.1',\n",
       "    'EAW83965.1',\n",
       "    'NP_001341538.1',\n",
       "    'NP_004324.2',\n",
       "    'P15056.4',\n",
       "    'XP_016868047.1',\n",
       "    'XP_016868048.1'],\n",
       "   'rna': ['AA252358.1',\n",
       "    'AA834931.1',\n",
       "    'AA975673.1',\n",
       "    'AI203435.1',\n",
       "    'AJ276310.1',\n",
       "    'AK054801.1',\n",
       "    'AK094023.1',\n",
       "    'AK098095.1',\n",
       "    'AK124257.1',\n",
       "    'AK314346.1',\n",
       "    'AW971583.1',\n",
       "    'BC038966.1',\n",
       "    'BC101757.1',\n",
       "    'BC112079.1',\n",
       "    'BM263585.1',\n",
       "    'DB454480.1',\n",
       "    'DN996440.1',\n",
       "    'HM437233.1',\n",
       "    'M21001.1',\n",
       "    'M95712.2',\n",
       "    'NM_001354609.1',\n",
       "    'NM_004333.5',\n",
       "    'NR_148928.1',\n",
       "    'XM_017012558.1',\n",
       "    'XM_017012559.1',\n",
       "    'XR_001744857.1',\n",
       "    'XR_001744858.1'],\n",
       "   'translation': [{'protein': 'AAA35609.2', 'rna': 'M95712.2'},\n",
       "    {'protein': 'AAA96495.1', 'rna': 'M21001.1'},\n",
       "    {'protein': 'XP_016868048.1', 'rna': 'XM_017012559.1'},\n",
       "    {'protein': 'ADN43065.1', 'rna': 'HM437233.1'},\n",
       "    {'protein': 'AAI01758.1', 'rna': 'BC101757.1'},\n",
       "    {'protein': 'NP_001341538.1', 'rna': 'NM_001354609.1'},\n",
       "    {'protein': 'XP_016868047.1', 'rna': 'XM_017012558.1'},\n",
       "    {'protein': 'CAB81553.1', 'rna': 'AJ276310.1'},\n",
       "    {'protein': 'AAI12080.1', 'rna': 'BC112079.1'},\n",
       "    {'protein': 'NP_004324.2', 'rna': 'NM_004333.5'}]},\n",
       "  'alias': ['B-RAF1', 'B-raf', 'BRAF1', 'NS7', 'RAFB1'],\n",
       "  'ec': '2.7.11.1',\n",
       "  'ensembl': {'gene': 'ENSG00000157764',\n",
       "   'protein': ['ENSP00000288602',\n",
       "    'ENSP00000418033',\n",
       "    'ENSP00000419060',\n",
       "    'ENSP00000420119',\n",
       "    'ENSP00000493543',\n",
       "    'ENSP00000493678',\n",
       "    'ENSP00000493783',\n",
       "    'ENSP00000494784',\n",
       "    'ENSP00000495132',\n",
       "    'ENSP00000495858',\n",
       "    'ENSP00000496776'],\n",
       "   'transcript': ['ENST00000288602',\n",
       "    'ENST00000469930',\n",
       "    'ENST00000479537',\n",
       "    'ENST00000496384',\n",
       "    'ENST00000497784',\n",
       "    'ENST00000642228',\n",
       "    'ENST00000642272',\n",
       "    'ENST00000642808',\n",
       "    'ENST00000642875',\n",
       "    'ENST00000643356',\n",
       "    'ENST00000643790',\n",
       "    'ENST00000644120',\n",
       "    'ENST00000644650',\n",
       "    'ENST00000644905',\n",
       "    'ENST00000644969',\n",
       "    'ENST00000645443',\n",
       "    'ENST00000646334',\n",
       "    'ENST00000646427',\n",
       "    'ENST00000646730',\n",
       "    'ENST00000646891',\n",
       "    'ENST00000647434'],\n",
       "   'translation': [{'protein': 'ENSP00000419060', 'rna': 'ENST00000496384'},\n",
       "    {'protein': 'ENSP00000496776', 'rna': 'ENST00000644969'},\n",
       "    {'protein': 'ENSP00000493543', 'rna': 'ENST00000646891'},\n",
       "    {'protein': 'ENSP00000493678', 'rna': 'ENST00000642228'},\n",
       "    {'protein': 'ENSP00000288602', 'rna': 'ENST00000288602'},\n",
       "    {'protein': 'ENSP00000494784', 'rna': 'ENST00000646730'},\n",
       "    {'protein': 'ENSP00000418033', 'rna': 'ENST00000479537'},\n",
       "    {'protein': 'ENSP00000495132', 'rna': 'ENST00000647434'},\n",
       "    {'protein': 'ENSP00000493783', 'rna': 'ENST00000644650'},\n",
       "    {'protein': 'ENSP00000420119', 'rna': 'ENST00000497784'},\n",
       "    {'protein': 'ENSP00000495858', 'rna': 'ENST00000469930'}],\n",
       "   'type_of_gene': 'protein_coding'},\n",
       "  'entrezgene': '673',\n",
       "  'exac': {'all': {'exp_lof': 38.7898242736,\n",
       "    'exp_mis': 222.804792623,\n",
       "    'exp_syn': 91.8960727685,\n",
       "    'lof_z': 5.85138231407808,\n",
       "    'mis_z': 3.99133872234548,\n",
       "    'mu_lof': 2.88380412169e-06,\n",
       "    'mu_mis': 2.2184090402e-05,\n",
       "    'mu_syn': 9.8889618129e-06,\n",
       "    'n_lof': 2.0,\n",
       "    'n_mis': 101.0,\n",
       "    'n_syn': 92.0,\n",
       "    'p_li': 0.999978196041997,\n",
       "    'p_null': 3.88216441101404e-14,\n",
       "    'p_rec': 2.18039579639691e-05,\n",
       "    'syn_z': -0.00672112442056413},\n",
       "   'bp': 2301,\n",
       "   'cds_end': 140624503,\n",
       "   'cds_start': 140434396,\n",
       "   'n_exons': 18,\n",
       "   'nonpsych': {'exp_lof': 34.7601572454,\n",
       "    'exp_mis': 201.311466134,\n",
       "    'exp_syn': 82.8264394585,\n",
       "    'lof_z': 5.62361517113138,\n",
       "    'mis_z': 4.02811051726418,\n",
       "    'mu_lof': 2.88380412169e-06,\n",
       "    'mu_mis': 2.2184090402e-05,\n",
       "    'mu_syn': 9.8889618129e-06,\n",
       "    'n_lof': 1.0,\n",
       "    'n_mis': 88.0,\n",
       "    'n_syn': 82.0,\n",
       "    'p_li': 0.999983482649624,\n",
       "    'p_null': 1.18961221524589e-13,\n",
       "    'p_rec': 1.65173502566583e-05,\n",
       "    'syn_z': 0.057172913417909},\n",
       "   'nontcga': {'exp_lof': 35.6526822996,\n",
       "    'exp_mis': 204.94646599,\n",
       "    'exp_syn': 84.5104358173,\n",
       "    'lof_z': 5.55974482036514,\n",
       "    'mis_z': 4.03503314525409,\n",
       "    'mu_lof': 2.88380412169e-06,\n",
       "    'mu_mis': 2.2184090402e-05,\n",
       "    'mu_syn': 9.8889618129e-06,\n",
       "    'n_lof': 2.0,\n",
       "    'n_mis': 89.0,\n",
       "    'n_syn': 81.0,\n",
       "    'p_li': 0.999932334264256,\n",
       "    'p_null': 6.11297736772402e-13,\n",
       "    'p_rec': 6.76657351324938e-05,\n",
       "    'syn_z': 0.241784586564238},\n",
       "   'transcript': 'ENST00000288602.6'},\n",
       "  'exons': [{'cdsend': 140924703,\n",
       "    'cdsstart': 140726493,\n",
       "    'chr': '7',\n",
       "    'position': [[140719326, 140726516],\n",
       "     [140734616, 140734770],\n",
       "     [140739811, 140739946],\n",
       "     [140749286, 140749418],\n",
       "     [140753274, 140753393],\n",
       "     [140754186, 140754233],\n",
       "     [140776911, 140777088],\n",
       "     [140777990, 140778075],\n",
       "     [140781575, 140781693],\n",
       "     [140783020, 140783157],\n",
       "     [140787547, 140787584],\n",
       "     [140794307, 140794467],\n",
       "     [140800361, 140800481],\n",
       "     [140801411, 140801560],\n",
       "     [140807959, 140808062],\n",
       "     [140808891, 140808995],\n",
       "     [140834608, 140834872],\n",
       "     [140850110, 140850212],\n",
       "     [140924565, 140924928]],\n",
       "    'strand': -1,\n",
       "    'transcript': 'NM_001354609',\n",
       "    'txend': 140924928,\n",
       "    'txstart': 140719326},\n",
       "   {'cdsend': 140924703,\n",
       "    'cdsstart': 140734596,\n",
       "    'chr': '7',\n",
       "    'position': [[140732563, 140734770],\n",
       "     [140739811, 140739946],\n",
       "     [140749286, 140749418],\n",
       "     [140753274, 140753393],\n",
       "     [140754186, 140754233],\n",
       "     [140776911, 140777088],\n",
       "     [140777990, 140778075],\n",
       "     [140781575, 140781693],\n",
       "     [140783020, 140783157],\n",
       "     [140787547, 140787584],\n",
       "     [140794307, 140794467],\n",
       "     [140800361, 140800481],\n",
       "     [140801411, 140801560],\n",
       "     [140807959, 140808062],\n",
       "     [140808891, 140808995],\n",
       "     [140834608, 140834872],\n",
       "     [140850110, 140850212],\n",
       "     [140924565, 140924928]],\n",
       "    'strand': -1,\n",
       "    'transcript': 'NM_004333',\n",
       "    'txend': 140924928,\n",
       "    'txstart': 140732563},\n",
       "   {'cdsend': 140924928,\n",
       "    'cdsstart': 140924928,\n",
       "    'chr': '7',\n",
       "    'position': [[140732563, 140734770],\n",
       "     [140739811, 140739946],\n",
       "     [140749286, 140749418],\n",
       "     [140753274, 140754233],\n",
       "     [140776911, 140777088],\n",
       "     [140777990, 140778075],\n",
       "     [140781575, 140781693],\n",
       "     [140783020, 140783157],\n",
       "     [140787547, 140787584],\n",
       "     [140794307, 140794467],\n",
       "     [140800361, 140800481],\n",
       "     [140801411, 140801560],\n",
       "     [140807959, 140808062],\n",
       "     [140808236, 140808316],\n",
       "     [140808891, 140808995],\n",
       "     [140834608, 140834872],\n",
       "     [140850110, 140850212],\n",
       "     [140924565, 140924928]],\n",
       "    'strand': -1,\n",
       "    'transcript': 'NR_148928',\n",
       "    'txend': 140924928,\n",
       "    'txstart': 140732563}],\n",
       "  'exons_hg19': [{'cdsend': 140624503,\n",
       "    'cdsstart': 140426293,\n",
       "    'chr': '7',\n",
       "    'position': [[140419126, 140426316],\n",
       "     [140434416, 140434570],\n",
       "     [140439611, 140439746],\n",
       "     [140449086, 140449218],\n",
       "     [140453074, 140453193],\n",
       "     [140453986, 140454033],\n",
       "     [140476711, 140476888],\n",
       "     [140477790, 140477875],\n",
       "     [140481375, 140481493],\n",
       "     [140482820, 140482957],\n",
       "     [140487347, 140487384],\n",
       "     [140494107, 140494267],\n",
       "     [140500161, 140500281],\n",
       "     [140501211, 140501360],\n",
       "     [140507759, 140507862],\n",
       "     [140508691, 140508795],\n",
       "     [140534408, 140534672],\n",
       "     [140549910, 140550012],\n",
       "     [140624365, 140624728]],\n",
       "    'strand': -1,\n",
       "    'transcript': 'NM_001354609',\n",
       "    'txend': 140624728,\n",
       "    'txstart': 140419126},\n",
       "   {'cdsend': 140624503,\n",
       "    'cdsstart': 140434396,\n",
       "    'chr': '7',\n",
       "    'position': [[140432363, 140434570],\n",
       "     [140439611, 140439746],\n",
       "     [140449086, 140449218],\n",
       "     [140453074, 140453193],\n",
       "     [140453986, 140454033],\n",
       "     [140476711, 140476888],\n",
       "     [140477790, 140477875],\n",
       "     [140481375, 140481493],\n",
       "     [140482820, 140482957],\n",
       "     [140487347, 140487384],\n",
       "     [140494107, 140494267],\n",
       "     [140500161, 140500281],\n",
       "     [140501211, 140501360],\n",
       "     [140507759, 140507862],\n",
       "     [140508691, 140508795],\n",
       "     [140534408, 140534672],\n",
       "     [140549910, 140550012],\n",
       "     [140624365, 140624728]],\n",
       "    'strand': -1,\n",
       "    'transcript': 'NM_004333',\n",
       "    'txend': 140624728,\n",
       "    'txstart': 140432363},\n",
       "   {'cdsend': 140624728,\n",
       "    'cdsstart': 140624728,\n",
       "    'chr': '7',\n",
       "    'position': [[140432363, 140434570],\n",
       "     [140439611, 140439746],\n",
       "     [140449086, 140449218],\n",
       "     [140453074, 140454033],\n",
       "     [140476711, 140476888],\n",
       "     [140477790, 140477875],\n",
       "     [140481375, 140481493],\n",
       "     [140482820, 140482957],\n",
       "     [140487347, 140487384],\n",
       "     [140494107, 140494267],\n",
       "     [140500161, 140500281],\n",
       "     [140501211, 140501360],\n",
       "     [140507759, 140507862],\n",
       "     [140508036, 140508116],\n",
       "     [140508691, 140508795],\n",
       "     [140534408, 140534672],\n",
       "     [140549910, 140550012],\n",
       "     [140624365, 140624728]],\n",
       "    'strand': -1,\n",
       "    'transcript': 'NR_148928',\n",
       "    'txend': 140624728,\n",
       "    'txstart': 140432363}],\n",
       "  'generif': [{'pubmed': 8621729, 'text': 'MEK1 interacts with B-Raf.'},\n",
       "   {'pubmed': 12068308,\n",
       "    'text': 'somatic missense mutations in 66% of malignant melanomas and at lower frequency in a wide range of human cancers'},\n",
       "   {'pubmed': 12198537,\n",
       "    'text': 'BRAF mutations in colorectal cancers occur only in tumours that do not carry mutations in a RAS gene known as KRAS, and BRAF mutation is linked to the proficiency of these tumours in repairing mismatched bases in DNA'},\n",
       "   {'pubmed': 12447372, 'text': 'High frequency of BRAF mutations in nevi'},\n",
       "   {'pubmed': 12619120,\n",
       "    'text': 'The V599E BRAF mutation appears to be a somatic mutation associated with melanoma development and/or progression in a proportion of affected individuals.'},\n",
       "   {'pubmed': 12644542,\n",
       "    'text': 'results demonstrate that the mutational status of BRAF and KRAS is distinctly different among histologic types of ovarian serous carcinoma, occurring most frequently in invasive micropapillary serous carcinomas and its precursors, serous borderline tumors'},\n",
       "   {'pubmed': 12670889,\n",
       "    'text': 'High prevalence of BRAF mutations in thyroid cancer is genetic evidence for constitutive activation of the RET/PTC-RAS-BRAF signaling pathway in papillary thyroid carcinoma.'},\n",
       "   {'pubmed': 12697856,\n",
       "    'text': 'activating BRAF mutations may be an important event in the development of papillary thyroid cancer'},\n",
       "   {'pubmed': 12753285,\n",
       "    'text': 'cAMP activates ERK and increases proliferation of autosomal dominant polycystic kindey epithelial cells through the sequential phosphorylation of PKA, B-Raf and MAPK in a pathway separate from the classical receptor tyrosine kinase cascade'},\n",
       "   {'pubmed': 12778069,\n",
       "    'text': 'gene is mutated in skin melanoma, but not in uveal melanomas'},\n",
       "   {'pubmed': 12810628,\n",
       "    'text': '13 germline BRAF variants, 4 of which were silent mutations in coding regions & 9 nucleotide substitutions in introns, were found in melanoma patients and melanoma family, but none appeared statistically likely to be a melanoma susceptibility gene.'},\n",
       "   {'pubmed': 12821662,\n",
       "    'text': 'B-raf is involved in adhesion-independent ERK1/2 signaling in melanocytes'},\n",
       "   {'pubmed': 12824225,\n",
       "    'text': 'Data suggest that BRAF T1796A activating mutation is not common in primary uveal melanoma.'},\n",
       "   {'pubmed': 12855697,\n",
       "    'text': 'B-Raf has a role in extracellular signal-regulated kinase (ERK) signaling in T cells and prevents antigen-presenting cell-induced anergy'},\n",
       "   {'pubmed': 12879021,\n",
       "    'text': 'BRAF has a role in in squamous cell carcinoma of the head and neck through uncommon mutations'},\n",
       "   {'pubmed': 12881714,\n",
       "    'text': 'The BRAF(V599E) mutation appears to be an alternative event to RET/PTC rearrangement rather than to RAS mutations, which are rare in PTC. BRAF(V599E) may represent an alternative pathway to oncogenic MAPK activation in PTCs without RET/PTC activation.'},\n",
       "   {'pubmed': 12893203,\n",
       "    'text': 'Mucinous ovarian cancers without a KRAS mutation have not sustained alternative activation of this signaling pathway through mutation of the BRAF oncogene.'},\n",
       "   {'pubmed': 12917419,\n",
       "    'text': '3 cell lines derived from human choroidal melanoma express B-Raf containing the V599E mutation and showed a 10-fold increase in endogenous B-RafV599E kinase activity and a constitutive activation of the MEK/ERK pathway that is independent of Ras'},\n",
       "   {'pubmed': 12931219,\n",
       "    'text': 'Mutations are not detectable in plasma cell leukemia and multiple myeloma.'},\n",
       "   {'pubmed': 12970315,\n",
       "    'text': 'mutation of BRAF gene could be a potentially useful marker of prognosis of patients with advanced thyroid cancers'},\n",
       "   {'pubmed': 14501284,\n",
       "    'text': 'Our findings of a high frequency of BRAF mutations at codon 599 in benign melanocytic lesions of the skin indicate that this mutation is not sufficient by itself for malignant transformation.'},\n",
       "   {'pubmed': 14507635,\n",
       "    'text': 'Both BRAF and FBXW7 mutations functionally activate kinase effectors important in pancreatic cancer and extend potential options for therapeutic targeting of kinases in treatment of phenotypically distinct pancreatic adenocarcinoma subsets.'},\n",
       "   {'pubmed': 14513361,\n",
       "    'text': 'BRAF mutations, which are present in a variety of other human cancers, do not seem to be involved in gastric cancer development'},\n",
       "   {'pubmed': 14522897,\n",
       "    'text': 'Uceal melanomas arise independent of oncogenic BRAF and NRAS mutations.'},\n",
       "   {'pubmed': 14534542,\n",
       "    'text': 'BRAF mutations were seen in stomach neoplasms.'},\n",
       "   {'pubmed': 14602780,\n",
       "    'text': 'BRAF mutations are restricted to papillary carcinomas and poorly differentiated and anaplastic carcinomas arising from papillary carcinomas'},\n",
       "   {'pubmed': 14612909,\n",
       "    'text': 'BRAF is occasionally mutated in NHL, and BRAF mutation may contribute to tumor development in some NHLs'},\n",
       "   {'pubmed': 14618633,\n",
       "    'text': 'None of the cases of gastric cancer showed braf mutations'},\n",
       "   {'pubmed': 14639609,\n",
       "    'text': 'Mutations of BRAF are associated with extensive hMLH1 promoter methylation in sporadic colorectal carcinomas'},\n",
       "   {'pubmed': 14668801,\n",
       "    'text': 'Missense mutation is marker of colonic but not gastric cancer.'},\n",
       "   {'pubmed': 14688025,\n",
       "    'text': 'Mutations were found in exon 15 in colorectal adenocarcinoma.'},\n",
       "   {'pubmed': 14691295,\n",
       "    'text': 'Our data indicate that BRAF gene mutations are rare to absent events in uveal melanoma of humans.'},\n",
       "   {'pubmed': 14695152,\n",
       "    'text': 'NRAS and BRAF mutations arise early during melanoma pathogenesis and are preserved throughout tumor progression'},\n",
       "   {'pubmed': 14695993,\n",
       "    'text': 'BRAF mutations are associated with proximal colon tumors with mismatch repair deficiency and MLH1 hypermethylation.'},\n",
       "   {'pubmed': 14719068,\n",
       "    'text': 'New enriched PCR-RFLP assay for detecting mutations of BRAF codon 599 mutation in pleural mesotheliomas.'},\n",
       "   {'pubmed': 14722037,\n",
       "    'text': 'Observational study of genotype prevalence and gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 14724583,\n",
       "    'text': \"RAS or BRAF mutations are detected in about 32% of all Barrett's adenocarcinomas; the disruption of the Raf/MEK/ERK (MAPK) kinase pathway is a frequent but also early event in the development of Barrett's adenocarcinoma\"},\n",
       "   {'pubmed': 14734469,\n",
       "    'text': 'BRAF mutations are frequently present in sporadic colorectal cancer with methylated hMLH1'},\n",
       "   {'pubmed': 14961576,\n",
       "    'text': 'Mutations in BRAF gene is associated with malignant melanomas'},\n",
       "   {'pubmed': 14966563,\n",
       "    'text': 'These studies identify isoprenylcysteine carboxyl methyltransferase as a potential target for reducing the growth of K-Ras- and B-Raf-induced malignancies.'},\n",
       "   {'pubmed': 15001635,\n",
       "    'text': 'The lack or low prevalence of BRAF mutation in other thyroid neoplasms is consistent with the notion that other previously defined genetic alterations on the same signaling pathway are sufficient to cause tumorigenesis in most thyroid neoplasms.'},\n",
       "   {'pubmed': 15009714,\n",
       "    'text': 'possible cooperation between BRAF activation and PTEN loss in melanoma development.'},\n",
       "   {'pubmed': 15009715,\n",
       "    'text': 'mutations in the BRAF gene and to some extent in the N-ras gene represent early somatic events that occur in melanocytic nevi'},\n",
       "   {'pubmed': 15014028,\n",
       "    'text': 'BRAF mutation may be acquired during development of metastasis but is not a significant factor for primary melanoma development and disease outcome.'},\n",
       "   {'pubmed': 15077125,\n",
       "    'text': 'ovarian serous cystadenomas do not contain mutations in either BRAF or KRAS genes'},\n",
       "   {'pubmed': 15104286,\n",
       "    'text': 'These results suggest that the BRAF mutation is unlikely to be involved in gastric carcinogenesis.'},\n",
       "   {'pubmed': 15126572,\n",
       "    'text': 'BRAF(V599E) is more common genetic alteration found to date in adult sporadic papillary thyroid carcinomas (PTCs). It is unique for this thyroid cancer histotype, and it might drive the development of PTCs of classic papillary subtype.'},\n",
       "   {'pubmed': 15140228,\n",
       "    'text': 'The finding of tandem mutations in thin melanomas makes it more likely that they arise as a simultaneous rather than sequential event.'},\n",
       "   {'pubmed': 15145515,\n",
       "    'text': 'Radiation-induced tumors have a low prevalence of BRAF point mutations and high prevalence of RET/PTC rearrangements'},\n",
       "   {'pubmed': 15150271,\n",
       "    'text': 'B-Raf kinase activity regulation by tuberin and Rheb is mammalian target of rapamycin (mTOR)-independent'},\n",
       "   {'pubmed': 15161700,\n",
       "    'text': 'mucosal melanomas of the head and neck do not frequently harbor an activating mutation of BRAF'},\n",
       "   {'pubmed': 15179189,\n",
       "    'text': 'in contrast to cutaneous melanoma, BRAF does not appear to be involved in the pathogenesis of uveal melanoma'},\n",
       "   {'pubmed': 15186612,\n",
       "    'text': 'BRAF mutations are rather rare in solitary cold adenomas and adenomatous nodules and do not explain the molecular etiology of ras mutation-negative cold thyroid nodules.'},\n",
       "   {'pubmed': 15191558,\n",
       "    'text': 'activation of this gene may be one of the early events in the pathogenesis of some melanomas.'},\n",
       "   {'pubmed': 15263001,\n",
       "    'text': 'B-Raf and ERK are activated by cyclic AMP after calcium restriction'},\n",
       "   {'pubmed': 15273715, 'text': 'mutated in papillary thyroid cancer.'},\n",
       "   {'pubmed': 15277467,\n",
       "    'text': 'In this study, this BRAF mutation was demonstrated in some conjunctival melanoma tissue samples, suggesting that some conjunctival melanomas may share biological features in common with cutaneous melanoma.'},\n",
       "   {'pubmed': 15313890,\n",
       "    'text': 'Data suggest that SPRY2, an inhibitor of ERK signaling, may be bypassed in melanoma cells either by down-regulation of its expression in WT BRAF cells, or by the presence of the BRAF mutation.'},\n",
       "   {'pubmed': 15330192,\n",
       "    'text': 'Mutations within the BRAF gene are useful markers for the differential diagnosis between Spitz nevus and malignant melanoma.'},\n",
       "   {'pubmed': 15331929,\n",
       "    'text': 'we found 19 cases (38%) to harbor somatic B-raf exon 15 mutations.'},\n",
       "   {'pubmed': 15339934,\n",
       "    'text': 'Data provide evidence that B-Raf is a positive regulator of T cell receptor-mediated sustained ERK activation, which is required for NFAT activation and the full production of IL-2.'},\n",
       "   {'pubmed': 15373778,\n",
       "    'text': 'BRAF(V599E) mutation is seven times higher in lesions with structural changes and 13 times higher in growing lesions as compared with lesions without changes'},\n",
       "   {'pubmed': 15488754,\n",
       "    'text': 'REVIEW: our understanding of B-RAF as an oncogene and of its role in cancer'},\n",
       "   {'pubmed': 15489648,\n",
       "    'text': 'Mutations of BRAF or KRAS oncogenes are early events in the serrated polyp neoplasia pathway. CpG island methylation plays a role in serrated polyp progression to colorectal carcinoma.'},\n",
       "   {'pubmed': 15538400,\n",
       "    'text': 'mutated in childhood acute lymphoblastic leukemia.'},\n",
       "   {'pubmed': 15577314,\n",
       "    'text': 'BRAF mutations are associated with conjunctival neoplasms'},\n",
       "   {'pubmed': 15630448,\n",
       "    'text': 'AKAP9-BRAF fusion was preferentially found in radiation-induced papillary carcinomas developing after a short latency, whereas BRAF point mutations were absent in this group'},\n",
       "   {'pubmed': 15632082,\n",
       "    'text': 'Data suggest that Rit is involved in a novel pathway of neuronal development and regeneration by coupling specific trophic factor signals to sustained activation of the B-Raf/ERK and p38 MAP kinase cascades.'},\n",
       "   {'pubmed': 15653554,\n",
       "    'text': 'a novel Ras-independent ERK1/2 activation system in which p110gamma/Raf-1/MEK1/2 and PKA/B-Raf/MEK1/2 cooperate to activate ERK1/2.'},\n",
       "   {'pubmed': 15702478,\n",
       "    'text': 'We found mutations in p53, K-ras, and BRAF genes in 35%, 30%, and 4% of tumors, respectively, and observed a minimal or no co-presence of these gene alterations.'},\n",
       "   {'pubmed': 15705790,\n",
       "    'text': 'KSHV-infected cell lines expressed higher levels of B-Raf and VEGF-A; B-Raf-induced VEGF-A expression was demonstrated to be sufficient to enhance tubule formation in endothelial cells'},\n",
       "   {'pubmed': 15710605,\n",
       "    'text': 'autoinhibition was negatively regulated by acidic substitutions at phosphorylation sites within the activation loop'},\n",
       "   {'pubmed': 15765445,\n",
       "    'text': 'Mutations in the BRAF protooncogene (V599E)may be an alternative pathway of tumorigenesis of familial colorectal cancer.'},\n",
       "   {'pubmed': 15782118,\n",
       "    'text': 'BRAF mutations proved to be absent in tumors from hereditary nonpolyposis colorectal cancer syndrome (HNPCC) families with germline mutations in the MMR genes MLH1 and MSH2.'},\n",
       "   {'pubmed': 15791479,\n",
       "    'text': 'The data of this study suggest that activating mutations of B-RAF are not a frequent event in gliomas; nevertheless, when present they are associated with high-grade malignant lesions.'},\n",
       "   {'pubmed': 15791648,\n",
       "    'text': 'B-raf mutations surrounding Thr439 found in human cancers are unlikely to contribute to increased oncogenic properties of B-raf'},\n",
       "   {'pubmed': 15824163,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 15842051,\n",
       "    'text': 'These results suggest that BRAF mutations do not have a role in tumorigenesis of neuroendocrine gastroenteropancreatic tumors.'},\n",
       "   {'pubmed': 15880523,\n",
       "    'text': 'Anaplastic thyroid carcinomas which are derived from papillary carcinomas are due to BRAF and p53 mutations'},\n",
       "   {'pubmed': 15904951,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 15935100,\n",
       "    'text': 'B-raf V599E and V599K oncogenic mutations are likely to affect melanocyte-specific pathways controlling proliferation and differentiation'},\n",
       "   {'pubmed': 15968271,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 15968271,\n",
       "    'text': 'The increasing frequency of BRAF mutations as a function of age could help account for the well documented but poorly understood observation that age is a relevant prognostic indicator for patients with papillary thyroid carcinoma.'},\n",
       "   {'pubmed': 15980887,\n",
       "    'text': 'BRAF mutation occurs later in thyroid tumor progression and is restricted mainly to papillary thyroid carcinoma and anaplastic thyroid carcinoma'},\n",
       "   {'pubmed': 15994075,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 15998781,\n",
       "    'text': 'Role of BRAF mutation in facilitating metastasis and progression of papillary thyroid cancer in lymph nodes.'},\n",
       "   {'pubmed': 16007166,\n",
       "    'text': 'determination of mutation specific gene expression profiles in papillary thyroid carcinoma'},\n",
       "   {'pubmed': 16007203,\n",
       "    'text': 'Single-cell clones with efficient knockdown of (V 600 E)B-RAF could be propagated in the presence of basic fibroblast growth factor but underwent apoptosis or senescence-like growth arrest upon withdrawal of this growth factor'},\n",
       "   {'pubmed': 16015629,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 16024606,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 16079850,\n",
       "    'text': 'sustained BRAF(V600E) expression in human melanocytes induces cell cycle arrest, which is accompanied by the induction of both p16(INK4a) and senescence-associated acidic beta-galactosidase (SA-beta-Gal) activity, a commonly used senescence marker'},\n",
       "   {'pubmed': 16096377,\n",
       "    'text': 'BRAF mutation in melanoma is most likely to occur prior to the development of metastatic disease'},\n",
       "   {'pubmed': 16098042,\n",
       "    'text': 'Although BRAF and NRAS mutations are likely to be important for the initiation and maintenance of some melanomas, other factors might be more significant for proliferation and prognosis in subgroups of aggressive melanoma'},\n",
       "   {'pubmed': 16098042,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 16123397,\n",
       "    'text': 'The results showed that conjunctival nevi, similar to skin nevi, have a high frequency of oncogenic BRAF mutations.'},\n",
       "   {'pubmed': 16129781,\n",
       "    'text': 'These data suggest that MITF is an anti-proliferation factor that is down-regulated by B-RAF signaling and that this is a crucial event for the progression of melanomas that harbor oncogenic B-RAF.'},\n",
       "   {'pubmed': 16143028,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 16144912,\n",
       "    'text': 'Mutations of the BRAF gene are partly involved in the malignant transformation of the endometrium.'},\n",
       "   {'pubmed': 16144912,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 16172610,\n",
       "    'text': 'selective reduction in catalytic activity and expression of B-Raf but not Raf-1 suggest that B-Raf may be playing an important role in altered ERK signaling in brain of suicide subjects, and thus in the pathophysiology of suicide'},\n",
       "   {'pubmed': 16174717,\n",
       "    'text': 'In patients with papillary thyroid cancer, BRAF mutation is associated with poorer clinicopathological outcomes and independently predicts recurrence.'},\n",
       "   {'pubmed': 16174717,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 16179867,\n",
       "    'text': 'As the BRAF oncogene is frequently found to be mutated in human cutaneous melanomas, it may constitute a risk factor for melanoma formation within CMN and DMN.'},\n",
       "   {'pubmed': 16179870,\n",
       "    'text': 'The oncogenic B-raf mutations V599E and V599K, as early events in melanocyte transformation, persist throughout metastasis with important prognostic implications.'},\n",
       "   {'pubmed': 16181240,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 16181547,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 16199894,\n",
       "    'text': 'copy number gain may represent another mechanism of BRAF activation in thyroid tumors'},\n",
       "   {'pubmed': 16268813,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 16354196,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 16354196,\n",
       "    'text': 'The estimated proportion of attributable risk of melanoma due to variants in BRAF is 1.6%, but the burden of disease associated with this variant is greater than that associated with the major melanoma locus (CDKN2A) which has a risk of 0.2%.'},\n",
       "   {'pubmed': 16354586,\n",
       "    'text': 'Mutation and elevated expression of BRAF is associated with the development of testicular germ cell tumors'},\n",
       "   {'pubmed': 16361694,\n",
       "    'text': 'The authors have developed and run a high-throughput screen to find inhibitors of V600E BRAF using an enzyme cascade assay in which oncogenic BRAF activates MEK1, which in turn activates ERK2, which then phosphorylates the transcription factor ELK1.'},\n",
       "   {'pubmed': 16364920,\n",
       "    'text': 'Data suggest that B-RAF activates C-RAF through a mechanism involving 14-3-3 mediated heterooligomerization and C-RAF transphosphorylation.'},\n",
       "   {'pubmed': 16371460,\n",
       "    'text': 'V600E B-Raf requires the Hsp90 chaperone for stability and is degraded in response to Hsp90 inhibitors.'},\n",
       "   {'pubmed': 16373964,\n",
       "    'text': 'activating mutations of PDGFR-alpha, c-kit and B-RAF are absent in gliosarcomas'},\n",
       "   {'pubmed': 16376942,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 16376942,\n",
       "    'text': 'V599E BRAF mutation was uncommon in Japanese lung cancer.'},\n",
       "   {'pubmed': 16382052,\n",
       "    'text': 'aberrant B-Raf activity in angiomyolipomas leads to abnormal cellular differentiation and migration [review]'},\n",
       "   {'pubmed': 16397024,\n",
       "    'text': 'Observational study of genotype prevalence. (HuGE Navigator)'},\n",
       "   {'pubmed': 16413100,\n",
       "    'text': 'The most frequent B-RAF gene alterations are not involved in prostate carcinogenesis'},\n",
       "   {'pubmed': 16417232,\n",
       "    'text': 'BRAF mutation does not seem to be sufficient to produce MAPK activation in melanocytic nevi.'},\n",
       "   {'pubmed': 16424035,\n",
       "    'text': 'gain-of-function BRAF signaling is strongly associated with in vivo tumorigenicity'},\n",
       "   {'pubmed': 16439621,\n",
       "    'text': 'findings demonstrate that heterogeneous de novo missense mutations in three genes within the mitogen-activated protein kinase pathway, BRAF, MEK1 and MEK2 cause cardio-facio-cutaneous syndrome'},\n",
       "   {'pubmed': 16452469,\n",
       "    'text': 'wild-type B-Raf-mediated ERK1/2 activation plays a major role in proliferation and transformation of uveal melanocytes; Raf-1 is not involved in this activation'},\n",
       "   {'pubmed': 16452550,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 16462768,\n",
       "    'text': 'NRAS and BRAF activating mutations can coexist in the same melanoma, but are mutually exclusive at the single-cell level'},\n",
       "   {'pubmed': 16474404,\n",
       "    'text': 'Cardio-facio-cutaneous (CFC) syndrome involves dysregulation of the RAS-RAF-ERK pathway.'},\n",
       "   {'pubmed': 16487015,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 16537381,\n",
       "    'text': 'Merlin and MLK3 can interact in situ and merlin can disrupt the interactions between B-Raf and Raf-1 or those between MLK3 and either B-Raf or Raf-1.'},\n",
       "   {'pubmed': 16547495,\n",
       "    'text': 'Melanoma cells require either B-RAF or phosphoinositide-3 kinase activation for protection from anoikis.'},\n",
       "   {'pubmed': 16601293,\n",
       "    'text': 'BRAF V600E is associated with a high risk of recurrence and less differentiated papillary thyroid carcinoma due to the impairment of Na+/I- targeting to the membrane'},\n",
       "   {'pubmed': 16601293,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 16618717,\n",
       "    'text': 'Observational study of gene-environment interaction and pharmacogenomic / toxicogenomic. (HuGE Navigator)'},\n",
       "   {'pubmed': 16687919,\n",
       "    'text': 'Observational study of genotype prevalence. (HuGE Navigator)'},\n",
       "   {'pubmed': 16691193,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 16691193,\n",
       "    'text': 'UV light is not necessarily required for the acquisition of the BRAF(V600E) mutation, and non-mutagenic effects of UV light to melanocytes may be more important in the nevogenesis'},\n",
       "   {'pubmed': 16721785,\n",
       "    'text': 'BRAF mutations are as uncommon as KRAS mutations in prostate adenocarcinoma'},\n",
       "   {'pubmed': 16728573,\n",
       "    'text': 'B-RAF (V600E) was confirmed to be associated with the papillary growth pattern, but not with poorer differentiated papillary thyroid carcinoma variants.'},\n",
       "   {'pubmed': 16728573,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 16773193,\n",
       "    'text': 'among 23 melanomas located at body sites with chronic UV exposure, only a single tumour harboured the B-raf V599E mutation which was a significantly lower frequency in comparison to melanomas from sun-protected body sites'},\n",
       "   {'pubmed': 16786134,\n",
       "    'text': 'a BRAFT1799A mutation may have a role in poor differentiation of thyroid carcinoma'},\n",
       "   {'pubmed': 16799476,\n",
       "    'text': 'A subset of Spitz nevi, some with atypical histologic features, possess BRAF mutations. The BRAF mutational status does not separate all Spitz nevi from spitzoid melanomas and non-Spitz types of melanocytic proliferations, contrary to previous reports.'},\n",
       "   {'pubmed': 16803888,\n",
       "    'text': 'Rheb has a central role in the regulation of the Ras/B-Raf/C-Raf/MEK signaling network'},\n",
       "   {'pubmed': 16804544,\n",
       "    'text': 'CpG island methylator phenotype-positive colorectal tumors represent a distinct subset, encompassing almost all cases of tumors with BRAF mutation'},\n",
       "   {'pubmed': 16809487,\n",
       "    'text': 'findings show that MC1R variants are strongly associated with BRAF mutations in non-chronic sun-induced damage melanomas; in this subtype, risk for melanoma associated with MC1R is due to increase in risk of developing melanomas with BRAF mutations'},\n",
       "   {'pubmed': 16845322,\n",
       "    'text': 'BRAF mutation is associated with melanoma and melanocytic nevi.'},\n",
       "   {'pubmed': 16858395,\n",
       "    'text': 'Thus, we propose that the hitherto unidentified function of the B-Raf amino-terminal region is to mediate calcium-dependent activation of B-Raf and the following MEK activation, which may occur in the absence of Ras activation.'},\n",
       "   {'pubmed': 16858683,\n",
       "    'text': 'Aberrant methylation and hence silencing of TIMP3, SLC5A8, DAPK and RARbeta2, in association with BRAF mutation, may be an important step in PTC tumorigenesis and progression.'},\n",
       "   {'pubmed': 16879389,\n",
       "    'text': 'BRAF mutation was frequent in hyperplastic polyps (67%) and sessile serrated adenomas (81%).'},\n",
       "   {'pubmed': 16912199,\n",
       "    'text': 'B-RAF has been identified as the most mutated gene in invasive cells and therefore an attractive therapeutic target in melanoma.'},\n",
       "   {'pubmed': 16918136,\n",
       "    'text': 'BRAF mutations are associated with colorectal cancers'},\n",
       "   {'pubmed': 16918957,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 16924241,\n",
       "    'text': 'Expression of p27Kip1 in melanoma is regulated by B-RAF at the mRNA level and via B-RAF control of Cks1/Skp2-mediated proteolysis.'},\n",
       "   {'pubmed': 16932278,\n",
       "    'text': 'Single nucleotide polymorphism found exclusively in papillary thyroid carcinoma.'},\n",
       "   {'pubmed': 16937524,\n",
       "    'text': 'BRAF, K-ras and BAT26 are expressed in colorectal polyps and stool'},\n",
       "   {'pubmed': 16937524,\n",
       "    'text': 'BRAF, K-ras and BAT26 are expressed in colorectal polyps and stool [BAT26]'},\n",
       "   {'pubmed': 16946010, 'text': 'Braf mutations in thyroid tumorigenesis.'},\n",
       "   {'pubmed': 16953233,\n",
       "    'text': 'Concomitant KRAS and BRAF mutations increased along progression of MSS colorectal cancer, suggesting that activation of both genes is likely to harbour a synergistic effect'},\n",
       "   {'pubmed': 16959844,\n",
       "    'text': 'BRAFV600E activates not only MAPK but also NF-kappaB signaling pathway in human thyroid cancer cells, leading to an acquisition of apoptotic resistance and promotion of invasion.'},\n",
       "   {'pubmed': 16960555,\n",
       "    'text': 'Expression of active mutants of B-Raf induces fibronectin.'},\n",
       "   {'pubmed': 16964379,\n",
       "    'text': 'Extracellular signal-regulated kinase-3 (ERK3/MAPK6) is highly expressed in response to BRAF signaling.'},\n",
       "   {'pubmed': 16973828,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 16987295,\n",
       "    'text': 'BRAF T1976A mutation is present at high frequency in benign naevi such as Spitz and Reed.'},\n",
       "   {'pubmed': 17001349,\n",
       "    'text': 'data support a model in which mutational activation of BRAF in human melanomas contributes to constitutive induction of NF-kappaB activity and to increased survival of melanoma cells'},\n",
       "   {'pubmed': 17018604,\n",
       "    'text': 'Normally, BRAF alone is responsible for signaling to MEK. However, when RAS is mutated in melanoma, melanocytes switch their signaling from BRAF to CRAF.'},\n",
       "   {'pubmed': 17044028,\n",
       "    'text': 'Activating BRAF mutation is associated with papillary thyroid carcinoma'},\n",
       "   {'pubmed': 17060774,\n",
       "    'text': 'BRAF mutation remained a significant prognostic factor for lymph node metastasis (odds ratio = 10.8, 95% confidence interval, 3.5-34.0, P < 0.0001).'},\n",
       "   {'pubmed': 17074813,\n",
       "    'text': 'phosphorylation on both S365 and S429 participate in the differential regulation of B-Raf isoforms through distinct mechanisms'},\n",
       "   {'pubmed': 17097223,\n",
       "    'text': 'data provide evidence that oncogenic properties of BRAF contribute to the tumorigenesis of intraductal papillary mucinous neoplasm/carcinoma (IPMN/IPMC), but at a lower frequency than KRAS'},\n",
       "   {'pubmed': 17119056,\n",
       "    'text': 'BRAF-V600E mutations are mainly involved in colorectal cancer families characterized by an increased risk of other common malignancies'},\n",
       "   {'pubmed': 17119447,\n",
       "    'text': 'Association with preexisting nevi and pronounced infiltration of lymphocytes was significantly higher in BRAF mutated melanoma tumours'},\n",
       "   {'pubmed': 17148775,\n",
       "    'text': 'Observational study of gene-disease association and gene-environment interaction. (HuGE Navigator)'},\n",
       "   {'pubmed': 17148775,\n",
       "    'text': 'Previously identified associations between smoking and colon cancer, whether microsatellite unstable or stable, appear to be explained by the association of smoking with BRAF mutation.'},\n",
       "   {'pubmed': 17159915,\n",
       "    'text': 'BRAF(T1799A) mutation is associated with a lower rate of tumor proliferation.'},\n",
       "   {'pubmed': 17159915,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 17170014,\n",
       "    'text': 'RASSF1A methylation was observed in a high frequency in endometrioid endometrial carcinoma whereas K-ras and B-raf mutations were observed in a low frequency'},\n",
       "   {'pubmed': 17179987,\n",
       "    'text': 'The role for BRAF activation in thyroid cancer development and establishing the potential therapeutic efficacy of BRAF-targeted agents in patients with thyroid cancerwill be reviewed.'},\n",
       "   {'pubmed': 17186541,\n",
       "    'text': 'BRAF mutation is associated with thyroid carcinogenesis'},\n",
       "   {'pubmed': 17186541,\n",
       "    'text': 'Observational study of gene-disease association and gene-environment interaction. (HuGE Navigator)'},\n",
       "   {'pubmed': 17195912,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 17195912,\n",
       "    'text': 'there is a subgroup of colorectal carcinomas which develop via the microsatellite instability pathway that carry an alteration of the BRAF gene'},\n",
       "   {'pubmed': 17199737,\n",
       "    'text': 'Absence of association between BRAF mutation and activation of MAPK pathway in papillary thyroid carcinoma suggests the presence of mechanisms that downregulate MAPK activation.'},\n",
       "   {'pubmed': 17227125,\n",
       "    'text': 'Copy gain of PDGFB occurs in a subset of tumors showing no evidence of mutated BRAF or rearranged ret, suggesting that copy gain of PDGFB may underlie the increased expression of platelet-derived growth factor described recently in the literature.'},\n",
       "   {'pubmed': 17270239,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 17297294,\n",
       "    'text': 'characterization of the T1799-1801del and A1799-1816ins BRAF mutations in papillary thyroid cancer; the two new mutations resulted in constitutive activation of the BRAF kinase and caused NIH3T3 cell transformation'},\n",
       "   {'pubmed': 17302867,\n",
       "    'text': 'Overexpression of B-Raf mRNA and protein may be a feature of nonfunctioning pituitary adenomas, highlighting overactivity of the Ras-B-Raf-MAP kinase pathway in these tumors.'},\n",
       "   {'pubmed': 17309670,\n",
       "    'text': 'BRAF gene plays a \"gatekeeper\" role but does not act as a predisposition gene in the development of low-grade ovarian serous carcinomas'},\n",
       "   {'pubmed': 17309670,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 17312306,\n",
       "    'text': 'Observational study of genetic testing. (HuGE Navigator)'},\n",
       "   {'pubmed': 17315191,\n",
       "    'text': 'BRAFV600E represents a detectable marker in the plasma/serum from melanoma patients for monitoring but not diagnostic purposes'},\n",
       "   {'pubmed': 17318013,\n",
       "    'text': 'B-RAF mutations are a rare event in pituitary tumorigenesis.'},\n",
       "   {'pubmed': 17355635,\n",
       "    'text': 'The aim of this study was to identify the effect that BRAF oncogene has on post-transcriptional regulation in papillary thyroid carcinoma by using microRNA analysis.'},\n",
       "   {'pubmed': 17360030,\n",
       "    'text': 'findings show that RASSF1A hypermethylation and KRAS mutations and BRAF mutations are inversely correlated and play an important role in the development of cervical adenocarcinomas'},\n",
       "   {'pubmed': 17366577,\n",
       "    'text': 'mutational analysis of KRAS, BRAF, and MAP2K1/2 in 56 patients with CFC syndrome; comparison of the genotype-phenotype correlation of CFC with that of Costello syndrome suggest a significant clinical overlap but not genotype overlap.'},\n",
       "   {'pubmed': 17387744,\n",
       "    'text': 'BRAF(V600E) mutation is identified in a subset of cutaneous metastases from papillary thyroid carcinomas'},\n",
       "   {'pubmed': 17393356,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 17393356,\n",
       "    'text': 'data suggest that BRAF mutations might be present less frequently than KRAS mutations in Greek patients with colorectal carcinomas'},\n",
       "   {'pubmed': 17440063,\n",
       "    'text': 'finding of a strong association between BRAF mutations and serrated histology in hyperplastic aberrant crypt foci supports the idea that these lesions are an early, sentinel, or a potentially initiating step on the serrated pathway to colorectal carcinoma'},\n",
       "   {'pubmed': 17453004,\n",
       "    'text': 'BRAF V600E mutation was occasionally observed in anaplastic carcinomas with papillary carcinoma.'},\n",
       "   {'pubmed': 17453358,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 17454879,\n",
       "    'text': 'MSI is rare in UC-related neoplasia as well as non-neoplastic lesions, and does not contribute to the development of dysplasia.'},\n",
       "   {'pubmed': 17464312,\n",
       "    'text': 'prevalence of BRAF mutation and RET/PTC were determined in diffuse sclerosing variant of papillary thyroid carcinoma; none of the cases showed a BRAF mutation'},\n",
       "   {'pubmed': 17483702,\n",
       "    'text': 'Molecular diagnosis and careful observations should be considered in children with Cardio-facio-cutaneous syndrome because they have germline mutations in BRAF and might develop malignancy.'},\n",
       "   {'pubmed': 17487277,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 17487504,\n",
       "    'text': 'c-kit expression is not alternative to BRAF and/or KRAS activation.'},\n",
       "   {'pubmed': 17488796,\n",
       "    'text': 'BRAF V600E mutation in PTCs is associated with reduced expression of key genes involved in iodine metabolism'},\n",
       "   {'pubmed': 17507627,\n",
       "    'text': 'Observational study of gene-disease association and gene-environment interaction. (HuGE Navigator)'},\n",
       "   {'pubmed': 17507627,\n",
       "    'text': 'data indicate that both early-life UV exposure and nevus propensity contribute to occurrence of BRAF+ melanoma, whereas nevus propensity and later-life sun exposure influence the occurrence of NRAS+ melanoma'},\n",
       "   {'pubmed': 17516929,\n",
       "    'text': 'analysis of a BRAF mutation-associated gene expression signature in melanoma'},\n",
       "   {'pubmed': 17518771,\n",
       "    'text': 'low rate of RAS-RAF mutations (2/22, 9.1%) observed in Spitz melanocytic nevi suggests that these lesions harbor as yet undetected activating mutations in other components of the RAS-RAF-MEK-ERK-MAPK pathway'},\n",
       "   {'pubmed': 17520704,\n",
       "    'text': 'Meta-analysis of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 17520704,\n",
       "    'text': 'frequency of the BRAF mutation and the associations between BRAF mutation and clinicopathologic parameters in papillary thyroid carcinoma were evaluated by meta-analysis'},\n",
       "   {'pubmed': 17525723,\n",
       "    'text': 'T1790A BRAF mutation (L597Q) in childhood acute lymphoblastic leukemia is a functional oncogene'},\n",
       "   {'pubmed': 17535994,\n",
       "    'text': 'The heterogeneous distribution of BRAF mutations suggests that discrete tumor foci in multifocal PTC may occur as independent tumors.'},\n",
       "   {'pubmed': 17542667,\n",
       "    'text': 'Presence of BRAF V600E in very early stages of papillary thyroid carcinoma.'},\n",
       "   {'pubmed': 17548320,\n",
       "    'text': 'influence of B-RAF-specific RNA interference on the proliferation and apoptosis of gastric cancer BGC823 cell line'},\n",
       "   {'pubmed': 17566669,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 17566669,\n",
       "    'text': 'We conclude that screening for BRAF 15 exon mutation is an efficient tool in the diagnostic strategy for HNPCC'},\n",
       "   {'pubmed': 17635919,\n",
       "    'text': 'In contrast to C-RAF that requires farnesylated H-Ras, cytosolic B-RAF associates effectively and with significantly higher affinity with both farnesylated and nonfarnesylated H-Ras.'},\n",
       "   {'pubmed': 17663506,\n",
       "    'text': 'KLF6 and p53 mutations are involved in the development of nonpolypoid colorectal carcinoma, whereas K-ras and B-raf mutations are not'},\n",
       "   {'pubmed': 17671688,\n",
       "    'text': 'PPARbeta/delta has a role in growth of RAF-induced lung adenomas'},\n",
       "   {'pubmed': 17685465,\n",
       "    'text': 'BRAF V600E mutation in papillary carcinoma of the thyroid may facilitate tumor cell growth and progression once seeded in the lymph nodes.'},\n",
       "   {'pubmed': 17693984,\n",
       "    'text': 'Observational study of genotype prevalence, gene-disease association, and genetic testing. (HuGE Navigator)'},\n",
       "   {'pubmed': 17693984,\n",
       "    'text': 'There was no coexistence of BRAF (V600E) mutation in papillary thyroid carcinoma.'},\n",
       "   {'pubmed': 17696195,\n",
       "    'text': 'data showed differences in gene expression between nevi with and without the V600E BRAF mutation. Moreover, nevi with mutations showed over-expression of genes involved in melanocytic senescence and cell cycle inhibition'},\n",
       "   {'pubmed': 17699719,\n",
       "    'text': 'RNA interference and pharmacologic approaches were used to assess the role of B-Raf activation in the growth of human melanomas and additionally determined if a similar role for mutant B-Raf is seen for colorectal carcinoma cell lines.'},\n",
       "   {'pubmed': 17704260,\n",
       "    'text': '5 unreported mutations (T241P, Q262R, G464R, E501V, N581K) were found in cardio-facio-cutaneous syndrome. A hotspot in exon 6 at Q257 was found.'},\n",
       "   {'pubmed': 17714762,\n",
       "    'text': 'diffuse expression of wild-type and/or mutant B-Raf may be involved in the tumorigenic process'},\n",
       "   {'pubmed': 17717450,\n",
       "    'text': 'BRAF V600E mutation is primarily present in conventional papillary thyroid cancer; it is associated with an aggressive tumor phenotype and higher risk of recurrent and persistent disease in patients with conventional papillary thyroid cancer'},\n",
       "   {'pubmed': 17717450,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 17721188,\n",
       "    'text': 'Develompment of malignant strumo ovarii with papillary thyroid carcinoma features is associated with BRAF mutations.'},\n",
       "   {'pubmed': 17727338,\n",
       "    'text': 'BRAF(V600E) mutation detected on fine-needle aspiration biopsy specimens, more than RET/PTC rearrangements, is highly specific for papillary thyroid carcinoma.'},\n",
       "   {'pubmed': 17785355,\n",
       "    'text': 'BRAF V600E mutation is associated with high-risk papillary thyroid carcinoma'},\n",
       "   {'pubmed': 17785355,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 17786355,\n",
       "    'text': 'BRAFV600E mutations were found in 41.2% of the papillary thyroid carcinomas'},\n",
       "   {'pubmed': 17854396,\n",
       "    'text': 'Papillary thyroid cancers with no 131I uptake had a high frequency of BRAF mutations.'},\n",
       "   {'pubmed': 17878251,\n",
       "    'text': 'MEK inhibition is cytostatic in papillary thyroid cancer and anaplastic thyroid cancer cells bearing a BRAF mutation'},\n",
       "   {'pubmed': 17911174,\n",
       "    'text': 'effects of a MEK inhibitor, CI-1040, on thyroid cancer cells, some of which, particularly cell proliferation and tumor growth, seemed to be BRAF mutation or RAS mutation selective'},\n",
       "   {'pubmed': 17914558,\n",
       "    'text': 'BRAF mutation is associated as early as the hyperplastic polyp stage followed by microsatellite instability at the carcinoma stage'},\n",
       "   {'pubmed': 17924122,\n",
       "    'text': 'Examined associations between BRAF mutations, morphology, and apoptosis in early colorectal cancer.'},\n",
       "   {'pubmed': 17940185,\n",
       "    'text': 'BRAF mutation represents a novel indicator of the progression and aggressiveness of papillary thyroid cancer (Review)'},\n",
       "   {'pubmed': 17942568,\n",
       "    'text': 'BRAF interacts with PLCepsilon1 in nephrotic syndrome type 3. Both proteins are coexpressed and colocalize in developing and mature glomerular podocytes.'},\n",
       "   {'pubmed': 17962436,\n",
       "    'text': 'In this small study, the T1799A BRAF mutation was identified in almost half of the iris melanoma tissues samples examined. This finding suggests that there may be genetic as well as clinical differences between iris and posterior uveal melanomas.'},\n",
       "   {'pubmed': 17972530,\n",
       "    'text': 'These results suggest that papillary thyroid carcinomas with BRAF (V600E) mutation are more aggressive than those with wildtype BRAF.'},\n",
       "   {'pubmed': 18000091,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 18008004,\n",
       "    'text': 'mutation of N-RAS or B-RAF, signature genetic lesions present in most MMs, potently induced the expression of cell-surface CD200, a repressor of DC function.'},\n",
       "   {'pubmed': 18024410,\n",
       "    'text': 'no BRAF mutations identified in 65 screened JMML patients; this gene is unlikely to play a role in the pathogenesis of JMML.'},\n",
       "   {'pubmed': 18032947,\n",
       "    'text': 'The BRAF mutation is common in melanomas, but variation in rates across melanoma subtypes points to a complex interplay between BRAF activation and other factors (eg, sun exposure).'},\n",
       "   {'pubmed': 18042262,\n",
       "    'text': 'the results of HRAS, BRAF and MAP2K1/2 mutation screening in a large cohort of patients with CS and CFC'},\n",
       "   {'pubmed': 18045960,\n",
       "    'text': 'Detection of BRAF improves the diagnosis in fine-needle biopsy with cytological findings suspicious for papillary thyroid carcinoma.'},\n",
       "   {'pubmed': 18045987,\n",
       "    'text': 'These results identify Rnd3 as a regulator of cross talk between the RAF/MEK/ERK and Rho/ROCK signaling pathways, and a key contributor to oncogene-mediated reorganization of the actin cytoskeleton and focal adhesions.'},\n",
       "   {'pubmed': 18060073,\n",
       "    'text': 'BRAF and MEK1/2 mutations may be more common than anticipated in ovarian cancer which could have important implications for treatment of patients with this disease and suggests potential new therapeutic avenues'},\n",
       "   {'pubmed': 18061181,\n",
       "    'text': 'Observational study of genetic testing. (HuGE Navigator)'},\n",
       "   {'pubmed': 18070147,\n",
       "    'text': \"BRAF(V600E)'alone' does not represent a marker for poor outcome\"},\n",
       "   {'pubmed': 18071315,\n",
       "    'text': 'B-Raf(V600E) signaling deregulates the mitotic spindle checkpoint through stabilizing Mps1 levels in melanoma cells.'},\n",
       "   {'pubmed': 18098337,\n",
       "    'text': 'BRAF provides proliferation and survival signals in MSI colorectal carcinoma cells displaying BRAF(V600E) but not KRAS mutations.'},\n",
       "   {'pubmed': 18172070,\n",
       "    'text': 'Because of the very sensitive pyrophosphorolysis-activated polymerization (PAP)technology, B-RAF mutations were found in cell lines and primary uveal melanomas.'},\n",
       "   {'pubmed': 18199160,\n",
       "    'text': 'A worse clinical outcome was found for CIMP-high, microsatellite stable colorectal cancer with KRAS/BRAF mutation but not for those lacking KRAS/BRAF mutation.'},\n",
       "   {'pubmed': 18224685,\n",
       "    'text': 'Observational study of gene-disease association and gene-gene interaction. (HuGE Navigator)'},\n",
       "   {'pubmed': 18226854,\n",
       "    'text': 'frequency of the occurrence of BRAF mutation and/or RET/PTC in H4-PTEN positive tumors was extremely high (75%) in papillary thyroid carcinoma'},\n",
       "   {'pubmed': 18227705,\n",
       "    'text': 'BRAF mutation is not associated with cutaneous melanoma'},\n",
       "   {'pubmed': 18228248,\n",
       "    'text': 'Important signalling role in T cell development.'},\n",
       "   {'pubmed': 18235983,\n",
       "    'text': 'Follicular histotypes of oncocytic thyroid carcinomas do not carry BRAF mutations'},\n",
       "   {'pubmed': 18246127,\n",
       "    'text': 'Mutant B-RAF mediates resistance to anoikis via Bad and Bim.'},\n",
       "   {'pubmed': 18267069,\n",
       "    'text': 'A genome-wide RNA-interference screening to identify genes required for an activated BRAF oncogene to block proliferation of fibroblasts and melanocytes revealed that a IGFBP7, has a central role in BRAF-mediated senescence and apoptosis.'},\n",
       "   {'pubmed': 18310286,\n",
       "    'text': 'BRAF T1799A mutation is associated with aggressive pathological outcomes of papillary thyroid cancer'},\n",
       "   {'pubmed': 18310287,\n",
       "    'text': 'BRAF(V600E) mutation is asscoiated with papillary thyroid cancer'},\n",
       "   {'pubmed': 18310288,\n",
       "    'text': 'BRAF-V600E mutation is associated with familial non-medullary thyroid carcinoma'},\n",
       "   {'pubmed': 18323787,\n",
       "    'text': 'Mitogen-activated protein kinase (MAPK) activity is subject to regulation even in BRAF/NRAS mutant melanoma cells and that high MAPK pathway signaling may be important only in distinct subsets of tumor cells.'},\n",
       "   {'pubmed': 18329792,\n",
       "    'text': 'RKIP could play an important role in the down-regulation of wild-type BRAF, serving thus as an endogenous inhibitor of the MAPK pathway in nasal polyps and their adjacent turbinate mucosa.'},\n",
       "   {'pubmed': 18337114,\n",
       "    'text': 'BRAF mutation testing of papillary thyroid carcinoma might improve the diagnosis, prognostic stratification and treatment of these tumors.'},\n",
       "   {'pubmed': 18343945,\n",
       "    'text': 'Our data provide evidence that PIK3CA and BRAF contribute to the tumorigenesis of IPMN/IPMC, but at a lower frequency than KRAS.'},\n",
       "   {'pubmed': 18368129,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 18368129,\n",
       "    'text': 'This study confirms that the known MC1R-melanoma risk association is confined to subjects whose melanomas harbor BRAF mutations.'},\n",
       "   {'pubmed': 18375819,\n",
       "    'text': 'BRAF mutation is associated with disease stabilization in melanoma'},\n",
       "   {'pubmed': 18381570,\n",
       "    'text': 'Thyroid cancers with BRAF mutation are preferentially sensitive to MEK inhibitors.'},\n",
       "   {'pubmed': 18382358,\n",
       "    'text': 'Detecting BRAF mutation by pyrosequencing is more sensitive, faster, and less expensive than direct DNA sequencing.'},\n",
       "   {'pubmed': 18383861,\n",
       "    'text': 'K-RAS and BRAF mutations are a frequent genetic event in our samples of sporadic papillary and medullary thyroid carcinoma.'},\n",
       "   {'pubmed': 18383861,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 18397470,\n",
       "    'text': 'is commonly activated by somatic point mutation, it may provide possible diagnostic and therapeutic targets in human malignant tumors.'},\n",
       "   {'pubmed': 18398503,\n",
       "    'text': 'Results implicate aberrant activation of the MAPK pathway due to gene duplication or mutation of BRAF as a molecular mechanism of pathogenesis in low-grade astrocytomas and suggest inhibition of the MAPK pathway as a potential treatment.'},\n",
       "   {'pubmed': 18402768,\n",
       "    'text': 'Aberrant BRAF and INK4A functionally interact to promote growth and survival of melanoma cells.'},\n",
       "   {'pubmed': 18408659,\n",
       "    'text': 'in melanocytic lesions, BRAF(V600E) mutation can affect a subset of the cells and is associated with the type and quantity of sun exposure'},\n",
       "   {'pubmed': 18413255,\n",
       "    'text': 'study describes the biochemical characterization of novel BRAF and MEK germline mutations in cardio-facio-cutaneous syndrome'},\n",
       "   {'pubmed': 18434602,\n",
       "    'text': 'Cdk1/cyclin B has a role in regulating B-raf activation at mitosis'},\n",
       "   {'pubmed': 18435933,\n",
       "    'text': 'CpG island methylator phenotype in colorectal neoplasms may result from activating mutations in either BRAF or KRAS.'},\n",
       "   {'pubmed': 18451171,\n",
       "    'text': 'Akt3 and mutant V600E B-Raf cooperate to promote early melanoma development.'},\n",
       "   {'pubmed': 18458053,\n",
       "    'text': 'oncogenic BRAF inhibition can have a different effect on cell fate depending on the cellular type'},\n",
       "   {'pubmed': 18470905,\n",
       "    'text': 'aberrant methylation of the hMLH1 gene may play a role in BRAF mutation-promoted thyroid tumorigenesis'},\n",
       "   {'pubmed': 18509003,\n",
       "    'text': 'study revealed a significant correlation of BRAFV600E mutation with a lower expression of both sodium iodide symporter and thyroperoxidase in papillary thyroid cancer'},\n",
       "   {'pubmed': 18509361,\n",
       "    'text': 'Shorter overall survival in primary melanoma was associated with the presence of ulceration and BRAF exon 15 mutations, as well as the absence of nuclear activation of Akt and of cytoplasmic activation of ERK.'},\n",
       "   {'pubmed': 18517279,\n",
       "    'text': 'BRAF mutations in colorectal cancer microsatellite-stable cases are associated with high levels of chromosomal instability that are likely responsible for the adverse outcomes in these cases'},\n",
       "   {'pubmed': 18519771,\n",
       "    'text': 'a significant relationship in overall survival in colon cancer patients with defective DNA mismatch repair and the presence of a specific mutation in BRAF (V600E)'},\n",
       "   {'pubmed': 18532874,\n",
       "    'text': 'Compared to melanomas without BRAF mutations, melanomas with BRAF mutations showed statistically significantly higher degrees of intraepidermal scatter of melanocytes, and a higher proportion of melanocytes arranged in nests.'},\n",
       "   {'pubmed': 18567582,\n",
       "    'text': 'the scaffold protein IQGAP1 couples Ca(2+) and calmodulin signaling to B-Raf function'},\n",
       "   {'pubmed': 18592405,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 18594528,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 18602919,\n",
       "    'text': 'Rac1b and B-Raf(V600E) functionally cooperate to sustain colorectal cell viability and suggest they constitute an alternative survival pathway to oncogenic K-Ras'},\n",
       "   {'pubmed': 18615679,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 18615679,\n",
       "    'text': 'V600E BRAF mutation is associated with imatinib-resistant gastrointestinal stromal tumors'},\n",
       "   {'pubmed': 18615680,\n",
       "    'text': 'MLH1 methylation and BRAF mutations are associated with microsatellite unstable colon tumors'},\n",
       "   {'pubmed': 18615680,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 18621636,\n",
       "    'text': 'Observational study of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)'},\n",
       "   {'pubmed': 18628356,\n",
       "    'text': 'The frequencies of LOHs of 17q21, 17p13, 10q23, and 22q13 were higher in tumors with lymph node metastasis, suggesting that these LOHs may be important in increased lymph node metastasis.'},\n",
       "   {'pubmed': 18628431,\n",
       "    'text': 'People of southern European origin had lower risk of colorectal cancers with CIMP and BRAF mutation than people of Anglo-Celtic origin, which may in part be due to genetic factors that are less common in people of southern European origin.'},\n",
       "   {'pubmed': 18628967,\n",
       "    'text': 'BRAF regulates melanoma proliferation through the lineage specific factor MITF'},\n",
       "   {'pubmed': 18632627,\n",
       "    'text': 'co-overexpression of KIT/CDK4 is a potential mechanism of oncogenic transformation in some BRAF/NRAS wild-type melanomas'},\n",
       "   {'pubmed': 18636014,\n",
       "    'text': 'lung adenocarcinoma of mixed type with a high incidence of papillary and lepidic growth may be worthwhile investigating for BRAF-V600E mutation as more genetically oriented drug therapies emerge.'},\n",
       "   {'pubmed': 18650848,\n",
       "    'text': 'hyperactivation of the MAPK pathway following activation of an inducible form of oncogenic C-Raf induces a senescence-like proliferation arrest in B-Raf mutant melanoma cells'},\n",
       "   {'pubmed': 18668139,\n",
       "    'text': \"N-RAS(Q61K) and B-RAF(V600E) contribute to melanoma's resistance to apoptosis in part by downregulating Bim expression\"},\n",
       "   {'pubmed': 18669866,\n",
       "    'text': 'Observational study of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)'},\n",
       "   {'pubmed': 18676742,\n",
       "    'text': 'CST6, CXCL14, DHRS3, and SPP1 are regulated by BRAF signaling and may play a role in papillary thyroid carcinoma pathogenesis'},\n",
       "   {'pubmed': 18676756,\n",
       "    'text': 'Observational study of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)'},\n",
       "   {'pubmed': 18682506,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 18682506,\n",
       "    'text': 'The BRAF(V600E) mutation was demonstrated to be a poor prognostic factor independent from other clinicopathological features.'},\n",
       "   {'pubmed': 18697864,\n",
       "    'text': 'Identification and functional characterization of a novel T599I-VKSR(600-603)del BRAF mutation in a patient with follicular variant papillary thyroid carcinoma.'},\n",
       "   {'pubmed': 18710471,\n",
       "    'text': 'There is a higher frequency of the BRAF(V600E) mutation in papillary thyroid carcinomas than in normal thyroid tissue.'},\n",
       "   {'pubmed': 18715233,\n",
       "    'text': 'These data suggest that regulation of BIM expression by BRAF-->MEK-->ERK signaling is one mechanism by which oncogenic BRAF(V600E) can influence the aberrant physiology of melanoma cells.'},\n",
       "   {'pubmed': 18716556,\n",
       "    'text': 'focal gains at chromosome 7q34 and increased BRAF-MEK-ERK signaling are common findings in sporadic pilocytic astrocytomas'},\n",
       "   {'pubmed': 18718023,\n",
       "    'text': 'presence of the BRAF (V600E) mutation,the incidence of microsatellite instability high colorectal cancer in populations based study.'},\n",
       "   {'pubmed': 18757341,\n",
       "    'text': 'KRAS and BRAF mutations can impair response to anti-EGFR therapy for colorectal neoplasms'},\n",
       "   {'pubmed': 18757433,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 18759827,\n",
       "    'text': 'Observational study of genetic testing. (HuGE Navigator)'},\n",
       "   {'pubmed': 18778891,\n",
       "    'text': 'BRAF mutation is associated with the CpG island methylator phenotype in colorectal cancer from young patients'},\n",
       "   {'pubmed': 18778891,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 18782444,\n",
       "    'text': 'BRAF, KRAS and PIK3CA mutations occur prior to malignant transformation demonstrating that these oncogenic alterations are primary genetic events in colorectal carcinogenesis'},\n",
       "   {'pubmed': 18782444,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 18787396,\n",
       "    'text': 'These data implicates a mitotic role for B-Raf in regulating spindle formation and the spindle checkpoint in human somatic cells.'},\n",
       "   {'pubmed': 18794094,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 18794803,\n",
       "    'text': 'study identified a group of melanomas with low-activity BRAF mutations (G469E- and D594G) that are reliant upon CRAF-mediated survival activity'},\n",
       "   {'pubmed': 18798261,\n",
       "    'text': 'BRAF mutation occurs independently of CpG island methylator phenotype and MSI in all types of serrated polyps and may serve as a marker of serrated pathway of colorectal carcinogenesis'},\n",
       "   {'pubmed': 18806830,\n",
       "    'text': 'study concludes a single endogenous BRAF(V600E) allele is sufficient to repress BIM & prevent death from growth factor withdrawal; colorectal cancer cells with V600E mutations are addicted to the ERK1/2 pathway for repression of BIM'},\n",
       "   {'pubmed': 18832519,\n",
       "    'text': 'CIMP-high appears to be an independent predictor of a low colon cancer-specific mortality, while BRAF mutation is associated with a high colon cancer-specific mortality.'},\n",
       "   {'pubmed': 18834226,\n",
       "    'text': 'With at least 3 markers methylated, new CIMP-positive colorectal cancers were closely associated with proximal tumor location, low frequency of KRAS mutation, and high frequency of BRAF mutation.'},\n",
       "   {'pubmed': 18840924,\n",
       "    'text': 'BRAF(V600E) mutation may play some roles in local carcinoma development, there is no evidence that BRAF(V600E) mutation significantly reflects the aggressive characteristics and poor prognosis of patients with papillary carcinoma in Japan.'},\n",
       "   {'pubmed': 18840924,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 18945298,\n",
       "    'text': 'BRAF V600E appeared to be the most commonly mutated gene in both the melanocytic aggregate (seven of 18, 39%) and the melanoma (four of 18, 22%)'},\n",
       "   {'pubmed': 18946221,\n",
       "    'text': 'Hereditary pancreatitis patients with PRSS1 mutations also had mutations in BRAF and KRAS2.'},\n",
       "   {'pubmed': 18953432,\n",
       "    'text': 'study shows high expression of p16(INK4a) or the absence of activated B-RAF correlates with in vivo response of melanoma to cytotoxic drugs'},\n",
       "   {'pubmed': 18974108,\n",
       "    'text': 'rearrangement, which was not observed in a series of 244 higher-grade astrocytomas, results in an in-frame fusion gene incorporating the kinase domain of the BRAF oncogene'},\n",
       "   {'pubmed': 18980976,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 18985043,\n",
       "    'text': 'the T1799A BRAF mutation is present in a proportion of posterior uveal melanomas but within these tumours the distribution of the mutation is heterogeneous.'},\n",
       "   {'pubmed': 18987552,\n",
       "    'text': 'BRAF mutations may not play an important role in the oncogenesis or therapy of prostate adenocarcinoma'},\n",
       "   {'pubmed': 18992635,\n",
       "    'text': '8% of sporadic colorectal tumors in this study harbor mutation in the BRAF gene.'},\n",
       "   {'pubmed': 18992635,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 19001320,\n",
       "    'text': 'Observational study of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)'},\n",
       "   {'pubmed': 19001320,\n",
       "    'text': 'Wild-type BRAF is required for response to panitumumab or cetuximab in metastatic colorectal cancer.'},\n",
       "   {'pubmed': 19003996,\n",
       "    'text': 'BRAF-V600E mutation is uncommon in endocrine tumors other than thyroid papillary carcinomas'},\n",
       "   {'pubmed': 19012001,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 19012001,\n",
       "    'text': 'The result showed that the mutation rate of PIK3CA in nasopharyngeal carcinomas (n = 73) was 9.6%, whereas both BRAF (n = 65) and RAS (n = 45) were wild type in every specimen with adequate DNA for analysis.'},\n",
       "   {'pubmed': 19014278,\n",
       "    'text': 'In Korean patients with papillary thyroid carcinoma, the BRAFV600E mutation is associated with a lower frequency of background Hashimoto thyroiditis and a high frequency of lymph node metastasis.'},\n",
       "   {'pubmed': 19014278,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 19016743,\n",
       "    'text': 'Reverse transcription polymerase chain reaction-based sequencing revealed a fusion product between KIAA1549 and BRAF in pediatric low-grade astrocytomas'},\n",
       "   {'pubmed': 19018267,\n",
       "    'text': 'Observational study of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)'},\n",
       "   {'pubmed': 19018267,\n",
       "    'text': 'ovarian cancer patients with KRAS or BRAF mutations may benefit from CI-1040 treatment'},\n",
       "   {'pubmed': 19026650,\n",
       "    'text': 'Observational study of genetic testing. (HuGE Navigator)'},\n",
       "   {'pubmed': 19033861,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 19034577,\n",
       "    'text': 'BRAF(V600E) mutation is assocciated with aggressive papillary thyroid microcarcinoma.'},\n",
       "   {'pubmed': 19034577,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 19037234,\n",
       "    'text': 'NRAS and BRAF mutations increase from the radial to the vertical growth phase in cutaneous melanoma'},\n",
       "   {'pubmed': 19064572,\n",
       "    'text': 'Observational study and meta-analysis of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 19079609,\n",
       "    'text': 'Genetic extinction of BRAF(V600E) in established prostate tumors did not lead to tumor regression, indicating that while sufficient to initiate development of invasive prostate adenocarcinoma, BRAF(V600E) is not required for its maintenance.'},\n",
       "   {'pubmed': 19087308,\n",
       "    'text': 'G12D mutation may be more likely selected in a BRAF mutated context'},\n",
       "   {'pubmed': 19098310,\n",
       "    'text': 'ERK activation was induced by PKD2 overexpression via B-Raf signaling, providing a possible molecular mechanism of cystogenesis'},\n",
       "   {'pubmed': 19107232,\n",
       "    'text': 'BRAF pseudogene activation may play a role in thyroid tumor development.'},\n",
       "   {'pubmed': 19126563,\n",
       "    'text': 'Sessile serrated adenomas are encountered commonly in routine endoscopy practice and the histological diagnosis correlates strongly with the presence of BRAF mutation.'},\n",
       "   {'pubmed': 19127559,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 19133693,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 19142971,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 19147753,\n",
       "    'text': 'BRAF and RET/PTC dual mutations are associated with recurrent papillary thyroid carcinoma'},\n",
       "   {'pubmed': 19147753,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 19152441,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 19159571,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 19164452,\n",
       "    'text': 'MLH1-hypermethylated tumors harbor fewer APC and KRAS mutations and more BRAF mutations, suggesting that they develop distinctly from an MGMT methylator pathway.'},\n",
       "   {'pubmed': 19178815,\n",
       "    'text': 'Mutations are absent or rare in the kinase domain of B-RAF in Japanese head and neck squamous cell carcinoma.'},\n",
       "   {'pubmed': 19178815,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 19190079,\n",
       "    'text': 'Mutation in BRAF is associated with adrenocortical carcinomas.'},\n",
       "   {'pubmed': 19190105,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 19190129,\n",
       "    'text': 'Distinct BRAF (V600E) and KRAS mutations in high microsatellite instability sporadic colorectal cancer in African Americans.'},\n",
       "   {'pubmed': 19190129,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 19194051,\n",
       "    'text': 'Expression levels of fibronectin, vimentin and CITED1 were positively correlated with those of BRAFV600E, suggesting pathophysiological links between activated BRAF and overexpression of these genes.'},\n",
       "   {'pubmed': 19200582,\n",
       "    'text': '(novel) mutation in the activation kinase domain of the BRAF (A598V), this mutation led to the up-regulation of the BRAF kinase activity and its downstream signaling factors.'},\n",
       "   {'pubmed': 19206169,\n",
       "    'text': 'Findings provide evidence for a wide phenotypic diversity associated with mutations affecting BRAF, and occurrence of a clinical continuum associated with these molecular lesions.'},\n",
       "   {'pubmed': 19207009,\n",
       "    'text': 'the presence of the braf protein mutation increases prohibitin promoter activity and therefore potentially mediates effects of this mutation on the behavior of BRAF protein'},\n",
       "   {'pubmed': 19208736,\n",
       "    'text': 'BRAFT1799A mutation or RET/PTC rearrangement, mainly corresponding to follicular variants, maintain a thyroid differentiation expression level close to that of normal tissue.'},\n",
       "   {'pubmed': 19226609,\n",
       "    'text': 'BRAF* melanomas appear to be associated with a specific profile of DNA copy number aberrations that is distinct from those found in NRAS* and BRAF/NRAS(wt/wt) tumors.'},\n",
       "   {'pubmed': 19237633,\n",
       "    'text': 'Observational study of gene-disease association and gene-gene interaction. (HuGE Navigator)'},\n",
       "   {'pubmed': 19240718,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 19255327,\n",
       "    'text': 'Clinical trial of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)'},\n",
       "   {'pubmed': 19274086,\n",
       "    'text': 'oncogenic BRAF(V600E) induces the uncoupling of LKB1-AMPKalpha complexes providing at the same time a possible mechanism in cell proliferation that engages cell growth and cell division in response to mitogenic stimuli'},\n",
       "   {'pubmed': 19276360,\n",
       "    'text': 'GDC-0879-mediated efficacy was associated strictly with BRAF(V600E) status, MEK inhibition also attenuated proliferation and tumor growth of cell lines expressing wild-type BRAF.'},\n",
       "   {'pubmed': 19282104,\n",
       "    'text': 'study of KRAS/BRAF mutation status in a large and well-documented cohort of primary and metastatic renal cell carcinoma'},\n",
       "   {'pubmed': 19289622,\n",
       "    'text': 'Observational study of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)'},\n",
       "   {'pubmed': 19289622,\n",
       "    'text': 'a correlation between a gene mutation--BRAF V600E--and cisplatin resistance in nonseminomatous germ cell tumors.'},\n",
       "   {'pubmed': 19342899,\n",
       "    'text': 'Both BRAF and RKIP expression levels exhibit a decrease from normal skin tissue and actinic keratosis, going to squamous cell carcinoma.'},\n",
       "   {'pubmed': 19344998,\n",
       "    'text': 'In BRAF mutated colorectal carcinoma cells quercetin, luteolin and ursolic acid decreased Akt phosphorylation'},\n",
       "   {'pubmed': 19351817,\n",
       "    'text': 'Observational study of gene-disease association and gene-environment interaction. (HuGE Navigator)'},\n",
       "   {'pubmed': 19355825,\n",
       "    'text': 'BRAF(V600E) is associated some of the aggressive clinicopathological features of papillary thyroid carcinoma including younger age at diagnosis, larger tumor size, and classic histological type, as well as also extrathyroidal invasion.'},\n",
       "   {'pubmed': 19355825,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 19358278,\n",
       "    'text': 'Observational study of gene-disease association and gene-environment interaction. (HuGE Navigator)'},\n",
       "   {'pubmed': 19362540,\n",
       "    'text': 'Targets of phosphorylation by B-Raf signaling are investigated in melanoma.'},\n",
       "   {'pubmed': 19369630,\n",
       "    'text': 'K-ras, EGFR, and BRAF mutations are disproportionately seen in adenocarcinomas of lung with a dominant micropapillary growth pattern compared with conventional adenocarcinoma in our institutional experience.'},\n",
       "   {'pubmed': 19369630,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 19370505,\n",
       "    'text': 'BRAF V600E mutation was significantly found in papillary thyroid carcinoma.'},\n",
       "   {'pubmed': 19370505,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 19372556,\n",
       "    'text': 'Mutation in BRAF is associated with ERK1/2 activation and MEK1/2 inhibitor therapy in colorectal cancer.'},\n",
       "   {'pubmed': 19378335,\n",
       "    'text': 'proliferation of cells harboring mutations in B-Raf, but not K-Ras, is exquisitely sensitive inhibition of the MAPK pathway'},\n",
       "   {'pubmed': 19383313,\n",
       "    'text': 'REVIEW summarizes the literature on NRAS and BRAF activating mutations in melanoma tumors with respect to available data on histogenetic classification as well as body site and presumed UV-exposure.'},\n",
       "   {'pubmed': 19383316,\n",
       "    'text': 'The genes whose expression is associated with BRAF mutations are not simply restricted to the MAPK/ERK signaling but also converge to enhanced immune responsiveness, cell motility and melanosomes processing involved in the adaptative UV response'},\n",
       "   {'pubmed': 19389934,\n",
       "    'text': 'a subpopulation of melanocytes possesses the ability to survive BRAF(V600E)-induced senescence'},\n",
       "   {'pubmed': 19393416,\n",
       "    'text': 'B-RAF mutation was found to be significantly higher in papillary carcinomas when compared to follicular variant of papillary thyroid carcinomas (55.6% vs 14.3%, P = 0.05).'},\n",
       "   {'pubmed': 19393416,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 19398955,\n",
       "    'text': 'The murine model of mutant BRAF-induced melanoma formation provides an important tool for identifying further genetic alterations that cooperates with BRAF and that may be useful in enhancing susceptibility to BRAF-targeted therapeutics in melanoma.'},\n",
       "   {'pubmed': 19404844,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 19404844,\n",
       "    'text': 'elevated pERK expression occurs in urothelial carcinoma in the absence of B-Raf mutations and is not correlated with FGFR3 over-expression'},\n",
       "   {'pubmed': 19404918,\n",
       "    'text': 'Investigated BRAF mutations in 30 bladder tumors. Detected two tumor specimens bearing two different mutations, both of which were found in exon 15. One sample showed the T1799A (V600E) and the other the G1798T (V600L) mutation.'},\n",
       "   {'pubmed': 19404918,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 19414674,\n",
       "    'text': 'Observational study of gene-disease association and genetic testing. (HuGE Navigator)'},\n",
       "   {'pubmed': 19415957,\n",
       "    'text': 'The T1799A BRAF mutation does not appear to play a role in the tumorigenesis of the cribriform-morular variant of papillary carcinoma.'},\n",
       "   {'pubmed': 19416762,\n",
       "    'text': 'Novel BRAF mutation in a patient with LEOPARD syndrome and normal intelligence is reported.'},\n",
       "   {'pubmed': 19424571,\n",
       "    'text': 'BRAF V600E mutation is not the target gene for abnormal DNA mismatch repair in patients with sporadic endometrial cancer.'},\n",
       "   {'pubmed': 19424639,\n",
       "    'text': \"Report efficient molecular screening of Lynch syndrome by specific 3' promoter methylation of the MLH1 or BRAF mutation in colorectal cancer with high-frequency microsatellite instability.\"},\n",
       "   {'pubmed': 19430562,\n",
       "    'text': 'Mutations in BRAF were found 10% patients in the low-grade carcinoma group, however, they were not found in the high-grade carcinoma group. KRAS and BRAF mutations were mutually exclusive, and both mutations were observed in 40%.'},\n",
       "   {'pubmed': 19430562,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 19440799,\n",
       "    'text': 'oncogenic properties of KRAS and BRAF but not NRAS, HRAS, and PIK3CA contribute to the tumorigenesis of periampullary and ampullary tumors'},\n",
       "   {'pubmed': 19461239,\n",
       "    'text': 'mismatch repair deficiency is not a crucial event for BRAF mutation in melanocytic tumors'},\n",
       "   {'pubmed': 19464601,\n",
       "    'text': 'The RAS/RAF/MEK/ERK signaling pathway has emerged as a major player in the induction and maintenance of melanoma, particularly the protein kinase BRAF, mutated in approximately 44% of melanoma cases. Review.'},\n",
       "   {'pubmed': 19474002,\n",
       "    'text': 'data confirm that KRAS and BRAF mutations do occur in the same cell and that BRAF V600E mutation is associated with CIMP+ status.'},\n",
       "   {'pubmed': 19483722,\n",
       "    'text': 'B-Raf/MKK/ERK provides a permissive environment for melanoma genesis by modulating plexin B1.'},\n",
       "   {'pubmed': 19487299,\n",
       "    'text': 'If BRAF is mutated in the primary thyroid neoplasm, it is likely that the metastases will harbor the defect.'},\n",
       "   {'pubmed': 19487299,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 19492075,\n",
       "    'text': 'Targeting NRAS alone or both BRAF and CRAF in combination or both BRAF and PIK3CA together showed delay in tumor growth.'},\n",
       "   {'pubmed': 19498322,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 19498322,\n",
       "    'text': 'Results show that activating BRAF somatic mutations may be occasionally found in advanced adrenocortical carcinomas, while CTNNB1 activating mutations are early and common events in adrenal tumorigenesis.'},\n",
       "   {'pubmed': 19504446,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 19534622,\n",
       "    'text': 'CTNNB1 and BRAF mutations may have roles in the cribriform-morular variant of papillary thyroid carcinoma'},\n",
       "   {'pubmed': 19534623,\n",
       "    'text': 'BRAF V600E may have a role in development of papillary thyroid carcinoma'},\n",
       "   {'pubmed': 19543740,\n",
       "    'text': 'Pilocytic astrocytomas had BRAF fusions in 70% of cases but not IDH1 or IDH2 mutations. Diffuse astrocytomas had IDH1 mutations in 76% of cases but not IDH2 mutations or BRAF fusions. Analysis of BRAF and IDH1 separates pilocytic from diffuse astrocytoma.'},\n",
       "   {'pubmed': 19547661,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 19551857,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 19561230,\n",
       "    'text': 'BRAF mutations represent an alternative molecular pathway in the early tumorigenesis of a subset of KIT/PDGFRA wild-type GISTs and are per se not associated with a high risk of malignancy.'},\n",
       "   {'pubmed': 19561230,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 19571295,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 19571295,\n",
       "    'text': 'study concludes that a BRAF mutation is a negative prognostic marker in patients with metastatic colorectal cancer'},\n",
       "   {'pubmed': 19571709,\n",
       "    'text': 'BRAF mutated tumors occurred with a much greater frequency in proximal colon tumors than in either distal colon or rectal tumors'},\n",
       "   {'pubmed': 19571821,\n",
       "    'text': 'We observed no association between germline MC1R status and somatic BRAF mutations in melanomas'},\n",
       "   {'pubmed': 19574281,\n",
       "    'text': 'BRAF V600E mutation analysis can significantly improve FNAB diagnostic accuracy.'},\n",
       "   {'pubmed': 19584155,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 19584155,\n",
       "    'text': 'Results suggest that the mutations of EGFR, KRAS, BRAF between primary tumors and corresponding lymph node metastases should be considered whenever mutations are used for the selection of patients for EGFR-directed tyrosine kinase inhibitor therapy.'},\n",
       "   {'pubmed': 19603018,\n",
       "    'text': 'Assessing KRAS and BRAF mutations might help optimising the selection of the candidate metastatic colorectal cancer patients to receive anti-EGFR moAbs.'},\n",
       "   {'pubmed': 19603018,\n",
       "    'text': 'Observational study of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)'},\n",
       "   {'pubmed': 19603024,\n",
       "    'text': 'BRAF (P=0.01) mutations predicted reduced progress free survival in response to cetuximab salvage therapy in patients with metastatic colorectal cancer .'},\n",
       "   {'pubmed': 19603024,\n",
       "    'text': 'Observational study of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)'},\n",
       "   {'pubmed': 19624312,\n",
       "    'text': 'Mutated BRAF is a target in metastatic melanomas'},\n",
       "   {'pubmed': 19626635,\n",
       "    'text': 'In this study, 28 matched tumor and serum samples obtained from patients with both benign and malignant thyroid disorders were analyzed for BRAF mutation.'},\n",
       "   {'pubmed': 19626635,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 19628078,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 19633643,\n",
       "    'text': 'Characterization of candidate gene copy number alterations in the 11q13 region along with BRAF and NRAS mutations in human melanoma.'},\n",
       "   {'pubmed': 19637313,\n",
       "    'text': 'strong inter-relation between DR4 AND DR5 overexpression and presence of oncogenic KRAS/ BRAF mutations in colon cancer.'},\n",
       "   {'pubmed': 19638574,\n",
       "    'text': 'Sorafenib inhibits NSCLC cell growth by targeting B-RAF in cells with wild-type KRAS and C-RAF in those with mutant KRAS.'},\n",
       "   {'pubmed': 19644722,\n",
       "    'text': 'BRAFV600E mutation is associated with papillary thyroid carcinoma.'},\n",
       "   {'pubmed': 19652585,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 19659611,\n",
       "    'text': 'simultaneous depletion of both MITF and BRAF(V600E) significantly inhibited melanoma growth even for the melanoma cell lines resistant to MITF depletion'},\n",
       "   {'pubmed': 19667985,\n",
       "    'text': 'Studies indicate that in pilocytic astrocytomas, the BRAF fusion gene has been identified as a specific and frequent event leading to potentially targetable mitogen-activated protein kinase pathway activation.'},\n",
       "   {'pubmed': 19669908,\n",
       "    'text': 'Observational study of gene-disease association and DATA ERROR. (HuGE Navigator)'},\n",
       "   {'pubmed': 19679016,\n",
       "    'text': 'Studies indicate that drugs are effective in targeting essential molecular pathways of BRAF, PTEN, Akt and mammalian target of rapamycin.'},\n",
       "   {'pubmed': 19679059,\n",
       "    'text': 'Mutations in BRAF protein is associated with Colorectal Carcinoma.'},\n",
       "   {'pubmed': 19679059,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 19681119,\n",
       "    'text': 'Investigated the prevalence of PTPN11, HRAS, KRAS, NRAS, BRAF, MEK1, and MEK2 mutations in a relatively large cohort of primary embryonal Rhabdomyosarcoma (RMS) tumors. No mutation was observed in BRAF and MEK genes.'},\n",
       "   {'pubmed': 19682280,\n",
       "    'text': 'This study provides a basis for understanding the molecular processes that are regulated by (V600E)BRAF/MEK signalling in melanoma cells.'},\n",
       "   {'pubmed': 19686742,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 19690147,\n",
       "    'text': 'a dual mechanism that affects the Sprouty2/B-Raf interaction: Sprouty phosphorylation and B-Raf conformation'},\n",
       "   {'pubmed': 19693938,\n",
       "    'text': 'Whenever necessary BRAF testing may be performed on the residual samples of thyroid nodules, without interfering with routine cytology.'},\n",
       "   {'pubmed': 19704056,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 19710001,\n",
       "    'text': 'The BRAF(V600E) mutation can be used as a potential prognostic factor in PTMC patients in a BRAF(V600E)-prevalent area.'},\n",
       "   {'pubmed': 19710016,\n",
       "    'text': 'DGKeta acts as a novel critical regulatory component of the Ras/B-Raf/C-Raf/MEK/ERK signaling cascade via a previously unidentified mechanism.'},\n",
       "   {'pubmed': 19718661,\n",
       "    'text': 'analysis of the effect on the Ras/Raf signaling pathway of post-translational modifications of neurofibromin'},\n",
       "   {'pubmed': 19724843,\n",
       "    'text': 'This article focuses on reviewing the impact of the BRAFV600E mutation in the tumorigenesis of Papillary thyroid carcinoma'},\n",
       "   {'pubmed': 19725049,\n",
       "    'text': 'EPAC-mediated cellular effects require activation of the B-Raf/ERK and mTOR signaling cascades'},\n",
       "   {'pubmed': 19735675,\n",
       "    'text': 'Insights into the molecular function of the inactivating mutations of B-Raf involving the DFG motif.'},\n",
       "   {'pubmed': 19738388,\n",
       "    'text': 'Observational study of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)'},\n",
       "   {'pubmed': 19738460,\n",
       "    'text': 'Papillary carcinomas of the thyroid with papillary growth and areas of follicular growth have a high frequency of BRAF mutations.'},\n",
       "   {'pubmed': 19745699,\n",
       "    'text': 'Beta-catenin nuclear labeling is a common feature of sessile serrated adenomas and correlates with early neoplastic progression after BRAF activation.'},\n",
       "   {'pubmed': 19752400,\n",
       "    'text': 'The polyclonality of BRAF mutations in acquired melanocytic nevi suggests that mutation of BRAF may not be an initial event in melanocyte transformation.'},\n",
       "   {'pubmed': 19759551,\n",
       "    'text': 'analysis of coexisting NRAS and BRAF mutations in primary familial melanomas with specific CDKN2A germline alterations'},\n",
       "   {'pubmed': 19765726,\n",
       "    'text': 'Observational study of gene-disease association and gene-gene interaction. (HuGE Navigator)'},\n",
       "   {'pubmed': 19794125,\n",
       "    'text': 'As predicted from the genomic organization at this locus, 22 of 36 patients with sporadic pilocytic astrocytomas and B-Raf gene rearrangement also exhibit corresponding homeodomain interacting protein kinase-2 (HIPK2) gene amplification.'},\n",
       "   {'pubmed': 19826477,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 19829302,\n",
       "    'text': 'data argues against obligatory downregulation in IGFBP7 expression in BRAF mutated melanoma cells'},\n",
       "   {'pubmed': 19850689,\n",
       "    'text': 'BRAF(T1799A) can be detected in the blood of papillary thyroid carcinoma patients with residual or metastatic disease and may provide diagnostic information'},\n",
       "   {'pubmed': 19850689,\n",
       "    'text': 'Observational study of genetic testing. (HuGE Navigator)'},\n",
       "   {'pubmed': 19855373,\n",
       "    'text': 'BRAF V600E mutations were seen in 83% of proximal and 74% of distal hyperplastic colonic polyps'},\n",
       "   {'pubmed': 19861538,\n",
       "    'text': 'BRAFV600E oncogene induces transforming growth factor beta secretion leading to sodium iodide symporter repression and increased malignancy in thyroid cancer.'},\n",
       "   {'pubmed': 19861964,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 19861964,\n",
       "    'text': 'These data demonstrate the feasibility of BRAF mutation detection in cfDNA of patients with advanced melanoma. Future studies should aim to incorporate BRAF mutation testing in cfDNA to further validate this biomarker for patient selection.'},\n",
       "   {'pubmed': 19878585,\n",
       "    'text': 'Suppression of BRAF gene expression inhibited cell proliferation in cells with BRAF(V600E) mutation.'},\n",
       "   {'pubmed': 19880519,\n",
       "    'text': 'Hyperactivation of BRAF-MEK signaling activates MAP2 expression in melanoma cells by two independent mechanisms, promoter demethylation or down-regulation of neuronal transcription repressor HES1.'},\n",
       "   {'pubmed': 19881948,\n",
       "    'text': 'BRAF and KRAS oncogenes have different transforming capability in colon cancer'},\n",
       "   {'pubmed': 19883729,\n",
       "    'text': 'The knowledge of BRAF mutation status can facilitate more accurate risk stratification and better decision making at various steps in the management of papillary thyroid cancer.'},\n",
       "   {'pubmed': 19884549,\n",
       "    'text': 'Clinical trial of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)'},\n",
       "   {'pubmed': 19884549,\n",
       "    'text': 'KRAS and BRAF mutations in advanced colorectal cancer are associated with poor prognosis but do not preclude benefit from oxaliplatin or irinotecan.'},\n",
       "   {'pubmed': 19884556,\n",
       "    'text': 'BRAF status, EGFR amplification, and cytoplasmic expression of PTEN were associated with outcome measures in KRAS wild-type patients treated with a cetuximab-based regimen.'},\n",
       "   {'pubmed': 19884556,\n",
       "    'text': 'Observational study of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)'},\n",
       "   {'pubmed': 19893451,\n",
       "    'text': 'Study identified the previously reported pathogenic mutation of NTRK3 in a KRAS/BRAF wild-type tumor and 2 somatic mutations in the Src family of kinases (YES1 and LYN) that would be expected to cause structural changes.'},\n",
       "   {'pubmed': 19903786,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 19908233,\n",
       "    'text': 'BRAF gene mutation is associated with colorectal cancer.'},\n",
       "   {'pubmed': 19908233,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 19913317,\n",
       "    'text': 'BRAF mutations are not relevant for rectal carcinogenesis'},\n",
       "   {'pubmed': 19913317,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 19917255,\n",
       "    'text': 'Data show that melanoma cells expressing B-Raf(V600E) display a reduced C-Raf:B-Raf ratio, and further suppression of C-Raf increases MAPK activation and proliferation.'},\n",
       "   {'pubmed': 19919630,\n",
       "    'text': 'The BRAF V600E mutational status appears to be of limited diagnostic utility in distinguishing genital naevi that exhibit atypia from those that do not.'},\n",
       "   {'pubmed': 19919912,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 19935791,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 19955937,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 19955937,\n",
       "    'text': 'v-Raf murine sarcoma viral oncogene mutations are common in ovarian serous bordeline tumors.'},\n",
       "   {'pubmed': 19956635,\n",
       "    'text': 'Uncategorized study of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)'},\n",
       "   {'pubmed': 19958951,\n",
       "    'text': 'clinical, cytologic, and pathologic parameters of 106 consecutive surgically treated patients with BRAF-positive PTC were compared with a concurrent cohort of 100 patients with BRAF-negative PTC (papillary thyroid carcinoma)'},\n",
       "   {'pubmed': 19959686,\n",
       "    'text': '2-fold increased risk of BRAF V600E colonic tumor mutation was observed in current and former cigarette smokers homozygous for the OGG1 polymorphism'},\n",
       "   {'pubmed': 19960590,\n",
       "    'text': 'BRAF T1796A mutation was identified in 27% of papillary thyroid cancer samples and its identification may be used to determine this risk factor of the development of papillary thyroid cancer.'},\n",
       "   {'pubmed': 19960590,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 20008640,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 20009493,\n",
       "    'text': 'BRAFV600E mutation is associated with high-risk clinicopathological characteristics of papillary thyroid carcinoma and worse prognosis of patients'},\n",
       "   {'pubmed': 20009493,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 20012784,\n",
       "    'text': 'Screening for BRAF, RET, KRAS, NRAS, and HRAS mutations, as well as RET-PTC1 and RET-PTC3 rearrangements, was performed on cases of Hashimoto thyroiditis with a dominant nodule'},\n",
       "   {'pubmed': 20023270,\n",
       "    'text': 'BRAF V600E detection in the tumor does not induce a higher expression of the B-raf protein or the preferential activation of the p42/44 mitogen-activated protein kinase (MAPK) signaling pathway compared with GISTs without the BRAF mutation.'},\n",
       "   {'pubmed': 20027224,\n",
       "    'text': 'CpG island methylator phenotype (CIMP)-specific inactivation of BRAF(V600E)-induced senescence and apoptosis pathways by IGFBP7 DNA hypermethylation might create a favorable context for the acquisition of BRAF(V600E) in CIMP+ colorectal cancer.'},\n",
       "   {'pubmed': 20043015,\n",
       "    'text': 'Observational study of gene-disease association and gene-gene interaction. (HuGE Navigator)'},\n",
       "   {'pubmed': 20043015,\n",
       "    'text': 'no support for MC1R variants with BRAF mutation for melanoma risk'},\n",
       "   {'pubmed': 20044755,\n",
       "    'text': 'BRAF gene rearrangements were more common in cerebellar pilocytic astrocytoma than non-cerebellar tumors; clinical outcome was independent of BRAF status'},\n",
       "   {'pubmed': 20049644,\n",
       "    'text': 'BRAF mutations only in metastases is not associated with resistance to anti-EGFR treatment in primary colorectal tumors.'},\n",
       "   {'pubmed': 20049644,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 20051945,\n",
       "    'text': 'Observational study of genetic testing. (HuGE Navigator)'},\n",
       "   {'pubmed': 20068183,\n",
       "    'text': 'BRAF(V600E) mutation seems to define a subset of malignant astrocytomas in children, in which there is frequent concomitant homozygous deletion of CDKN2A (five of seven cases).'},\n",
       "   {'pubmed': 20098682,\n",
       "    'text': 'Observational study of genetic testing. (HuGE Navigator)'},\n",
       "   {'pubmed': 20118768,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 20140953,\n",
       "    'text': 'Formalin-fixed primary melanomas from relapsed and nonrelapsed patients were sequenced for common BRAF and NRAS mutations. BRAF/NRAS mutations were detected in 77% of relapsers and 58% of nonrelapsers and did not predict ulceration or mitotic rate.'},\n",
       "   {'pubmed': 20146801,\n",
       "    'text': 'Data demonstrate a signaling loop between B-Raf activation and p73 function, and suggest that low expression of TAp73 in colorectal cancer cell lines with mutated B-Raf may lead to lack of response to oxaliplatin/cetuximab.'},\n",
       "   {'pubmed': 20156809,\n",
       "    'text': 'BRAF activating mutations are a major genetic alteration in this histologic group of pediatric low-grade brain tumors.'},\n",
       "   {'pubmed': 20162668,\n",
       "    'text': 'Observational study of gene-disease association and gene-gene interaction. (HuGE Navigator)'},\n",
       "   {'pubmed': 20162668,\n",
       "    'text': 'With MSI, specific KRAS and BRAF mutations, 3 distinct prognostic subgroups were observed: patients with (i) KRAS mutation G12D, G12V or BRAFmutation, (ii) KRAS/BRAFwild-type or KRAS G13D mutations in MSS/MSI-L and (iii) MSI-H and KRAS G13D mutations.'},\n",
       "   {'pubmed': 20177422,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 20182446,\n",
       "    'text': 'High oncogenic BRAF levels trigger autophagy, which may have a role in melanoma tumor progression.'},\n",
       "   {'pubmed': 20186801,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 20187782,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 20200438,\n",
       "    'text': 'Observational study of gene-disease association and gene-environment interaction. (HuGE Navigator)'},\n",
       "   {'pubmed': 20200438,\n",
       "    'text': 'we measured the prevalence and epidemiologic correlates of the BRAF V600E somatic mutation in cases collected as a part of a population-based case-control study of colorectal cancer in northern Israel.'},\n",
       "   {'pubmed': 20230995,\n",
       "    'text': 'pathogenesis of papillary thyroid cancer , and the clinical implications of BRAF(V600E) mutation in the diagnosis, prognosis and potential targeted therapeutic strategies for thyroid cancer [review]'},\n",
       "   {'pubmed': 20233436,\n",
       "    'text': 'data support the model of BRAF and K-ras mutations arising in distinct colorectal cancer subsets associated with different clinicopathological and dietary factors, acting as mutually exclusive mechanisms of activation of the same signalling pathway'},\n",
       "   {'pubmed': 20234366,\n",
       "    'text': 'Observational study of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)'},\n",
       "   {'pubmed': 20300843,\n",
       "    'text': 'BRAF mutation is not associated with interval cancers but is a marker of poor prognosis, particularly in microsatellite stable cancers.'},\n",
       "   {'pubmed': 20300843,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 20302979,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 20303012,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 20303012,\n",
       "    'text': 'Our study suggests that mutations of KRAS, not BRAF, may play a role in the pathogenesis of prostate carcinoma in Chinese patients.'},\n",
       "   {'pubmed': 20305537,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 20332228,\n",
       "    'text': 'Studies show FOXD3 is suppressed by B-RAF, uncover a novel role and mechanism for FOXD3 as a negative cell cycle regulator, and have implications for the repression of melanocytic lineage cells.'},\n",
       "   {'pubmed': 20351680, 'text': 'Mutated in melanoma.'},\n",
       "   {'pubmed': 20379614,\n",
       "    'text': 'Clinical trial of gene-disease association and gene-environment interaction. (HuGE Navigator)'},\n",
       "   {'pubmed': 20381121,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 20406109,\n",
       "    'text': 'The miR-146b expression levels in papillary thyroid carcinoma with BRAF mutation were significantly higher than those without this mutation'},\n",
       "   {'pubmed': 20407018,\n",
       "    'text': 'Activated Raf-1 induces focal adhesion kinase expression and regulates neuroendocrine and metastatic phenotypes in gastrointestinal carcinoid cell line BON.'},\n",
       "   {'pubmed': 20410389,\n",
       "    'text': 'thyroid carcinoma with the BRAF(V600E) mutation tends to be taller than wide and is not associated with the presence of calcifications on ultrasound.'},\n",
       "   {'pubmed': 20413299,\n",
       "    'text': 'Observational study of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)'},\n",
       "   {'pubmed': 20444249,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 20445557,\n",
       "    'text': 'B-RAF(V600E) can protect melanocytes from anoikis independently of cell cycle inhibition'},\n",
       "   {'pubmed': 20453000,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 20454969,\n",
       "    'text': 'This study identified an exceptionally high frequency of KIAA1549-BRAF fusions in pilocytic astrocytoma.'},\n",
       "   {'pubmed': 20460314,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 20460314,\n",
       "    'text': 'These data demonstrate a high prevalence of B-RAF mutations in the present study population, underscoring the possibility of strong regional differences.'},\n",
       "   {'pubmed': 20473281,\n",
       "    'text': 'Hypoxia-inducible factor-1alpha is expressed in papillary thyroid carcinomas and is regulated not only by hypoxia but also by BRAF(V600E)-mediated signaling pathway.'},\n",
       "   {'pubmed': 20473281,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 20478260,\n",
       "    'text': 'Study concludes that the secreted protein IGFBP7 is dispensable for B-RAF(V600E)-induced senescence in human melanocytes.'},\n",
       "   {'pubmed': 20485284,\n",
       "    'text': 'BRAF V600E mutations are associated with MSI-H status and cyclin D1 overexpression and characterize a subgroup of patients with poor prognosis.'},\n",
       "   {'pubmed': 20485284,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 20489114,\n",
       "    'text': 'Observational study of genetic testing. (HuGE Navigator)'},\n",
       "   {'pubmed': 20495538,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 20496269,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 20498063,\n",
       "    'text': 'Knockdown of B-Raf(V600E) resulted in thrombospondin-1 down-regulation and a reduction of adhesion and migration/invasion of human thyroid cancer cells.'},\n",
       "   {'pubmed': 20501503,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 20501503,\n",
       "    'text': 'The V600E BRAF mutation confers a worse prognosis to stage II and stage III colon cancer patients independently of disease stage and therapy.'},\n",
       "   {'pubmed': 20501689,\n",
       "    'text': 'Observational study of gene-disease association and genetic testing. (HuGE Navigator)'},\n",
       "   {'pubmed': 20514492,\n",
       "    'text': 'BRAF mutation may be used a biomarker for the selection of patients with colorectal cancer patients who might benefit from anti-egf receptor monoclonal antibodies.'},\n",
       "   {'pubmed': 20514492,\n",
       "    'text': 'Meta-analysis of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)'},\n",
       "   {'pubmed': 20519626,\n",
       "    'text': 'Studies identified the oncogenic BRAF V600E mutation in 35 of 61 archived specimens (57%).'},\n",
       "   {'pubmed': 20526288,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 20526288,\n",
       "    'text': 'The BRAF 1799T>A mutation was found in 5 of 19 (26%) of infiltrative follicular variant of papillary thyroid carcinomas and in none of the encapsulated carcinomas'},\n",
       "   {'pubmed': 20543023,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 20563851,\n",
       "    'text': 'HER2, but not EGFR gene amplification, is frequently observed in KRAS and BRAF wild type colorectal cancer patients'},\n",
       "   {'pubmed': 20563851,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 20569675,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 20569675,\n",
       "    'text': 'reports the low frequency of PIK3CA and B-RAF mutations in astrocytomas, despite the presence of activated ERK and AKT proteins'},\n",
       "   {'pubmed': 20570909,\n",
       "    'text': 'Incidence of cancer in FDRs of index CRC patients with the p.V600E BRAF mutation may be explained by a genetic predisposition to develop cancer through the serrated pathway of colorectal carcinogenesis.'},\n",
       "   {'pubmed': 20570909,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 20571907,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 20571907,\n",
       "    'text': 'PIK3CA mutations may have a role in KRAS and BRAF wild type colorectal cancer'},\n",
       "   {'pubmed': 20573852,\n",
       "    'text': 'BRAF mutational status of metastases is not required when the primary tumour is BRAF wild type.'},\n",
       "   {'pubmed': 20576522,\n",
       "    'text': 'allele specific Taqman-based real-time PCR assay allows the sensitive, accurate and reliable measurement of BRAF(V600E) mutated DNA in plasma'},\n",
       "   {'pubmed': 20591910,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 20605766,\n",
       "    'text': 'in melanomas activation of the MAPK pathway can occur through signaling pathways operating independently of BRAF T1799A'},\n",
       "   {'pubmed': 20607849,\n",
       "    'text': 'V600E BRAF mutation is not associated with seminoma.'},\n",
       "   {'pubmed': 20616366,\n",
       "    'text': 'Using traditional PCR and direct sequencing, we found KRAS mutations in 47 (40%) patients and BRAF(V600E) in 10 (8.5%)'},\n",
       "   {'pubmed': 20619739,\n",
       "    'text': 'if KRAS is not mutated, assessing BRAF, NRAS, and PIK3CA exon 20 mutations (in that order) gives additional information about the efficacy of cetuximab plus chemotherapy in metastatic colorectal cancer.'},\n",
       "   {'pubmed': 20627194,\n",
       "    'text': 'PCR is practically applicable to KRAS/BRAF genotyping using small amounts of biopsied colorectal tumor cells.'},\n",
       "   {'pubmed': 20631031,\n",
       "    'text': 'No significant difference in BRAF alterations was found between pT1 tumors and thyroid capsule invasion and pT3 tumors.'},\n",
       "   {'pubmed': 20631031,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 20635392,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 20640859,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 20645028,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 20645028,\n",
       "    'text': 'samples of metastatic colorectal cancer were tested for the presence of the seven most common mutations in the KRAS gene and the V600E mutation in the BRAF gene'},\n",
       "   {'pubmed': 20647301,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 20647317,\n",
       "    'text': 'Findings delineate how mutant B-RAF protects melanoma cells from apoptosis and provide insight into possible resistance mechanisms to B-RAF inhibitors.'},\n",
       "   {'pubmed': 20652941,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 20670148,\n",
       "    'text': 'Traditional DNA sequencing and the somewhat more-sensitive pyrosequencing method can detect multiple alternative BRAF mutations.'},\n",
       "   {'pubmed': 20679909,\n",
       "    'text': 'Mutant Braf can be detected in RNA from mixed populations with as few as 0.1% Braf(V600E) mutant cells.'},\n",
       "   {'pubmed': 20689758,\n",
       "    'text': 'PLX4032 has robust activity in BRAF mutated melanoma.'},\n",
       "   {'pubmed': 20702649,\n",
       "    'text': 'Observational study of gene-disease association and gene-gene interaction. (HuGE Navigator)'},\n",
       "   {'pubmed': 20703476,\n",
       "    'text': 'Observational study of genetic testing. (HuGE Navigator)'},\n",
       "   {'pubmed': 20720566,\n",
       "    'text': 'Observational study of gene-disease association and gene-gene interaction. (HuGE Navigator)'},\n",
       "   {'pubmed': 20720566,\n",
       "    'text': 'association between MC1 receptor germline variation and BRAF/NRAS mutations in melanoma'},\n",
       "   {'pubmed': 20736745,\n",
       "    'text': 'Observational study of gene-disease association and gene-gene interaction. (HuGE Navigator)'},\n",
       "   {'pubmed': 20802181,\n",
       "    'text': 'BRAF mutation is rare in advanced-stage low-grade ovarian serous carcinomas.'},\n",
       "   {'pubmed': 20802181,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 20807807,\n",
       "    'text': 'Mutant protein kinase elicits significant therapeutic responses in mutant BRAF-driven human melanoma xenografts.'},\n",
       "   {'pubmed': 20813562,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 20813562,\n",
       "    'text': 'first report implicating BRAF mutation in OSCC. study supports that mutations in the BRAF gene makes at least a minor contribution to OSCC tumorigenesis.'},\n",
       "   {'pubmed': 20837233,\n",
       "    'text': 'BRAF mutation detection in fine needle biopsy may be an adjunct tool for preoperative didagnosis of papillary thyroid carcinoma.'},\n",
       "   {'pubmed': 20840674,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 20840674,\n",
       "    'text': 'RET rearrangements and BRAF mutation in undifferentiated thyroid carcinomas having papillary carcinoma components'},\n",
       "   {'pubmed': 20843808,\n",
       "    'text': 'A BRAF aberrant splice variant with an intact kinase domain and partial loss of the N-terminal autoinhibitory domain was identified in fibroblasts from an additional patient, and fibroblast proliferation was inhibited by BRAF-specific siRNA.'},\n",
       "   {'pubmed': 20853079,\n",
       "    'text': 'reduced RKIP mRNA levels and the elevated levels of B-RAF in pT1, grade III tumors vs. normal tissue, corroborate that these genes are involved in the pathogenesis of urinary bladder cancer.'},\n",
       "   {'pubmed': 20857202,\n",
       "    'text': 'BRAF V600E mutation is associated with lack of response in wild-type KRAS metastatic colorectal cancer treated with anti-EGFR monoclonal antibodies.'},\n",
       "   {'pubmed': 20860430,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 20881644,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 20944096,\n",
       "    'text': 'Determination of the BRAF mutation and the growth fraction of melanomas may add a prognostic value.'},\n",
       "   {'pubmed': 20944096,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 20945104,\n",
       "    'text': 'BRAF(V600E) mutation is associated with thyroid nodules.'},\n",
       "   {'pubmed': 20945104,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 20947270,\n",
       "    'text': 'In the present series, no BRAF mutation was detected. The presence of KRAS mutations and loss of PTEN expression were not associated with impaired response to cetuximab-based chemoradiotherapy and 3-year disease free survival.'},\n",
       "   {'pubmed': 20947270,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 20950194,\n",
       "    'text': 'BRAF is mutated in a low percentage of follicular variant of papillary thyroid carcinoma, and most of these mutated cases are suspicious or positive on fine-needle aspiration.'},\n",
       "   {'pubmed': 20953721,\n",
       "    'text': 'BRAF mutation is associated with papillary thyroid microcarcinoma.'},\n",
       "   {'pubmed': 20955560,\n",
       "    'text': 'Anti-BRAF autoantibodies from RA patients preferentially recognize one BRAF peptide: P2'},\n",
       "   {'pubmed': 20959481,\n",
       "    'text': 'Braf mutation is associated with basal and treatment-induced regulation of the PI3K-AKT pathway as a critical regulator of AZD6244 sensitivity in cutaneous melanoma.'},\n",
       "   {'pubmed': 20962618,\n",
       "    'text': 'Describe benign serrated colorectal fibroblastic polyps/intramucosal perineuriomas are true mixed epithelial-stromal polyps (hybrid hyperplastic polyp/mucosal perineurioma) with frequent BRAF mutations.'},\n",
       "   {'pubmed': 20975100,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 20979647,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 21048031,\n",
       "    'text': 'Observational study of gene-disease association and gene-environment interaction. (HuGE Navigator)'},\n",
       "   {'pubmed': 21049459,\n",
       "    'text': 'Although many studies document BRAF mutation as a prognostic factor in PTC our results underline that it is too early to consider it as a routine clinical predictive factor.'},\n",
       "   {'pubmed': 21049459,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 21051183,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 21051183,\n",
       "    'text': 'findings indicate that somatic mutations in KRAS and PIK3CA but not BRAF oncogenes are closely associated with the development of cholangiocarcinoma in Chinese population'},\n",
       "   {'pubmed': 21068756,\n",
       "    'text': 'The dermoscopical and histopathological patterns of nevi correlate with the frequency of BRAF mutations.'},\n",
       "   {'pubmed': 21076620,\n",
       "    'text': 'Data show that BRAF knockdown led to suppression of the expression of the GABPbeta, which involved in regulating HPR1 promoter activity.'},\n",
       "   {'pubmed': 21098728,\n",
       "    'text': 'BRAF gene amplification can promote acquired resistance to MEK inhibitors in cancer cells harboring the BRAF V600E mutation.'},\n",
       "   {'pubmed': 21102258,\n",
       "    'text': 'Mutations of EGFR, BRAF, and KRAS in adenocarcinoma were mutually exclusive and inversely correlated with RASSF1A methylation'},\n",
       "   {'pubmed': 21102416,\n",
       "    'text': 'We show a strong association between concordant methylation of >/= 3 of five 3p22 genes with the CpG island methylator phenotype and the BRAF V600E mutation.'},\n",
       "   {'pubmed': 21103049,\n",
       "    'text': 'Data show that among 181 CRC patients, stratified by microsatellite instability status, DNA sequence changes were identified in KRAS (32%), BRAF (16%), PIK3CA (4%), PTEN (14%) and TP53 (51%).'},\n",
       "   {'pubmed': 21107320,\n",
       "    'text': 'identification of MAP3K8 (the gene encoding COT/Tpl2) as a MAPK pathway agonist that drives resistance to RAF inhibition in B-RAF(V600E) cell lines'},\n",
       "   {'pubmed': 21107323,\n",
       "    'text': 'melanomas escape B-RAF(V600E) targeting not through secondary B-RAF(V600E) mutations but via receptor tyrosine kinase (RTK)-mediated activation of alternative survival pathway(s) or activated RAS-mediated reactivation of the MAPK pathway'},\n",
       "   {'pubmed': 21129611,\n",
       "    'text': 'It therefore appears that BRAF mutations may play a strong negative prognostic role and only a slight role in resistance to anti-EGFR Abs.'},\n",
       "   {'pubmed': 21131919,\n",
       "    'text': 'Primary esophageal melanomas of Caucasian patients harbor mutations of c-Kit, KRAS and BRAF in varied frequencies.'},\n",
       "   {'pubmed': 21134544,\n",
       "    'text': 'BRAF mutation in papillary thyroid carcinoma is associated with an increased risk of palpable nodal recurrence and the need for reoperative surgery.'},\n",
       "   {'pubmed': 21134562,\n",
       "    'text': 'BRAF mutations activate the mitogen-activated protein kinase pathway and confer an aggressive thyroid cancer phenotype.'},\n",
       "   {'pubmed': 21161938,\n",
       "    'text': 'KRAS mutations arise more frequently than BRAF mutations in Moroccan patients with colorectal carcinomas.'},\n",
       "   {'pubmed': 21166657,\n",
       "    'text': 'The BRAF mutation was frequently detected in patients with superficial spreading melanoma (OR=2.021; P<0.001) and in melanomas arising in nonchronic sun-damaged skin (OR=2.043; P=0.001).'},\n",
       "   {'pubmed': 21167555,\n",
       "    'text': 'concluded that follicular variant of papillary thyroid carcinoma differs from conventional papillary thyroid carcinoma in the rate of BRAF mutation'},\n",
       "   {'pubmed': 21176117,\n",
       "    'text': 'These results show that melanoma cell phenotype is an important factor in MAPK pathway inhibition response, as invasive phenotype cell response is dependent on BRAF mutation status.'},\n",
       "   {'pubmed': 21185263,\n",
       "    'text': 'this study has confirmed that the BRAF(T1799A) mutation confers cancer cells sensitivity to PLX4032 and demonstrated its specific potential as an effective and BRAF(T1799A) mutation-selective therapeutic agent for thyroid cancer.'},\n",
       "   {'pubmed': 21190184,\n",
       "    'text': 'B-Raf(insT) and B-Raf(V600E) , but not B-Raf(wt) , provoke drastic morphological alterations in human astrocytes.'},\n",
       "   {'pubmed': 21203559,\n",
       "    'text': 'BRAF alternative splicing is differentially regulated in human and mouse. BRAF exon 9b is required for learning and memory associated with the hippocampus.'},\n",
       "   {'pubmed': 21215707,\n",
       "    'text': 'In melanoma cells, oncogenic (V600E) BRAF signaling downregulates PDE5A through the transcription factor BRN2, leading to increased cGMP and Ca2+ and the induction of invasion through increased cell contractility.'},\n",
       "   {'pubmed': 21223556,\n",
       "    'text': 'B-Raf signaling has a key function in the altered expression of contractile receptors in the cerebrovasculature.'},\n",
       "   {'pubmed': 21223812,\n",
       "    'text': 'The high expression of activated ERK is not caused by BRAF gene mutation in nasal mucosa malignant melanomas.'},\n",
       "   {'pubmed': 21224857,\n",
       "    'text': 'Acquisition of a BRAF mutation is not a founder event, but may be one of the multiple clonal events in melanoma development, which is selected for during the progression.'},\n",
       "   {'pubmed': 21239517,\n",
       "    'text': 'We found that performing BRAF(V600E) mutation analysis on the fine-needle aspiration biopsy specimens was of great help to make a therapeutic decision for thyroid nodules when the fine-needle aspiration biopsy results were equivocal'},\n",
       "   {'pubmed': 21249150,\n",
       "    'text': 'the oncogenic effect of BRAF(V600E) is associated with the inhibition of MST1 tumor suppressor pathways, and the activity of RASSF1A-MST1-FoxO3 pathways determines the phenotypes of BRAF(V600E) tumors.'},\n",
       "   {'pubmed': 21263251,\n",
       "    'text': 'These findings suggest that BRAF mutations may be associated with the pathogenesis of sessile serrated colorectal adenomas.'},\n",
       "   {'pubmed': 21270111,\n",
       "    'text': 'Findings suggest inhibition of autophagy in combination with ER stress-inducing agents may represent a means by which to harness autophagy for the therapeutic benefit of B-RAF wild-type melanoma.'},\n",
       "   {'pubmed': 21274671,\n",
       "    'text': 'B-Raf mutations, microsatellite instability and p53 protein expression is not associated with sporadic basal cell carcinomas.'},\n",
       "   {'pubmed': 21274720,\n",
       "    'text': 'The analysis of BRAF V600E mutation in 1,320 nervous system tumors reveals high mutation frequencies in pleomorphic xanthoastrocytoma, ganglioglioma and extra-cerebellar pilocytic astrocytoma.'},\n",
       "   {'pubmed': 21285991,\n",
       "    'text': 'Presence of mutated BRAF is one of the most powerful prognostic factors for advanced and recurrent CRC'},\n",
       "   {'pubmed': 21289333,\n",
       "    'text': '803 metastatic colorectal cancer samples studied for KRAS exon 2 and BRAF exon 15 mutations; BRAF mutated samples were characterized for mismatch repair function; 344 tumours were mutated -34 involving BRAF mutations (8 of microsatellite instability type)'},\n",
       "   {'pubmed': 21303778,\n",
       "    'text': 'Ras/Raf/MAPK and RhoA/ROCKII signalling pathways are abnormally activated in eutopic endometrial stromal cells of patients with endometriosis'},\n",
       "   {'pubmed': 21305640,\n",
       "    'text': '78 colorectal tumor samples were mutant for BRAF.'},\n",
       "   {'pubmed': 21307665,\n",
       "    'text': 'analysis of gallbladder carcinomas, gallbladder adenomas, and high-grade dysplastic lesions for the BRAF and the KRAS mutations'},\n",
       "   {'pubmed': 21317202,\n",
       "    'text': 'Findings suggest that inhibition of Raf-MEK-Erk pathway might offer a novel therapeutic strategy in neuroendocrine tumors'},\n",
       "   {'pubmed': 21317224,\n",
       "    'text': 'Studies showed that siRNA knockdown of BIM significantly blunted the apoptotic response in PTEN+ melanoma cells.'},\n",
       "   {'pubmed': 21317286,\n",
       "    'text': 'identified BAD serine 134 to be strongly involved in survival signaling of B-RAF-V600E-containing tumor cells and found that phosphorylation of BAD at this residue is critical for efficient proliferation in these cells.'},\n",
       "   {'pubmed': 21321384,\n",
       "    'text': 'identifying downstream events from the BRAFV600E/ERK1/2 pathway will eventually identify novel biomarkers that can be used to correlate with disease outcome and overall survival.'},\n",
       "   {'pubmed': 21324100,\n",
       "    'text': 'Data show that BRAF-mutated melanomas occur in a younger age group on skin without marked solar elastosis and less frequently affect the head and neck area, compared to melanomas without BRAF mutations.'},\n",
       "   {'pubmed': 21326296,\n",
       "    'text': 'BRAF mutations have a smaller role in the carcinogenesis of malignant melanoma in Chinese Han than in Western patients.'},\n",
       "   {'pubmed': 21332555,\n",
       "    'text': 'BRAF mutations were rare in colorectal laterally-spreading tumors.'},\n",
       "   {'pubmed': 21343559,\n",
       "    'text': 'The presence of mutant BRAF had no impact on the disease-free interval from diagnosis of first-ever melanoma to first distant metastasis; however, it may have impacted survival thereafter.'},\n",
       "   {'pubmed': 21345796,\n",
       "    'text': 'B-Raf associates with and stimulates NHE1 activity and that B-Raf(V600E) also increases NHE1 activity that raises intracellular pH.'},\n",
       "   {'pubmed': 21351275,\n",
       "    'text': 'BRAF mutation is associated with selective inhibition of thyroid cancer cells by the novel MEK inhibitor RDEA119 and genetic-potentiated synergism with the mTOR inhibitor temsirolimus'},\n",
       "   {'pubmed': 21356389,\n",
       "    'text': 'IDH1 mutation works with other oncogenic mutations and could contribute to the metastasis in melanoma.'},\n",
       "   {'pubmed': 21362156,\n",
       "    'text': 'Regulation of NR4A nuclear receptor expression by oncogenic BRAF in melanoma cells.'},\n",
       "   {'pubmed': 21383284,\n",
       "    'text': 'BRAF mutational status yielded no useful prognostic information in predicting recurrence and benefits from adjuvant chemotherapy in colorectal cancer.'},\n",
       "   {'pubmed': 21383288,\n",
       "    'text': 'Thus, MEK1(C121S) or functionally similar mutations are predicted to confer drug resistance of neoplasms to combined MEK/RAF inhibition.'},\n",
       "   {'pubmed': 21383698,\n",
       "    'text': 'tumor initiation by oncogenic BRAF renders thyroid cells susceptible to TGFbeta-induced epithelial-mesenchymal transition, through a MAPK-dependent process'},\n",
       "   {'pubmed': 21390154,\n",
       "    'text': 'K-ras gene mutation is a common event in Chinese colorectal cancer (CRC) patients, but may not be a prognostic factor in CRC , while BRAF is rarely mutated in Chinese CRC patients.'},\n",
       "   {'pubmed': 21408138,\n",
       "    'text': 'Allele-specific qPCR assays for the most frequent activating mutations in EGFR, KRAS, BRAF and PIK3CA in tumor-positive fine needle cytological aspirates were compared against histological material of primary tumors.'},\n",
       "   {'pubmed': 21412762,\n",
       "    'text': 'BRAF mutation is associated with papillary thyroid cancer.'},\n",
       "   {'pubmed': 21424126,\n",
       "    'text': 'study suggested that both KRAS and BRAF mutations are exclusive, but KRAS and PIK3CA mutations are coexistent'},\n",
       "   {'pubmed': 21424530,\n",
       "    'text': 'This study demonistrated that the role of RAF kinase fusions as a central oncogenic mechanism in the development of pilocytic astrocytoma.'},\n",
       "   {'pubmed': 21426297,\n",
       "    'text': 'Mutations at the position V600 of BRAF were described in approximately 8% of all solid tumors, including 50% of melanomas, 30 to 70% of papillary thyroid carcinomas and 5 to 8% of colorectal adenocarcinomas.'},\n",
       "   {'pubmed': 21427714,\n",
       "    'text': 'There were no significant differences in the frequency of BRAF mutations among lesions exhibiting the hyperplastic, adenomatous, or mixed patterns.'},\n",
       "   {'pubmed': 21430505,\n",
       "    'text': 'The presence of the BRAF(V600E) mutation may play different roles between medium and giant CMNs in melanocytic tumorigenesis.'},\n",
       "   {'pubmed': 21431280,\n",
       "    'text': 'BRAF T1799A mutation may be an early and essential carcinogenic event in nearly all Korean papillary thyroid carcinomas'},\n",
       "   {'pubmed': 21441079,\n",
       "    'text': 'In papilary thyroid carcinoma, the BRAFT1799A mutation is associated with age over 60 & a tumor size of 1cm or greater, but not with other clinicopathological characteristics, tumor recurrence or persistence.'},\n",
       "   {'pubmed': 21441910,\n",
       "    'text': \"KSR interacts with a regulatory Raf molecule in cis to induce a conformational switch of MEK, facilitating MEK's phosphorylation by a separate catalytic Raf molecule in trans\"},\n",
       "   {'pubmed': 21447798,\n",
       "    'text': 'Amplification of the driving oncogene, KRAS or BRAF, underpins acquired resistance to MEK1/2 inhibitors in colorectal cancer cells.'},\n",
       "   {'pubmed': 21451543,\n",
       "    'text': 'Activated BRAF promotes melanoma cell growth by matrix metalloproteinase-1'},\n",
       "   {'pubmed': 21455633,\n",
       "    'text': 'No V600E mutation was identified in the BRAF gene in any sample.'},\n",
       "   {'pubmed': 21456008,\n",
       "    'text': 'the impact of BRAF mutation and microsatellite instability on prognosis in metastatic colorectal cancer'},\n",
       "   {'pubmed': 21457162,\n",
       "    'text': 'BRAF mutations are specific for serrated adenocarcinoma and identify a subset of serrated adenocarcinomas with gene methylation and a tendency for MSI-H'},\n",
       "   {'pubmed': 21479234,\n",
       "    'text': 'BRAF V600E mutations are common in the majority of pleomorphic xanthoastrocytoma.'},\n",
       "   {'pubmed': 21483104,\n",
       "    'text': 'Heterogeneity of KRAS and BRAF mutation status intra-tumorally in colorectal cancer was assessed.'},\n",
       "   {'pubmed': 21498916,\n",
       "    'text': 'findings support the notion that BRAF(V600E), which can be detected preoperatively in papillary thyroid carcinoma fine-needle aspiration biopsy material, has a potential to contribute to patients stratification into high- and low-risk groups.'},\n",
       "   {'pubmed': 21512141,\n",
       "    'text': 'Mutated BRAF is detected in approximately 45% of papillary thyroid carcinomas (PTC).'},\n",
       "   {'pubmed': 21514245,\n",
       "    'text': 'Ablation of B-Raf had no significant effect on development of K-Ras oncogene-driven non-small cell lung carcinoma.'},\n",
       "   {'pubmed': 21553007,\n",
       "    'text': 'BRAF mutations, but not KRAS mutations, were associated with a worse outcome in Chinese colorectal cancer patients.'},\n",
       "   {'pubmed': 21557216,\n",
       "    'text': 'MSS/BRAF mutant cancers were more commonly proximal (38/54, 70.3%).'},\n",
       "   {'pubmed': 21570823,\n",
       "    'text': 'Analysis showed that blood samples with PCR evidence for CMC were heterogeneous for BRAF status under limiting-dilution conditions, suggestive of heterogeneity of CMC'},\n",
       "   {'pubmed': 21577205,\n",
       "    'text': 'Studies indicate that Raf kinases are excellent molecular targets for anticancer therapy.'},\n",
       "   {'pubmed': 21587258,\n",
       "    'text': 'Wnt5a methylation was strongly associated with tumour microsatellite instability tumours after adjustment for age, sex, and tumour location and with BRAF V600E mutation, a marker of CpG island methylator phenotype'},\n",
       "   {'pubmed': 21594703,\n",
       "    'text': 'BRAF V600E mutation is associated with recurrent papillary thyroid cancer.'},\n",
       "   {'pubmed': 21636552,\n",
       "    'text': 'introduction of constitutively active BRAF V600E into human cortical stem and progenitor cells initially promotes clonogenic growth in soft agar but ultimately results in dramatically reduced proliferation and arrested growth of the culture.'},\n",
       "   {'pubmed': 21653734,\n",
       "    'text': 'Compared with BRAF-wt papillary thyroid cancer, those harboring BRAF(V600E) exhibit downregulated VEGFA, VEGFR, and PDGFRbeta expression, suggesting presence of BRAF mutation does not imply stronger response to drugs targeting VEGF and PDGFB signal pathways.'},\n",
       "   {'pubmed': 21663470,\n",
       "    'text': 'The BRAF V600E mutation was present in all patients with hairy-cell leukemia who were evaluated.'},\n",
       "   {'pubmed': 21681432,\n",
       "    'text': 'The BRAF V600E mutation did not show association with clinical or molecular characteristics of colorectal cancer.'},\n",
       "   {'pubmed': 21693616,\n",
       "    'text': 'Eight of 16 primary tumor samples and 4 of 6 metastatic samples showed BRAF V600E gene mutations and no copy number changes were associated exclusively with metastatic cancer'},\n",
       "   {'pubmed': 21696415,\n",
       "    'text': 'The frequency of BRAF-KIAA1549 fusion transcripts is significantly lower in adult patients with pilocytic astrocytoma.'},\n",
       "   {'pubmed': 21705440,\n",
       "    'text': 'MEK1(F129L) mutation also strengthened binding to c-Raf, suggesting an underlying mechanism of higher intrinsic kinase activity'},\n",
       "   {'pubmed': 21707687,\n",
       "    'text': 'The application of BRAF(V600E) mutation analysis in US-guided FNAB can improve the diagnostic accuracy of thyroid nodules.'},\n",
       "   {'pubmed': 21716161,\n",
       "    'text': 'We describe a new mutation of BRAF, T599dup, in a case of anaplastic thyroid carcinoma with tall cell papillary thyroid carcinomas component.'},\n",
       "   {'pubmed': 21725359,\n",
       "    'text': 'identified concurrent mutational inactivation of the PTEN and RB1 tumor suppressors as a mechanism for loss of BRAF/MEK dependence in melanomas harboring (V600E)BRAF mutations'},\n",
       "   {'pubmed': 21750338,\n",
       "    'text': 'BRAF mutation of papillary thyroid carcinoma may have differential predictive values for LN metastasis, according to tumor size.'},\n",
       "   {'pubmed': 21774961,\n",
       "    'text': 'BRAF(V600E) mutation analysis using residual liquid-based preparation cytologic samples is, therefore, a powerful additional diagnostic tool for diagnosis of papillary thyroid carcinoma.'},\n",
       "   {'pubmed': 21788131,\n",
       "    'text': 'Patients with mutations in BRAF or NRAS gene are frequently present with ulceration, and mutation in BRAF or NRAS gene is indicator for poor prognosis.'},\n",
       "   {'pubmed': 21796448,\n",
       "    'text': 'Importance of infiltrative growth pattern and invasiveness over presence of BRAF mutation in classic and follicular variant papillary thyroid carcinoma for development of nodal metastases.'},\n",
       "   {'pubmed': 21803329,\n",
       "    'text': 'BRAF mutation is not indicative for predicting papillary thyroid cancer prognosis.'},\n",
       "   {'pubmed': 21825258,\n",
       "    'text': 'study reports that V600E and non-V600E BRAF mutations affect different patients with non-small-cell lung cancer; V600E mutations are significantly associated with female sex and represent a negative prognostic factor'},\n",
       "   {'pubmed': 21826673,\n",
       "    'text': 'BRAF mutations and llelic loss of susceptibility loci are associated with familial non-medullary thyroid cancer.'},\n",
       "   {'pubmed': 21835307,\n",
       "    'text': 'The BRAF/MEK/ERK pathway is upregulated in progressive retinal arterial macroaneurysm patients, caused by mutation in IGFBP7.'},\n",
       "   {'pubmed': 21863388,\n",
       "    'text': 'Braf mutation in metastatic melanoma treated with BRAF inhibitor vemurafenib.'},\n",
       "   {'pubmed': 21871821,\n",
       "    'text': 'Genetic analysis revealed individual heterozygous mutations in the KRAS (phenotype of CFC/Noonan syndrome) and BRAF genes (phenotype of CFC syndrome)'},\n",
       "   {'pubmed': 21875464,\n",
       "    'text': 'BRAF V600E mutation has a significant correlation with papillary thyroid carcinomas.'},\n",
       "   {'pubmed': 21882184,\n",
       "    'text': 'the BRAF(V600E) mutation should be considered as a poor prognostic marker in papillary thyroid cancer (Meta-Analysis)'},\n",
       "   {'pubmed': 21900390,\n",
       "    'text': 'Studies indicate that BRAF V600E mutation initiates follicular cell transformation.'},\n",
       "   {'pubmed': 21901162,\n",
       "    'text': 'In sporadic colorectal tumourspatients, the most frequently mutated gene was APC (68.9% of tumours), followed by KRAS (31.1%), TP53 (27.2%), BRAF (8.7%) and CTNNB1 (1.9%).'},\n",
       "   {'pubmed': 21903858,\n",
       "    'text': 'BRAF(V600E) causes upregulation of TIMP-1 via NF-kappaB. TIMP-1 binds then its surface receptor CD63, leading eventually to Akt activation, which in turn confers antiapoptotic behavior and promotion of cell invasion.'},\n",
       "   {'pubmed': 21906875,\n",
       "    'text': 'BRAF mutations are of pathogenetic significance in wild type gastrointestinal stromal tumors.'},\n",
       "   {'pubmed': 21909080,\n",
       "    'text': \"CXCR4 expression and BRAF mutation status could cooperatively induce and promote a more aggressive phenotype in papillary thyroid carcinoma through several pathways and specifically increase the tumors' spread outside of the thyroid gland.\"},\n",
       "   {'pubmed': 21915661,\n",
       "    'text': 'Aberrant CIMP was detected in 16% of chromosomal instable tumors and in 44% of both microsatellite instable and microsatellite and chromosomally stable carcinomas'},\n",
       "   {'pubmed': 21936566,\n",
       "    'text': 'this novel B-Raf fusion protein (SND-1 was identified as the B-Raf fusion partner) presents a novel target with potential clinical implications in the treatment of patients resistant to c-Met inhibitors.'},\n",
       "   {'pubmed': 21937738,\n",
       "    'text': 'A prominent epigenetic mechanism through which BRAF V600E can promote papillary thyroid cancer tumorigenesis by altering the methylation and hence the expression of numerous important genes.'},\n",
       "   {'pubmed': 21943101,\n",
       "    'text': 'BRAF mutation V600E significantly induces cell migration and invasion properties in vitro in colon cancer cells'},\n",
       "   {'pubmed': 21948220,\n",
       "    'text': 'In malignant FNABs in papillary thyroid carcinoma, BRAF(V600E) mutation was significantly associated with presence of extra-thyroidal extension and metastases after surgery.'},\n",
       "   {'pubmed': 22006538,\n",
       "    'text': 'DNA methylation of each marker was quantified using combined bisulfite restriction analysis (COBRA) and analyzed along with various genetic factors associated with CRC [the BRAF and KRAS mutations, MLH1 methylation and microsatellite instability'},\n",
       "   {'pubmed': 22012135,\n",
       "    'text': 'An integrated approach combining both VE1 mutant protein immunohistochemistry and genetic analysis may increase the diagnostic accuracy of BRAF mutation analysis.'},\n",
       "   {'pubmed': 22027477,\n",
       "    'text': 'Postmenopausal hormone therapy was associated with borderline statistically significant risk reductions for BRAF-wildtype tumours among women with prolonged exposure to Postmenopausal hormone therapy.'},\n",
       "   {'pubmed': 22028477,\n",
       "    'text': 'BRAF V600E mutation is associated with hairy cell leukemia and B-cell neoplasms'},\n",
       "   {'pubmed': 22033631,\n",
       "    'text': 'high prevalence of BRAF (V600E) mutation is associated with synchronous bilateral papillary thyroid carcinoma.'},\n",
       "   {'pubmed': 22038996,\n",
       "    'text': 'Results support evaluation of BRAF(V600E)-specific inhibitors for treating BRAF(V600E) malignant astrocytomas (MA) patients.'},\n",
       "   {'pubmed': 22039425,\n",
       "    'text': 'study examined the clinical characteristics and outcomes of patients with mutant BRAF advanced cancer; conclude that BRAF appears to be a druggable mutation that also defines subgroups of patients with phenotypic overlap, albeit with differences that correlate with histology or site of mutation'},\n",
       "   {'pubmed': 22043994,\n",
       "    'text': 'This article reviewes the spectrum of KRAS/BRAF genotype and the impact of KRAS/BRAF mutations on the clinicopathological features and prognosis of patients with colorectal cancer. [review]'},\n",
       "   {'pubmed': 22065586,\n",
       "    'text': 'Ras induces DR5 expression through co-activation of ERK/RSK and JNK signaling pathways'},\n",
       "   {'pubmed': 22072557,\n",
       "    'text': 'BRAF V600E mutation is associated with hairy cell leukemia and other mature B-cell neoplasms'},\n",
       "   {'pubmed': 22072743,\n",
       "    'text': 'BAG3 protein sustains anaplastic thyroid tumor growth in vitro and in vivo. The underlying molecular mechanism appears to rely on BAG3 binding to BRAF, thus protecting it from proteasome-dependent degradation.'},\n",
       "   {'pubmed': 22105174,\n",
       "    'text': 'Murine thyroid tumors carrying the human BRAF(V600E) mutations are exquisitely dependent on the oncoprotein for viability.'},\n",
       "   {'pubmed': 22105775,\n",
       "    'text': 'BRAF (V600E) is a prevalent genetic alteration in adult sporadic papillary thyroid carcinoma in Indian cohort and it may be responsible for the progression of its classic variant.'},\n",
       "   {'pubmed': 22114137,\n",
       "    'text': 'Overall, no difference existed in microsatellite instability or BRAF mutation frequencies between African Americans and Caucasians with colorectal neoplasms.'},\n",
       "   {'pubmed': 22133769,\n",
       "    'text': 'BRAF mutations are associated with hairy cell leukemia and related lymphoproliferative disorders.'},\n",
       "   {'pubmed': 22136270,\n",
       "    'text': 'Case Report: describe case of follicular thyroid carcinoma with BRAF mutation.'},\n",
       "   {'pubmed': 22137342,\n",
       "    'text': 'thieno[2,3-d]pyrimidines are B-Raf inhibitors'},\n",
       "   {'pubmed': 22145942,\n",
       "    'text': 'Pyrosequencing of BRAF V600E in routine samples of hairy cell leukaemia identifies CD5+ variant hairy cell leukaemia that lacks V600E.'},\n",
       "   {'pubmed': 22147429,\n",
       "    'text': 'V600E mutation of the BRAF gene reported to be associated with poor prognosis of germ cell tumors in adults prognostic biomarkers cannot necessarily be transferred from one age group to the other.'},\n",
       "   {'pubmed': 22147942,\n",
       "    'text': 'BRAF mutation is associated with inferior survival in stage III colon cancer.'},\n",
       "   {'pubmed': 22150560,\n",
       "    'text': 'papillary thyroid cancers in young patients display a low prevalence of the already identified oncogenic alterations; the increasing prevalence with age is mainly due to V600E BRAF mutation'},\n",
       "   {'pubmed': 22156467,\n",
       "    'text': 'The BRAF V600E mutation is associated with a higher pathological stage at surgery and a higher rate of recurrence.'},\n",
       "   {'pubmed': 22156468,\n",
       "    'text': 'BRAF mutations enhance the predictability of malignancy in thyroid follicular lesions of undetermined significance.'},\n",
       "   {'pubmed': 22157687,\n",
       "    'text': 'BRAF and KRAS mutations were observed in six (46.2%) and four (30.3%) filiform serrated adenomaS, respectively.'},\n",
       "   {'pubmed': 22170714,\n",
       "    'text': 'BRAF mutation in papillary thyroid carcinoma is a later subclonal event, its intratumoral heterogeneity may hamper the efficacy of targeted pharmacotherapy, and its association with a more aggressive disease should be reevaluated.'},\n",
       "   {'pubmed': 22174938,\n",
       "    'text': 'The antibody response against the catalytic domain of BRAF is not specific for rheumatoid arthritis.'},\n",
       "   {'pubmed': 22178589,\n",
       "    'text': 'Report mutations in KRAS, EGFR, and BRAF in cholangiocarcinoma and identify therapeutic targets for tyrosine kinase inhibitors.'},\n",
       "   {'pubmed': 22180495,\n",
       "    'text': 'Findings suggest that the BRAF inhibitor vemurafenib in combination with standard-of-care or novel targeted therapies may lead to enhanced and sustained clinical antitumor efficacy in CRCs harboring the BRAF(V600E) mutation.'},\n",
       "   {'pubmed': 22189819,\n",
       "    'text': 'Aberrant gene methylation driven by BRAF(V600E) altered expression of the DNA methyltransferase 1 and histone methyltransferase EZH2 profoundly.'},\n",
       "   {'pubmed': 22190222,\n",
       "    'text': 'The BRAF(V600E) mutation was associated with high-risk clinicopathologic characteristics in patients with papillary thyroid cancer (PTC). The BRAF(V600E) mutation may be a potential prognostic factor in PTC patients.'},\n",
       "   {'pubmed': 22190283,\n",
       "    'text': 'B-Raf gene mutation primarily occurs at two loci--the exon 11 glycine loop and the activation area of exon 15--in surgically resected specimens of hepatocellular carcinoma patients.'},\n",
       "   {'pubmed': 22194995,\n",
       "    'text': 'These data support a model where the continuous regenerative process initiated by oncogenic B-RAF-driven alveolar disruption provides a tumor-promoting environment associated with chronic inflammation.'},\n",
       "   {'pubmed': 22199277,\n",
       "    'text': 'RET mutations may have a role in medullary thyroid carcinoma, while BRAF, AKT1, and CTNNB1 do not; the role of HRAS, KRAS, and NRAS mutations are not determined'},\n",
       "   {'pubmed': 22199339,\n",
       "    'text': 'analysis of BRAF gene mutations in non-small cell lung cancer'},\n",
       "   {'pubmed': 22203991,\n",
       "    'text': 'These results provide a functional link between oncogenic BRAF and angiogenesis.'},\n",
       "   {'pubmed': 22210186,\n",
       "    'text': 'Patients with microsatellite instability tumor phenotype had favorable prognosis, but in those with the V600E BRAF mutation higher recurrence rate was observed.'},\n",
       "   {'pubmed': 22210875,\n",
       "    'text': 'Our results suggest that HCLv and IGHV4-34(+) HCLs have a different pathogenesis than HCLc and that a significant minority of other HCLc are also wild-type for BRAF V600.'},\n",
       "   {'pubmed': 22214007,\n",
       "    'text': 'Although it constitutes a poor prognostic factor in colorectal cancer, it is not conclusive if it interferes with a poor therapeutic effect when cetuximab is used.[review]'},\n",
       "   {'pubmed': 22227015,\n",
       "    'text': 'The findings show mutant BRAF-induced oncogenic stress manifests itself by DNA damage and growth arrest by activating the pCHK2-p53-p21 pathway.It also confers tumor-promoting phenotypes such as the up-regulation of GLUT1 and enhances glucose metabolism.'},\n",
       "   {'pubmed': 22228154,\n",
       "    'text': 'In patients with colorectal adenocarcinoma, there were significant differences between BRAF wild-type and mutant tumors in age, female sex, proximal tumor location, frequency of microsatellite instability, and survival.'},\n",
       "   {'pubmed': 22230299,\n",
       "    'text': 'One chronic lymphocytic leukaemia patient and one patient with B-prolymphocytic leukaemia were found to harbour the BRAF V600E mutation'},\n",
       "   {'pubmed': 22233696,\n",
       "    'text': 'Sessile serrated adenomas are precursors of sporadic colorectal cancers with microsatellite instability.Identified a novel surface microstructure, the Type II open-shape pit pattern (Type II-O), which was specific to SSAs with BRAF mutation and CIMP.'},\n",
       "   {'pubmed': 22235286,\n",
       "    'text': 'evidence for heterogeneity of the BRAF(V600E) mutation within individual melanoma tumor specimens'},\n",
       "   {'pubmed': 22245873,\n",
       "    'text': 'No BRAF mutations were found in colon adenocarcinomas from renal transplant recipients.'},\n",
       "   {'pubmed': 22246856,\n",
       "    'text': 'BRAF V600E mutation in low and intermediate grade lymphomas is associated with frequent occurrence in hairy cell leukaemia.'},\n",
       "   {'pubmed': 22249628,\n",
       "    'text': 'None of the molecular marker mutations that were analyzed in this study, including the BRAF mutation, predicted lymph node metastasis in classic papillary thyroid carcinoma.'},\n",
       "   {'pubmed': 22250191,\n",
       "    'text': 'During therapy with selective BRAF inhibitors, panniculitis with arthralgia represents a new adverse effect that can require dose reduction.'},\n",
       "   {'pubmed': 22258409,\n",
       "    'text': 'Mutational activation of both BRAF and PIK3CA genes does contribute to hepatocellular tumorigenesis at somatic level in Southern Italian population.'},\n",
       "   {'pubmed': 22282465,\n",
       "    'text': 'In naive GISTs carrying activating mutations in KIT or PDGFRA a concomitant activating mutation was detected in KRAS (5%) or BRAF (about 2%) genes. I'},\n",
       "   {'pubmed': 22287190,\n",
       "    'text': 'BRAF mutation is associated with colorectal serrated adenocarcinoma.'},\n",
       "   {'pubmed': 22294102,\n",
       "    'text': 'No hotspot mutations in Braf were found in oral squamous cell carcinoma in a Greek population.'},\n",
       "   {'pubmed': 22314188,\n",
       "    'text': 'Colon adenocarcinomas with BRAF mutations have morphologic characteristics distinct from those with KRAS mutations and BRAF-mutated proximal colonic adenocarcinomas with proficient DNA mismatch repair have an aggressive clinical course.'},\n",
       "   {'pubmed': 22317764,\n",
       "    'text': 'Data indicate that 266 (76.2%) tumors harbored EGFR mutations, 16 (4.6%) HER2 mutations, 15 (4.3%) EML4-ALK fusions, 7 (2.0%) KRAS mutations, and 2 (0.6%) BRAF mutations.'},\n",
       "   {'pubmed': 22317887,\n",
       "    'text': 'Report of oncogenic BRAF/KRAS mutations in sporadic glomus tumors.'},\n",
       "   {'pubmed': 22331186,\n",
       "    'text': 'BRAFmut as a useful marker in hairy cell leukemia.'},\n",
       "   {'pubmed': 22331825,\n",
       "    'text': 'BRAF mutation is an independent prognostic biomarker for colorectal liver metastasectomy.'},\n",
       "   {'pubmed': 22335197,\n",
       "    'text': 'BRAF V600E mutation-positive papillary thyroid carcinomas (PTCs) displayed infiltrative growth, stromal fibrosis, psammoma bodies, plump eosinophilic tumour cells, and classic fully developed nuclear features of PTC.'},\n",
       "   {'pubmed': 22339435,\n",
       "    'text': 'Data suggest that the BRAF V600E mutation does not seem to play a role in myeloid malignant transformation.'},\n",
       "   {'pubmed': 22358007,\n",
       "    'text': '(BRAF(V600E))detected in 141/170 malignant thyroid nodules (82.9%) (140 PTCs and one follicular variant of PTC). BRAF status not associated with US features with the exception of a negative relation between BRAF(V600E) and an irregular shape (p = 0.004).'},\n",
       "   {'pubmed': 22361037,\n",
       "    'text': 'This is the first reported study of the relationship between CK20/CK7 immunophenotype, BRAF mutations and microsatellite status in colorectal carcinomas'},\n",
       "   {'pubmed': 22367297,\n",
       "    'text': 'A distinct subset of atypical Spitz tumors is characterized by BRAF mutation and loss of BAP1 expression.'},\n",
       "   {'pubmed': 22368298,\n",
       "    'text': \"review demonstrates that tumour BRAF V600E mutation, and MLH1 promoter 'C region' methylation specifically, are strong predictors of negative MMR mutation status[review]\"},\n",
       "   {'pubmed': 22374786,\n",
       "    'text': 'The presence of activating GNAS mutations, in association with KRAS or BRAF mutations, is a characteristic genetic feature of colorectal villous adenoma.'},\n",
       "   {'pubmed': 22376079,\n",
       "    'text': 'evidence presented that ERK activation occurs in a K-ras or B-raf -independent manner in the majority of primary colon cancer cases; B-raf mutations are not associated with mismatch-repair deficiency through loss of hMLH1 or hMSH2 expression'},\n",
       "   {'pubmed': 22376167,\n",
       "    'text': 'The V600E BRAF mutation in papillary thyroid carcinomas may contribute to the initiation of the glycolytic phenotype and confers growth advantages in cancer'},\n",
       "   {'pubmed': 22382362,\n",
       "    'text': 'Eleven patients displayed Durable Disease Control (DDC) of which 55% had BRAF-V600E mutation positive tumors and 45% did not.'},\n",
       "   {'pubmed': 22393095,\n",
       "    'text': 'Patient diagnosed with colon cancer shows poor prognosis with BRAF genetic mutation.'},\n",
       "   {'pubmed': 22395615,\n",
       "    'text': 'findings show (V600E)B-RAF copy-number gain as a mechanism of acquired B-RAF inhibitor resistance in 4 out of 20 patients treated with B-RAF inhibitor'},\n",
       "   {'pubmed': 22398042,\n",
       "    'text': 'In a cohort of Indian patients with ulcerative colitis, with or without neoplasia, none showed the BRAF mutation.'},\n",
       "   {'pubmed': 22417847,\n",
       "    'text': 'we have analyzed the prevalence of somatic mutations in the FGFR3, PIK3CA, AKT1, KRAS, HRAS, and BRAF genes in bladder cancers'},\n",
       "   {'pubmed': 22426079,\n",
       "    'text': 'Data indicate that TaqMan(R) Mutation Detection assay is an important technology to consider in the field of mutation detection for KRAS, BRAF and EGFR point mutation screening.'},\n",
       "   {'pubmed': 22426956,\n",
       "    'text': 'genetic association studies in population in Turkey: Data suggest that a mutation in BRAF (V600E; found in 39.45% of patients) is associated with aggressiveness of papillary thyroid neoplasms; lymph node metastasis increases when mutation is present.'},\n",
       "   {'pubmed': 22427190,\n",
       "    'text': 'Investigation the prevalence of mutations in the BRAF gene and its correlation with demographic characteristics, tumor location and stage in 100 colorectal carcinoma patients from India.'},\n",
       "   {'pubmed': 22429583,\n",
       "    'text': 'Article reviews the current understanding of BRAF gene, its structure, expression, and signal pathway in non-small cell lung cancer. [Review]'},\n",
       "   {'pubmed': 22430133,\n",
       "    'text': 'The prevalence of EGFR, KRAS, BRAF and PIK3CA somatic mutations in 861 randomly selected Chinese patients with non-small cell lung cancer'},\n",
       "   {'pubmed': 22430208,\n",
       "    'text': 'We propose that , and that persistent phosphorylation of Mps1 through BRAF(V600E) signaling is a key event in disrupting the control of centrosome duplication and chromosome stability that may contribute to tumorigenesis.'},\n",
       "   {'pubmed': 22430215,\n",
       "    'text': 'expression of these oncogenes markedly stimulated ERK1/2 activities and morphologically transformed IECs. Importantly however'},\n",
       "   {'pubmed': 22431777,\n",
       "    'text': 'Effective use of PDT in the treatment of BRAF inhibitor-associated KAs and SCCs.'},\n",
       "   {'pubmed': 22431868,\n",
       "    'text': 'EFVPTC 1 patient BRAFV600E mutation, NVPTC 2 patients, FVPTC 2 patients.'},\n",
       "   {'pubmed': 22435913,\n",
       "    'text': 'analysis of a patient with pancreatic metastasis arising from a BRAF(V600E)-positive papillary thyroid cancer [case report]'},\n",
       "   {'pubmed': 22451557,\n",
       "    'text': 'The BRAF(V600E) mutation analysis from FNA specimens for calcified thyroid nodules may be performed for a greater negative predictive value and unveil the malignancy in 25% of indeterminate or nondiagnostic cytology.'},\n",
       "   {'pubmed': 22456166,\n",
       "    'text': 'Report marked differences in the genetic pattern of the BRAF or NRAS mutated and wild-type melanoma subgroups.'},\n",
       "   {'pubmed': 22459936,\n",
       "    'text': 'BRAF mutations play a limited role in the development of sinonasal cancer.'},\n",
       "   {'pubmed': 22471241,\n",
       "    'text': 'Out of 1041 Korean patients with papillary thyroid carcinoma, 0.4% had rare types of BRAF mutation and three new somatic mutations were identified'},\n",
       "   {'pubmed': 22471666,\n",
       "    'text': 'An update on malignancies displaying high frequencies of BRAF mutations and the mechanisms underlying the side effects and drug resistance phenomena associated with Raf inhibitors.'},\n",
       "   {'pubmed': 22488961,\n",
       "    'text': 'prevalence of the BRAF(V600E) mutation increased with increased tumor size'},\n",
       "   {'pubmed': 22492957, 'text': 'BRAF V600E is associated with gliomas.'},\n",
       "   {'pubmed': 22498935,\n",
       "    'text': 'No BRAF V600E mutations were indentified in this study of patients with endometrial cancer.'},\n",
       "   {'pubmed': 22500044,\n",
       "    'text': 'Highly sensitive and specific molecular assays such as MEMO sequencing are optimal for detecting the BRAF mutations in thyroid FNAC because these techniques can detect PTC that might be missed by cytology or less sensitive molecular assays.'},\n",
       "   {'pubmed': 22506009,\n",
       "    'text': 'The (600DLAT)B-RAF and (V600E)B-RAF mutations were found enriched in DNA and mRNA from the CD1a+ fraction of granuloma.'},\n",
       "   {'pubmed': 22508706,\n",
       "    'text': 'The analysis of BRAF mutations by pyrosequencing is useful to refine the risk stratification of patients with papillary thyroid carcinoma.'},\n",
       "   {'pubmed': 22510757,\n",
       "    'text': 'Patients with serrated polyposis syndrome referred to genetics clinics had a pan-colonic disease with a high polyp burden and a high rate of BRAF mutation.'},\n",
       "   {'pubmed': 22510884,\n",
       "    'text': 'It was shown that the dimer interface within the kinase domain plays a pivotal role for the activity of B-Raf and several of its gain-of-function mutants.'},\n",
       "   {'pubmed': 22514085,\n",
       "    'text': 'The tumor with T1799A BRAF mutation and tumor sizes of 2 cm or more were clinicopathologic parameters associated with lower STAT1 activity.'},\n",
       "   {'pubmed': 22515292,\n",
       "    'text': 'BRAF V600E is common in patients with low-risk papillary thyroid carcinoma but does not predict recurrence.'},\n",
       "   {'pubmed': 22515520,\n",
       "    'text': 'Mutation BRAF transforms cells through cross talk with developmental pathways Hedgehog and Wnt, as well as by deregulation of colorectal cancer related kinase pathways.'},\n",
       "   {'pubmed': 22516966,\n",
       "    'text': 'Report upregulation of Bim and the splicing factor SRp55 in melanoma cells from patients treated with selective BRAF inhibitors.'},\n",
       "   {'pubmed': 22522845,\n",
       "    'text': 'In signet ring cell carcinoma, BRAF V600E mutation adversely affects survival in microsatellite-stable tumors, but not in high-level microsatellite-unstable tumor'},\n",
       "   {'pubmed': 22531127,\n",
       "    'text': 'study concludes that generally, overweight increases the risk of colorectal cancer; taller individuals have an increased risk of developing a tumour with a BRAF mutation or microsatellite instability'},\n",
       "   {'pubmed': 22531170,\n",
       "    'text': 'Demonstrate that BRAF V600E mutation-specific antibody can be used in immunohistochemical diagnosis of hairy cell leukemia.'},\n",
       "   {'pubmed': 22534474,\n",
       "    'text': 'BRAF and KIT mutations have been found in Japanese melanoma patients.'},\n",
       "   {'pubmed': 22535154,\n",
       "    'text': 'study shows there are clinically and biologically distinct subtypes of BRAF-mutant metastatic melanoma, defined by genotype, with distinct etiology and behavior; cumulative sun-induced damage in primary cutaneous melanoma and older age are associated with V600K BRAF mutations;it establishes prevalence of the BRAF mutation by age-decade'},\n",
       "   {'pubmed': 22535974,\n",
       "    'text': 'The diagnostic sensitivity for thyroid cancer is significantly increased by BRAF V600E mutation analysis, indicating that the screening for BRAF mutation in FNAB samples has a relevant diagnostic potential.'},\n",
       "   {'pubmed': 22549559,\n",
       "    'text': 'Recurrent/persistent PTC in the central compartment typically harbors the BRAF mutation'},\n",
       "   {'pubmed': 22549727,\n",
       "    'text': 'abrogation of BRAFV600E-induced senescence contributes to melanomagenesis.'},\n",
       "   {'pubmed': 22549934,\n",
       "    'text': 'The mTOR pathway could be a good target to enhance therapy effects in certain types of thyroid carcinoma, namely in those harboring the BRAF(V600E) mutation.'},\n",
       "   {'pubmed': 22568401,\n",
       "    'text': 'These results suggest that low-grade diffuse gliomas with 1p/19q loss have frequent BRAF gains'},\n",
       "   {'pubmed': 22579930,\n",
       "    'text': 'KRAS, BRAF, and PIK3CA mutations in colorectal cancer have sustained prevalence rate in the Taiwanese population.'},\n",
       "   {'pubmed': 22581800,\n",
       "    'text': 'BRAF regulates expression of long noncoding RNAs in melanocytes and melanoma cells'},\n",
       "   {'pubmed': 22586484,\n",
       "    'text': 'In the present study, we did not find any significant correlations between KRAS, BRAF and PIK3CA mutations and the loss of PTEN expression and various clinicopathological features in Chinese patients with colorectal cancer.'},\n",
       "   {'pubmed': 22591444,\n",
       "    'text': 'Our results suggest that in a small fraction of diffuse gliomas, KIAA1549-BRAF fusion gene and BRAF(v600E) mutation may be responsible for deregulation of the Ras-RAF-ERK signaling pathway'},\n",
       "   {'pubmed': 22592144,\n",
       "    'text': 'Immunohistochemical detection of the mutated V600E BRAF protein in papillary thyroid carcinoma may facilitate mutational analysis in the clinical setting.'},\n",
       "   {'pubmed': 22614711,\n",
       "    'text': 'BRAF p.Val600Lys mutations were present at a relatively high frequency in the cohort of metastatic melanoma patients (27/183, 15%)'},\n",
       "   {'pubmed': 22614978,\n",
       "    'text': 'BRAF/NRAS mutations were identified in 58% of primary melanomas (43% BRAF; 15% NRAS)'},\n",
       "   {'pubmed': 22628551,\n",
       "    'text': 'Data show that RNF149 (RING finger protein 149) interacts with wild-type BRAF.'},\n",
       "   {'pubmed': 22639828,\n",
       "    'text': 'Data suggest that BRAF V600E mutation may not be widespread in hematologic malignancies, excluding hairy-cell leukemia (HCL).'},\n",
       "   {'pubmed': 22649091,\n",
       "    'text': \"Patient's BRAF mutation was likely responsible for his tumor's marked response to dasatinib, suggesting that tumors bearing kinase-impaired BRAF mutations may be exquisitely sensitive to dasatinib.\"},\n",
       "   {'pubmed': 22681706,\n",
       "    'text': 'BRAFV600E mutation is associated with lymph node metastasis in multiple papillary thyroid carcinoma.'},\n",
       "   {'pubmed': 22684223,\n",
       "    'text': 'The presence of BRAF mutations in these adenomatous precursors to colon cancer suggests that they represent sessile serrated adenomas with complete cytologic dysplasia.'},\n",
       "   {'pubmed': 22694820,\n",
       "    'text': 'In papillary thyroid cancer, significant correlations between the methylation status of four genes (TIMP3, RASSF1A, RARbeta2 and DCC) and the V600E BRAF mutation were found.'},\n",
       "   {'pubmed': 22699145,\n",
       "    'text': 'Data indicate that 14% with pancreatic ductal adenocarcinomas (PDACs) and 7% ampullary adenocarcinomas (A-ACs) had mutations in both KRAS and BRAF.'},\n",
       "   {'pubmed': 22702340,\n",
       "    'text': 'In papillary thyroid carcinoma BRAFV600E is associated with increased expression of the urokinase plasminogen activator and its cognate receptor, but not with disease-free interval.'},\n",
       "   {'pubmed': 22705994,\n",
       "    'text': 'Hairy cell leukemia cell lines expressing annexin A1 and displaying B-cell receptor signals characteristic of primary tumor cells lack the signature BRAF mutation to reveal unrepresentative origins.'},\n",
       "   {'pubmed': 22706026,\n",
       "    'text': 'The combined effects of EGFR downregulation, ligand competition, and immune effector function conspire to inhibit tumor growth in xenograft models of cetuximab-resistant BRAF and KRAS mutant cancers.'},\n",
       "   {'pubmed': 22727996,\n",
       "    'text': 'BRAF V600E mutations are present in approximately 90% of all kidney metanephric adenoma cases, serving as a potential valuable diagnostic tool in the differential diagnosis.'},\n",
       "   {'pubmed': 22730329,\n",
       "    'text': 'Reactivation of mitogen-activated protein kinase (MAPK) pathway by FGF receptor 3 (FGFR3)/Ras mediates resistance to vemurafenib in human B-RAF V600E mutant melanoma.'},\n",
       "   {'pubmed': 22732794,\n",
       "    'text': 'BRAF V600E mutation revealed a strong association with specific histological variants of papillary thyroid carcinoma.'},\n",
       "   {'pubmed': 22740704,\n",
       "    'text': 'These results clearly prove that the BRAFV600E mutation is not associated with the development of distant metastases or fatal outcome in papillary thyroid carcinoma'},\n",
       "   {'pubmed': 22742884,\n",
       "    'text': 'Vemurafenib is effective for advanced melanomas expressing the BRAF V600E mutations [review]'},\n",
       "   {'pubmed': 22743296,\n",
       "    'text': 'BRAF V600E mutation is associated with response to vemurafenib in lung adenocarcinoma.'},\n",
       "   {'pubmed': 22751131,\n",
       "    'text': 'B-Raf/MKK/ERK controls key aspects of cancer cell behavior and gene expression by modulating a network of miRNAs with cross-regulatory functions.'},\n",
       "   {'pubmed': 22752848,\n",
       "    'text': 'study reports a novel complex BRAF mutation identified in 4/492 Japanese papillary thyroid carcinoma(PTC) cases; findings suggest the BRAF(V600delinsYM)mutation, is a gain-of-function mutation and plays an important role in PTC development'},\n",
       "   {'pubmed': 22767446,\n",
       "    'text': 'study found a relatively higher B-Raf serine/threonine-protein kinase (BRAF)(V600E) mutation rate in classical type papillary thyroid carcinomas than in other similar studies'},\n",
       "   {'pubmed': 22770943,\n",
       "    'text': 'BRAF mRNA expression may help to identify PTC among thyroid nodules independently of the presence of BRAFV600E mutation.'},\n",
       "   {'pubmed': 22772867,\n",
       "    'text': 'BRAF (V600) mutations are are associated with melanomas.'},\n",
       "   {'pubmed': 22773810,\n",
       "    'text': 'Lung cancers with acquired resistance to EGFR inhibitors occasionally harbor BRAF gene mutations but lack mutations in KRAS, NRAS, or MEK1.'},\n",
       "   {'pubmed': 22797077,\n",
       "    'text': 'RSK regulates activated BRAF signalling to mTORC1 and promotes melanoma growth'},\n",
       "   {'pubmed': 22798288,\n",
       "    'text': 'Data show clinical significance to BRAF(L597) mutations in melanoma.'},\n",
       "   {'pubmed': 22798500,\n",
       "    'text': 'In CRC patients treated with cetuximab, activating mutation signatures for BRAF (58 genes) were developed.'},\n",
       "   {'pubmed': 22799316,\n",
       "    'text': 'Preoperative BRAF mutation was a predictive factor for occult contralateral papillary thyroid microcarcinoma presence.'},\n",
       "   {'pubmed': 22809251,\n",
       "    'text': 'As has been reported in other common types of melanoma, V600 BRAF mutation is the most common mutation of those tested in spindle cell melanoma. NRAS or KIT mutation appears to be rare, if not completely absent.'},\n",
       "   {'pubmed': 22814862,\n",
       "    'text': 'we found no cases of Rosette-forming glioneuronal tumors of the fourth ventricle showing KIAA1549-BRAF gene fusion or BRAF (V600E) mutation'},\n",
       "   {'pubmed': 22820187,\n",
       "    'text': 'these results link epigenetic genes to methylation and suppression of tumor suppressor genes as a mechanism involved in BRAFV600E-promoted melanoma tumorigenesis and uncover a novel molecular signature that predicts a poor prognosis of melanoma.'},\n",
       "   {'pubmed': 22820660,\n",
       "    'text': 'No BRAF V600E mutations were detected in nonserous epithelial ovarian tumors.'},\n",
       "   {'pubmed': 22824468,\n",
       "    'text': 'Single Nucleotide Polymorphisms in BRAF gene is associated with diseases.'},\n",
       "   {'pubmed': 22826122,\n",
       "    'text': 'It was concluded that extracellular kinase-mediated up-regulation of c-myc by K-Ras or B-Raf oncogenes disrupts the establishment of apical/basolateral polarity in colon epithelial cells independently of its effect on proliferation.'},\n",
       "   {'pubmed': 22826437,\n",
       "    'text': 'RAF1(D486N), as well as other kinase-impaired RAF1 mutants, showed increased heterodimerization with BRAF, which was necessary and sufficient to promote increased MEK/ERK activation.'},\n",
       "   {'pubmed': 22833462,\n",
       "    'text': 'Investigated BRAF and RAF1 alterations in Chinese prostate cancer.Found BRAF truncated in five of 200 informative Chinese cases & RAF1 was truncated in three of 204 informative cases and genomic rearrangements were correlated w/high Gleason scores.'},\n",
       "   {'pubmed': 22850568,\n",
       "    'text': 'This study reveals a novel mechanism of immune suppression sensitive to BRAF(V600E) inhibition, and indicates that clinical blockade of IL-1 may benefit patients'},\n",
       "   {'pubmed': 22858857,\n",
       "    'text': 'A review summarizes the role of the BRAF V600E mutation in the development and progression of thyroid cancer.'},\n",
       "   {'pubmed': 22859608,\n",
       "    'text': 'BRAFV600E mutation is associated with Langerhans cell histiocytosis.'},\n",
       "   {'pubmed': 22863493,\n",
       "    'text': 'The BRAFV600E occurs exclusively in papillary thyroid carcinoma and papillary carcinoma-derived anaplastic cancer, rising as a specific diagnostic marker for this tumor when identified in cytological / histological exams'},\n",
       "   {'pubmed': 22870241,\n",
       "    'text': 'High-throughput genotyping in metastatic esophageal squamous cell carcinoma identifies phosphoinositide-3-kinase and BRAF mutations.'},\n",
       "   {'pubmed': 22876591,\n",
       "    'text': 'Cardio-facio-cutaneous syndrome is caused by heterogeneous mutations in BRAF gene.'},\n",
       "   {'pubmed': 22879539,\n",
       "    'text': 'High prevalence of BRAF V600E mutations is associated with Erdheim-Chester disease but not in other non-Langerhans cell histiocytoses.'},\n",
       "   {'pubmed': 22880048,\n",
       "    'text': 'This study reveals a novel molecular mechanism underlying the regulation of feedback loops between the MAPK and AKT pathways.'},\n",
       "   {'pubmed': 22887810,\n",
       "    'text': 'A K601E BRAF mutation is associated with papillary thyroid carcinoma.'},\n",
       "   {'pubmed': 22892521,\n",
       "    'text': 'The results of this study supported an important role for BRAF duplication and MAPK pathway activation in gliomas of the optic nerve proper.'},\n",
       "   {'pubmed': 22898351,\n",
       "    'text': 'MSI status, KRAS and BRAF mutation rates varied remarkably among the colonic carcinoma subsites irrespective of right- and left-sided origin.'},\n",
       "   {'pubmed': 22899730,\n",
       "    'text': 'The presence of a BRAF c.1799T>A (p.V600E) mutation is associated with significantly poorer prognosis after colorectal cancer diagnosis among subgroups of patients.'},\n",
       "   {'pubmed': 22912864,\n",
       "    'text': 'Data indicate that mutation frequency in malanoma patients was found witih BRAF(V600) in 51%, NRAS in 19%, PI3K pathway in 41% and PTEN in 22%.'},\n",
       "   {'pubmed': 22918165,\n",
       "    'text': 'BRAF(V600E) mutation is an early event in thyroid carcinogenesis, and is associated with distinctive morphology and aggressive features even in papillary thyroid microcarcinomas'},\n",
       "   {'pubmed': 22926515,\n",
       "    'text': 'ARAF seems to stabilize BRAF:CRAF complexes in cells treated with RAF inhibitors and thereby regulate cell signaling in a subtle manner to ensure signaling efficiency'},\n",
       "   {'pubmed': 22930283,\n",
       "    'text': 'BRAF mutation is associated with early stage disease and improved outcome in patients with low-grade serous ovarian cancer.'},\n",
       "   {'pubmed': 22931913,\n",
       "    'text': 'We conclude that the presence of BRAF mutation, NRAS mutation, and the absence of an immune-related expressed gene profile predict poor outcome in melanoma patients with macroscopic stage III disease.'},\n",
       "   {'pubmed': 22932786,\n",
       "    'text': 'Thus, in this meta-analysis, the BRAF mutation in PTC was significantly associated with PTC recurrence, lymph node metastasis, extrathyroidal extension, and advanced stage AJCC III/IV.'},\n",
       "   {'pubmed': 22938585,\n",
       "    'text': 'Data indicate that KRAS, BRAF, PIK3CA, and AKT1 mutations can be rapidly and accurately detected for cancer diagnosis.'},\n",
       "   {'pubmed': 22941165,\n",
       "    'text': 'The BRAF V600E mutation is the only independent predictor of compartment lymph node metastasis in papillary thyroid carcinoma.'},\n",
       "   {'pubmed': 22946697,\n",
       "    'text': 'Data indicate that of the 32 cardio-facio-cutaneous syndrome (CFC) patients, 28 (88%) had a known mutation in a gene that is causative for CFC, including BRAF (n = 21), MEK1 (n = 2), MEK2 (n = 4), and KRAS (n = 1).'},\n",
       "   {'pubmed': 22972589,\n",
       "    'text': 'Higher response rates and longer time to progression were observed with selumetinib-containing regimens in patients who had melanoma that harbored a BRAF mutation.'},\n",
       "   {'pubmed': 22973979,\n",
       "    'text': 'found a significantly increased risk of papillary thyroid carcinoma attributed to the SNP variants rs17161747, rs1042179, and rs3748093 for those with a family history of cancer, for smokers, and for both those of age <45 years and nondrinkers'},\n",
       "   {'pubmed': 22996177,\n",
       "    'text': 'This report is the first to identify the rare, variant BRAF V600D mutation in LCH, and provides support for constitutively activated BRAF oncogene-induced cell senescence as a mechanism of regression in congenital, benign LCH.'},\n",
       "   {'pubmed': 23009221,\n",
       "    'text': 'consistent with previous studies, it was concluded that the incidence of BRAF V600E mutation in adult acute lymphoblastic leukemia, if any, is extremely infrequent'},\n",
       "   {'pubmed': 23010278,\n",
       "    'text': 'B-RAF upregulates SGLT1 activity, an effect requiring vesicle insertion into the cell membrane.'},\n",
       "   {'pubmed': 23010994,\n",
       "    'text': 'BRAF mutation is suggested to be poor prognostic factors in CRLM.'},\n",
       "   {'pubmed': 23014346,\n",
       "    'text': 'Braf mutation status is not significantly associated with poor survival for melanoma in Koreans.'},\n",
       "   {'pubmed': 23021375,\n",
       "    'text': 'EGFR and downstream genetic alterations in KRAS/BRAF and PI3K/AKT pathways have roles in colorectal cancer and treatment [review]'},\n",
       "   {'pubmed': 23026937,\n",
       "    'text': 'Immunohistochemistry is highly sensitive and specific for the detection of V600E BRAF mutation in melanoma.'},\n",
       "   {'pubmed': 23033302,\n",
       "    'text': 'the spectrum and frequency distribution of the identified KRAS and BRAF mutations in Serbian patient with colorectal cancer are in good accordance with literature data.'},\n",
       "   {'pubmed': 23036672,\n",
       "    'text': 'We describe 3 patients with BRAF V600E mutation metastatic melanoma in whom treatment with vemurafenib resulted in prompt extracranial disease response but progression of metastatic disease in the brain.'},\n",
       "   {'pubmed': 23039341,\n",
       "    'text': 'Studied the cytotoxicity and anti-tumour activity of novel MEK inhibitor, E6201, in a panel of melanoma cell lines. Most melanoma cell lines were sensitive or hypersensitive to E6201; the sensitivity correlated with wildtype PTEN and mutant BRAF status.'},\n",
       "   {'pubmed': 23041829,\n",
       "    'text': 'Findings support the potential use of immunohistochemistry as an ancillary screening tool to assess the BRAFV600E mutation status in primary cutaneous melanoma.'},\n",
       "   {'pubmed': 23051629,\n",
       "    'text': 'Increased BRAF mutation with age along with the lack of a UVR magnitude-BRAF mutation association suggests that duration of exposure rather than UVR exposure dose is the more likely link to acquiring mutations in melanocytic nevi.'},\n",
       "   {'pubmed': 23055340,\n",
       "    'text': 'KRAS and BRAF mutations are infrequent or absent, respectively in Intestinal-type sinonasal adenocarcinoma'},\n",
       "   {'pubmed': 23055546,\n",
       "    'text': 'BRAF mutation was associated with lymph node metastases (LNM), advanced stage, extrathyroidal extension, tumor size, male gender, multifocality, absence of capsule, classic PTC, and tall-cell variant papillary thyroid cancer.'},\n",
       "   {'pubmed': 23056577,\n",
       "    'text': 'A systematic review and meta-analysis revealed that BRAF mutation is an absolute risk factor for patient survival in colorectal cancer and melanoma.'},\n",
       "   {'pubmed': 23062653,\n",
       "    'text': 'BRAF mutation was not found to be significantly associated with lymph node metastasis in patients with papillary thyroid cancer'},\n",
       "   {'pubmed': 23066120,\n",
       "    'text': 'The BRAF(V600E) mutation was demonstrated to be a poor prognostic factor for the persistence of the disease independent from other clinical-pathological features in low-risk intrathyroid papillary thyroid carcinoma patients.'},\n",
       "   {'pubmed': 23069257,\n",
       "    'text': 'Histopathologic changes suggesting prolapsed rectal mucosa should take precedence over BRAF results in diagnosing sessile serrated adenomas in the rectum.'},\n",
       "   {'pubmed': 23088640,\n",
       "    'text': 'analysis suggests that BRAF mutations occur at a low frequency in chronic lymphocytic leukemia'},\n",
       "   {'pubmed': 23095503,\n",
       "    'text': 'Desmoplastic malignant melanoma: a study of ten cases and status of BRAF mutation.'},\n",
       "   {'pubmed': 23096133,\n",
       "    'text': 'BRAF mutation is associated with pleomorphic xanthoastrocytomas with anaplastic features.'},\n",
       "   {'pubmed': 23096702,\n",
       "    'text': 'We found that NRAS-mutant melanomas were significantly more likely from older patients and BRAF-mutant melanomas were more frequent in melanomas from the trunk.'},\n",
       "   {'pubmed': 23098991,\n",
       "    'text': 'Studied differential miRNA expression in metastatic colorectal cancer by microarrays from primary tumors of 33 patients who had wild-type KRAS/BRAF and third- to sixth-line anti-EGFRmAb treatment, with/without irinotecan.'},\n",
       "   {'pubmed': 23110075,\n",
       "    'text': 'Study demonstrates that chromosomal instability commonly occurs in advanced BRAF mutant/MSS colorectal cancers where it may contribute to poorer survival, and further highlights molecular similarities occurring between these and BRAF wild type cancers.'},\n",
       "   {'pubmed': 23125007,\n",
       "    'text': 'One hundred and ten patients (51%) were identified who were potentially nonresponders to anti-EGFR therapy:  13/117 (11.1%) had the V600E BRAF mutation.'},\n",
       "   {'pubmed': 23132792,\n",
       "    'text': 'BRAFV600E mutation is associated with cervical lymph node metastasis and recurrence in papillary thyroid cancer.'},\n",
       "   {'pubmed': 23138171,\n",
       "    'text': 'Clinical characteristics of colorectal cancer with the V600E BRAF mutation.'},\n",
       "   {'pubmed': 23153455,\n",
       "    'text': 'These findings indicate that ABCG2 confers resistance to vemurafenib in A375 cells, suggesting involvement of this transporter in acquired resistance to vemurafenib.'},\n",
       "   {'pubmed': 23157614,\n",
       "    'text': 'Data indicate that the presence of the BRAF V600E mutation was more frequent in women, but this gender difference was not statistically significant.'},\n",
       "   {'pubmed': 23157823,\n",
       "    'text': 'In Chinese colorectal carcinoma patients, BRAF mutation is associated with tumor differentiation and primary tumor sites.'},\n",
       "   {'pubmed': 23157824,\n",
       "    'text': 'Codon 12, 13 in KRAS gene and codon 600 in BRAF gene are the most common mutation points in Chinese colorectal cancer. KRAS and BRAF mutations are mutually exclusive. KRAS and BRAF gene mutation is higher in females than that in males.'},\n",
       "   {'pubmed': 23158172,\n",
       "    'text': 'BRAF mutational status is predictive of papillary thyroid carcinoma recurrence'},\n",
       "   {'pubmed': 23159116,\n",
       "    'text': 'V600E point mutation was identified in the BRAF gene in 3 intramucosal nevi and in 2 melanomas. Only 1 blue nevus harbored the GNAQ209 mutation'},\n",
       "   {'pubmed': 23161556,\n",
       "    'text': 'BRAF mutation as a new serum marker for papillary thyroid carcinomas were not detectable in patientts diagnosed with thyroid neoplasms.'},\n",
       "   {'pubmed': 23161722,\n",
       "    'text': 'data confirm that among lymphoproliferative disorders, BRAF V600E mutation is restricted to hairy cell leukemia (HCL); no mutations were identified in variant HCL, NMZL, ENMZL, PTLD, PTCL, ALCL, or LGL proliferations'},\n",
       "   {'pubmed': 23163107,\n",
       "    'text': 'The BRAF(V600E) mutation might be associated with a more aggressive phenotype and a poor prognosis in classic variant of papillary thyroid carcinomas.'},\n",
       "   {'pubmed': 23179992,\n",
       "    'text': 'BRAF (V600E) mutation is associated with papillary thyroid carcinomas.'},\n",
       "   {'pubmed': 23188063,\n",
       "    'text': 'BRAF mutations were correlated with poor overall survival in the full patient cohort'},\n",
       "   {'pubmed': 23190154,\n",
       "    'text': 'Our findings suggest that RAS pathway activation due to BRAF V600E and KRAS mutations is an important event in a subset of peripheral nerve sheath tumours not related to neurofibromatosis'},\n",
       "   {'pubmed': 23190890,\n",
       "    'text': 'Oncogenic B-RAF(V600E) signaling induces the T-Box3 transcriptional repressor to repress E-cadherin and enhance melanoma cell invasion.'},\n",
       "   {'pubmed': 23192464,\n",
       "    'text': 'Aim of this work is to provide a detailed comparison of clinical-pathologic features between well-differentiated and poorly differentiated tumors according to their BRAF and RASSF1A status.'},\n",
       "   {'pubmed': 23192956,\n",
       "    'text': 'BRAF (V600E) mutation is associated with papillary thyroid microcarcinoma.'},\n",
       "   {'pubmed': 23203004,\n",
       "    'text': 'BRAF (V600E) is non-associated with Gal-3 expression, whereas it is associated with cytoplasmatic localization of p27kip1 and higher CK19 expression in papillary thyroid carcinoma.'},\n",
       "   {'pubmed': 23207070,\n",
       "    'text': 'The present study revealed that ESCC of Brazilian patients do not present mutations in hot spots of EGFR, K-RAS and BRAF and only a minor proportion present overexpression of EGFR or HER2.'},\n",
       "   {'pubmed': 23208503,\n",
       "    'text': 'results suggest that mutant B-RAF signaling downregulates Tiam1/Rac activity resulting in an increase in N-cadherin levels and a decrease in E-cadherin levels and ultimately enhanced invasion'},\n",
       "   {'pubmed': 23224067,\n",
       "    'text': 'Mutations affecting BRAF, EGFR, PIK3CA, and KRAS are not associated with sporadic vestibular schwannomas.'},\n",
       "   {'pubmed': 23235345,\n",
       "    'text': 'the BRAF V600E mutation is not pathobiologically relevant in primary central nervous system lymphoma'},\n",
       "   {'pubmed': 23237741,\n",
       "    'text': 'Patients with V600R BRAF mutations can be treated successfully with oral BRAF inhibitors.'},\n",
       "   {'pubmed': 23242808,\n",
       "    'text': 'Data indicate that BRAF and EGF receptor or SRC family kinase inhibition blocked proliferation and invasion of the resistant tumors.'},\n",
       "   {'pubmed': 23246082,\n",
       "    'text': 'the role of BRAF mutations in melanoma and colorectal cancer, focusing on similarities and differences of BRAF mutations (Review)'},\n",
       "   {'pubmed': 23253715,\n",
       "    'text': 'The status of BRAF(V600E) mutation was more frequent in multifocal PTC patients with lymph node metastasis and diagnosis at later age.'},\n",
       "   {'pubmed': 23263826,\n",
       "    'text': 'we deduce that in the absence of mutation activation, B-Raf overexpression or downregulation is a protective event, since it delays the development of both malignant and benign thyroid tumors.'},\n",
       "   {'pubmed': 23274581,\n",
       "    'text': 'BRAF mutation is associated with esophageal squamous cell carcinoma.'},\n",
       "   {'pubmed': 23280049,\n",
       "    'text': 'Preoperative mutation screening for BRAF(V600E) does not meaningfully improve risk stratification and is unlikely to alter the initial management of patients with indeterminate nodules.'},\n",
       "   {'pubmed': 23287985,\n",
       "    'text': 'Pulmonary Langerhans cell histiocytosis appears to be a clonal proliferation that may or may not have BRAF V600E mutations.'},\n",
       "   {'pubmed': 23290787,\n",
       "    'text': 'Studies indicate that BRAF mutations are identified in 40-50% of patients with melanoma, and treatment with either of two BRAF inhibitors (vemurafenib, dabrafenib) or the MEK inhibitor trametinib is associated with improved clinical benefit.'},\n",
       "   {'pubmed': 23297805,\n",
       "    'text': 'No point mutations were identified in BRAF codon Val600Glu in the studied colorectal adenocarcinomas in the Turkish population.'},\n",
       "   {'pubmed': 23307859,\n",
       "    'text': 'High BRAF is associated with metastatic melanoma.'},\n",
       "   {'pubmed': 23310942,\n",
       "    'text': 'This study shows that BRAF mutation occurs in Nigerian colorectal cancers.'},\n",
       "   {'pubmed': 23317446,\n",
       "    'text': 'Results demonstrated the action of Dabrafenib and the inhibition of MAPK pathway in melanoma cell lines carrying BRAFV600D/R mutations; these results could be helpful to enlarge the number of patients who may benefit of a more effective targeted treatment'},\n",
       "   {'pubmed': 23324583,\n",
       "    'text': 'BRAF mutations is associated with colorectal cancer.'},\n",
       "   {'pubmed': 23334329,\n",
       "    'text': 'Human neural crest progenitor cells are susceptible to BRAF(V600E)-induced transformation.'},\n",
       "   {'pubmed': 23343956,\n",
       "    'text': 'no association with BRAF-V600E mutation in gastroeosophageal tumors'},\n",
       "   {'pubmed': 23349307,\n",
       "    'text': 'Data indicate that besides confirming the constant presence of BRAF-V600E in all patients with hairy cell leukemia, phospho-ERK1/ERK2 expression was observed.'},\n",
       "   {'pubmed': 23352452,\n",
       "    'text': 'Ras pathway activation via EGF treatment induced strong binding between B-Raf and C-Raf and a low level of binding between B-Raf and A-Raf.'},\n",
       "   {'pubmed': 23354951,\n",
       "    'text': 'Alternative splicing of exons 14, 15, 15b, 16b and 16c occurs in a considerable fraction of BRAF mRNA in normal colon and colorectal cancer cells and is independent of the V600E mutational status of the parental allele.'},\n",
       "   {'pubmed': 23355004,\n",
       "    'text': 'The detected Merkel cell polyomavirus prevalence in non-small cell lung cancer in combination with the deregulated expression of BRAF and Bcl-2 genes suggests that these events are likely to contribute to the pathogenesis of non-small cell lung cancer.'},\n",
       "   {'pubmed': 23359496,\n",
       "    'text': 'Kidins220 is a novel T-cell receptor (TCR)-interacting protein that couples B-Raf to the TCR. Kidins220 is mandatory for sustained Erk signaling and is crucial for TCR-mediated T cell activation.'},\n",
       "   {'pubmed': 23370429,\n",
       "    'text': 'This is the first report of BRAF V600E mutation in endometrial cancer, indicating that it may contribute to tumorigenesis of endometrial cancer, although at a low frequency compared with KRAS mutations.'},\n",
       "   {'pubmed': 23370668,\n",
       "    'text': 'study suggests that highly aggressive papillary thyroid microcarcinoma may arise in a subset of patients with BRAF(V600E) mutation and tumors greater than 5 mm; multivariate analysis showed that tumor recurrence was not associated with BRAF(V600E)mutation'},\n",
       "   ...],\n",
       "  'genomic_pos': {'chr': '7',\n",
       "   'end': 140924928,\n",
       "   'ensemblgene': 'ENSG00000157764',\n",
       "   'start': 140719327,\n",
       "   'strand': -1},\n",
       "  'genomic_pos_hg19': {'chr': '7',\n",
       "   'end': 140624564,\n",
       "   'start': 140419127,\n",
       "   'strand': -1},\n",
       "  'go': {'BP': [{'evidence': 'IBA',\n",
       "     'gocategory': 'BP',\n",
       "     'id': 'GO:0000165',\n",
       "     'pubmed': 21873635,\n",
       "     'term': 'MAPK cascade'},\n",
       "    {'evidence': 'TAS',\n",
       "     'gocategory': 'BP',\n",
       "     'id': 'GO:0000165',\n",
       "     'term': 'MAPK cascade'},\n",
       "    {'evidence': 'IEA',\n",
       "     'gocategory': 'BP',\n",
       "     'id': 'GO:0000186',\n",
       "     'term': 'activation of MAPKK activity'},\n",
       "    {'evidence': 'IEA',\n",
       "     'gocategory': 'BP',\n",
       "     'id': 'GO:0002318',\n",
       "     'term': 'myeloid progenitor cell differentiation'},\n",
       "    {'evidence': 'IDA',\n",
       "     'gocategory': 'BP',\n",
       "     'id': 'GO:0006468',\n",
       "     'pubmed': 17563371,\n",
       "     'term': 'protein phosphorylation'},\n",
       "    {'evidence': 'IEA',\n",
       "     'gocategory': 'BP',\n",
       "     'id': 'GO:0008542',\n",
       "     'term': 'visual learning'},\n",
       "    {'evidence': 'TAS',\n",
       "     'gocategory': 'BP',\n",
       "     'id': 'GO:0009887',\n",
       "     'pubmed': 9207797,\n",
       "     'term': 'animal organ morphogenesis'},\n",
       "    {'evidence': 'IMP',\n",
       "     'gocategory': 'BP',\n",
       "     'id': 'GO:0010628',\n",
       "     'pubmed': 22065586,\n",
       "     'term': 'positive regulation of gene expression'},\n",
       "    {'evidence': 'IEA',\n",
       "     'gocategory': 'BP',\n",
       "     'id': 'GO:0010764',\n",
       "     'term': 'negative regulation of fibroblast migration'},\n",
       "    {'evidence': 'IDA',\n",
       "     'gocategory': 'BP',\n",
       "     'id': 'GO:0010828',\n",
       "     'pubmed': 23010278,\n",
       "     'term': 'positive regulation of glucose transmembrane transport'},\n",
       "    {'evidence': 'IEA',\n",
       "     'gocategory': 'BP',\n",
       "     'id': 'GO:0030878',\n",
       "     'term': 'thyroid gland development'},\n",
       "    {'evidence': 'IDA',\n",
       "     'gocategory': 'BP',\n",
       "     'id': 'GO:0033138',\n",
       "     'pubmed': 19667065,\n",
       "     'term': 'positive regulation of peptidyl-serine phosphorylation'},\n",
       "    {'evidence': 'IEA',\n",
       "     'gocategory': 'BP',\n",
       "     'id': 'GO:0035019',\n",
       "     'term': 'somatic stem cell population maintenance'},\n",
       "    {'evidence': 'IEA',\n",
       "     'gocategory': 'BP',\n",
       "     'id': 'GO:0035690',\n",
       "     'term': 'cellular response to drug'},\n",
       "    {'evidence': 'IEA',\n",
       "     'gocategory': 'BP',\n",
       "     'id': 'GO:0042127',\n",
       "     'term': 'regulation of cell proliferation'},\n",
       "    {'evidence': 'IDA',\n",
       "     'gocategory': 'BP',\n",
       "     'id': 'GO:0043066',\n",
       "     'pubmed': 19667065,\n",
       "     'term': 'negative regulation of apoptotic process'},\n",
       "    {'evidence': 'IEA',\n",
       "     'gocategory': 'BP',\n",
       "     'id': 'GO:0043367',\n",
       "     'term': 'CD4-positive, alpha-beta T cell differentiation'},\n",
       "    {'evidence': 'IEA',\n",
       "     'gocategory': 'BP',\n",
       "     'id': 'GO:0043369',\n",
       "     'term': 'CD4-positive or CD8-positive, alpha-beta T cell lineage commitment'},\n",
       "    {'evidence': 'IEA',\n",
       "     'gocategory': 'BP',\n",
       "     'id': 'GO:0043434',\n",
       "     'term': 'response to peptide hormone'},\n",
       "    {'evidence': 'IEA',\n",
       "     'gocategory': 'BP',\n",
       "     'id': 'GO:0043524',\n",
       "     'term': 'negative regulation of neuron apoptotic process'},\n",
       "    {'evidence': 'IEA',\n",
       "     'gocategory': 'BP',\n",
       "     'id': 'GO:0045580',\n",
       "     'term': 'regulation of T cell differentiation'},\n",
       "    {'evidence': 'IEA',\n",
       "     'gocategory': 'BP',\n",
       "     'id': 'GO:0048538',\n",
       "     'term': 'thymus development'},\n",
       "    {'evidence': 'IEA',\n",
       "     'gocategory': 'BP',\n",
       "     'id': 'GO:0048680',\n",
       "     'term': 'positive regulation of axon regeneration'},\n",
       "    {'evidence': 'IEA',\n",
       "     'gocategory': 'BP',\n",
       "     'id': 'GO:0050772',\n",
       "     'term': 'positive regulation of axonogenesis'},\n",
       "    {'evidence': 'IEA',\n",
       "     'gocategory': 'BP',\n",
       "     'id': 'GO:0050852',\n",
       "     'term': 'T cell receptor signaling pathway'},\n",
       "    {'evidence': 'IEA',\n",
       "     'gocategory': 'BP',\n",
       "     'id': 'GO:0051291',\n",
       "     'term': 'protein heterooligomerization'},\n",
       "    {'evidence': 'IEA',\n",
       "     'gocategory': 'BP',\n",
       "     'id': 'GO:0051496',\n",
       "     'term': 'positive regulation of stress fiber assembly'},\n",
       "    {'evidence': 'IEA',\n",
       "     'gocategory': 'BP',\n",
       "     'id': 'GO:0051591',\n",
       "     'term': 'response to cAMP'},\n",
       "    {'evidence': 'IEA',\n",
       "     'gocategory': 'BP',\n",
       "     'id': 'GO:0060291',\n",
       "     'term': 'long-term synaptic potentiation'},\n",
       "    {'evidence': 'IEA',\n",
       "     'gocategory': 'BP',\n",
       "     'id': 'GO:0060323',\n",
       "     'term': 'head morphogenesis'},\n",
       "    {'evidence': 'IEA',\n",
       "     'gocategory': 'BP',\n",
       "     'id': 'GO:0060324',\n",
       "     'term': 'face development'},\n",
       "    {'evidence': 'IDA',\n",
       "     'gocategory': 'BP',\n",
       "     'id': 'GO:0070374',\n",
       "     'pubmed': 22065586,\n",
       "     'term': 'positive regulation of ERK1 and ERK2 cascade'},\n",
       "    {'evidence': 'IMP',\n",
       "     'gocategory': 'BP',\n",
       "     'id': 'GO:0070413',\n",
       "     'pubmed': 9837904,\n",
       "     'term': 'trehalose metabolism in response to stress'},\n",
       "    {'evidence': 'IDA',\n",
       "     'gocategory': 'BP',\n",
       "     'id': 'GO:0071277',\n",
       "     'pubmed': 18567582,\n",
       "     'term': 'cellular response to calcium ion'},\n",
       "    {'evidence': 'IDA',\n",
       "     'gocategory': 'BP',\n",
       "     'id': 'GO:0090150',\n",
       "     'pubmed': 23010278,\n",
       "     'term': 'establishment of protein localization to membrane'},\n",
       "    {'evidence': 'IEA',\n",
       "     'gocategory': 'BP',\n",
       "     'id': 'GO:1900026',\n",
       "     'term': 'positive regulation of substrate adhesion-dependent cell spreading'},\n",
       "    {'evidence': 'IEA',\n",
       "     'gocategory': 'BP',\n",
       "     'id': 'GO:1990090',\n",
       "     'term': 'cellular response to nerve growth factor stimulus'},\n",
       "    {'evidence': 'IEA',\n",
       "     'gocategory': 'BP',\n",
       "     'id': 'GO:2000301',\n",
       "     'term': 'negative regulation of synaptic vesicle exocytosis'},\n",
       "    {'evidence': 'IEA',\n",
       "     'gocategory': 'BP',\n",
       "     'id': 'GO:2000352',\n",
       "     'term': 'negative regulation of endothelial cell apoptotic process'}],\n",
       "   'CC': [{'evidence': 'IEA',\n",
       "     'gocategory': 'CC',\n",
       "     'id': 'GO:0005634',\n",
       "     'term': 'nucleus'},\n",
       "    {'evidence': 'IBA',\n",
       "     'gocategory': 'CC',\n",
       "     'id': 'GO:0005739',\n",
       "     'pubmed': 21873635,\n",
       "     'term': 'mitochondrion'},\n",
       "    {'evidence': 'IBA',\n",
       "     'gocategory': 'CC',\n",
       "     'id': 'GO:0005829',\n",
       "     'pubmed': 21873635,\n",
       "     'term': 'cytosol'},\n",
       "    {'evidence': 'IDA',\n",
       "     'gocategory': 'CC',\n",
       "     'id': 'GO:0005829',\n",
       "     'term': 'cytosol'},\n",
       "    {'evidence': 'TAS',\n",
       "     'gocategory': 'CC',\n",
       "     'id': 'GO:0005829',\n",
       "     'term': 'cytosol'},\n",
       "    {'evidence': 'IBA',\n",
       "     'gocategory': 'CC',\n",
       "     'id': 'GO:0005886',\n",
       "     'pubmed': 21873635,\n",
       "     'term': 'plasma membrane'},\n",
       "    {'evidence': 'TAS',\n",
       "     'gocategory': 'CC',\n",
       "     'id': 'GO:0005886',\n",
       "     'term': 'plasma membrane'},\n",
       "    {'evidence': 'IEA',\n",
       "     'gocategory': 'CC',\n",
       "     'id': 'GO:0043005',\n",
       "     'term': 'neuron projection'},\n",
       "    {'evidence': 'IDA',\n",
       "     'gocategory': 'CC',\n",
       "     'id': 'GO:0043231',\n",
       "     'term': 'intracellular membrane-bounded organelle'},\n",
       "    {'evidence': 'IEA',\n",
       "     'gocategory': 'CC',\n",
       "     'id': 'GO:0044297',\n",
       "     'term': 'cell body'}],\n",
       "   'MF': [{'category': 'MF',\n",
       "     'evidence': 'IDA',\n",
       "     'id': 'GO:0004672',\n",
       "     'pubmed': 17563371,\n",
       "     'term': 'protein kinase activity'},\n",
       "    {'category': 'MF',\n",
       "     'evidence': 'IBA',\n",
       "     'id': 'GO:0004674',\n",
       "     'pubmed': 21873635,\n",
       "     'term': 'protein serine/threonine kinase activity'},\n",
       "    {'category': 'MF',\n",
       "     'evidence': 'IDA',\n",
       "     'id': 'GO:0004674',\n",
       "     'pubmed': 19667065,\n",
       "     'term': 'protein serine/threonine kinase activity'},\n",
       "    {'category': 'MF',\n",
       "     'evidence': 'IEA',\n",
       "     'id': 'GO:0004709',\n",
       "     'term': 'MAP kinase kinase kinase activity'},\n",
       "    {'category': 'MF',\n",
       "     'evidence': 'IDA',\n",
       "     'id': 'GO:0005509',\n",
       "     'pubmed': 18567582,\n",
       "     'term': 'calcium ion binding'},\n",
       "    {'category': 'MF',\n",
       "     'evidence': 'IPI',\n",
       "     'id': 'GO:0005515',\n",
       "     'pubmed': [12620389,\n",
       "      15161933,\n",
       "      16810323,\n",
       "      16888650,\n",
       "      17380122,\n",
       "      17563371,\n",
       "      17979178,\n",
       "      18567582,\n",
       "      20130576,\n",
       "      20141835,\n",
       "      21441910,\n",
       "      21478863,\n",
       "      22169110,\n",
       "      22510884,\n",
       "      22939624,\n",
       "      23153539,\n",
       "      23680146,\n",
       "      23934108,\n",
       "      24255178,\n",
       "      24441586,\n",
       "      24746704,\n",
       "      25155755,\n",
       "      25241761,\n",
       "      25437913,\n",
       "      25600339,\n",
       "      26165597,\n",
       "      26466569,\n",
       "      26496610,\n",
       "      27353360],\n",
       "     'term': 'protein binding'},\n",
       "    {'category': 'MF',\n",
       "     'evidence': 'IEA',\n",
       "     'id': 'GO:0005524',\n",
       "     'term': 'ATP binding'},\n",
       "    {'category': 'MF',\n",
       "     'evidence': 'IPI',\n",
       "     'id': 'GO:0031267',\n",
       "     'pubmed': 12194967,\n",
       "     'qualifier': 'NOT',\n",
       "     'term': 'small GTPase binding'},\n",
       "    {'category': 'MF',\n",
       "     'evidence': 'IEA',\n",
       "     'id': 'GO:0031434',\n",
       "     'term': 'mitogen-activated protein kinase kinase binding'},\n",
       "    {'category': 'MF',\n",
       "     'evidence': 'IPI',\n",
       "     'id': 'GO:0042802',\n",
       "     'pubmed': [16858395, 19727074, 22169110, 22510884, 25155755, 25437913],\n",
       "     'term': 'identical protein binding'},\n",
       "    {'category': 'MF',\n",
       "     'evidence': 'IEA',\n",
       "     'id': 'GO:0046982',\n",
       "     'term': 'protein heterodimerization activity'}]},\n",
       "  'homologene': {'genes': [[6239, 177436],\n",
       "    [7165, 1278538],\n",
       "    [7227, 31221],\n",
       "    [7955, 403065],\n",
       "    [8364, 779570],\n",
       "    [9031, 396239],\n",
       "    [9544, 693554],\n",
       "    [9598, 463781],\n",
       "    [9606, 673],\n",
       "    [9615, 475526],\n",
       "    [9913, 536051],\n",
       "    [10090, 109880],\n",
       "    [10116, 114486]],\n",
       "   'id': 3197},\n",
       "  'interpro': [{'desc': 'Protein kinase domain',\n",
       "    'id': 'IPR000719',\n",
       "    'short_desc': 'Prot_kinase_dom'},\n",
       "   {'desc': 'Serine-threonine/tyrosine-protein kinase, catalytic domain',\n",
       "    'id': 'IPR001245',\n",
       "    'short_desc': 'Ser-Thr/Tyr_kinase_cat_dom'},\n",
       "   {'desc': 'Protein kinase C-like, phorbol ester/diacylglycerol-binding domain',\n",
       "    'id': 'IPR002219',\n",
       "    'short_desc': 'PE/DAG-bd'},\n",
       "   {'desc': 'Raf-like Ras-binding',\n",
       "    'id': 'IPR003116',\n",
       "    'short_desc': 'RBD_dom'},\n",
       "   {'desc': 'Serine/threonine-protein kinase, active site',\n",
       "    'id': 'IPR008271',\n",
       "    'short_desc': 'Ser/Thr_kinase_AS'},\n",
       "   {'desc': 'Protein kinase-like domain superfamily',\n",
       "    'id': 'IPR011009',\n",
       "    'short_desc': 'Kinase-like_dom_sf'},\n",
       "   {'desc': 'Protein kinase, ATP binding site',\n",
       "    'id': 'IPR017441',\n",
       "    'short_desc': 'Protein_kinase_ATP_BS'},\n",
       "   {'desc': 'Diacylglycerol/phorbol-ester binding',\n",
       "    'id': 'IPR020454',\n",
       "    'short_desc': 'DAG/PE-bd'},\n",
       "   {'desc': 'Ubiquitin-like domain superfamily',\n",
       "    'id': 'IPR029071',\n",
       "    'short_desc': 'Ubiquitin-like_domsf'}],\n",
       "  'ipi': 'IPI00303797',\n",
       "  'map_location': '7q34',\n",
       "  'name': 'B-Raf proto-oncogene, serine/threonine kinase',\n",
       "  'other_names': ['94 kDa B-raf protein',\n",
       "   'B-Raf proto-oncogene serine/threonine-protein kinase (p94)',\n",
       "   'B-Raf serine/threonine-protein',\n",
       "   'murine sarcoma viral (v-raf) oncogene homolog B1',\n",
       "   'proto-oncogene B-Raf',\n",
       "   'serine/threonine-protein kinase B-raf',\n",
       "   'v-raf murine sarcoma viral oncogene homolog B',\n",
       "   'v-raf murine sarcoma viral oncogene homolog B1'],\n",
       "  'pantherdb': {'HGNC': '1097',\n",
       "   'ortholog': [{'MGI': '88190',\n",
       "     'ortholog_type': 'LDO',\n",
       "     'panther_family': 'PTHR44329',\n",
       "     'taxid': 10090,\n",
       "     'uniprot_kb': 'P28028'},\n",
       "    {'RGD': '619908',\n",
       "     'ortholog_type': 'LDO',\n",
       "     'panther_family': 'PTHR44329',\n",
       "     'taxid': 10116,\n",
       "     'uniprot_kb': 'F1M9C3'},\n",
       "    {'Ensembl': 'ENSGALG00000012865',\n",
       "     'ortholog_type': 'LDO',\n",
       "     'panther_family': 'PTHR44329',\n",
       "     'taxid': 9031,\n",
       "     'uniprot_kb': 'Q04982'},\n",
       "    {'ZFIN': 'ZDB-GENE-040805-1',\n",
       "     'ortholog_type': 'LDO',\n",
       "     'panther_family': 'PTHR44329',\n",
       "     'taxid': 7955,\n",
       "     'uniprot_kb': 'Q1LYG2'},\n",
       "    {'WormBase': 'WBGene00003030',\n",
       "     'ortholog_type': 'LDO',\n",
       "     'panther_family': 'PTHR44329',\n",
       "     'taxid': 6239,\n",
       "     'uniprot_kb': 'Q07292'},\n",
       "    {'FlyBase': 'FBgn0003079',\n",
       "     'ortholog_type': 'LDO',\n",
       "     'panther_family': 'PTHR44329',\n",
       "     'taxid': 7227,\n",
       "     'uniprot_kb': 'P11346'},\n",
       "    {'HGNC': '42952',\n",
       "     'ortholog_type': 'P',\n",
       "     'panther_family': 'PTHR44329',\n",
       "     'taxid': 9606,\n",
       "     'uniprot_kb': 'V9GXZ4'},\n",
       "    {'HGNC': '26617',\n",
       "     'ortholog_type': 'P',\n",
       "     'panther_family': 'PTHR44329',\n",
       "     'taxid': 9606,\n",
       "     'uniprot_kb': 'Q8NB16'},\n",
       "    {'HGNC': '6850',\n",
       "     'ortholog_type': 'P',\n",
       "     'panther_family': 'PTHR44329',\n",
       "     'taxid': 9606,\n",
       "     'uniprot_kb': 'Q16584'},\n",
       "    {'HGNC': '10019',\n",
       "     'ortholog_type': 'P',\n",
       "     'panther_family': 'PTHR44329',\n",
       "     'taxid': 9606,\n",
       "     'uniprot_kb': 'Q13546'},\n",
       "    {'HGNC': '10020',\n",
       "     'ortholog_type': 'P',\n",
       "     'panther_family': 'PTHR44329',\n",
       "     'taxid': 9606,\n",
       "     'uniprot_kb': 'O43353'},\n",
       "    {'HGNC': '6851',\n",
       "     'ortholog_type': 'P',\n",
       "     'panther_family': 'PTHR44329',\n",
       "     'taxid': 9606,\n",
       "     'uniprot_kb': 'Q12852'},\n",
       "    {'HGNC': '6849',\n",
       "     'ortholog_type': 'P',\n",
       "     'panther_family': 'PTHR44329',\n",
       "     'taxid': 9606,\n",
       "     'uniprot_kb': 'Q02779'},\n",
       "    {'HGNC': '6852',\n",
       "     'ortholog_type': 'P',\n",
       "     'panther_family': 'PTHR44329',\n",
       "     'taxid': 9606,\n",
       "     'uniprot_kb': 'O43283'},\n",
       "    {'HGNC': '6861',\n",
       "     'ortholog_type': 'P',\n",
       "     'panther_family': 'PTHR44329',\n",
       "     'taxid': 9606,\n",
       "     'uniprot_kb': 'P80192'},\n",
       "    {'dictyBase': 'DDB_G0273445',\n",
       "     'ortholog_type': 'LDO',\n",
       "     'panther_family': 'PTHR44329',\n",
       "     'taxid': 352472,\n",
       "     'uniprot_kb': 'Q86AT8'},\n",
       "    {'dictyBase': 'DDB_G0278909',\n",
       "     'ortholog_type': 'O',\n",
       "     'panther_family': 'PTHR44329',\n",
       "     'taxid': 352472,\n",
       "     'uniprot_kb': 'Q54XI9'},\n",
       "    {'dictyBase': 'DDB_G0289555',\n",
       "     'ortholog_type': 'O',\n",
       "     'panther_family': 'PTHR44329',\n",
       "     'taxid': 352472,\n",
       "     'uniprot_kb': 'Q54HC6'},\n",
       "    {'dictyBase': 'DDB_G0278535',\n",
       "     'ortholog_type': 'O',\n",
       "     'panther_family': 'PTHR44329',\n",
       "     'taxid': 352472,\n",
       "     'uniprot_kb': 'Q54XX5'},\n",
       "    {'TAIR': 'AT4G24480',\n",
       "     'ortholog_type': 'O',\n",
       "     'panther_family': 'PTHR44329',\n",
       "     'taxid': 3702,\n",
       "     'uniprot_kb': 'F4JQX7'},\n",
       "    {'TAIR': 'AT5G03730',\n",
       "     'ortholog_type': 'O',\n",
       "     'panther_family': 'PTHR44329',\n",
       "     'taxid': 3702,\n",
       "     'uniprot_kb': 'Q05609'}],\n",
       "   'uniprot_kb': 'P15056'},\n",
       "  'pathway': {'kegg': [{'id': 'hsa04010',\n",
       "     'name': 'MAPK signaling pathway - Homo sapiens (human)'},\n",
       "    {'id': 'hsa04012',\n",
       "     'name': 'ErbB signaling pathway - Homo sapiens (human)'},\n",
       "    {'id': 'hsa04015',\n",
       "     'name': 'Rap1 signaling pathway - Homo sapiens (human)'},\n",
       "    {'id': 'hsa04024',\n",
       "     'name': 'cAMP signaling pathway - Homo sapiens (human)'},\n",
       "    {'id': 'hsa04062',\n",
       "     'name': 'Chemokine signaling pathway - Homo sapiens (human)'},\n",
       "    {'id': 'hsa04068',\n",
       "     'name': 'FoxO signaling pathway - Homo sapiens (human)'},\n",
       "    {'id': 'hsa04150',\n",
       "     'name': 'mTOR signaling pathway - Homo sapiens (human)'},\n",
       "    {'id': 'hsa04270',\n",
       "     'name': 'Vascular smooth muscle contraction - Homo sapiens (human)'},\n",
       "    {'id': 'hsa04510', 'name': 'Focal adhesion - Homo sapiens (human)'},\n",
       "    {'id': 'hsa04650',\n",
       "     'name': 'Natural killer cell mediated cytotoxicity - Homo sapiens (human)'},\n",
       "    {'id': 'hsa04720',\n",
       "     'name': 'Long-term potentiation - Homo sapiens (human)'},\n",
       "    {'id': 'hsa04722',\n",
       "     'name': 'Neurotrophin signaling pathway - Homo sapiens (human)'},\n",
       "    {'id': 'hsa04726', 'name': 'Serotonergic synapse - Homo sapiens (human)'},\n",
       "    {'id': 'hsa04730', 'name': 'Long-term depression - Homo sapiens (human)'},\n",
       "    {'id': 'hsa04810',\n",
       "     'name': 'Regulation of actin cytoskeleton - Homo sapiens (human)'},\n",
       "    {'id': 'hsa04910',\n",
       "     'name': 'Insulin signaling pathway - Homo sapiens (human)'},\n",
       "    {'id': 'hsa04914',\n",
       "     'name': 'Progesterone-mediated oocyte maturation - Homo sapiens (human)'},\n",
       "    {'id': 'hsa04934', 'name': 'Cushing,s syndrome - Homo sapiens (human)'},\n",
       "    {'id': 'hsa05034', 'name': 'Alcoholism - Homo sapiens (human)'},\n",
       "    {'id': 'hsa05160', 'name': 'Hepatitis C - Homo sapiens (human)'},\n",
       "    {'id': 'hsa05200', 'name': 'Pathways in cancer - Homo sapiens (human)'},\n",
       "    {'id': 'hsa05205',\n",
       "     'name': 'Proteoglycans in cancer - Homo sapiens (human)'},\n",
       "    {'id': 'hsa05210', 'name': 'Colorectal cancer - Homo sapiens (human)'},\n",
       "    {'id': 'hsa05211', 'name': 'Renal cell carcinoma - Homo sapiens (human)'},\n",
       "    {'id': 'hsa05212', 'name': 'Pancreatic cancer - Homo sapiens (human)'},\n",
       "    {'id': 'hsa05213', 'name': 'Endometrial cancer - Homo sapiens (human)'},\n",
       "    {'id': 'hsa05214', 'name': 'Glioma - Homo sapiens (human)'},\n",
       "    {'id': 'hsa05215', 'name': 'Prostate cancer - Homo sapiens (human)'},\n",
       "    {'id': 'hsa05216', 'name': 'Thyroid cancer - Homo sapiens (human)'},\n",
       "    {'id': 'hsa05218', 'name': 'Melanoma - Homo sapiens (human)'},\n",
       "    {'id': 'hsa05219', 'name': 'Bladder cancer - Homo sapiens (human)'},\n",
       "    {'id': 'hsa05220',\n",
       "     'name': 'Chronic myeloid leukemia - Homo sapiens (human)'},\n",
       "    {'id': 'hsa05221',\n",
       "     'name': 'Acute myeloid leukemia - Homo sapiens (human)'},\n",
       "    {'id': 'hsa05223',\n",
       "     'name': 'Non-small cell lung cancer - Homo sapiens (human)'},\n",
       "    {'id': 'hsa05224', 'name': 'Breast cancer - Homo sapiens (human)'},\n",
       "    {'id': 'hsa05225',\n",
       "     'name': 'Hepatocellular carcinoma - Homo sapiens (human)'},\n",
       "    {'id': 'hsa05226', 'name': 'Gastric cancer - Homo sapiens (human)'}],\n",
       "   'netpath': {'id': 'Pathway_EGFR1', 'name': 'EGFR1'},\n",
       "   'pharmgkb': [{'id': 'PA165959425', 'name': 'Pathway_PA165959425'},\n",
       "    {'id': 'PA165959584', 'name': 'Sorafenib Pharmacodynamics'},\n",
       "    {'id': 'PA165980050', 'name': 'Vemurafenib Pathway, Pharmacodynamics'},\n",
       "    {'id': 'PA165980050', 'name': 'update your name in edit mode'}],\n",
       "   'pid': [{'id': 'cd8tcrdownstreampathway',\n",
       "     'name': 'Downstream signaling in na&#xef;ve CD8+ T cells'},\n",
       "    {'id': 'cdc42_pathway', 'name': 'CDC42 signaling events'},\n",
       "    {'id': 'erbb1_downstream_pathway', 'name': 'ErbB1 downstream signaling'},\n",
       "    {'id': 'fak_pathway',\n",
       "     'name': 'Signaling events mediated by focal adhesion kinase'},\n",
       "    {'id': 'mapktrkpathway',\n",
       "     'name': 'Trk receptor signaling mediated by the MAPK pathway'},\n",
       "    {'id': 'mtor_4pathway', 'name': 'mTOR signaling pathway'},\n",
       "    {'id': 'pdgfrbpathway', 'name': 'PDGFR-beta signaling pathway'},\n",
       "    {'id': 'tcrraspathway', 'name': 'Ras signaling in the CD4+ TCR pathway'},\n",
       "    {'id': 'vegfr1_2_pathway',\n",
       "     'name': 'Signaling events mediated by VEGFR1 and VEGFR2'}],\n",
       "   'reactome': [{'id': 'R-HSA-112314',\n",
       "     'name': 'Neurotransmitter receptors and postsynaptic signal transmission'},\n",
       "    {'id': 'R-HSA-112315', 'name': 'Transmission across Chemical Synapses'},\n",
       "    {'id': 'R-HSA-112316', 'name': 'Neuronal System'},\n",
       "    {'id': 'R-HSA-1295596', 'name': 'Spry regulation of FGF signaling'},\n",
       "    {'id': 'R-HSA-162582', 'name': 'Signal Transduction'},\n",
       "    {'id': 'R-HSA-162582', 'name': 'Signal Transduction'},\n",
       "    {'id': 'R-HSA-1643685', 'name': 'Disease'},\n",
       "    {'id': 'R-HSA-166520', 'name': 'Signaling by NTRKs'},\n",
       "    {'id': 'R-HSA-169893', 'name': 'Prolonged ERK activation events'},\n",
       "    {'id': 'R-HSA-170968', 'name': 'Frs2-mediated activation'},\n",
       "    {'id': 'R-HSA-170984', 'name': 'ARMS-mediated activation'},\n",
       "    {'id': 'R-HSA-187037', 'name': 'Signaling by NTRK1 (TRKA)'},\n",
       "    {'id': 'R-HSA-187687', 'name': 'Signalling to ERKs'},\n",
       "    {'id': 'R-HSA-187706', 'name': 'Signalling to p38 via RIT and RIN'},\n",
       "    {'id': 'R-HSA-190236', 'name': 'Signaling by FGFR'},\n",
       "    {'id': 'R-HSA-438064', 'name': 'Post NMDA receptor activation events'},\n",
       "    {'id': 'R-HSA-442742',\n",
       "     'name': 'CREB phosphorylation through the activation of Ras'},\n",
       "    {'id': 'R-HSA-442755',\n",
       "     'name': 'Activation of NMDA receptors and postsynaptic events'},\n",
       "    {'id': 'R-HSA-5654726', 'name': 'Negative regulation of FGFR1 signaling'},\n",
       "    {'id': 'R-HSA-5654727', 'name': 'Negative regulation of FGFR2 signaling'},\n",
       "    {'id': 'R-HSA-5654732', 'name': 'Negative regulation of FGFR3 signaling'},\n",
       "    {'id': 'R-HSA-5654733', 'name': 'Negative regulation of FGFR4 signaling'},\n",
       "    {'id': 'R-HSA-5654736', 'name': 'Signaling by FGFR1'},\n",
       "    {'id': 'R-HSA-5654738', 'name': 'Signaling by FGFR2'},\n",
       "    {'id': 'R-HSA-5654741', 'name': 'Signaling by FGFR3'},\n",
       "    {'id': 'R-HSA-5654743', 'name': 'Signaling by FGFR4'},\n",
       "    {'id': 'R-HSA-5663202', 'name': 'Diseases of signal transduction'},\n",
       "    {'id': 'R-HSA-5673000', 'name': 'RAF activation'},\n",
       "    {'id': 'R-HSA-5673001', 'name': 'RAF/MAP kinase cascade'},\n",
       "    {'id': 'R-HSA-5674135', 'name': 'MAP2K and MAPK activation'},\n",
       "    {'id': 'R-HSA-5674499',\n",
       "     'name': 'Negative feedback regulation of MAPK pathway'},\n",
       "    {'id': 'R-HSA-5675221', 'name': 'Negative regulation of MAPK pathway'},\n",
       "    {'id': 'R-HSA-5683057', 'name': 'MAPK family signaling cascades'},\n",
       "    {'id': 'R-HSA-5684996', 'name': 'MAPK1/MAPK3 signaling'},\n",
       "    {'id': 'R-HSA-6802946',\n",
       "     'name': 'Signaling by moderate kinase activity BRAF mutants'},\n",
       "    {'id': 'R-HSA-6802948',\n",
       "     'name': 'Signaling by high-kinase activity BRAF mutants'},\n",
       "    {'id': 'R-HSA-6802949', 'name': 'Signaling by RAS mutants'},\n",
       "    {'id': 'R-HSA-6802952', 'name': 'Signaling by BRAF and RAF fusions'},\n",
       "    {'id': 'R-HSA-6802955',\n",
       "     'name': 'Paradoxical activation of RAF signaling by kinase inactive BRAF'},\n",
       "    {'id': 'R-HSA-6802957', 'name': 'Oncogenic MAPK signaling'},\n",
       "    {'id': 'R-HSA-9006934', 'name': 'Signaling by Receptor Tyrosine Kinases'},\n",
       "    {'id': 'R-HSA-9006934', 'name': 'Signaling by Receptor Tyrosine Kinases'}],\n",
       "   'smpdb': [{'id': 'SMP00320',\n",
       "     'name': 'Intracellular Signalling Through Adenosine Receptor A2a and Adenosine'},\n",
       "    {'id': 'SMP00321',\n",
       "     'name': 'Intracellular Signalling Through Adenosine Receptor A2b and Adenosine'}],\n",
       "   'wikipathways': [{'id': 'WP185', 'name': 'Integrin-mediated Cell Adhesion'},\n",
       "    {'id': 'WP2032',\n",
       "     'name': 'Human Thyroid Stimulating Hormone (TSH) signaling pathway'},\n",
       "    {'id': 'WP2261', 'name': 'Signaling Pathways in Glioblastoma'},\n",
       "    {'id': 'WP23', 'name': 'B Cell Receptor Signaling Pathway'},\n",
       "    {'id': 'WP2355',\n",
       "     'name': 'Corticotropin-releasing hormone signaling pathway'},\n",
       "    {'id': 'WP2512', 'name': 'Integrated Lung Cancer Pathway'},\n",
       "    {'id': 'WP2571', 'name': 'Polycystic Kidney Disease Pathway'},\n",
       "    {'id': 'WP2828', 'name': 'Bladder Cancer'},\n",
       "    {'id': 'WP306', 'name': 'Focal Adhesion'},\n",
       "    {'id': 'WP3676', 'name': 'BDNF-TrkB Signaling'},\n",
       "    {'id': 'WP382', 'name': 'MAPK Signaling Pathway'},\n",
       "    {'id': 'WP3929', 'name': 'Chemokine signaling pathway'},\n",
       "    {'id': 'WP3931', 'name': 'ESC Pluripotency Pathways'},\n",
       "    {'id': 'WP4155', 'name': 'Endometrial cancer'},\n",
       "    {'id': 'WP4205', 'name': 'MET in type 1 papillary renal cell carcinoma'},\n",
       "    {'id': 'WP4216',\n",
       "     'name': 'Chromosomal and microsatellite instability in colorectal cancer'},\n",
       "    {'id': 'WP422', 'name': 'MAPK Cascade'},\n",
       "    {'id': 'WP437', 'name': 'EGF-EGFR Signaling Pathway'},\n",
       "    {'id': 'WP51', 'name': 'Regulation of Actin Cytoskeleton'},\n",
       "    {'id': 'WP615', 'name': 'Senescence and Autophagy in Cancer'},\n",
       "    {'id': 'WP712', 'name': 'Estrogen signaling pathway'},\n",
       "    {'id': 'WP722', 'name': 'Serotonin HTR1 Group and FOS Pathway'},\n",
       "    {'id': 'WP734', 'name': 'Serotonin Receptor 4-6-7 and NR3C Signaling'}]},\n",
       "  'pdb': ['1UWH',\n",
       "   '1UWJ',\n",
       "   '2FB8',\n",
       "   '2L05',\n",
       "   '3C4C',\n",
       "   '3D4Q',\n",
       "   '3IDP',\n",
       "   '3II5',\n",
       "   '3NY5',\n",
       "   '3OG7',\n",
       "   '3PPJ',\n",
       "   '3PPK',\n",
       "   '3PRF',\n",
       "   '3PRI',\n",
       "   '3PSB',\n",
       "   '3PSD',\n",
       "   '3Q4C',\n",
       "   '3Q96',\n",
       "   '3SKC',\n",
       "   '3TV4',\n",
       "   '3TV6',\n",
       "   '4CQE',\n",
       "   '4DBN',\n",
       "   '4E26',\n",
       "   '4E4X',\n",
       "   '4EHE',\n",
       "   '4EHG',\n",
       "   '4FC0',\n",
       "   '4FK3',\n",
       "   '4G9C',\n",
       "   '4G9R',\n",
       "   '4H58',\n",
       "   '4JVG',\n",
       "   '4KSP',\n",
       "   '4KSQ',\n",
       "   '4MBJ',\n",
       "   '4MNE',\n",
       "   '4MNF',\n",
       "   '4PP7',\n",
       "   '4R5Y',\n",
       "   '4RZV',\n",
       "   '4RZW',\n",
       "   '4WO5',\n",
       "   '4XV1',\n",
       "   '4XV2',\n",
       "   '4XV3',\n",
       "   '4XV9',\n",
       "   '4YHT',\n",
       "   '5C9C',\n",
       "   '5CSW',\n",
       "   '5CSX',\n",
       "   '5CT7',\n",
       "   '5FD2',\n",
       "   '5HI2',\n",
       "   '5HID',\n",
       "   '5HIE',\n",
       "   '5ITA',\n",
       "   '5J17',\n",
       "   '5J18',\n",
       "   '5J2R',\n",
       "   '5JRQ',\n",
       "   '5JSM',\n",
       "   '5JT2',\n",
       "   '5VAL',\n",
       "   '5VAM',\n",
       "   '5VR3',\n",
       "   '5VYK',\n",
       "   '6B8U',\n",
       "   '6CAD'],\n",
       "  'pfam': ['PF00130', 'PF02196', 'PF07714'],\n",
       "  'pharmgkb': 'PA25408',\n",
       "  'pharos': {'target_id': 1932},\n",
       "  'pir': 'A57977',\n",
       "  'prosite': ['PS50011', 'PS50081', 'PS50898'],\n",
       "  'reagent': {'GNF_Qia_hs-genome_v1_siRNA': [{'id': 'GNF246467',\n",
       "     'relationship': 'is'},\n",
       "    {'id': 'GNF246468', 'relationship': 'is'},\n",
       "    {'id': 'GNF246469', 'relationship': 'is'},\n",
       "    {'id': 'GNF246470', 'relationship': 'is'}],\n",
       "   'GNF_hs-Origene': [{'id': 'GNF033097', 'relationship': 'similar to'},\n",
       "    {'id': 'GNF036220', 'relationship': 'is'},\n",
       "    {'id': 'GNF046927', 'relationship': 'weakly similar to'}],\n",
       "   'GNF_hs-druggable_lenti-shRNA': [{'id': 'GNF092340', 'relationship': 'is'},\n",
       "    {'id': 'GNF092341', 'relationship': 'is'},\n",
       "    {'id': 'GNF092342', 'relationship': 'is'}],\n",
       "   'GNF_hs-druggable_plasmid-shRNA': [{'id': 'GNF051312',\n",
       "     'relationship': 'is'},\n",
       "    {'id': 'GNF056078', 'relationship': 'is'},\n",
       "    {'id': 'GNF060793', 'relationship': 'is'}],\n",
       "   'GNF_hs-druggable_siRNA': [{'id': 'GNF067889', 'relationship': 'is'},\n",
       "    {'id': 'GNF067890', 'relationship': 'is'}],\n",
       "   'GNF_hs-pkinase_IDT-siRNA': [{'id': 'GNF165248', 'relationship': 'is'},\n",
       "    {'id': 'GNF165249', 'relationship': 'is'},\n",
       "    {'id': 'GNF165250', 'relationship': 'is'},\n",
       "    {'id': 'GNF165251', 'relationship': 'is'}],\n",
       "   'GNF_mm+hs-MGC': {'id': 'GNF279495', 'relationship': 'is'},\n",
       "   'Invitrogen_IVTHSSIPKv2': [{'id': 'GNF324655', 'relationship': 'is'},\n",
       "    {'id': 'GNF324656', 'relationship': 'is'}],\n",
       "   'NIBRI_hs-Secretome_pDEST': {'id': 'GNF339157', 'relationship': 'is'},\n",
       "   'NOVART_hs-genome_siRNA': [{'id': 'GNF092847', 'relationship': 'is'},\n",
       "    {'id': 'GNF132545', 'relationship': 'is'}]},\n",
       "  'refseq': {'genomic': ['NC_000007.14', 'NG_007873.3'],\n",
       "   'protein': ['NP_001341538.1',\n",
       "    'NP_004324.2',\n",
       "    'XP_016868047.1',\n",
       "    'XP_016868048.1'],\n",
       "   'rna': ['NM_001354609.1',\n",
       "    'NM_004333.5',\n",
       "    'NR_148928.1',\n",
       "    'XM_017012558.1',\n",
       "    'XM_017012559.1',\n",
       "    'XR_001744857.1',\n",
       "    'XR_001744858.1'],\n",
       "   'translation': [{'protein': 'XP_016868047.1', 'rna': 'XM_017012558.1'},\n",
       "    {'protein': 'XP_016868048.1', 'rna': 'XM_017012559.1'},\n",
       "    {'protein': 'NP_001341538.1', 'rna': 'NM_001354609.1'},\n",
       "    {'protein': 'NP_004324.2', 'rna': 'NM_004333.5'}]},\n",
       "  'reporter': {'HG-U133_Plus_2': ['206044_s_at',\n",
       "    '226391_at',\n",
       "    '236402_at',\n",
       "    '243829_at'],\n",
       "   'HG-U95Av2': ['1654_at', '40306_at'],\n",
       "   'HG-U95B': '55694_at',\n",
       "   'HTA-2_0': ['TC07001926.hg.1', 'TC07001927.hg.1', 'TC07003197.hg.1'],\n",
       "   'HuEx-1_0': ['2320411', '3076340', '3982172'],\n",
       "   'HuGene-1_1': ['7897745', '8143417'],\n",
       "   'HuGene-2_1': ['16659054', '17063631']},\n",
       "  'summary': 'This gene encodes a protein belonging to the RAF family of serine/threonine protein kinases. This protein plays a role in regulating the MAP kinase/ERK signaling pathway, which affects cell division, differentiation, and secretion. Mutations in this gene, most commonly the V600E mutation, are the most frequently identified cancer-causing mutations in melanoma, and have been identified in various other cancers as well, including non-Hodgkin lymphoma, colorectal cancer, thyroid carcinoma, non-small cell lung carcinoma, hairy cell leukemia and adenocarcinoma of lung. Mutations in this gene are also associated with cardiofaciocutaneous, Noonan, and Costello syndromes, which exhibit overlapping phenotypes. A pseudogene of this gene has been identified on the X chromosome. [provided by RefSeq, Aug 2017].',\n",
       "  'symbol': 'BRAF',\n",
       "  'taxid': 9606,\n",
       "  'type_of_gene': 'protein-coding',\n",
       "  'umls': {'cui': 'C0812241'},\n",
       "  'unigene': ['Hs.550061', 'Hs.324250', 'Hs.600998', 'Hs.659507', 'Hs.684552'],\n",
       "  'uniprot': {'Swiss-Prot': 'P15056',\n",
       "   'TrEMBL': ['H7C4S5',\n",
       "    'A0A2R8Y8E0',\n",
       "    'A0A2U3TZI2',\n",
       "    'A0A2R8Y492',\n",
       "    'A0A2R8Y467',\n",
       "    'H7C560',\n",
       "    'A0A2R8Y679',\n",
       "    'A0A2R8YES9',\n",
       "    'H7C5K3',\n",
       "    'A0A2R8YDP5']},\n",
       "  'wikipedia': {'url_stub': 'BRAF (gene)'}},\n",
       " {'query': '1017',\n",
       "  'HGNC': '1771',\n",
       "  'MIM': '116953',\n",
       "  'Vega': 'OTTHUMG00000170575',\n",
       "  '_id': '1017',\n",
       "  '_score': 20.411018,\n",
       "  'accession': {'genomic': ['AC025162.48',\n",
       "    'AC034102.32',\n",
       "    'AF512553.1',\n",
       "    'AJ223951.1',\n",
       "    'CH471054.1',\n",
       "    'KT584459.1',\n",
       "    'NC_000012.12',\n",
       "    'NG_034014.1',\n",
       "    'U50730.2'],\n",
       "   'protein': ['AAA35667.1',\n",
       "    'AAH03065.1',\n",
       "    'AAM34794.1',\n",
       "    'AAP35467.1',\n",
       "    'BAA32794.1',\n",
       "    'BAF84630.1',\n",
       "    'BAG56780.1',\n",
       "    'CAA43807.1',\n",
       "    'CAA43985.1',\n",
       "    'EAW96856.1',\n",
       "    'EAW96857.1',\n",
       "    'EAW96858.1',\n",
       "    'EAW96859.1',\n",
       "    'EAW96860.1',\n",
       "    'NP_001277159.1',\n",
       "    'NP_001789.2',\n",
       "    'NP_439892.2',\n",
       "    'P24941.2',\n",
       "    'XP_011536034.1'],\n",
       "   'rna': ['AA789250.1',\n",
       "    'AA810989.1',\n",
       "    'AB012305.1',\n",
       "    'AK291941.1',\n",
       "    'AK293246.1',\n",
       "    'BC003065.2',\n",
       "    'BJ991087.1',\n",
       "    'BT006821.1',\n",
       "    'DA814453.1',\n",
       "    'M68520.1',\n",
       "    'NM_001290230.1',\n",
       "    'NM_001798.4',\n",
       "    'NM_052827.3',\n",
       "    'X61622.1',\n",
       "    'X62071.1',\n",
       "    'XM_011537732.2'],\n",
       "   'translation': [{'protein': 'BAA32794.1', 'rna': 'AB012305.1'},\n",
       "    {'protein': 'BAF84630.1', 'rna': 'AK291941.1'},\n",
       "    {'protein': 'BAG56780.1', 'rna': 'AK293246.1'},\n",
       "    {'protein': 'AAA35667.1', 'rna': 'M68520.1'},\n",
       "    {'protein': 'AAP35467.1', 'rna': 'BT006821.1'},\n",
       "    {'protein': 'CAA43985.1', 'rna': 'X62071.1'},\n",
       "    {'protein': 'AAH03065.1', 'rna': 'BC003065.2'},\n",
       "    {'protein': 'XP_011536034.1', 'rna': 'XM_011537732.2'},\n",
       "    {'protein': 'NP_001277159.1', 'rna': 'NM_001290230.1'},\n",
       "    {'protein': 'NP_001789.2', 'rna': 'NM_001798.4'},\n",
       "    {'protein': 'CAA43807.1', 'rna': 'X61622.1'},\n",
       "    {'protein': 'NP_439892.2', 'rna': 'NM_052827.3'}]},\n",
       "  'alias': ['CDKN2', 'p33(CDK2)'],\n",
       "  'ec': '2.7.11.22',\n",
       "  'ensembl': {'gene': 'ENSG00000123374',\n",
       "   'protein': ['ENSP00000243067',\n",
       "    'ENSP00000266970',\n",
       "    'ENSP00000393605',\n",
       "    'ENSP00000450983',\n",
       "    'ENSP00000452138',\n",
       "    'ENSP00000452514'],\n",
       "   'transcript': ['ENST00000266970',\n",
       "    'ENST00000354056',\n",
       "    'ENST00000440311',\n",
       "    'ENST00000553376',\n",
       "    'ENST00000554545',\n",
       "    'ENST00000554619',\n",
       "    'ENST00000555357',\n",
       "    'ENST00000555408',\n",
       "    'ENST00000556146',\n",
       "    'ENST00000556276',\n",
       "    'ENST00000556464',\n",
       "    'ENST00000556656'],\n",
       "   'translation': [{'protein': 'ENSP00000266970', 'rna': 'ENST00000266970'},\n",
       "    {'protein': 'ENSP00000450983', 'rna': 'ENST00000555408'},\n",
       "    {'protein': 'ENSP00000452514', 'rna': 'ENST00000553376'},\n",
       "    {'protein': 'ENSP00000393605', 'rna': 'ENST00000440311'},\n",
       "    {'protein': 'ENSP00000452138', 'rna': 'ENST00000555357'},\n",
       "    {'protein': 'ENSP00000243067', 'rna': 'ENST00000354056'}],\n",
       "   'type_of_gene': 'protein_coding'},\n",
       "  'entrezgene': '1017',\n",
       "  'exac': {'all': {'exp_lof': 14.064243652,\n",
       "    'exp_mis': 103.582926056,\n",
       "    'exp_syn': 40.3209373824,\n",
       "    'lof_z': 3.45076866809409,\n",
       "    'mis_z': 3.05571457340068,\n",
       "    'mu_lof': 1.02721752647e-06,\n",
       "    'mu_mis': 9.19091133625e-06,\n",
       "    'mu_syn': 3.45583178284e-06,\n",
       "    'n_lof': 1.0,\n",
       "    'n_mis': 40.0,\n",
       "    'n_syn': 40.0,\n",
       "    'p_li': 0.958299189494179,\n",
       "    'p_null': 2.00659367791929e-05,\n",
       "    'p_rec': 0.041680744569042,\n",
       "    'syn_z': 0.0313334362386},\n",
       "   'bp': 897,\n",
       "   'cds_end': 56365409,\n",
       "   'cds_start': 56360792,\n",
       "   'n_exons': 7,\n",
       "   'nonpsych': {'exp_lof': 12.5888844843,\n",
       "    'exp_mis': 93.611933068,\n",
       "    'exp_syn': 36.3537267212,\n",
       "    'lof_z': 3.48454051513261,\n",
       "    'mis_z': 2.89910545322279,\n",
       "    'mu_lof': 1.02721752647e-06,\n",
       "    'mu_mis': 9.19091133625e-06,\n",
       "    'mu_syn': 3.45583178284e-06,\n",
       "    'n_lof': 0.0,\n",
       "    'n_mis': 38.0,\n",
       "    'n_syn': 36.0,\n",
       "    'p_li': 0.987477460052364,\n",
       "    'p_null': 6.18333159581444e-06,\n",
       "    'p_rec': 0.0125163566160399,\n",
       "    'syn_z': 0.0369369403215127},\n",
       "   'nontcga': {'exp_lof': 12.9253985908,\n",
       "    'exp_mis': 95.282592769,\n",
       "    'exp_syn': 37.0815586845,\n",
       "    'lof_z': 3.27214293719079,\n",
       "    'mis_z': 3.02573046413952,\n",
       "    'mu_lof': 1.02721752647e-06,\n",
       "    'mu_mis': 9.19091133625e-06,\n",
       "    'mu_syn': 3.45583178284e-06,\n",
       "    'n_lof': 1.0,\n",
       "    'n_mis': 36.0,\n",
       "    'n_syn': 38.0,\n",
       "    'p_li': 0.939863326722736,\n",
       "    'p_null': 5.01892923357667e-05,\n",
       "    'p_rec': 0.0600864839849285,\n",
       "    'syn_z': -0.0954979610569747},\n",
       "   'transcript': 'ENST00000266970.4'},\n",
       "  'exons': [{'cdsend': 55971625,\n",
       "    'cdsstart': 55967008,\n",
       "    'chr': '12',\n",
       "    'position': [[55966768, 55967124],\n",
       "     [55968048, 55968169],\n",
       "     [55968777, 55968948],\n",
       "     [55971043, 55971247],\n",
       "     [55971520, 55972789]],\n",
       "    'strand': 1,\n",
       "    'transcript': 'NM_001290230',\n",
       "    'txend': 55972789,\n",
       "    'txstart': 55966768},\n",
       "   {'cdsend': 55971625,\n",
       "    'cdsstart': 55967008,\n",
       "    'chr': '12',\n",
       "    'position': [[55966768, 55967124],\n",
       "     [55967856, 55967934],\n",
       "     [55968048, 55968169],\n",
       "     [55968777, 55968948],\n",
       "     [55969474, 55969576],\n",
       "     [55971043, 55971247],\n",
       "     [55971520, 55972789]],\n",
       "    'strand': 1,\n",
       "    'transcript': 'NM_001798',\n",
       "    'txend': 55972789,\n",
       "    'txstart': 55966768},\n",
       "   {'cdsend': 55971625,\n",
       "    'cdsstart': 55967008,\n",
       "    'chr': '12',\n",
       "    'position': [[55966768, 55967124],\n",
       "     [55967856, 55967934],\n",
       "     [55968048, 55968169],\n",
       "     [55968777, 55968948],\n",
       "     [55971043, 55971247],\n",
       "     [55971520, 55972789]],\n",
       "    'strand': 1,\n",
       "    'transcript': 'NM_052827',\n",
       "    'txend': 55972789,\n",
       "    'txstart': 55966768}],\n",
       "  'exons_hg19': [{'cdsend': 56365409,\n",
       "    'cdsstart': 56360792,\n",
       "    'chr': '12',\n",
       "    'position': [[56360552, 56360908],\n",
       "     [56361832, 56361953],\n",
       "     [56362561, 56362732],\n",
       "     [56364827, 56365031],\n",
       "     [56365304, 56366573]],\n",
       "    'strand': 1,\n",
       "    'transcript': 'NM_001290230',\n",
       "    'txend': 56366573,\n",
       "    'txstart': 56360552},\n",
       "   {'cdsend': 56365409,\n",
       "    'cdsstart': 56360792,\n",
       "    'chr': '12',\n",
       "    'position': [[56360552, 56360908],\n",
       "     [56361640, 56361718],\n",
       "     [56361832, 56361953],\n",
       "     [56362561, 56362732],\n",
       "     [56363258, 56363360],\n",
       "     [56364827, 56365031],\n",
       "     [56365304, 56366573]],\n",
       "    'strand': 1,\n",
       "    'transcript': 'NM_001798',\n",
       "    'txend': 56366573,\n",
       "    'txstart': 56360552},\n",
       "   {'cdsend': 56365409,\n",
       "    'cdsstart': 56360792,\n",
       "    'chr': '12',\n",
       "    'position': [[56360552, 56360908],\n",
       "     [56361640, 56361718],\n",
       "     [56361832, 56361953],\n",
       "     [56362561, 56362732],\n",
       "     [56364827, 56365031],\n",
       "     [56365304, 56366573]],\n",
       "    'strand': 1,\n",
       "    'transcript': 'NM_052827',\n",
       "    'txend': 56366573,\n",
       "    'txstart': 56360552}],\n",
       "  'generif': [{'pubmed': 11907280,\n",
       "    'text': 'Cyclin A/Cdk2 and cyclin E/cdk2 continuously shuttle between the nucleus and the cytoplasm'},\n",
       "   {'pubmed': 12049628,\n",
       "    'text': 'results argue that TTK-associated CDK2 may function to maintain target-specific phosphorylation of RNA Pol II that is essential for Tat transactivation of HIV-1 promoter'},\n",
       "   {'pubmed': 12081504,\n",
       "    'text': 'Activation mechanism role of cyclin binding versus phosphorylation'},\n",
       "   {'pubmed': 12114499,\n",
       "    'text': 'CDK2/cyclin E is required for Tat-dependent transcription in vitro.'},\n",
       "   {'pubmed': 12149264,\n",
       "    'text': 'CDK2 binding to cyclin E is required to drive cells from G(1) into S phase'},\n",
       "   {'pubmed': 12531694,\n",
       "    'text': 'Interferon gamma reduces the activity of Cdk4 and Cdk2, inhibiting he G1 cell cycle in human hepatocellular carcinoma cells.'},\n",
       "   {'pubmed': 12676582,\n",
       "    'text': 'CDK2 is not required for sustained cell division.'},\n",
       "   {'pubmed': 12729791,\n",
       "    'text': 'Data suggest that the interaction between PKCeta and cyclin E is carefully regulated, and is correlated with the inactivated form of the cyclin E/Cdk2 complex.'},\n",
       "   {'pubmed': 12732645,\n",
       "    'text': 'IRF1 represses CDK2 gene expression by interfering with SP1-dependent transcriptional activation.'},\n",
       "   {'pubmed': 12801928, 'text': 'role in regulating Cdc25A half life'},\n",
       "   {'pubmed': 12810668,\n",
       "    'text': 'TGF-beta 1 inhibition requires early G(1) induction and stabilization of p21 protein, which binds to & inhibits cyclin E-CDK2 and cyclin A-CDK2 kinase activity rather than direct modulation of cyclin or CDK protein levels as seen in other systems.'},\n",
       "   {'pubmed': 12857729,\n",
       "    'text': 'Cdk2 has a role in phosphorylation of the NF-Y transcription factor'},\n",
       "   {'pubmed': 12912980,\n",
       "    'text': 'CDK2 has a role in the G2 DNA damage checkpoint'},\n",
       "   {'pubmed': 12915577,\n",
       "    'text': \"Kaposi's sarcoma-associated herpesvirus K-bZIP physically associates with cyclin-CDK2 and downmodulates its kinase activity.\"},\n",
       "   {'pubmed': 12947099,\n",
       "    'text': 'it is evident that B-Myb protein may promote cell proliferation by a non-transcriptional mechanism that involves release of active cyclin/cyclin dependent kinase 2 from cyclin-dependent inhibitor 1C p57(KIP2)'},\n",
       "   {'pubmed': 12954644,\n",
       "    'text': 'Inhibition of Cdk2 by 1,25-(OH)2D3 may thus involve two mechanisms: 1) reduced nuclear Cdk2 available for cyclin binding and activation and 2) impairment of cyclin E-Cdk2-dependent p27 degradation through cytoplasmic mislocalization of Cdk2.'},\n",
       "   {'pubmed': 14506259,\n",
       "    'text': 'kinetic insight into the basis for selecting suboptimal specificity determinants for the phosphorylation of cellular substrates'},\n",
       "   {'pubmed': 14536078,\n",
       "    'text': 'multisite phosphorylation by Cdk2 and GSK3 controls cyclin E degradation'},\n",
       "   {'pubmed': 14550307, 'text': 'CDK2 binds to SU9516 at Leu83 and Glu81'},\n",
       "   {'pubmed': 14551212,\n",
       "    'text': 'CDK2 activation process through phosphorylation is examined using 2D PAGE'},\n",
       "   {'pubmed': 14562046,\n",
       "    'text': 'Epstein-Barr virus can inhibit genotoxin-induced G1 arrest downstream of p53 by preventing the inactivation of CDK2'},\n",
       "   {'pubmed': 14612403,\n",
       "    'text': 'p220 is an essential downstream component of the cyclin E/Cdk2 signaling pathway and functions to coordinate multiple elements of the G1/S transition.'},\n",
       "   {'pubmed': 14645251,\n",
       "    'text': 'CDK2-cyclin E, without prior CDK4-cyclin D activity, can phosphorylate and inactivate pRb, activate E2F, and induce DNA synthesis.'},\n",
       "   {'pubmed': 14646596,\n",
       "    'text': 'significant difference in their biochemical properties between CDK4/cyclin D1 and CDK2/cyclin A affecting regulation of cellular RB function'},\n",
       "   {'pubmed': 14694185,\n",
       "    'text': 'cyclin-dependent kinase (CDK)2, -4, and -6 were down-regulated from the myelocytes/metamyelocytes stages and onward'},\n",
       "   {'pubmed': 14701826,\n",
       "    'text': 'CDK2 complexes have roles in G(1)/S deregulation and tumor progression'},\n",
       "   {'pubmed': 14985333,\n",
       "    'text': 'CDK2 regulates beta-catenin phosphorylation/ degradation'},\n",
       "   {'pubmed': 15004027,\n",
       "    'text': 'Cdk2 and Cdk4 phosphorylate human Cdt1 and induce its degradation'},\n",
       "   {'pubmed': 15024385,\n",
       "    'text': 'Binding to Cdk2-cyclin A is accompanied by p27 folding, and kinetic data suggest a sequential mechanism that is initiated by binding to cyclin A'},\n",
       "   {'pubmed': 15063782,\n",
       "    'text': 'We also found that cyclin A/CDK2 phosphorylates Axin, thereby enhancing its association with beta-catenin.'},\n",
       "   {'pubmed': 15159402,\n",
       "    'text': 'study provides evidence that the cyclin A1-cyclin dependent kinase 2 complex plays a role in several signaling pathways important for cell cycle control and meiosis'},\n",
       "   {'pubmed': 15178429, 'text': 'interacts with dephosphorylated NIRF'},\n",
       "   {'pubmed': 15199159,\n",
       "    'text': 'cyclin A-cdk2 plays an ancillary noncatalytic role in the ubiquitination of p27(KIP1) by the SCF(skp2) complex'},\n",
       "   {'pubmed': 15226429,\n",
       "    'text': 'Results identify an important role for CDK2 in the maintenance of genomic stability, acting via an ATM- and ATR-dependent pathway.'},\n",
       "   {'pubmed': 15309028,\n",
       "    'text': 'after CDK4/6 inactivation, the fate of pancreatic tumor cells depends on the ability to modulate CDK2 activity'},\n",
       "   {'pubmed': 15355984,\n",
       "    'text': 'Data suggest that cyclin D1-Cdk2 complexes mediate some of the transforming effects of cyclin D1 and demonstrate that the cyclin D1-Cdk2 fusion protein is a useful model to investigate the biological functions of cyclin D1-Cdk2 complexes.'},\n",
       "   {'pubmed': 15456866,\n",
       "    'text': 'These findings establish a novel function for cyclin A1 and CDK2 in DNA double strand break repair following radiation damage.'},\n",
       "   {'pubmed': 15572662,\n",
       "    'text': 'Phosphborylation of progesterone receptor serine 400 mediates ligand-independent transcriptional activity in response to activation of CDK2.'},\n",
       "   {'pubmed': 15601848,\n",
       "    'text': 'cyclin A/Cdk2 has a role as a progesterone receptor coactivator'},\n",
       "   {'pubmed': 15607961,\n",
       "    'text': 'CDK2 depletion suppressed growth and cell cycle progression in melanoma and may be a suitable drug target in melanoma.'},\n",
       "   {'pubmed': 15611077,\n",
       "    'text': 'Inhibition of CDK2 kinase by indole-3-carbinol is accompanied by selective alterations in cyclin E composition.'},\n",
       "   {'pubmed': 15632290,\n",
       "    'text': 'molecular dynamics study on the complex CDK2 with the peptide substrate HHASPRK'},\n",
       "   {'pubmed': 15649889,\n",
       "    'text': 'Results demonstrate that a peptide derived from the alpha5 helix of cyclin A significantly inhibits kinase activity of complexes harboring CDK2, and forms stable complexes with CDK2-cyclin A.'},\n",
       "   {'pubmed': 15660127,\n",
       "    'text': 'crystal structure of phospho-CDK2 in complex with a truncated cyclin E1 (residues 81-363) at 2.25 A resolution'},\n",
       "   {'pubmed': 15665273,\n",
       "    'text': 'CDK2-BRCA1-Nucleophosmin pathway coordinately functions in cell growth and tumor progression pathways.'},\n",
       "   {'pubmed': 15671017,\n",
       "    'text': 'HTm4 binding to KAP.Cdk2.cyclin A complex enhances the phosphatase activity of KAP, dissociates cyclin A, and facilitates KAP dephosphorylation of Cdk2'},\n",
       "   {'pubmed': 15695825,\n",
       "    'text': 'Results present a comprehensive description of the dynamic behavior of cyclin-dependent kinase 2 in complex with cyclin A.'},\n",
       "   {'pubmed': 15707957,\n",
       "    'text': 'Puralpha has been shown to colocalize with cyclin A/Cdk2 and to coimmunoprecipitate with cyclin A during S-phase and we show that this interaction is mediated by a specific affinity of Puralpha for Cdk2.'},\n",
       "   {'pubmed': 15890360,\n",
       "    'text': 'Rapid binding of p27 domain 1 to cyclin A tethers the inhibitor to the binary Cdk2/cyclin A complex'},\n",
       "   {'pubmed': 15922732,\n",
       "    'text': 'CDK2 translational down-regulation may be a key regulatory event in replicative senescence of endothelial cells.'},\n",
       "   {'pubmed': 15944161,\n",
       "    'text': 'origin recognition complex 2 has an unexpected role in CDK2 activation, a linkage that could be important for maintaining genomic stability'},\n",
       "   {'pubmed': 15964852,\n",
       "    'text': 'Cdk2 destabilizes p21 via the cy2 cyclin-binding motif and p21 phosphorylation'},\n",
       "   {'pubmed': 16036217,\n",
       "    'text': 'Our results demonstrate that differential regulation of Cdc2 and Cdk2 activity by different doses of doxorubicin may contribute to the induction of two modes of cell death in hepatoma cells, either apoptosis or cell death through mitotic catastrophe.'},\n",
       "   {'pubmed': 16082200,\n",
       "    'text': 'CINP is part of the Cdc7-dependent mechanism of origin firing and a functional and physical link between Cdk2 and Cdc7 complexes at the origins'},\n",
       "   {'pubmed': 16082227,\n",
       "    'text': 'CDK2 inhibition modifies the dynamics of chromatin-bound minichromosome maintenance complex and replication protein A'},\n",
       "   {'pubmed': 16085226,\n",
       "    'text': 'results indicate that CDK2 participates in Tat-mediated HIV-1 transcription and may serve as a potential therapeutic target'},\n",
       "   {'pubmed': 16150942,\n",
       "    'text': 'Cdk2 inhibition decreases the efficiency of chemical induction of KSHV lytic transcripts ORF 50 and 26. Importantly, Cdk2 activity is also essential for replication in other human herpesviruses'},\n",
       "   {'pubmed': 16258277,\n",
       "    'text': 'A new concept indicates in this review that both Cdk2 and/or Cdc2 can drive cells through G1/S phase in parallel.'},\n",
       "   {'pubmed': 16262700,\n",
       "    'text': 'Cdk2 dependent phosphorylation(s) cannot be a critical trigger of replicon initiation in response to reoxygenation after several hours of hypoxia, at least in the T24 cells studied'},\n",
       "   {'pubmed': 16343435,\n",
       "    'text': 'We propose that during TNFalpha-induced apoptosis, PKCdelta-mediated phosphorylation of p21(WAF1/CIP1) at (146)Ser attenuates the Cdk2 binding of p21(WAF1/CIP1) and thereby upregulates Cdk2 activity.'},\n",
       "   {'pubmed': 16407256,\n",
       "    'text': 'molecular analysis of the CDK5/p25 and CDK2/cyclin A systems'},\n",
       "   {'pubmed': 16504183,\n",
       "    'text': 'Cyclin-dependent kinases regulate the transcriptional activity of FOXM1c; a combination of three phosphorylation sites mediates the Cyclin E and Cyclin A/CDK2 effects.'},\n",
       "   {'pubmed': 16540140,\n",
       "    'text': 'Here, we show that human papillomavirus type 16 16E1--E4 is also able to associate with cyclin A and Cdk2 during the G2 phase of the cell cycle.'},\n",
       "   {'pubmed': 16575928,\n",
       "    'text': 'The interaction between roscovitine and cyclin-dependent kinase 2 (cdk2) was investigated by performing correlated ab initio quantum-chemical calculations.'},\n",
       "   {'pubmed': 16707497,\n",
       "    'text': 'the phospho-CDK2/cyclin A recruitment site has a role in substrate recognition'},\n",
       "   {'pubmed': 16762841,\n",
       "    'text': 'Phosphorylation of the linker histone H1 by CDK regulates its binding to HP1alpha'},\n",
       "   {'pubmed': 16765349,\n",
       "    'text': 'suggest a novel retinoic acid (RA)-signaling, by which RA-induced p21 induction and complex formation with cyclin E/CDK2 diverts CDK2 function from normally driving proliferation to alternatively promoting apoptosis'},\n",
       "   {'pubmed': 16824683,\n",
       "    'text': 'Membrane depolarization may stimulate cellular proliferation by augmenting the expression of cyclin E leading to increases in Cdk2 activity and RB phosphorylation in a neuroblastoma cell line.'},\n",
       "   {'pubmed': 16912045,\n",
       "    'text': 'the Chk1-mediated S-phase checkpoint targets initiation factor Cdc45 via a Cdc25A/Cdk2-independent mechanism'},\n",
       "   {'pubmed': 16912201,\n",
       "    'text': 'Breast cancer cells lacking cancer predisposition genes BRCA1 are more sensitive to CDK2 inhibitors.'},\n",
       "   {'pubmed': 17001081,\n",
       "    'text': 'analysis of the NBI1-binding site on cyclin A which inhibits the catalytic activity of the complex cyclin-dependent kinase 2-cyclin A'},\n",
       "   {'pubmed': 17013093,\n",
       "    'text': 'progression of melanoma is associated with changes in CDK-2 expression level'},\n",
       "   {'pubmed': 17038621,\n",
       "    'text': 'functional interaction between CDK2 and FOXO1 provides a mechanism that regulates apoptotic cell death after DNA strand breakage'},\n",
       "   {'pubmed': 17095507,\n",
       "    'text': 'Kinetic and crystallographic analyses of CDK2-cyclin A complexes reveal that this inhibitory mechanism operates through steric blockade of peptide substrate binding.'},\n",
       "   {'pubmed': 17207508,\n",
       "    'text': 'Review highlights an alternative role for CDK2 in the regulation of progesterone receptor signaling.'},\n",
       "   {'pubmed': 17293600,\n",
       "    'text': 'TopBP1 necessary for the G(1)/S transition: one for activating cyclin E/CDK2 kinase and the other for loading replication components onto chromatin to initiate DNA synthesis.'},\n",
       "   {'pubmed': 17361108,\n",
       "    'text': 'Our results demonstrate that CDK2 is capable of autophosphorylation at Thr160.'},\n",
       "   {'pubmed': 17371838,\n",
       "    'text': 'results argue that Mdm2 is needed for full inhibition of Cdk2 activity by p21, thereby positively contributing to p53-dependent cell cycle arrest'},\n",
       "   {'pubmed': 17386261,\n",
       "    'text': 'Both Cdk1 and -2 require cyclin binding and T loop phosphorylation for full activity.'},\n",
       "   {'pubmed': 17409409,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 17495531,\n",
       "    'text': 'The structure of phospho-CDK2/cyclin B is reported. pCDK2/cyclin B is less discriminatory in substrate recognition than CDK2/cyclin A & has properties of both an S-phase & an M-phase kinase. CDK2/cyclin B is effective against S phase substrates.'},\n",
       "   {'pubmed': 17638878,\n",
       "    'text': 'ATRIP is a CDK2 substrate, and CDK2-dependent phosphorylation of S224 regulates the ability of ATR-ATRIP to promote cell cycle arrest in response to DNA damage'},\n",
       "   {'pubmed': 17713927,\n",
       "    'text': 'Phosphorylation on a conserved Thr14 can inhibit activities of both the kinases, but phosphorylating another conserved Tyr15, however, can lead to totally opposite inhibition and stimulation consequences in CDK2 and CDK5.'},\n",
       "   {'pubmed': 18042686,\n",
       "    'text': 'The conserved rigid regions are important for nucleotide binding, catalysis, and substrate recognition; most flexible regions correlate with those where large conformational changes occur during CDK2 regulation processes.'},\n",
       "   {'pubmed': 18156799,\n",
       "    'text': 'cdk2 activity is necessary for the survival of human DLBCL.'},\n",
       "   {'pubmed': 18174243,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 18199752,\n",
       "    'text': 'major Cdk2-dependent multiple gene regulatory events are present in pemphigus vulgar'},\n",
       "   {'pubmed': 18202766,\n",
       "    'text': 'serum starvation induces G1 arrest through suppression of Skp2-dependent CDK2 activity and Skp2-independent CDK4 activity in human SK-OV-3 ovarian cancer cells'},\n",
       "   {'pubmed': 18208561,\n",
       "    'text': 'growth arrest by SmE directly correlates with the reduction of cyclin E, CDK2, CDC25C and CDC2 expression, and up-regulation of p27Kip'},\n",
       "   {'pubmed': 18236071,\n",
       "    'text': 'Findings strongly demonstrate that retinoblastoma (RB) and cyclin-dependent kinase 2 (CDK2) on one side and cytokeratin 8 (CK8) and epidermal growth factor receptor 2 (HER2) on the other may affect the clinical course of the disease in 56% of patients.'},\n",
       "   {'pubmed': 18276582,\n",
       "    'text': 'Cyclin E and SV40 small T antigen cooperate to bypass quiescence and contribute to transformation by activating CDK2 in human fibroblasts'},\n",
       "   {'pubmed': 18281541,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 18345036,\n",
       "    'text': 'Bim-mediated apoptosis following actin damage due to deregulation of Cdk2 and the cell cycle by the absence of functional p53.'},\n",
       "   {'pubmed': 18372919,\n",
       "    'text': 'G2 phase cyclin A/cdk2 controls the timing of entry into mitosis by controlling the subsequent activation of cyclin B/cdk1, but also has an unexpected role in coordinating the activation of cyclin B/cdk1 at the centrosome and in the nucleus'},\n",
       "   {'pubmed': 18400748,\n",
       "    'text': 'disruption of the spindle-assembly checkpoint does not directly influence p53 activation, but the shortening of the mitotic arrest allows cyclin E-CDK2 to be activated before the accumulation of p21(CIP1/WAF1).'},\n",
       "   {'pubmed': 18408738,\n",
       "    'text': 'Results suggest that GSK-3 regulates nuclear p27 Kip1 expression through downregulation of Skp2 expression and regulates p27 Kip1 assembly with CDK2, playing a critical role in the G0/G1 arrest associated with intestinal cell differentiation.'},\n",
       "   {'pubmed': 18470542,\n",
       "    'text': 'The structures of fully active cyclin-dependent kinase-2 (CDK2)complexed with ATP and peptide substrate, CDK2 after the catalytic reaction, and CDK2 inhibited by phosphorylation at Thr14/Tyr15 were studied using molecular dynamics simulations.'},\n",
       "   {'pubmed': 18507837,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 18617527,\n",
       "    'text': 'Cdk2-associated complexes, by targeting SHP-1 for proteolysis, counteract the ability of SHP-1 to block cell cycle progression of intestinal epithelial cells'},\n",
       "   {'pubmed': 18635963,\n",
       "    'text': 'Cyclin A-CDK activity during G(1) would result in an inhibition of progression into the S phase.'},\n",
       "   {'pubmed': 18667424,\n",
       "    'text': 'the cyclin A-CDK2 complex may be a potential effector of NFATs, specifically NFATc1, in mediating SMC multiplication leading to neointima formation.'},\n",
       "   {'pubmed': 18784074,\n",
       "    'text': 'Cdk2 negatively regulates the activity of hPXR, and suggest an important role for Cdk2 in regulating hPXR activity and CYP3A4 expression in hepatocytes passing through the cell cycle'},\n",
       "   {'pubmed': 18806832,\n",
       "    'text': 'This suggests an important role for CDK2 in cell cycle regulation in hESCs that are likely to bear significant impacts on the maintenance of their pluripotent phenotype.'},\n",
       "   {'pubmed': 18941885,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 19061641,\n",
       "    'text': 'Cyclin A assembles with Cdk1 only after complex formation with Cdk2 reaches a plateau during late S and G2 phases.'},\n",
       "   {'pubmed': 19066288,\n",
       "    'text': 'These findings establish phosphorylation events by CDKs 1 and 2 as key regulators of Discs Large 1 localisation and function.'},\n",
       "   {'pubmed': 19091404,\n",
       "    'text': 'Notch-1 may be mediated through regulating the expression of cell cycle regulatory proteins cyclin D1, CDK2 and p21 and the activity of Akt signaling'},\n",
       "   {'pubmed': 19101503,\n",
       "    'text': 'These results demonstrate that double phosphorylation of CDK2 peptides increases the stoichiometry of metal ion binding, and hence may contribute to the previously observed regulation of CDK2 activity by metal ions.'},\n",
       "   {'pubmed': 19103742,\n",
       "    'text': 'the pathway of apoptin-induced apoptosis and show that it essentially depends on abnormal phosphatidylinositol 3-kinase (PI3-kinase)/Akt activation, resulting in the activation of the cyclin-dependent kinase CDK2'},\n",
       "   {'pubmed': 19124506,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 19166026,\n",
       "    'text': 'Overexpression of CDK2 was strongly correlated with abnormal proliferation in laryngeal squamous cell carcinoma.'},\n",
       "   {'pubmed': 19197163,\n",
       "    'text': 'Results show that human Cdk2 is a functional homolog for most of Ime2 functions.'},\n",
       "   {'pubmed': 19201832,\n",
       "    'text': 'disruption of Smad2 function by CDK2 phosphorylation acts as a mechanism for TGF-beta resistance in multiple myeloma.'},\n",
       "   {'pubmed': 19258477,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 19258477,\n",
       "    'text': 'Strengthened signals in imputation-based analysis at CDK2 SNPs rs2069391, rs2069414 and rs17528736 lend evidence to the role of cell cycle genes in ovarian cancer etiology.'},\n",
       "   {'pubmed': 19321444,\n",
       "    'text': 'The combination of st and deregulated cyclin E result in cooperative and coordinated activation of both an essential origin licensing factor, CDC6, and an activity required for origin firing, CDK2, resulting in progression from quiescence to S phase.'},\n",
       "   {'pubmed': 19440053,\n",
       "    'text': 'Co-depletion of Cdc6 and p53 in normal cells restored Cdk2 activation and Rb phosphorylation, permitting them to enter S phase with a reduced rate of replication.'},\n",
       "   {'pubmed': 19594747,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 19596857,\n",
       "    'text': 'resistance of oral squamous carcinoma to IFNgamma is not due to deficiency in STAT1-dependent signaling but from a defect in the signaling component that mediates IFNgamma-induced down-regulation of CcnA2 and Cdk2 expression'},\n",
       "   {'pubmed': 19609547,\n",
       "    'text': 'Four genes previously not examined in that respect in laryngeal carcinoma, occurred to be good markers of the neoplasm. They are: metal-proteinase ADAM12, cyclin-dependent kinase 2-CDK2, kinesin 14-KIF14, suppressor 1 of checkpoint-CHES1.'},\n",
       "   {'pubmed': 19631451,\n",
       "    'text': 'Data demonstrate that the novel anticancer mechanism of hinokitiol involves accumulation of p27, down-regulation of pRb, Skp2, and impairment of Cdk2 function.'},\n",
       "   {'pubmed': 19703905,\n",
       "    'text': 'cyclin A/cdk2-dependent phosphorylation of APC affects astral microtubule attachment to the cortical surface in mitosis'},\n",
       "   {'pubmed': 19706521,\n",
       "    'text': 'Results suggest that simple but robust rules encoded in the CDK2 structure play a dominant role in predefining the mechanisms of ligand binding, which may be advantageously exploited in designing inhibitors.'},\n",
       "   {'pubmed': 19723060,\n",
       "    'text': 'Studies indicate that roscovitine arrests the cell cycle is direct inhibition of CDK1, a mitotic regulator, and CDK2, involved in G1/S transition.'},\n",
       "   {'pubmed': 19724860,\n",
       "    'text': 'Overexpression of Notch1 in laryngeal carcinoma cell line was coupled with the downregulation of cdk2'},\n",
       "   {'pubmed': 19738611,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 19797611,\n",
       "    'text': 'results show that the expression of UGT1A1 and CYP2B6 is negatively regulated through a CDK2 signaling pathway linked to cell cycle progression in HepG2 and SW480 cells'},\n",
       "   {'pubmed': 19822658,\n",
       "    'text': 'Results underscore the crucial role of cyclin A2-CDK2 in regulating the PLK1-SCF(beta-TrCP1)-EMI1-APC/C axis and CDC6 to trigger genome reduplication after the activity of CDK1 is suppressed.'},\n",
       "   {'pubmed': 19829063,\n",
       "    'text': 'Since CAC1 interacts with CDK2 and promotes the kinase activity of CDK2 protein, we propose that CAC1 is a novel cell cycle associated protein capable of promoting cell proliferation.'},\n",
       "   {'pubmed': 19838212,\n",
       "    'text': 'Chk1 signalling causes centrosome amplification after ionizing radiation by upregulating Cdk2 activity through activating phosphorylation.'},\n",
       "   {'pubmed': 19838216,\n",
       "    'text': 'Data show that SHP-1 knockdown increases p27stability, decreases the CDK6 levels, inducing retinoblastoma protein hypophosphorylation, downregulation of cyclin E and thereby a decrease in the CDK2 activity.'},\n",
       "   {'pubmed': 19854217,\n",
       "    'text': 'expression upregulation is critical for TLR9-stimulated proliferation of kung cancer cells'},\n",
       "   {'pubmed': 19858290,\n",
       "    'text': 'Export was also reduced by Cdk inhibition or cyclin A RNA interference, suggesting that cyclin A/Cdk complexes contribute to Wee1 export.'},\n",
       "   {'pubmed': 19885547,\n",
       "    'text': 'aberrant regulation of S100P in HCC might activate cyclin D1 and CDK expression and contribute to the mitogenic potential of tumor cells during Hepatocellular carcinoma carcinogenesis.'},\n",
       "   {'pubmed': 19960406,\n",
       "    'text': 'Cellular production of IGFBP-3 leads to G1 cell cycle arrest with inhibition of CDK2 and CDK4.'},\n",
       "   {'pubmed': 19966300,\n",
       "    'text': 'Data show that Myc repressed Ras-induced senescence, and that Cdk2 interacted with Myc at promoters, where it affected Myc-dependent regulation of genes, including those of proteins known to control senescence.'},\n",
       "   {'pubmed': 20017906, 'text': 'FUS-DDIT3 and the normal DDIT3 bind CDK2.'},\n",
       "   {'pubmed': 20062077,\n",
       "    'text': 'Results directly show that the inhibition of Cdk1 activity and the persistence of Cdk2 activity in G2 cells induces endoreplication without mitosis.'},\n",
       "   {'pubmed': 20068231,\n",
       "    'text': 'Results show that most of the up-regulated sites phosphorylated by cyclin-dependent CDK1 or CDK2 were almost fully phosphorylated in mitotic cells.'},\n",
       "   {'pubmed': 20079829,\n",
       "    'text': 'the nitric oxide-mediated biphasic effect was dependent on Cdk2 nitrosylation/activation and the loss of mitochondrial potential'},\n",
       "   {'pubmed': 20147522,\n",
       "    'text': 'central roles for CDK2 nuclear-cytoplasmic trafficking and cyclin E in the mechanism of 1,25-(OH)(2)D(3)-mediated growth inhibition in prostate cancer cells'},\n",
       "   {'pubmed': 20195506,\n",
       "    'text': 'These findings demonstrate that Cdk2 maintains a balance of S-phase regulatory proteins and thereby coordinates subsequent p53-independent G(2)/M checkpoint activation.'},\n",
       "   {'pubmed': 20399812,\n",
       "    'text': 'Data describe the properties of a mutant form of Cdk2 identified during large-scale sequencing of protein kinases from cancerous tissue.'},\n",
       "   {'pubmed': 20422243,\n",
       "    'text': 'Triticum aestivum-5B2 (( Ta ) 5B2) is suggested to be a wheat analogue of human CDK2 enzyme.'},\n",
       "   {'pubmed': 20444741,\n",
       "    'text': 'Conclude that cisplatin likely activates both caspase-dependent and -independent cell death, and Cdk2 is required for both pathways.'},\n",
       "   {'pubmed': 20465575,\n",
       "    'text': 'In addition to having a pivotal role in the up-regulation of IL-2 and IL-2RA gene expression, IKK controls the expression of cyclin D3, cyclin E and CDK2, and the stability SKP2 and its co-factor CKS1B, through mechanisms independent of IL-2.'},\n",
       "   {'pubmed': 20508983,\n",
       "    'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "   {'pubmed': 20512928,\n",
       "    'text': 'Hr and VDR interact via multiple protein-protein interfaces, catalyzing histone demethylation to effect chromatin remodeling and repress the transcription of VDR target genes that control the hair cycle.'},\n",
       "   {'pubmed': 20694007,\n",
       "    'text': 'protein phosphatase 1 competition with Cdk-cyclins for retinoblastoma protein(Rb) binding is sufficient to retain Rb activity and block cell-cycle advancement.'},\n",
       "   {'pubmed': 20711190,\n",
       "    'text': 'cyclin-dependent kinases (Cdks), especially Cdk1 and Cdk2, promote interphase nuclear pore complex formation in human dividing cells.'},\n",
       "   {'pubmed': 20844047,\n",
       "    'text': 'Nuclear export of HPV31 E1 is inhibited by Cdk2 phosphorylation at two serines residues, S92 and S106.'},\n",
       "   {'pubmed': 20935635,\n",
       "    'text': 'The results demonstrate that CDK2-mediated phosphorylation is a key mechanism governing EZH2 function and that there is a link between the cell-cycle machinery and epigenetic gene silencing.'},\n",
       "   {'pubmed': 21048031,\n",
       "    'text': 'Observational study of gene-disease association and gene-environment interaction. (HuGE Navigator)'},\n",
       "   {'pubmed': 21062975,\n",
       "    'text': 'Data show that miR-302 simultaneously suppressed both the cyclin E-CDK2 and cyclin D-CDK4/6 pathways to block>70% of the G1-S cell cycle transition.'},\n",
       "   {'pubmed': 21099355,\n",
       "    'text': 'Overexpression of human Cdk2 resulted in a defect in the G1 to S transition and a reduction in viability.'},\n",
       "   {'pubmed': 21233845,\n",
       "    'text': 'MicroRNA miR-885-5p targets CDK2 and MCM5, activates p53 and inhibits proliferation and survival.'},\n",
       "   {'pubmed': 21262353,\n",
       "    'text': 'Cdk2 functions via a Cdk2/SHP-1/beta-catenin/CEACAM1 axis, and show that Cdk2 has the capacity to regulate insulin internalization.'},\n",
       "   {'pubmed': 21264535,\n",
       "    'text': 'XPD may play an important role in cell apoptosis of hepatoma by inducing an over-expression of p53, but suppressing expressions of c-myc and cdk2'},\n",
       "   {'pubmed': 21319273,\n",
       "    'text': 'CDK2 downregulation causes high apoptosis at the early time points'},\n",
       "   {'pubmed': 21325496,\n",
       "    'text': 'Conclude that in cisplatin induced-kidney injury phosphorylation of p21 by Cdk2 limits the effectiveness of p21 to inhibit Cdk2.'},\n",
       "   {'pubmed': 21454540,\n",
       "    'text': 'the ability of Emi1 to inhibit APC/C is negatively regulated by CDKs'},\n",
       "   {'pubmed': 21515670,\n",
       "    'text': 'cyclin E and CDK2 genes are key physiological effectors of the c-ETS1 proto-oncogene. Furthermore, c-ETS1 is indispensable for the hepatotropic action of HBx in cell cycle deregulation.'},\n",
       "   {'pubmed': 21565702,\n",
       "    'text': 'Transient binding of a second catalytic magnesium activates the structure and dynamics of CDK2 kinase for catalysis.'},\n",
       "   {'pubmed': 21596315,\n",
       "    'text': 'The deubiquitinase USP37 binds CDH1 and removes degradative polyubiquitin from cyclin A. USP37 was induced by E2F factors in G1, peaked at G1/S, and was degraded in late mitosis. Phosphorylation of USP37 by CDK2 stimulated its full activity.'},\n",
       "   {'pubmed': 21646351,\n",
       "    'text': 'anti-oncogenic role of miR-372 may be through control of cell growth and cell cycle progression by down-regulating the cell cycle genes CDK2 and cyclin A1'},\n",
       "   {'pubmed': 21658603, 'text': 'Cdk2 is required for cell proliferation.'},\n",
       "   {'pubmed': 21769424,\n",
       "    'text': 'RT-PCR and Western blotting results revealed that both mRNA and protein levels of CDK2 were significantly higher in tumor tissues.'},\n",
       "   {'pubmed': 21871181,\n",
       "    'text': 'NF-Y binds to CCAAT sequences in the Cyclin A promoter, as well as to those in the promoters of cell cycle G2 regulators such as CDC2, Cyclin B and CDC25C.'},\n",
       "   {'pubmed': 21918011,\n",
       "    'text': 'Epstein-Barr virus Rta-mediated transactivation of p21 and 14-3-3sigma arrests cells at the G1/S transition by reducing cyclin E/CDK2 activity.'},\n",
       "   {'pubmed': 21941773,\n",
       "    'text': 'The expression level of CDK2 protein did not change significantly in silica-induced human embryo lung fibroblasts.'},\n",
       "   {'pubmed': 21965652,\n",
       "    'text': 'excess of MCM3 up-regulates the phosphorylation of CHK1 Ser-345 and CDK2 Thr-14.'},\n",
       "   {'pubmed': 22084169,\n",
       "    'text': 'The S-phase-specific cyclin-dependent kinase 2 was required for robust activation of ATR in response to diverse chemotherapeutic agents.'},\n",
       "   {'pubmed': 22231403,\n",
       "    'text': 'The authors show that, in human and mouse, Mre11 controls these events through a direct interaction with CDK2 that is required for CtIP phosphorylation and BRCA1 interaction in normally dividing cells.'},\n",
       "   {'pubmed': 22467868,\n",
       "    'text': 'Lin-28 homologue A (LIN28A) promotes cell cycle progression via regulation of cyclin-dependent kinase 2 (CDK2), cyclin D1 (CCND1), and cell division cycle 25 homolog A (CDC25A) expression in cancer.'},\n",
       "   {'pubmed': 22474407,\n",
       "    'text': 'CDK2 inhibition drastically diminishes anchorage-independent growth of human cancer cells and cells transformed with various oncogenes'},\n",
       "   {'pubmed': 22479189,\n",
       "    'text': 'low molecular weight cyclin E (LMW-E) requires CDK2-associated kinase activity to induce mammary tumor formation by disrupting acinar development'},\n",
       "   {'pubmed': 22673765,\n",
       "    'text': 'The activation of p21(Waf1/Cip1) was significantly up-regulated over time, but there was no change in the level of CDK2 expression by treatment of HEK293 cells with various concentrations of veterinary antibiotics.'},\n",
       "   {'pubmed': 22718829,\n",
       "    'text': 'Human cytomegalovirus IE1/2 expression was downregulated by cyclin A2, CDK1 and CDK2.'},\n",
       "   {'pubmed': 22819841,\n",
       "    'text': 'exposure of cancer cells (such as HeLa and MCF7 cells) to H2O2 increased CDK2 activity with no accompanying change in the PCNA level, leading to cell proliferation.'},\n",
       "   {'pubmed': 22927831,\n",
       "    'text': 'By a chemical-genetic approach study identified Nbs1 as a target of Cdk2, and mapped the phosphorylation to a conserved CDK consensus recognition site.'},\n",
       "   {'pubmed': 22951823,\n",
       "    'text': 'cellular CDK2 phosphorylates the functionally critical S/T-P sites of the hepadnavirus core CTD and is incorporated into viral capsids'},\n",
       "   {'pubmed': 23028682,\n",
       "    'text': 'cyclin A-Cdk2 regulates apoptosis through a mechanism that involves Rad9phosphorylation'},\n",
       "   {'pubmed': 23065011,\n",
       "    'text': 'human papillomavirus E4 proteins can interact with cyclin A and cdk2, which may contribute to viral manipulation of the host cell cycle.'},\n",
       "   {'pubmed': 23082202,\n",
       "    'text': 'Cdk2 also binds the N-terminal domain of Fbw7-gamma as well as SLP-1.'},\n",
       "   {'pubmed': 23140174,\n",
       "    'text': 'CDK2 phosphorylates CDK9 on Ser 90 and thereby contributes to HIV-1 transcription.'},\n",
       "   {'pubmed': 23184662,\n",
       "    'text': 'EEF2 phosphorylation by cyclin A-cyclin-dependent kinase 2 (CDK2) on a novel site, serine 595 (S595), directly regulates T56 phosphorylation by eEF2K.'},\n",
       "   {'pubmed': 23185313,\n",
       "    'text': 'This study aimed to explore the effects of single nucleotide polymorphisms in CDK2 and CCNE1 on breast cancer risk, progression and survival in a Chinese Han population.'},\n",
       "   {'pubmed': 23230143,\n",
       "    'text': 'Findings revealed a novel function of simultaneous p27 and CDK2 cytoplasmic mislocalization in mediating growth-factor-regulated cell proliferation, migration and invasion.'},\n",
       "   {'pubmed': 23300027,\n",
       "    'text': 'possible relationship between the CDK2 deleterious variants and the drug-binding ability'},\n",
       "   {'pubmed': 23321641,\n",
       "    'text': 'Constitutive Cdk2 activity promotes aneuploidy while altering the spindle assembly and tetraploidy checkpoints.'},\n",
       "   {'pubmed': 23390492,\n",
       "    'text': 'Constitutive CCND1/CDK2 expression contributes to neoplastic mammary epithelial cell transformation.'},\n",
       "   {'pubmed': 23390529,\n",
       "    'text': 'The prolyl isomerase Pin1 acts synergistically with CDK2 to regulate the basal activity of estrogen receptor alpha in breast cancer.'},\n",
       "   {'pubmed': 23446853,\n",
       "    'text': 'Aurora-A kinase-induced centrosome amplification was mediated by Cdk2 kinase.'},\n",
       "   {'pubmed': 23479742,\n",
       "    'text': 'the up-regulation of CDK2 by CUL4B is achieved via the repression of miR-372 and miR-373, which target CDK2.'},\n",
       "   {'pubmed': 23532886,\n",
       "    'text': 'Data indicate that TG02 blocked signaling by CDKs 1, 2, 7, and 9 and ERK5, leading to potent and highly consistent antimyeloma activity.'},\n",
       "   {'pubmed': 23643165,\n",
       "    'text': 'The expression of CDK2 mRNA significantly decreased in P(CDK2-siRNA).'},\n",
       "   {'pubmed': 23671119,\n",
       "    'text': 'A specific and essential roles for Cdk2 inhibitory phosphorylation in the successful execution of the replication stress checkpoint response and in maintaining genome integrity.'},\n",
       "   {'pubmed': 23720738,\n",
       "    'text': 'MCM7 is a substrate of cyclin E/Cdk2 and can be phosphorylated on Ser-121.'},\n",
       "   {'pubmed': 23727278,\n",
       "    'text': 'Data indicate that different binding sites of cyclin-dependent kinase (CDK2) contributing towards the binding of inhibitors.'},\n",
       "   {'pubmed': 23737759,\n",
       "    'text': 'CDK7 involved in phosphorylation/activation of CDK4 and CDK6; existence of CDK4-activating kinase(s) other than CDK7; and novel CDK7-dependent positive feedbacks mediated by p21 phosphorylation by CDK4 and CDK2 to sustain CDK4 activation.'},\n",
       "   {'pubmed': 23776131,\n",
       "    'text': 'FBXO28 activity and stability are regulated during the cell cycle by CDK1/2-mediated phosphorylation of FBXO28, which is required for its efficient ubiquitylation of MYC.'},\n",
       "   {'pubmed': 23781148,\n",
       "    'text': 'antitumor effects of DOC-1R may be mediated by negatively regulating G1 phase progression and G1/S transition through inhibiting CDK2 expression and activation'},\n",
       "   {'pubmed': 23787073,\n",
       "    'text': 'This study indicates that genetic polymorphisms of AURKA, BRCA1 and CCNE1 may affect ovarian cancer susceptibility in Chinese Han women.'},\n",
       "   {'pubmed': 24075009,\n",
       "    'text': 'Cells decide at the end of mitosis to either start the next cell cycle by immediately building up CDK2 activity or to enter a transient G0-like state by suppressing CDK2 activity.'},\n",
       "   {'pubmed': 24204256,\n",
       "    'text': 'PKC activation then triggered activation of cdk-2, which became further activated by caspase-3.'},\n",
       "   {'pubmed': 24216307,\n",
       "    'text': 'Two nuclear export signals of Cdc6 work cooperatively and distinctly for the cytoplasmic translocation of Cdc6 phosphorylated by cyclin A/Cdk2.'},\n",
       "   {'pubmed': 24240190,\n",
       "    'text': 'CDK2 knockdown alters the profile of Rb phosphorylation in coronary artery smooth muscle cells, as well as the proliferative response of these cells to mitogenic stimulation.'},\n",
       "   {'pubmed': 24386425,\n",
       "    'text': 'Of the total, the deregulation of several genes (CDK1, CDK2, CDK4, MCM2, MCM3, MCM4, EIF3a and RPN2) were potentially associated with disease development and progression.'},\n",
       "   {'pubmed': 24444383,\n",
       "    'text': 'MYC-dependent breast cancer cells possess high MYC expression and high level of MYC phosphorylation, but are not sensitive to inhibition of CDK2.'},\n",
       "   {'pubmed': 24520316,\n",
       "    'text': 'CRIF1 may play a regulatory role in the BM microenvironment-induced leukemia cell cycle arrest possibly through interacting with CDK2 and acting as a cyclin-dependent kinase inhibitor.'},\n",
       "   {'pubmed': 24623419,\n",
       "    'text': 'Authors identified and validated two additional host proteins interacting with human SAMHD1, namely, cyclin-dependent kinase 2 (CDK2) and S-phase kinase-associated protein 2 (SKP2).'},\n",
       "   {'pubmed': 24671051,\n",
       "    'text': 'Expression of Notch1, -2, and -3, CDK2, and CCNE1 was significantly decreased by upregulation of ALDH1A1 in A549 cells, but increased by its interruption in A549s cells.'},\n",
       "   {'pubmed': 24700371,\n",
       "    'text': 'In the subsequent molecular experiments, western blot analysis and kinase activity detection demonstrated that TAMs can significantly boost the expression levels and activities of CDK2 and CDK4 in SKOV3 cells.'},\n",
       "   {'pubmed': 24820417,\n",
       "    'text': 'Results show that CDK2 phosphorylates Thr-156 in GATA3.'},\n",
       "   {'pubmed': 24911186,\n",
       "    'text': 'Report structure-based discovery of allosteric inhibitors of CDK2.'},\n",
       "   {'pubmed': 24922574,\n",
       "    'text': 'CDK2 Supports HIV-1 Reverse Transcription in CD4+ T Cells.HIV-1 reverse transcriptase Is a Substrate for CDK2-Dependent Phosphorylation'},\n",
       "   {'pubmed': 24935000,\n",
       "    'text': 'It is concluded that non-response to everolimus is characterized by increased cdk2/cyclin A, driving RCC cells into the G2/M-phase. VPA hinders everolimus non-response by diminishing cdk2/cyclin A.'},\n",
       "   {'pubmed': 24947816,\n",
       "    'text': 'More effective packing and interactions between CDK2 and LMW cyclin E isoforms, however, produce more efficient protein-protein complexes that accelerate the cell division processes in cancer cells, where these cyclin E isoforms are overexpressed.'},\n",
       "   {'pubmed': 25015816,\n",
       "    'text': 'CDK2 was strongly linked to cell cycle progression and coordinated SAMHD1 phosphorylation and inactivation.'},\n",
       "   {'pubmed': 25071185,\n",
       "    'text': 'Cdk1 activity blocks lysosomal degradation of HIF-1alpha and increases HIF-1alpha protein stability and transcriptional activity. By contrast, Cdk2 activity promotes lysosomal degradation of HIF-1alpha at the G1/S phase transition.'},\n",
       "   {'pubmed': 25136960,\n",
       "    'text': 'A positive correlation between cdk2/cyclin A expression level and tumor growth. Amygdalin, therefore, may block tumor growth.'},\n",
       "   {'pubmed': 25149358,\n",
       "    'text': 'for both oncogene- and DNA damage-induced cellular senescence, CDK2 transcript and protein are decreased in a p53- and RB-dependent manner, and this repression is necessary for cell-cycle exit during senescence'},\n",
       "   {'pubmed': 25154617,\n",
       "    'text': 'Which is mutated at the CDK2 phosphorylation site.'},\n",
       "   {'pubmed': 25218592,\n",
       "    'text': 'The Cell Cycle Profiling - Risk Score (C2P-RS) based on CDK1 and CDK2 specific activities was significantly associated with relapse in breast cancers.'},\n",
       "   {'pubmed': 25218637,\n",
       "    'text': 'Data indicate that tumour suppressor RASSF1A triggers large tumor suppressor kinase 1 (LATS)-CDK2 interaction and restricts CDK2 kinase activity towards BRCA2.'},\n",
       "   {'pubmed': 25220500,\n",
       "    'text': 'Cyclin A2 and its associated kinase (CDK2) activity are required for optimal induction of progesterone receptor target genes in breast cancer cells.'},\n",
       "   {'pubmed': 25265349,\n",
       "    'text': 'High CDK2 expression is associated with nasopharyngeal carcinoma.'},\n",
       "   {'pubmed': 25271736,\n",
       "    'text': 'observations suggested that androgen suppresses the proliferation of CRPC cells partially through inhibition of Cyclin A, Cdk2, and Skp2'},\n",
       "   {'pubmed': 25303791,\n",
       "    'text': 'TPPII, MYBBP1A and CDK2 form a protein-protein interaction network.'},\n",
       "   {'pubmed': 25410660,\n",
       "    'text': 'Inhibition of CDK2 phosphorylation blocked phosphorylation of hnRNP K, preventing its incorporation into stress granules (SGs). Due to interaction between hnRNP K with TDP-43, the loss of hnRNP K from SGs prevented accumulation of TDP-43.'},\n",
       "   {'pubmed': 25443276,\n",
       "    'text': 'At a median follow-up of 36 months (1-109M), tumor with low CDK2SA-CDK1SA ratio showed significantly better 5-year recurrence-free survival than those with high CDK2SA-CDK1SA ratio (88.7% vs. 54.7%, P = 0.00141).'},\n",
       "   {'pubmed': 25451924,\n",
       "    'text': 'miR-638 regulates proliferation and myeloid differentiation by targeting CDK2 and may serve as a novel target for leukemia therapy or marker for AML diagnosis and prognosis'},\n",
       "   {'pubmed': 25463638,\n",
       "    'text': 'No association of CDK2 polymorphisms with risk of endometrial carcinoma found in Chinese Han women.'},\n",
       "   {'pubmed': 25501982,\n",
       "    'text': 'HOXA7 promotes cell proliferation, and these changes are mediated by cyclin E1/CDK2'},\n",
       "   {'pubmed': 25541464,\n",
       "    'text': 'Using the fact that deletion of the yeast CDC28 gene is functionally complemented by human CDK1 or CDK2, we set up an in vivo screen system to evaluate the inhibitory potency of purine derivatives against these two human Cdks.'},\n",
       "   {'pubmed': 25728284,\n",
       "    'text': 'CDK2 up-regulates the protein level of KLF10 through reducing its association with SIAH1, a KLF10 E3-ubiqutin ligase involved in proteasomal degradation.'},\n",
       "   {'pubmed': 25744732,\n",
       "    'text': 'Diclofenac and curcumin overcome these carcinogenic effects by downregulating telomerase activity, diminishing the expression of TERT, CDK4, CDK2, cyclin D1, and cyclin E.'},\n",
       "   {'pubmed': 25754137,\n",
       "    'text': 'The docking and molecular dynamics investigation performed here led to the identification of the interactions responsible for stabilizing the ligand ChEMBL474807 at the active sites of the glycogen synthase kinase-3beta (GSK-3) and cyclin-dependent kinase-2'},\n",
       "   {'pubmed': 25808870,\n",
       "    'text': 'CP110 plays a mechanistic role in response of lung cancer cells to CDK2 inhibition, especially in the presence of activated KRAS mutations.'},\n",
       "   {'pubmed': 25832654,\n",
       "    'text': 'NUAK2 silencing and inactivation of the PI3K pathway efficiently controlled CDK2 expression, whereas CDK2 inactivation specifically abrogated the growth of NUAK2-amplified and PTEN-deficient melanoma cells.'},\n",
       "   {'pubmed': 25860957,\n",
       "    'text': 'Identified ING5 as a novel CDK2 substrate. ING5 is phosphorylated at a single site, threonine 152, by cyclin E/CDK2 and cyclin A/CDK2. This site is also phosphorylated in cells in a cell cycle dependent manner, consistent with it being a CDK2 substrate.'},\n",
       "   {'pubmed': 25918937,\n",
       "    'text': 'analysis of the conformational characteristics and ligand binding mechanisms of CDK2 [review]'},\n",
       "   {'pubmed': 26026083,\n",
       "    'text': 'G1 arrest induced by SB265610 occurred at concentrations lacking CXCR2 selectivity and revealed cyclin-dependent kinase 2 (CDK2) (Thr160) hypophosphorylation, cyclin D3 gene down-regulation, and p21 post-translational induction'},\n",
       "   {'pubmed': 26028036,\n",
       "    'text': 'our study reveals a novel function of CDK2 in EGF-induced cell transformation and the associated signal transduction pathways. This indicates that CDK2 is a useful molecular target for the chemoprevention and therapy against skin cancer.'},\n",
       "   {'pubmed': 26124340,\n",
       "    'text': 'We found no significant associations for CDKN2 p16 580 C>T and MDM2 SNP309 T>G variants between cases and controls.'},\n",
       "   {'pubmed': 26139602,\n",
       "    'text': 'Sox2 phosphorylation by Cdk2 promotes the establishment but not the maintenance of the pluripotent state.'},\n",
       "   {'pubmed': 26147897,\n",
       "    'text': 'fluspirilene is a potential CDK2 inhibitor and a candidate anti-cancer drug for the treatment of human hepatocellular carcinoma.'},\n",
       "   {'pubmed': 26151768,\n",
       "    'text': 'In G28 cells, a dosedependent induction of CDK2, p21 and cyclin D was observed between 10 and 50 microM roscovitine after 72 h, however, at the highest concentration of 100 microM, all investigated genes were downregulated.'},\n",
       "   {'pubmed': 26204491,\n",
       "    'text': 'ovary tumors with elevated CCNE1 expression may be staged for Cdk2-targeted therapy'},\n",
       "   {'pubmed': 26248649,\n",
       "    'text': 'Results show that miR-200c plays an antioncogenic role in clear cell renal cell carcinomas, through controlling cell growth and cell-cycle progression by downregulating the G1-S regulator CDK2.'},\n",
       "   {'pubmed': 26297806,\n",
       "    'text': 'Centriolar satellites build a centrosomal microcephaly protein complex critical for human neurodevelopment that promotes CDK2 centrosomal localization and centriole duplication.'},\n",
       "   {'pubmed': 26304236,\n",
       "    'text': 'show thata combining cyclin-dependent kinase 2 (CDK2) antagonism and ubiquitin thioesterase 33 (USP33) depletion augments anaphase catastrophe via changes in centrosomal protein of 110 kDa (CP110) protein expression.'},\n",
       "   {'pubmed': 26373553,\n",
       "    'text': 'PIWIL2 has a role in promoting progression of non-small cell lung cancer by inducing CDK2 and Cyclin A expression'},\n",
       "   {'pubmed': 26464264,\n",
       "    'text': 'the results suggest that CK1delta activity can be modulated by the interplay between CK1delta and CDK2/E or CDK5/p35.'},\n",
       "   {'pubmed': 26555773,\n",
       "    'text': 'both cell lines feature a significant reduction of CDK2 expression verified at the RNA and protein level, respectively'},\n",
       "   {'pubmed': 26595527,\n",
       "    'text': 'Inappropriate activation of CDK2 in S phase underlies the sensitivity of a subset of cell lines to Chk1 inhibitors.'},\n",
       "   {'pubmed': 26644182,\n",
       "    'text': 'PHD1 is phosphorylated by CDK2, CDK4 and CDK6 at Serine 130.'},\n",
       "   {'pubmed': 26652902,\n",
       "    'text': 'CDK2 and DNA-PK regulate PR transcriptional activity by distinct mechanisms.'},\n",
       "   {'pubmed': 26677902,\n",
       "    'text': 'Clioquinol suppressed cell cycle progression in the S-phase in SMMC-7721 hepatoma cells via the p21, p27-cyclin E,A/Cdk2 pathway.'},\n",
       "   {'pubmed': 26714749,\n",
       "    'text': 'SATB2 regulates the mitosis of cell cycle and affects G1 cell cycle via interaction with CDK2.'},\n",
       "   {'pubmed': 26730572,\n",
       "    'text': 'A novel link has been discussed between CDK2 expression and cell migration by characterizing the CDK2-mediated phosphorylation of BRMS1.'},\n",
       "   {'pubmed': 26828990,\n",
       "    'text': 'The expression of cdk2 in malignancy of ovarian tumors.'},\n",
       "   {'pubmed': 26857166,\n",
       "    'text': 'CDK2 controls a wide-spread epigenetic program that drives transcription at differentiation-related gene promoters specifically in G1. (Review)'},\n",
       "   {'pubmed': 26861625,\n",
       "    'text': 'Foxo3 circular RNA retards cell cycle progression via forming ternary complexes with p21 and CDK2.'},\n",
       "   {'pubmed': 26876672,\n",
       "    'text': 'CDK2 protects podocytes from apoptosis and reduced expression of CDK2 associates with the development of diabetic nephropathy.'},\n",
       "   {'pubmed': 26890070,\n",
       "    'text': 'Consistent with these findings, a genome-scale pooled RNA interference screen revealed that toxic doses of MK-1775 are suppressed by CDK2 or Cyclin A2 knockdown. These findings support G2 exit as the more significant effect of Wee1 inhibition in pancreatic cancers.'},\n",
       "   {'pubmed': 26960431,\n",
       "    'text': 'Study describes a positive feedback loop centred on cyclin A2-Cdk2 inhibition of interphase APC/C-Cdc20 to allow further cyclin A2 accumulation and mitotic entry.'},\n",
       "   {'pubmed': 27065328,\n",
       "    'text': 'Here, we found that centrosomal protein of 76 kDa (Cep76), previously shown to restrain centriole amplification, interacts with cyclin-dependent kinase 2 (CDK2) and is a bona fide substrate of this kinase. Cep76 is preferentially phosphorylated by cyclin A/CDK2 at a single site S83, and this event is crucial to suppress centriole amplification in S phase'},\n",
       "   {'pubmed': 27100206,\n",
       "    'text': 'These two states are separated by different metastable states that share hybrid structural features with both forms of the kinase. In contrast, the CDK2/ANS complex landscape is compatible with a conformational selection picture where the binding of ANS in proximity of the alphaC helix causes a population shift toward the inactive conformation'},\n",
       "   {'pubmed': 27109354,\n",
       "    'text': 'evidence that CDK1/2 participate in the regulation of constitutive pre-mRNA splicing by EGF stimulation in MDA-MB-468 cells.'},\n",
       "   {'pubmed': 27163259,\n",
       "    'text': 'a SUMO-deficient Rb mutant results in reduced SUMOylation and phosphorylation, weakened CDK2 binding, and attenuated E2F-1 sequestration.'},\n",
       "   {'pubmed': 27166195,\n",
       "    'text': 'Data show that Noxa-mediated MCL-1 phosphorylation and degradation is regulated by CDK2.'},\n",
       "   {'pubmed': 27259234,\n",
       "    'text': \"Findings suggest that ERK1/2-mediated Cdk2/cyclin A signaling pathway is involved in 7-hydroxy-5,4'-dimethoxy-2-arylbenzofuran (Ary) - induced G1/S-phase arrest.\"},\n",
       "   {'pubmed': 27285764,\n",
       "    'text': 'WHSC1L1 and H3K36me2 are enriched in the gene bodies of the cell cycle-related genes CDC6 and CDK2, implying that WHSC1L1 directly regulates the transcription of these gene'},\n",
       "   {'pubmed': 27378523,\n",
       "    'text': 'this study suggests that CDK2 and CDK9 are potential therapeutic targets in Neuroblastoma (NB) and that abrogating CDK2 and CDK9 activity by small molecules like dinaciclib is a promising strategy and a treatment option for NB patients'},\n",
       "   {'pubmed': 27402161,\n",
       "    'text': 'periodic phosphorylation of Ku70 by cyclin-cyclin dependent kinases prevents the interaction of Ku with replication origin after initiation events in S-phase.'},\n",
       "   {'pubmed': 27465546,\n",
       "    'text': 'The upregulation of miR-302b reduced the expression of CDK2, and inhibited ERK signaling pathway, thereby inhibiting cell proliferation and G1/S phase conversion rate.'},\n",
       "   {'pubmed': 27629878,\n",
       "    'text': 'Dsg2 knockdown arrests non-small cell lung cancer cell cycle progression via modulation of p27-CDK2 levels.'},\n",
       "   {'pubmed': 27663592,\n",
       "    'text': 'Analysis of genomic data from TCGA demonstrated coamplification of CCNE1 and AKT2 Overexpression of Cyclin E1 and AKT isoforms, in addition to mutant TP53, imparted malignant characteristics in untransformed fallopian tube secretory cells, the dominant site of origin of high-grade serous ovarian cancer'},\n",
       "   {'pubmed': 27819669,\n",
       "    'text': 'Here, we introduce a transcriptional signature to specifically track CDK2 activity. It responds to genetic and chemical perturbations in the CDK-RB-E2F axis, correlates with mitotic rate in vitro and in vivo and reacts rapidly to changes in CDK2 activity during cell cycle progression'},\n",
       "   {'pubmed': 27831832,\n",
       "    'text': 'The data presented here suggest that the temporal separation of pro- and anti-apoptotic pathways by selective inhibition of CDK2 disrupts coherent signaling modules and may synergize with anti-proliferative drugs, averting toxic side effects from CDK1 inhibition.'},\n",
       "   {'pubmed': 28003546,\n",
       "    'text': 'CDK2 phosphorylates polyQ-AR specifically at Ser(96). Phosphorylation of polyQ-AR by CDK2 increased protein stabilization and toxicity and is negatively regulated by the adenylyl cyclase/protein kinase A signaling pathway in spinobulbar muscular atrophy.'},\n",
       "   {'pubmed': 28030798,\n",
       "    'text': 'Date show that when Wee1 alone is inhibited, Chk1 suppresses CDC45 loading and thereby limits the extent of unscheduled replication initiation and subsequent S-phase DNA damage, despite very high CDK-activity.'},\n",
       "   {'pubmed': 28100774,\n",
       "    'text': 'CDK2 serves as an important nexus linking primary beta-cell dysfunction to progressive beta-cell mass deterioration in diabetes'},\n",
       "   {'pubmed': 28345297,\n",
       "    'text': 'Residual Cdk1/Cdk2 activity after DNA damage promotes cell senescence.'},\n",
       "   {'pubmed': 28350121,\n",
       "    'text': 'Results show that cyclin E1 and CDK2 participate in STC1 promoting cell proliferation of prostate neoplasm cells.'},\n",
       "   {'pubmed': 28430399,\n",
       "    'text': 'These compounds bind CDK2/ Cyclin A, inhibit its kinase activity, compete with substrate binding, but not with ATP, and dock onto the T-loop of CDK2. The best compound also binds CDK4 and CDK4/Cyclin D1, but not CDK1.'},\n",
       "   {'pubmed': 28666995,\n",
       "    'text': 'The authors find that Spy1 confers structural changes to Cdk2 that obviate the requirement of Cdk activation loop phosphorylation.'},\n",
       "   {'pubmed': 28760857,\n",
       "    'text': 'High CDK2 expression is associated with breast cancer.'},\n",
       "   {'pubmed': 28842430,\n",
       "    'text': 'identified a new phosphorylation-based substrate recognition mechanism of PTPN12 by CDK2, which orchestrated signaling crosstalk between the oncogenic CDK2 and HER2 pathways'},\n",
       "   {'pubmed': 29157894,\n",
       "    'text': 'CDK2 contributes to S81-AR phosphorylation and transactivation while CDK4 was not shown to be involved in this process.'},\n",
       "   {'pubmed': 29203878,\n",
       "    'text': 'ATM and CDK2 control the chromatin remodeling activity of CSB in the regulation of double strand break repair pathway choice.'},\n",
       "   {'pubmed': 29254517,\n",
       "    'text': 'The authors show that human Cyclin-Dependent-Kinases (CDKs) target the RAD9 subunit of the 9-1-1 checkpoint clamp on Thr292, to modulate DNA damage checkpoint activation. Thr292 phosphorylation on RAD9 creates a binding site for Polo-Like-Kinase1 (PLK1), which phosphorylates RAD9 on Thr313.'},\n",
       "   {'pubmed': 29323532,\n",
       "    'text': 'Among these genes, STAT3 and CDK2 were significantly associated with recurrence. Further study suggested that inhibition of CDK2 reduced invasion of Pca cell lines. The invasion ability was rescued after reintroduction of CDK2.'},\n",
       "   {'pubmed': 29328425,\n",
       "    'text': 'CDK2 may have key functions in neuroblastoma progression by regulating the expression of neoplastic genes.'},\n",
       "   {'pubmed': 29372687,\n",
       "    'text': 'Our findings provide a rationale for clinical use of Bcl-2 family inhibitors in combination with CDK2 inhibitors for treatment of Mcl-1-dependent colorectal tumours associated with expression of Bcl-2, Bcl-XL and Bcl-w proteins. In addition, we have shown potential of CDK2 inhibitors for treatment of tumours expressing R273H mutant p53.'},\n",
       "   {'pubmed': 29507054,\n",
       "    'text': 'Proteomics and phosphoproteomics analyses identified CDK2 as a driver of resistance to both BRAF and Hsp90 inhibitors and its expression is regulated by the transcription factor MITF upon XL888 treatment of melanoma cells.'},\n",
       "   {'pubmed': 29570358,\n",
       "    'text': 'LINC00958 acts as an oncogenic gene in the gliomagenesis through miR-203-CDK2 regulation, providing a novel insight into glioma tumorigenesis.'},\n",
       "   {'pubmed': 29896817,\n",
       "    'text': 'The roles of the CDK2/SIRT5 axis in gastric cancer.'},\n",
       "   {'pubmed': 30300385,\n",
       "    'text': 'CDK2 gene is a strong candidate gene for type-2 diabetes. CDK2 gene is located in a risk area composed of 4 blocks in strong LD around the type-2 diabetes SNP rs2069408. CDK2 overexpression inhibits the association of insulin receptor to the microtubule components, tubulin alpha and tubulin beta. Physical association of the insulin receptor complex with CDK2 is inhibited by the expression of tyrosine phosphatase PTPLAD1.'}],\n",
       "  'genomic_pos': {'chr': '12',\n",
       "   'end': 55972784,\n",
       "   'ensemblgene': 'ENSG00000123374',\n",
       "   'start': 55966769,\n",
       "   'strand': 1},\n",
       "  'genomic_pos_hg19': {'chr': '12',\n",
       "   'end': 56366568,\n",
       "   'start': 56360553,\n",
       "   'strand': 1},\n",
       "  'go': {'BP': [{'evidence': 'IBA',\n",
       "     'gocategory': 'BP',\n",
       "     'id': 'GO:0000082',\n",
       "     'pubmed': 21873635,\n",
       "     'term': 'G1/S transition of mitotic cell cycle'},\n",
       "    {'evidence': 'TAS',\n",
       "     'gocategory': 'BP',\n",
       "     'id': 'GO:0000082',\n",
       "     'term': 'G1/S transition of mitotic cell cycle'},\n",
       "    {'evidence': 'NAS',\n",
       "     'gocategory': 'BP',\n",
       "     'id': 'GO:0000086',\n",
       "     'pubmed': 1653904,\n",
       "     'term': 'G2/M transition of mitotic cell cycle'},\n",
       "    {'evidence': 'TAS',\n",
       "     'gocategory': 'BP',\n",
       "     'id': 'GO:0000086',\n",
       "     'term': 'G2/M transition of mitotic cell cycle'},\n",
       "    {'evidence': 'IEA',\n",
       "     'gocategory': 'BP',\n",
       "     'id': 'GO:0000122',\n",
       "     'term': 'negative regulation of transcription by RNA polymerase II'},\n",
       "    {'evidence': 'TAS',\n",
       "     'gocategory': 'BP',\n",
       "     'id': 'GO:0006260',\n",
       "     'pubmed': 19238148,\n",
       "     'term': 'DNA replication'},\n",
       "    {'evidence': 'IEA',\n",
       "     'gocategory': 'BP',\n",
       "     'id': 'GO:0006281',\n",
       "     'term': 'DNA repair'},\n",
       "    {'evidence': 'IBA',\n",
       "     'gocategory': 'BP',\n",
       "     'id': 'GO:0006468',\n",
       "     'pubmed': 21873635,\n",
       "     'term': 'protein phosphorylation'},\n",
       "    {'evidence': 'IDA',\n",
       "     'gocategory': 'BP',\n",
       "     'id': 'GO:0006468',\n",
       "     'pubmed': [12944431, 28666995],\n",
       "     'term': 'protein phosphorylation'},\n",
       "    {'evidence': 'IEA',\n",
       "     'gocategory': 'BP',\n",
       "     'id': 'GO:0006813',\n",
       "     'term': 'potassium ion transport'},\n",
       "    {'evidence': 'TAS',\n",
       "     'gocategory': 'BP',\n",
       "     'id': 'GO:0006977',\n",
       "     'term': 'DNA damage response, signal transduction by p53 class mediator resulting in cell cycle arrest'},\n",
       "    {'evidence': 'IMP',\n",
       "     'gocategory': 'BP',\n",
       "     'id': 'GO:0007099',\n",
       "     'pubmed': 26297806,\n",
       "     'term': 'centriole replication'},\n",
       "    {'evidence': 'IEP',\n",
       "     'gocategory': 'BP',\n",
       "     'id': 'GO:0007265',\n",
       "     'pubmed': 9054499,\n",
       "     'term': 'Ras protein signal transduction'},\n",
       "    {'evidence': 'IBA',\n",
       "     'gocategory': 'BP',\n",
       "     'id': 'GO:0008284',\n",
       "     'pubmed': 21873635,\n",
       "     'term': 'positive regulation of cell proliferation'},\n",
       "    {'evidence': 'IDA',\n",
       "     'gocategory': 'BP',\n",
       "     'id': 'GO:0008284',\n",
       "     'pubmed': 10767298,\n",
       "     'term': 'positive regulation of cell proliferation'},\n",
       "    {'evidence': 'IBA',\n",
       "     'gocategory': 'BP',\n",
       "     'id': 'GO:0010389',\n",
       "     'pubmed': 21873635,\n",
       "     'term': 'regulation of G2/M transition of mitotic cell cycle'},\n",
       "    {'evidence': 'IDA',\n",
       "     'gocategory': 'BP',\n",
       "     'id': 'GO:0016572',\n",
       "     'pubmed': 11746698,\n",
       "     'term': 'histone phosphorylation'},\n",
       "    {'evidence': 'IDA',\n",
       "     'gocategory': 'BP',\n",
       "     'id': 'GO:0018105',\n",
       "     'pubmed': 23184662,\n",
       "     'term': 'peptidyl-serine phosphorylation'},\n",
       "    {'evidence': 'TAS',\n",
       "     'gocategory': 'BP',\n",
       "     'id': 'GO:0031145',\n",
       "     'term': 'anaphase-promoting complex-dependent catabolic process'},\n",
       "    {'evidence': 'TAS',\n",
       "     'gocategory': 'BP',\n",
       "     'id': 'GO:0031571',\n",
       "     'pubmed': 21319273,\n",
       "     'term': 'mitotic G1 DNA damage checkpoint'},\n",
       "    {'evidence': 'IEA',\n",
       "     'gocategory': 'BP',\n",
       "     'id': 'GO:0032298',\n",
       "     'term': 'positive regulation of DNA-dependent DNA replication initiation'},\n",
       "    {'evidence': 'IEA',\n",
       "     'gocategory': 'BP',\n",
       "     'id': 'GO:0045893',\n",
       "     'term': 'positive regulation of transcription, DNA-templated'},\n",
       "    {'evidence': 'TAS',\n",
       "     'gocategory': 'BP',\n",
       "     'id': 'GO:0051298',\n",
       "     'pubmed': 19238148,\n",
       "     'term': 'centrosome duplication'},\n",
       "    {'evidence': 'IEA',\n",
       "     'gocategory': 'BP',\n",
       "     'id': 'GO:0051301',\n",
       "     'term': 'cell division'},\n",
       "    {'evidence': 'TAS',\n",
       "     'gocategory': 'BP',\n",
       "     'id': 'GO:0051321',\n",
       "     'pubmed': 19238148,\n",
       "     'term': 'meiotic cell cycle'},\n",
       "    {'evidence': 'IDA',\n",
       "     'gocategory': 'BP',\n",
       "     'id': 'GO:0060968',\n",
       "     'pubmed': 20935635,\n",
       "     'term': 'regulation of gene silencing'},\n",
       "    {'evidence': 'TAS',\n",
       "     'gocategory': 'BP',\n",
       "     'id': 'GO:0071732',\n",
       "     'pubmed': 20079829,\n",
       "     'term': 'cellular response to nitric oxide'},\n",
       "    {'evidence': 'TAS',\n",
       "     'gocategory': 'BP',\n",
       "     'id': 'GO:1901796',\n",
       "     'term': 'regulation of signal transduction by p53 class mediator'}],\n",
       "   'CC': [{'evidence': 'IBA',\n",
       "     'gocategory': 'CC',\n",
       "     'id': 'GO:0000307',\n",
       "     'pubmed': 21873635,\n",
       "     'term': 'cyclin-dependent protein kinase holoenzyme complex'},\n",
       "    {'evidence': 'IDA',\n",
       "     'gocategory': 'CC',\n",
       "     'id': 'GO:0000307',\n",
       "     'pubmed': [1312467, 8692841],\n",
       "     'term': 'cyclin-dependent protein kinase holoenzyme complex'},\n",
       "    {'evidence': 'IEA',\n",
       "     'gocategory': 'CC',\n",
       "     'id': 'GO:0000781',\n",
       "     'term': 'chromosome, telomeric region'},\n",
       "    {'evidence': 'IEA',\n",
       "     'gocategory': 'CC',\n",
       "     'id': 'GO:0000793',\n",
       "     'term': 'condensed chromosome'},\n",
       "    {'evidence': 'IEA',\n",
       "     'gocategory': 'CC',\n",
       "     'id': 'GO:0000805',\n",
       "     'term': 'X chromosome'},\n",
       "    {'evidence': 'IEA',\n",
       "     'gocategory': 'CC',\n",
       "     'id': 'GO:0000806',\n",
       "     'term': 'Y chromosome'},\n",
       "    {'evidence': 'IBA',\n",
       "     'gocategory': 'CC',\n",
       "     'id': 'GO:0005634',\n",
       "     'pubmed': 21873635,\n",
       "     'term': 'nucleus'},\n",
       "    {'evidence': 'IDA',\n",
       "     'gocategory': 'CC',\n",
       "     'id': 'GO:0005634',\n",
       "     'pubmed': 10767298,\n",
       "     'term': 'nucleus'},\n",
       "    {'evidence': 'IDA',\n",
       "     'gocategory': 'CC',\n",
       "     'id': 'GO:0005654',\n",
       "     'pubmed': 8245034,\n",
       "     'term': 'nucleoplasm'},\n",
       "    {'evidence': 'TAS',\n",
       "     'gocategory': 'CC',\n",
       "     'id': 'GO:0005654',\n",
       "     'term': 'nucleoplasm'},\n",
       "    {'evidence': 'IEA',\n",
       "     'gocategory': 'CC',\n",
       "     'id': 'GO:0005667',\n",
       "     'term': 'transcription factor complex'},\n",
       "    {'evidence': 'IBA',\n",
       "     'gocategory': 'CC',\n",
       "     'id': 'GO:0005737',\n",
       "     'pubmed': 21873635,\n",
       "     'term': 'cytoplasm'},\n",
       "    {'evidence': 'IDA',\n",
       "     'gocategory': 'CC',\n",
       "     'id': 'GO:0005737',\n",
       "     'pubmed': 10767298,\n",
       "     'term': 'cytoplasm'},\n",
       "    {'evidence': 'IDA',\n",
       "     'gocategory': 'CC',\n",
       "     'id': 'GO:0005768',\n",
       "     'pubmed': 21262353,\n",
       "     'term': 'endosome'},\n",
       "    {'evidence': 'IDA',\n",
       "     'gocategory': 'CC',\n",
       "     'id': 'GO:0005813',\n",
       "     'term': 'centrosome'},\n",
       "    {'evidence': 'TAS',\n",
       "     'gocategory': 'CC',\n",
       "     'id': 'GO:0005813',\n",
       "     'pubmed': 19238148,\n",
       "     'term': 'centrosome'},\n",
       "    {'evidence': 'TAS',\n",
       "     'gocategory': 'CC',\n",
       "     'id': 'GO:0005829',\n",
       "     'term': 'cytosol'},\n",
       "    {'evidence': 'IDA',\n",
       "     'gocategory': 'CC',\n",
       "     'id': 'GO:0015030',\n",
       "     'pubmed': 10995387,\n",
       "     'term': 'Cajal body'},\n",
       "    {'evidence': 'IEA',\n",
       "     'gocategory': 'CC',\n",
       "     'id': 'GO:0097123',\n",
       "     'term': 'cyclin A1-CDK2 complex'},\n",
       "    {'evidence': 'IDA',\n",
       "     'gocategory': 'CC',\n",
       "     'id': 'GO:0097124',\n",
       "     'pubmed': [1312467, 8876165, 11746698, 15024385],\n",
       "     'term': 'cyclin A2-CDK2 complex'},\n",
       "    {'evidence': 'IEA',\n",
       "     'gocategory': 'CC',\n",
       "     'id': 'GO:0097134',\n",
       "     'term': 'cyclin E1-CDK2 complex'},\n",
       "    {'evidence': 'IEA',\n",
       "     'gocategory': 'CC',\n",
       "     'id': 'GO:0097135',\n",
       "     'term': 'cyclin E2-CDK2 complex'}],\n",
       "   'MF': [{'category': 'MF',\n",
       "     'evidence': 'IEA',\n",
       "     'id': 'GO:0000287',\n",
       "     'term': 'magnesium ion binding'},\n",
       "    {'category': 'MF',\n",
       "     'evidence': 'IGI',\n",
       "     'id': 'GO:0004674',\n",
       "     'pubmed': 26996940,\n",
       "     'term': 'protein serine/threonine kinase activity'},\n",
       "    {'category': 'MF',\n",
       "     'evidence': 'IBA',\n",
       "     'id': 'GO:0004693',\n",
       "     'pubmed': 21873635,\n",
       "     'term': 'cyclin-dependent protein serine/threonine kinase activity'},\n",
       "    {'category': 'MF',\n",
       "     'evidence': 'IDA',\n",
       "     'id': 'GO:0004693',\n",
       "     'pubmed': 21596315,\n",
       "     'term': 'cyclin-dependent protein serine/threonine kinase activity'},\n",
       "    {'category': 'MF',\n",
       "     'evidence': 'TAS',\n",
       "     'id': 'GO:0004693',\n",
       "     'term': 'cyclin-dependent protein serine/threonine kinase activity'},\n",
       "    {'category': 'MF',\n",
       "     'evidence': 'IPI',\n",
       "     'id': 'GO:0005515',\n",
       "     'pubmed': [2227411,\n",
       "      7630397,\n",
       "      8242750,\n",
       "      8521818,\n",
       "      8601310,\n",
       "      8684460,\n",
       "      8756328,\n",
       "      8756624,\n",
       "      9840943,\n",
       "      10330164,\n",
       "      11463386,\n",
       "      11980914,\n",
       "      12244298,\n",
       "      12361598,\n",
       "      12839962,\n",
       "      12941338,\n",
       "      15107404,\n",
       "      15178429,\n",
       "      15189033,\n",
       "      15232106,\n",
       "      15239650,\n",
       "      15530371,\n",
       "      15611625,\n",
       "      15890360,\n",
       "      16061792,\n",
       "      16209941,\n",
       "      16326706,\n",
       "      16327805,\n",
       "      16765349,\n",
       "      16962592,\n",
       "      17053782,\n",
       "      17254966,\n",
       "      17254967,\n",
       "      17418410,\n",
       "      19150984,\n",
       "      19470470,\n",
       "      19829063,\n",
       "      20098747,\n",
       "      20871633,\n",
       "      21092281,\n",
       "      21423803,\n",
       "      21565702,\n",
       "      21596315,\n",
       "      21952639,\n",
       "      22810586,\n",
       "      22940584,\n",
       "      23082202,\n",
       "      23455922,\n",
       "      23602568,\n",
       "      23781148,\n",
       "      23853094,\n",
       "      24218572,\n",
       "      24358021,\n",
       "      25218637,\n",
       "      25241761,\n",
       "      25416956,\n",
       "      25852190,\n",
       "      26496610,\n",
       "      28666995],\n",
       "     'term': 'protein binding'},\n",
       "    {'category': 'MF',\n",
       "     'evidence': 'IEA',\n",
       "     'id': 'GO:0005524',\n",
       "     'term': 'ATP binding'},\n",
       "    {'category': 'MF',\n",
       "     'evidence': 'IPI',\n",
       "     'id': 'GO:0019904',\n",
       "     'pubmed': [8876165, 15024385],\n",
       "     'term': 'protein domain specific binding'},\n",
       "    {'category': 'MF',\n",
       "     'evidence': 'IBA',\n",
       "     'id': 'GO:0030332',\n",
       "     'pubmed': 21873635,\n",
       "     'term': 'cyclin binding'},\n",
       "    {'category': 'MF',\n",
       "     'evidence': 'IDA',\n",
       "     'id': 'GO:0030332',\n",
       "     'pubmed': [1653904, 23781148],\n",
       "     'term': 'cyclin binding'},\n",
       "    {'category': 'MF',\n",
       "     'evidence': 'IPI',\n",
       "     'id': 'GO:0030332',\n",
       "     'pubmed': [1312467, 15024385],\n",
       "     'term': 'cyclin binding'},\n",
       "    {'category': 'MF',\n",
       "     'evidence': 'IDA',\n",
       "     'id': 'GO:0035173',\n",
       "     'pubmed': 8692841,\n",
       "     'qualifier': 'contributes_to',\n",
       "     'term': 'histone kinase activity'},\n",
       "    {'category': 'MF',\n",
       "     'evidence': 'IDA',\n",
       "     'id': 'GO:0097472',\n",
       "     'pubmed': [1312467, 28666995],\n",
       "     'term': 'cyclin-dependent protein kinase activity'}]},\n",
       "  'homologene': {'genes': [[3702, 824036],\n",
       "    [4530, 4328135],\n",
       "    [4530, 4331415],\n",
       "    [4896, 2539869],\n",
       "    [4932, 852457],\n",
       "    [5141, 3876264],\n",
       "    [7165, 3291042],\n",
       "    [7227, 42453],\n",
       "    [7955, 406715],\n",
       "    [8364, 493498],\n",
       "    [9031, 100529062],\n",
       "    [9544, 711002],\n",
       "    [9598, 467032],\n",
       "    [9606, 1017],\n",
       "    [9615, 100855704],\n",
       "    [9913, 519217],\n",
       "    [10090, 12566],\n",
       "    [10116, 362817],\n",
       "    [28985, 2896999],\n",
       "    [33169, 4620303],\n",
       "    [318829, 2679140]],\n",
       "   'id': 74409},\n",
       "  'interpro': [{'desc': 'Protein kinase domain',\n",
       "    'id': 'IPR000719',\n",
       "    'short_desc': 'Prot_kinase_dom'},\n",
       "   {'desc': 'Serine/threonine-protein kinase, active site',\n",
       "    'id': 'IPR008271',\n",
       "    'short_desc': 'Ser/Thr_kinase_AS'},\n",
       "   {'desc': 'Protein kinase-like domain superfamily',\n",
       "    'id': 'IPR011009',\n",
       "    'short_desc': 'Kinase-like_dom_sf'},\n",
       "   {'desc': 'Protein kinase, ATP binding site',\n",
       "    'id': 'IPR017441',\n",
       "    'short_desc': 'Protein_kinase_ATP_BS'}],\n",
       "  'ipi': ['IPI00031681', 'IPI00910650'],\n",
       "  'map_location': '12q13.2',\n",
       "  'name': 'cyclin dependent kinase 2',\n",
       "  'other_names': ['cdc2-related protein kinase',\n",
       "   'cell division protein kinase 2',\n",
       "   'cyclin-dependent kinase 2',\n",
       "   'p33 protein kinase'],\n",
       "  'pantherdb': {'HGNC': '1771',\n",
       "   'ortholog': [{'MGI': '104772',\n",
       "     'ortholog_type': 'LDO',\n",
       "     'panther_family': 'PTHR24056',\n",
       "     'taxid': 10090,\n",
       "     'uniprot_kb': 'P97377'},\n",
       "    {'RGD': '70486',\n",
       "     'ortholog_type': 'LDO',\n",
       "     'panther_family': 'PTHR24056',\n",
       "     'taxid': 10116,\n",
       "     'uniprot_kb': 'Q63699'},\n",
       "    {'Ensembl': 'ENSGALG00000032699',\n",
       "     'ortholog_type': 'LDO',\n",
       "     'panther_family': 'PTHR24056',\n",
       "     'taxid': 9031,\n",
       "     'uniprot_kb': 'A0A1D5PUK9'},\n",
       "    {'ZFIN': 'ZDB-GENE-040426-2741',\n",
       "     'ortholog_type': 'LDO',\n",
       "     'panther_family': 'PTHR24056',\n",
       "     'taxid': 7955,\n",
       "     'uniprot_kb': 'Q7ZWB1'},\n",
       "    {'FlyBase': 'FBgn0004107',\n",
       "     'ortholog_type': 'LDO',\n",
       "     'panther_family': 'PTHR24056',\n",
       "     'taxid': 7227,\n",
       "     'uniprot_kb': 'P23573'},\n",
       "    {'SGD': 'S000000364',\n",
       "     'ortholog_type': 'LDO',\n",
       "     'panther_family': 'PTHR24056',\n",
       "     'taxid': 4932,\n",
       "     'uniprot_kb': 'P00546'},\n",
       "    {'PomBase': 'SPBC11B10.09',\n",
       "     'ortholog_type': 'LDO',\n",
       "     'panther_family': 'PTHR24056',\n",
       "     'taxid': 4896,\n",
       "     'uniprot_kb': 'P04551'},\n",
       "    {'dictyBase': 'DDB_G0272813',\n",
       "     'ortholog_type': 'LDO',\n",
       "     'panther_family': 'PTHR24056',\n",
       "     'taxid': 352472,\n",
       "     'uniprot_kb': 'P34112'},\n",
       "    {'TAIR': 'AT3G48750',\n",
       "     'ortholog_type': 'LDO',\n",
       "     'panther_family': 'PTHR24056',\n",
       "     'taxid': 3702,\n",
       "     'uniprot_kb': 'P24100'},\n",
       "    {'HGNC': '1779',\n",
       "     'ortholog_type': 'P',\n",
       "     'panther_family': 'PTHR24056',\n",
       "     'taxid': 9606,\n",
       "     'uniprot_kb': 'P49336'},\n",
       "    {'HGNC': '19338',\n",
       "     'ortholog_type': 'P',\n",
       "     'panther_family': 'PTHR24056',\n",
       "     'taxid': 9606,\n",
       "     'uniprot_kb': 'Q9BWU1'},\n",
       "    {'HGNC': '1778',\n",
       "     'ortholog_type': 'P',\n",
       "     'panther_family': 'PTHR24056',\n",
       "     'taxid': 9606,\n",
       "     'uniprot_kb': 'P50613'},\n",
       "    {'HGNC': '14434',\n",
       "     'ortholog_type': 'P',\n",
       "     'panther_family': 'PTHR24056',\n",
       "     'taxid': 9606,\n",
       "     'uniprot_kb': 'Q96Q40'},\n",
       "    {'HGNC': '8883',\n",
       "     'ortholog_type': 'P',\n",
       "     'panther_family': 'PTHR24056',\n",
       "     'taxid': 9606,\n",
       "     'uniprot_kb': 'O94921'},\n",
       "    {'HGNC': '8751',\n",
       "     'ortholog_type': 'P',\n",
       "     'panther_family': 'PTHR24056',\n",
       "     'taxid': 9606,\n",
       "     'uniprot_kb': 'Q07002'},\n",
       "    {'HGNC': '8749',\n",
       "     'ortholog_type': 'P',\n",
       "     'panther_family': 'PTHR24056',\n",
       "     'taxid': 9606,\n",
       "     'uniprot_kb': 'Q00536'},\n",
       "    {'HGNC': '8750',\n",
       "     'ortholog_type': 'P',\n",
       "     'panther_family': 'PTHR24056',\n",
       "     'taxid': 9606,\n",
       "     'uniprot_kb': 'Q00537'},\n",
       "    {'HGNC': '1774',\n",
       "     'ortholog_type': 'P',\n",
       "     'panther_family': 'PTHR24056',\n",
       "     'taxid': 9606,\n",
       "     'uniprot_kb': 'Q00535'},\n",
       "    {'HGNC': '1722',\n",
       "     'ortholog_type': 'P',\n",
       "     'panther_family': 'PTHR24056',\n",
       "     'taxid': 9606,\n",
       "     'uniprot_kb': 'P06493'},\n",
       "    {'HGNC': '17346',\n",
       "     'ortholog_type': 'P',\n",
       "     'panther_family': 'PTHR24056',\n",
       "     'taxid': 9606,\n",
       "     'uniprot_kb': 'Q13523'}],\n",
       "   'uniprot_kb': 'P24941'},\n",
       "  'pathway': {'biocarta': [{'id': 'cellcyclepathway',\n",
       "     'name': 'cyclins and cell cycle regulation'},\n",
       "    {'id': 'efppathway',\n",
       "     'name': 'estrogen responsive protein efp controls cell cycle and breast tumors growth'},\n",
       "    {'id': 'fbw7pathway', 'name': 'cyclin e destruction pathway'},\n",
       "    {'id': 'g1pathway', 'name': 'cell cycle: g1/s check point'},\n",
       "    {'id': 'mcmpathway', 'name': 'cdk regulation of dna replication'},\n",
       "    {'id': 'p27pathway',\n",
       "     'name': 'regulation of p27 phosphorylation during cell cycle progression'},\n",
       "    {'id': 'p53pathway', 'name': 'p53 signaling pathway'},\n",
       "    {'id': 'raccycdpathway',\n",
       "     'name': 'influence of ras and rho proteins on g1 to s transition'},\n",
       "    {'id': 'rbpathway',\n",
       "     'name': 'rb tumor suppressor/checkpoint signaling in response to dna damage'},\n",
       "    {'id': 'skp2e2fpathway', 'name': 'e2f1 destruction pathway'}],\n",
       "   'kegg': [{'id': 'hsa04068',\n",
       "     'name': 'FoxO signaling pathway - Homo sapiens (human)'},\n",
       "    {'id': 'hsa04110', 'name': 'Cell cycle - Homo sapiens (human)'},\n",
       "    {'id': 'hsa04114', 'name': 'Oocyte meiosis - Homo sapiens (human)'},\n",
       "    {'id': 'hsa04115', 'name': 'p53 signaling pathway - Homo sapiens (human)'},\n",
       "    {'id': 'hsa04151',\n",
       "     'name': 'PI3K-Akt signaling pathway - Homo sapiens (human)'},\n",
       "    {'id': 'hsa04218', 'name': 'Cellular senescence - Homo sapiens (human)'},\n",
       "    {'id': 'hsa04914',\n",
       "     'name': 'Progesterone-mediated oocyte maturation - Homo sapiens (human)'},\n",
       "    {'id': 'hsa04934', 'name': 'Cushing,s syndrome - Homo sapiens (human)'},\n",
       "    {'id': 'hsa05161', 'name': 'Hepatitis B - Homo sapiens (human)'},\n",
       "    {'id': 'hsa05162', 'name': 'Measles - Homo sapiens (human)'},\n",
       "    {'id': 'hsa05165',\n",
       "     'name': 'Human papillomavirus infection - Homo sapiens (human)'},\n",
       "    {'id': 'hsa05168',\n",
       "     'name': 'Herpes simplex infection - Homo sapiens (human)'},\n",
       "    {'id': 'hsa05169',\n",
       "     'name': 'Epstein-Barr virus infection - Homo sapiens (human)'},\n",
       "    {'id': 'hsa05200', 'name': 'Pathways in cancer - Homo sapiens (human)'},\n",
       "    {'id': 'hsa05203', 'name': 'Viral carcinogenesis - Homo sapiens (human)'},\n",
       "    {'id': 'hsa05215', 'name': 'Prostate cancer - Homo sapiens (human)'},\n",
       "    {'id': 'hsa05222',\n",
       "     'name': 'Small cell lung cancer - Homo sapiens (human)'},\n",
       "    {'id': 'hsa05226', 'name': 'Gastric cancer - Homo sapiens (human)'}],\n",
       "   'netpath': [{'id': 'Pathway_BCR', 'name': 'BCR'},\n",
       "    {'id': 'Pathway_EGFR1', 'name': 'EGFR1'},\n",
       "    {'id': 'Pathway_ID', 'name': 'ID'},\n",
       "    {'id': 'Pathway_IL2', 'name': 'IL2'},\n",
       "    {'id': 'Pathway_KitReceptor', 'name': 'KitReceptor'},\n",
       "    {'id': 'Pathway_RAGE', 'name': 'RAGE'},\n",
       "    {'id': 'Pathway_TGF_beta_Receptor', 'name': 'TGF_beta_Receptor'}],\n",
       "   'pid': [{'id': 'atr_pathway', 'name': 'ATR signaling pathway'},\n",
       "    {'id': 'bard1pathway', 'name': 'BARD1 signaling events'},\n",
       "    {'id': 'e2f_pathway', 'name': 'E2F transcription factor network'},\n",
       "    {'id': 'foxm1pathway', 'name': 'FOXM1 transcription factor network'},\n",
       "    {'id': 'foxopathway', 'name': 'FoxO family signaling'},\n",
       "    {'id': 'il2_1pathway', 'name': 'IL2-mediated signaling events'},\n",
       "    {'id': 'mtor_4pathway', 'name': 'mTOR signaling pathway'},\n",
       "    {'id': 'p53regulationpathway', 'name': 'p53 pathway'},\n",
       "    {'id': 'p73pathway', 'name': 'p73 transcription factor network'},\n",
       "    {'id': 'prlsignalingeventspathway',\n",
       "     'name': 'Signaling events mediated by PRL'},\n",
       "    {'id': 'rb_1pathway', 'name': 'Regulation of retinoblastoma protein'},\n",
       "    {'id': 'smad2_3nuclearpathway',\n",
       "     'name': 'Regulation of nuclear SMAD2/3 signaling'}],\n",
       "   'reactome': [{'id': 'R-HSA-109582', 'name': 'Hemostasis'},\n",
       "    {'id': 'R-HSA-1474165', 'name': 'Reproduction'},\n",
       "    {'id': 'R-HSA-1500620', 'name': 'Meiosis'},\n",
       "    {'id': 'R-HSA-1538133', 'name': 'G0 and Early G1'},\n",
       "    {'id': 'R-HSA-162582', 'name': 'Signal Transduction'},\n",
       "    {'id': 'R-HSA-1640170', 'name': 'Cell Cycle'},\n",
       "    {'id': 'R-HSA-1640170', 'name': 'Cell Cycle'},\n",
       "    {'id': 'R-HSA-174143',\n",
       "     'name': 'APC/C-mediated degradation of cell cycle proteins'},\n",
       "    {'id': 'R-HSA-176187',\n",
       "     'name': 'Activation of ATR in response to replication stress'},\n",
       "    {'id': 'R-HSA-176408',\n",
       "     'name': 'Regulation of APC/C activators between G1/S and early anaphase'},\n",
       "    {'id': 'R-HSA-187577',\n",
       "     'name': 'SCF(Skp2)-mediated degradation of p27/p21'},\n",
       "    {'id': 'R-HSA-212436', 'name': 'Generic Transcription Pathway'},\n",
       "    {'id': 'R-HSA-2262752', 'name': 'Cellular responses to stress'},\n",
       "    {'id': 'R-HSA-2559582',\n",
       "     'name': 'Senescence-Associated Secretory Phenotype (SASP)'},\n",
       "    {'id': 'R-HSA-2559583', 'name': 'Cellular Senescence'},\n",
       "    {'id': 'R-HSA-2559586',\n",
       "     'name': 'DNA Damage/Telomere Stress Induced Senescence'},\n",
       "    {'id': 'R-HSA-3700989', 'name': 'Transcriptional Regulation by TP53'},\n",
       "    {'id': 'R-HSA-453274', 'name': 'Mitotic G2-G2/M phases'},\n",
       "    {'id': 'R-HSA-453276', 'name': 'Regulation of mitotic cell cycle'},\n",
       "    {'id': 'R-HSA-453279', 'name': 'Mitotic G1-G1/S phases'},\n",
       "    {'id': 'R-HSA-5633007', 'name': 'Regulation of TP53 Activity'},\n",
       "    {'id': 'R-HSA-5693532', 'name': 'DNA Double-Strand Break Repair'},\n",
       "    {'id': 'R-HSA-5693538', 'name': 'Homology Directed Repair'},\n",
       "    {'id': 'R-HSA-5693567',\n",
       "     'name': 'HDR through Homologous Recombination (HRR) or Single Strand Annealing (SSA)'},\n",
       "    {'id': 'R-HSA-5693607',\n",
       "     'name': 'Processing of DNA double-strand break ends'},\n",
       "    {'id': 'R-HSA-6791312',\n",
       "     'name': 'TP53 Regulates Transcription of Cell Cycle Genes'},\n",
       "    {'id': 'R-HSA-6804116',\n",
       "     'name': 'TP53 Regulates Transcription of Genes Involved in G1 Cell Cycle Arrest'},\n",
       "    {'id': 'R-HSA-6804756',\n",
       "     'name': 'Regulation of TP53 Activity through Phosphorylation'},\n",
       "    {'id': 'R-HSA-6804757', 'name': 'Regulation of TP53 Degradation'},\n",
       "    {'id': 'R-HSA-6806003',\n",
       "     'name': 'Regulation of TP53 Expression and Degradation'},\n",
       "    {'id': 'R-HSA-68911', 'name': 'G2 Phase'},\n",
       "    {'id': 'R-HSA-68949', 'name': 'Orc1 removal from chromatin'},\n",
       "    {'id': 'R-HSA-68962', 'name': 'Activation of the pre-replicative complex'},\n",
       "    {'id': 'R-HSA-69002', 'name': 'DNA Replication Pre-Initiation'},\n",
       "    {'id': 'R-HSA-69017',\n",
       "     'name': 'CDK-mediated phosphorylation and removal of Cdc6'},\n",
       "    {'id': 'R-HSA-69052',\n",
       "     'name': 'Switching of origins to a post-replicative state'},\n",
       "    {'id': 'R-HSA-69200',\n",
       "     'name': 'Phosphorylation of proteins involved in G1/S transition by active Cyclin E:Cdk2 complexes'},\n",
       "    {'id': 'R-HSA-69202',\n",
       "     'name': 'Cyclin E associated events during G1/S transition '},\n",
       "    {'id': 'R-HSA-69206', 'name': 'G1/S Transition'},\n",
       "    {'id': 'R-HSA-69239', 'name': 'Synthesis of DNA'},\n",
       "    {'id': 'R-HSA-69242', 'name': 'S Phase'},\n",
       "    {'id': 'R-HSA-69273',\n",
       "     'name': 'Cyclin A/B1/B2 associated events during G2/M transition'},\n",
       "    {'id': 'R-HSA-69275', 'name': 'G2/M Transition'},\n",
       "    {'id': 'R-HSA-69278', 'name': 'Cell Cycle, Mitotic'},\n",
       "    {'id': 'R-HSA-69306', 'name': 'DNA Replication'},\n",
       "    {'id': 'R-HSA-69481', 'name': 'G2/M Checkpoints'},\n",
       "    {'id': 'R-HSA-69563', 'name': 'p53-Dependent G1 DNA Damage Response'},\n",
       "    {'id': 'R-HSA-69580', 'name': 'p53-Dependent G1/S DNA damage checkpoint'},\n",
       "    {'id': 'R-HSA-69615', 'name': 'G1/S DNA Damage Checkpoints'},\n",
       "    {'id': 'R-HSA-69620', 'name': 'Cell Cycle Checkpoints'},\n",
       "    {'id': 'R-HSA-69656',\n",
       "     'name': 'Cyclin A:Cdk2-associated events at S phase entry'},\n",
       "    {'id': 'R-HSA-73857', 'name': 'RNA Polymerase II Transcription'},\n",
       "    {'id': 'R-HSA-73894', 'name': 'DNA Repair'},\n",
       "    {'id': 'R-HSA-74160', 'name': 'Gene expression (Transcription)'},\n",
       "    {'id': 'R-HSA-8848021', 'name': 'Signaling by PTK6'},\n",
       "    {'id': 'R-HSA-8849470', 'name': 'PTK6 Regulates Cell Cycle'},\n",
       "    {'id': 'R-HSA-8953897', 'name': 'Cellular responses to external stimuli'},\n",
       "    {'id': 'R-HSA-9006927',\n",
       "     'name': 'Signaling by Non-Receptor Tyrosine Kinases'},\n",
       "    {'id': 'R-HSA-912446', 'name': 'Meiotic recombination'},\n",
       "    {'id': 'R-HSA-983231',\n",
       "     'name': 'Factors involved in megakaryocyte development and platelet production'}],\n",
       "   'wikipathways': [{'id': 'WP1530',\n",
       "     'name': 'miRNA Regulation of DNA Damage Response'},\n",
       "    {'id': 'WP179', 'name': 'Cell Cycle'},\n",
       "    {'id': 'WP2032',\n",
       "     'name': 'Human Thyroid Stimulating Hormone (TSH) signaling pathway'},\n",
       "    {'id': 'WP2261', 'name': 'Signaling Pathways in Glioblastoma'},\n",
       "    {'id': 'WP2374', 'name': 'Oncostatin M Signaling Pathway'},\n",
       "    {'id': 'WP2431', 'name': 'Spinal Cord Injury'},\n",
       "    {'id': 'WP2446', 'name': 'Retinoblastoma (RB) in Cancer'},\n",
       "    {'id': 'WP2586', 'name': 'Aryl Hydrocarbon Receptor'},\n",
       "    {'id': 'WP2877', 'name': 'Vitamin D Receptor Pathway'},\n",
       "    {'id': 'WP4172', 'name': 'PI3K-Akt Signaling Pathway'},\n",
       "    {'id': 'WP45', 'name': 'G1 to S cell cycle control'},\n",
       "    {'id': 'WP466', 'name': 'DNA Replication'},\n",
       "    {'id': 'WP53', 'name': 'ID signaling pathway'},\n",
       "    {'id': 'WP707', 'name': 'DNA Damage Response'}]},\n",
       "  'pdb': ['1AQ1',\n",
       "   '1B38',\n",
       "   '1B39',\n",
       "   '1BUH',\n",
       "   '1CKP',\n",
       "   '1DI8',\n",
       "   '1DM2',\n",
       "   '1E1V',\n",
       "   '1E1X',\n",
       "   '1E9H',\n",
       "   '1F5Q',\n",
       "   '1FIN',\n",
       "   '1FQ1',\n",
       "   '1FVT',\n",
       "   '1FVV',\n",
       "   '1G5S',\n",
       "   '1GIH',\n",
       "   '1GII',\n",
       "   '1GIJ',\n",
       "   '1GY3',\n",
       "   '1GZ8',\n",
       "   '1H00',\n",
       "   '1H01',\n",
       "   '1H07',\n",
       "   '1H08',\n",
       "   '1H0V',\n",
       "   '1H0W',\n",
       "   '1H1P',\n",
       "   '1H1Q',\n",
       "   '1H1R',\n",
       "   '1H1S',\n",
       "   '1H24',\n",
       "   '1H25',\n",
       "   '1H26',\n",
       "   '1H27',\n",
       "   '1H28',\n",
       "   '1HCK',\n",
       "   '1HCL',\n",
       "   '1JST',\n",
       "   '1JSU',\n",
       "   '1JSV',\n",
       "   '1JVP',\n",
       "   '1KE5',\n",
       "   '1KE6',\n",
       "   '1KE7',\n",
       "   '1KE8',\n",
       "   '1KE9',\n",
       "   '1OGU',\n",
       "   '1OI9',\n",
       "   '1OIQ',\n",
       "   '1OIR',\n",
       "   '1OIT',\n",
       "   '1OIU',\n",
       "   '1OIY',\n",
       "   '1OKV',\n",
       "   '1OKW',\n",
       "   '1OL1',\n",
       "   '1OL2',\n",
       "   '1P2A',\n",
       "   '1P5E',\n",
       "   '1PF8',\n",
       "   '1PKD',\n",
       "   '1PW2',\n",
       "   '1PXI',\n",
       "   '1PXJ',\n",
       "   '1PXK',\n",
       "   '1PXL',\n",
       "   '1PXM',\n",
       "   '1PXN',\n",
       "   '1PXO',\n",
       "   '1PXP',\n",
       "   '1PYE',\n",
       "   '1QMZ',\n",
       "   '1R78',\n",
       "   '1URC',\n",
       "   '1URW',\n",
       "   '1V1K',\n",
       "   '1VYW',\n",
       "   '1VYZ',\n",
       "   '1W0X',\n",
       "   '1W8C',\n",
       "   '1W98',\n",
       "   '1WCC',\n",
       "   '1Y8Y',\n",
       "   '1Y91',\n",
       "   '1YKR',\n",
       "   '2A0C',\n",
       "   '2A4L',\n",
       "   '2B52',\n",
       "   '2B53',\n",
       "   '2B54',\n",
       "   '2B55',\n",
       "   '2BHE',\n",
       "   '2BHH',\n",
       "   '2BKZ',\n",
       "   '2BPM',\n",
       "   '2BTR',\n",
       "   '2BTS',\n",
       "   '2C4G',\n",
       "   '2C5N',\n",
       "   '2C5O',\n",
       "   '2C5V',\n",
       "   '2C5X',\n",
       "   '2C5Y',\n",
       "   '2C68',\n",
       "   '2C69',\n",
       "   '2C6I',\n",
       "   '2C6K',\n",
       "   '2C6L',\n",
       "   '2C6M',\n",
       "   '2C6O',\n",
       "   '2C6T',\n",
       "   '2CCH',\n",
       "   '2CCI',\n",
       "   '2CJM',\n",
       "   '2CLX',\n",
       "   '2DS1',\n",
       "   '2DUV',\n",
       "   '2EXM',\n",
       "   '2FVD',\n",
       "   '2G9X',\n",
       "   '2HIC',\n",
       "   '2I40',\n",
       "   '2IW6',\n",
       "   '2IW8',\n",
       "   '2IW9',\n",
       "   '2J9M',\n",
       "   '2JGZ',\n",
       "   '2R3F',\n",
       "   '2R3G',\n",
       "   '2R3H',\n",
       "   '2R3I',\n",
       "   '2R3J',\n",
       "   '2R3K',\n",
       "   '2R3L',\n",
       "   '2R3M',\n",
       "   '2R3N',\n",
       "   '2R3O',\n",
       "   '2R3P',\n",
       "   '2R3Q',\n",
       "   '2R3R',\n",
       "   '2R64',\n",
       "   '2UUE',\n",
       "   '2UZB',\n",
       "   '2UZD',\n",
       "   '2UZE',\n",
       "   '2UZL',\n",
       "   '2UZN',\n",
       "   '2UZO',\n",
       "   '2V0D',\n",
       "   '2V22',\n",
       "   '2VTA',\n",
       "   '2VTH',\n",
       "   '2VTI',\n",
       "   '2VTJ',\n",
       "   '2VTL',\n",
       "   '2VTM',\n",
       "   '2VTN',\n",
       "   '2VTO',\n",
       "   '2VTP',\n",
       "   '2VTQ',\n",
       "   '2VTR',\n",
       "   '2VTS',\n",
       "   '2VTT',\n",
       "   '2VU3',\n",
       "   '2VV9',\n",
       "   '2W05',\n",
       "   '2W06',\n",
       "   '2W17',\n",
       "   '2W1H',\n",
       "   '2WEV',\n",
       "   '2WFY',\n",
       "   '2WHB',\n",
       "   '2WIH',\n",
       "   '2WIP',\n",
       "   '2WMA',\n",
       "   '2WMB',\n",
       "   '2WPA',\n",
       "   '2WXV',\n",
       "   '2X1N',\n",
       "   '2XMY',\n",
       "   '2XNB',\n",
       "   '3BHT',\n",
       "   '3BHU',\n",
       "   '3BHV',\n",
       "   '3DDP',\n",
       "   '3DDQ',\n",
       "   '3DOG',\n",
       "   '3EID',\n",
       "   '3EJ1',\n",
       "   '3EOC',\n",
       "   '3EZR',\n",
       "   '3EZV',\n",
       "   '3F5X',\n",
       "   '3FZ1',\n",
       "   '3IG7',\n",
       "   '3IGG',\n",
       "   '3LE6',\n",
       "   '3LFN',\n",
       "   '3LFQ',\n",
       "   '3LFS',\n",
       "   '3MY5',\n",
       "   '3NS9',\n",
       "   '3PJ8',\n",
       "   '3PXF',\n",
       "   '3PXQ',\n",
       "   '3PXR',\n",
       "   '3PXY',\n",
       "   '3PXZ',\n",
       "   '3PY0',\n",
       "   '3PY1',\n",
       "   '3QHR',\n",
       "   '3QHW',\n",
       "   '3QL8',\n",
       "   '3QQF',\n",
       "   '3QQG',\n",
       "   '3QQH',\n",
       "   '3QQJ',\n",
       "   '3QQK',\n",
       "   '3QQL',\n",
       "   '3QRT',\n",
       "   '3QRU',\n",
       "   '3QTQ',\n",
       "   '3QTR',\n",
       "   '3QTS',\n",
       "   '3QTU',\n",
       "   '3QTW',\n",
       "   '3QTX',\n",
       "   '3QTZ',\n",
       "   '3QU0',\n",
       "   '3QWJ',\n",
       "   '3QWK',\n",
       "   '3QX2',\n",
       "   '3QX4',\n",
       "   '3QXO',\n",
       "   '3QXP',\n",
       "   '3QZF',\n",
       "   '3QZG',\n",
       "   '3QZH',\n",
       "   '3QZI',\n",
       "   '3R1Q',\n",
       "   '3R1S',\n",
       "   '3R1Y',\n",
       "   '3R28',\n",
       "   '3R6X',\n",
       "   '3R71',\n",
       "   '3R73',\n",
       "   '3R7E',\n",
       "   '3R7I',\n",
       "   '3R7U',\n",
       "   '3R7V',\n",
       "   '3R7Y',\n",
       "   '3R83',\n",
       "   '3R8L',\n",
       "   '3R8M',\n",
       "   '3R8P',\n",
       "   '3R8U',\n",
       "   '3R8V',\n",
       "   '3R8Z',\n",
       "   '3R9D',\n",
       "   '3R9H',\n",
       "   '3R9N',\n",
       "   '3R9O',\n",
       "   '3RAH',\n",
       "   '3RAI',\n",
       "   '3RAK',\n",
       "   '3RAL',\n",
       "   '3RJC',\n",
       "   '3RK5',\n",
       "   '3RK7',\n",
       "   '3RK9',\n",
       "   '3RKB',\n",
       "   '3RM6',\n",
       "   '3RM7',\n",
       "   '3RMF',\n",
       "   '3RNI',\n",
       "   '3ROY',\n",
       "   '3RPO',\n",
       "   '3RPR',\n",
       "   '3RPV',\n",
       "   '3RPY',\n",
       "   '3RZB',\n",
       "   '3S00',\n",
       "   '3S0O',\n",
       "   '3S1H',\n",
       "   '3S2P',\n",
       "   '3SQQ',\n",
       "   '3SW4',\n",
       "   '3SW7',\n",
       "   '3TI1',\n",
       "   '3TIY',\n",
       "   '3TIZ',\n",
       "   '3TNW',\n",
       "   '3ULI',\n",
       "   '3UNJ',\n",
       "   '3UNK',\n",
       "   '3WBL',\n",
       "   '4ACM',\n",
       "   '4BCK',\n",
       "   '4BCM',\n",
       "   '4BCN',\n",
       "   '4BCO',\n",
       "   '4BCP',\n",
       "   '4BCQ',\n",
       "   '4BGH',\n",
       "   '4BZD',\n",
       "   '4CFM',\n",
       "   '4CFN',\n",
       "   '4CFU',\n",
       "   '4CFV',\n",
       "   '4CFW',\n",
       "   '4CFX',\n",
       "   '4D1X',\n",
       "   '4D1Z',\n",
       "   '4EK3',\n",
       "   '4EK4',\n",
       "   '4EK5',\n",
       "   '4EK6',\n",
       "   '4EK8',\n",
       "   '4EOI',\n",
       "   '4EOJ',\n",
       "   '4EOK',\n",
       "   '4EOL',\n",
       "   '4EOM',\n",
       "   '4EON',\n",
       "   '4EOO',\n",
       "   '4EOP',\n",
       "   '4EOQ',\n",
       "   '4EOR',\n",
       "   '4EOS',\n",
       "   '4ERW',\n",
       "   '4EZ3',\n",
       "   '4EZ7',\n",
       "   '4FKG',\n",
       "   '4FKI',\n",
       "   '4FKJ',\n",
       "   '4FKL',\n",
       "   '4FKO',\n",
       "   '4FKP',\n",
       "   '4FKQ',\n",
       "   '4FKR',\n",
       "   '4FKS',\n",
       "   '4FKT',\n",
       "   '4FKU',\n",
       "   '4FKV',\n",
       "   '4FKW',\n",
       "   '4FX3',\n",
       "   '4GCJ',\n",
       "   '4I3Z',\n",
       "   '4II5',\n",
       "   '4KD1',\n",
       "   '4LYN',\n",
       "   '4NJ3',\n",
       "   '4RJ3',\n",
       "   '5A14',\n",
       "   '5AND',\n",
       "   '5ANE',\n",
       "   '5ANG',\n",
       "   '5ANI',\n",
       "   '5ANJ',\n",
       "   '5ANK',\n",
       "   '5ANO',\n",
       "   '5CYI',\n",
       "   '5D1J',\n",
       "   '5FP5',\n",
       "   '5FP6',\n",
       "   '5IEV',\n",
       "   '5IEX',\n",
       "   '5IEY',\n",
       "   '5IF1',\n",
       "   '5JQ5',\n",
       "   '5JQ8',\n",
       "   '5K4J',\n",
       "   '5L2W',\n",
       "   '5LMK',\n",
       "   '5MHQ',\n",
       "   '5NEV',\n",
       "   '5OO0',\n",
       "   '5OO1',\n",
       "   '5OO3',\n",
       "   '5OSJ',\n",
       "   '5OSM',\n",
       "   '5UQ1',\n",
       "   '5UQ2',\n",
       "   '5UQ3'],\n",
       "  'pfam': 'PF00069',\n",
       "  'pharmgkb': 'PA101',\n",
       "  'pharos': {'target_id': 10687},\n",
       "  'pir': 'A41227',\n",
       "  'prosite': 'PS50011',\n",
       "  'reagent': {'GNF_Qia_hs-genome_v1_siRNA': [{'id': 'GNF247215',\n",
       "     'relationship': 'is'},\n",
       "    {'id': 'GNF247216', 'relationship': 'is'},\n",
       "    {'id': 'GNF247217', 'relationship': 'is'},\n",
       "    {'id': 'GNF247218', 'relationship': 'is'}],\n",
       "   'GNF_hs-ORFeome1_1_reads': {'id': 'GNF161504', 'relationship': 'is'},\n",
       "   'GNF_hs-Origene': [{'id': 'GNF035860', 'relationship': 'similar to'},\n",
       "    {'id': 'GNF037258', 'relationship': 'is'},\n",
       "    {'id': 'GNF048982', 'relationship': 'is'}],\n",
       "   'GNF_hs-druggable_lenti-shRNA': [{'id': 'GNF081385', 'relationship': 'is'},\n",
       "    {'id': 'GNF081386', 'relationship': 'is'},\n",
       "    {'id': 'GNF081387', 'relationship': 'is'}],\n",
       "   'GNF_hs-druggable_plasmid-shRNA': [{'id': 'GNF051995',\n",
       "     'relationship': 'is'},\n",
       "    {'id': 'GNF056761', 'relationship': 'is'},\n",
       "    {'id': 'GNF061563', 'relationship': 'is'},\n",
       "    {'id': 'GNF078683', 'relationship': 'is'}],\n",
       "   'GNF_hs-druggable_siRNA': [{'id': 'GNF066537', 'relationship': 'is'},\n",
       "    {'id': 'GNF066538', 'relationship': 'is'}],\n",
       "   'GNF_hs-pkinase_IDT-siRNA': [{'id': 'GNF166768', 'relationship': 'is'},\n",
       "    {'id': 'GNF166769', 'relationship': 'is'},\n",
       "    {'id': 'GNF166770', 'relationship': 'is'},\n",
       "    {'id': 'GNF166771', 'relationship': 'is'}],\n",
       "   'GNF_hs_LentiORF-HA-MYC': {'id': 'GNF282834', 'relationship': 'is'},\n",
       "   'GNF_hs_LentiORF-Jred': {'id': 'GNF283761', 'relationship': 'is'},\n",
       "   'GNF_mm+hs-MGC': {'id': 'GNF002384', 'relationship': 'is'},\n",
       "   'Invitrogen_IVTHSSIPKv2': [{'id': 'GNF324610', 'relationship': 'is'},\n",
       "    {'id': 'GNF324611', 'relationship': 'is'}],\n",
       "   'NIBRI_hs-Secretome_pDEST': {'id': 'GNF337962', 'relationship': 'is'},\n",
       "   'NOVART_hs-genome_siRNA': [{'id': 'GNF093028', 'relationship': 'is'},\n",
       "    {'id': 'GNF132726', 'relationship': 'is'}]},\n",
       "  'refseq': {'genomic': ['NC_000012.12', 'NG_034014.1'],\n",
       "   'protein': ['NP_001277159.1',\n",
       "    'NP_001789.2',\n",
       "    'NP_439892.2',\n",
       "    'XP_011536034.1'],\n",
       "   'rna': ['NM_001290230.1', 'NM_001798.4', 'NM_052827.3', 'XM_011537732.2'],\n",
       "   'translation': [{'protein': 'NP_001789.2', 'rna': 'NM_001798.4'},\n",
       "    {'protein': 'NP_001277159.1', 'rna': 'NM_001290230.1'},\n",
       "    {'protein': 'NP_439892.2', 'rna': 'NM_052827.3'},\n",
       "    {'protein': 'XP_011536034.1', 'rna': 'XM_011537732.2'}]},\n",
       "  'reporter': {'HG-U133_Plus_2': ['204252_at', '211803_at', '211804_s_at'],\n",
       "   'HG-U95Av2': ['1792_g_at', '1833_at'],\n",
       "   'HTA-2_0': 'TC12000496.hg.1',\n",
       "   'HuEx-1_0': '3417146',\n",
       "   'HuGene-1_1': '7956076',\n",
       "   'HuGene-2_1': '16752305'},\n",
       "  'summary': 'This gene encodes a member of a family of serine/threonine protein kinases that participate in cell cycle regulation. The encoded protein is the catalytic subunit of the cyclin-dependent protein kinase complex, which regulates progression through the cell cycle. Activity of this protein is especially critical during the G1 to S phase transition. This protein associates with and regulated by other subunits of the complex including cyclin A or E, CDK inhibitor p21Cip1 (CDKN1A), and p27Kip1 (CDKN1B). Alternative splicing results in multiple transcript variants. [provided by RefSeq, Mar 2014].',\n",
       "  'symbol': 'CDK2',\n",
       "  'taxid': 9606,\n",
       "  'type_of_gene': 'protein-coding',\n",
       "  'umls': {'cui': 'C1332733'},\n",
       "  'unigene': ['Hs.689624', 'Hs.19192'],\n",
       "  'uniprot': {'Swiss-Prot': 'P24941',\n",
       "   'TrEMBL': ['A0A024RB10',\n",
       "    'G3V5T9',\n",
       "    'E7ESI2',\n",
       "    'B4DDL9',\n",
       "    'A0A024RB77',\n",
       "    'G3V317']},\n",
       "  'wikipedia': {'url_stub': 'Cyclin-dependent kinase 2'}}]"
      ]
     },
     "execution_count": 31,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "payload = {'ids': '673,1017', 'species': 'human'}\n",
    "response = requests.post('http://mygene.info/v3/gene', data=payload)\n",
    "response.json()"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 32,
   "metadata": {},
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "BRAF: This gene encodes a protein belonging to the RAF family of serine/threonine protein kinases. This protein plays a role in regulating the MAP kinase/ERK signaling pathway, which affects cell division, differentiation, and secretion. Mutations in this gene, most commonly the V600E mutation, are the most frequently identified cancer-causing mutations in melanoma, and have been identified in various other cancers as well, including non-Hodgkin lymphoma, colorectal cancer, thyroid carcinoma, non-small cell lung carcinoma, hairy cell leukemia and adenocarcinoma of lung. Mutations in this gene are also associated with cardiofaciocutaneous, Noonan, and Costello syndromes, which exhibit overlapping phenotypes. A pseudogene of this gene has been identified on the X chromosome. [provided by RefSeq, Aug 2017].\n",
      "CDK2: This gene encodes a member of a family of serine/threonine protein kinases that participate in cell cycle regulation. The encoded protein is the catalytic subunit of the cyclin-dependent protein kinase complex, which regulates progression through the cell cycle. Activity of this protein is especially critical during the G1 to S phase transition. This protein associates with and regulated by other subunits of the complex including cyclin A or E, CDK inhibitor p21Cip1 (CDKN1A), and p27Kip1 (CDKN1B). Alternative splicing results in multiple transcript variants. [provided by RefSeq, Mar 2014].\n"
     ]
    }
   ],
   "source": [
    "for gene in response.json():\n",
    "    print(gene['symbol'] + ':', gene['summary'])"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 33,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/plain": [
       "[{'pubmed': 8621729, 'text': 'MEK1 interacts with B-Raf.'},\n",
       " {'pubmed': 12068308,\n",
       "  'text': 'somatic missense mutations in 66% of malignant melanomas and at lower frequency in a wide range of human cancers'},\n",
       " {'pubmed': 12198537,\n",
       "  'text': 'BRAF mutations in colorectal cancers occur only in tumours that do not carry mutations in a RAS gene known as KRAS, and BRAF mutation is linked to the proficiency of these tumours in repairing mismatched bases in DNA'},\n",
       " {'pubmed': 12447372, 'text': 'High frequency of BRAF mutations in nevi'},\n",
       " {'pubmed': 12619120,\n",
       "  'text': 'The V599E BRAF mutation appears to be a somatic mutation associated with melanoma development and/or progression in a proportion of affected individuals.'},\n",
       " {'pubmed': 12644542,\n",
       "  'text': 'results demonstrate that the mutational status of BRAF and KRAS is distinctly different among histologic types of ovarian serous carcinoma, occurring most frequently in invasive micropapillary serous carcinomas and its precursors, serous borderline tumors'},\n",
       " {'pubmed': 12670889,\n",
       "  'text': 'High prevalence of BRAF mutations in thyroid cancer is genetic evidence for constitutive activation of the RET/PTC-RAS-BRAF signaling pathway in papillary thyroid carcinoma.'},\n",
       " {'pubmed': 12697856,\n",
       "  'text': 'activating BRAF mutations may be an important event in the development of papillary thyroid cancer'},\n",
       " {'pubmed': 12753285,\n",
       "  'text': 'cAMP activates ERK and increases proliferation of autosomal dominant polycystic kindey epithelial cells through the sequential phosphorylation of PKA, B-Raf and MAPK in a pathway separate from the classical receptor tyrosine kinase cascade'},\n",
       " {'pubmed': 12778069,\n",
       "  'text': 'gene is mutated in skin melanoma, but not in uveal melanomas'},\n",
       " {'pubmed': 12810628,\n",
       "  'text': '13 germline BRAF variants, 4 of which were silent mutations in coding regions & 9 nucleotide substitutions in introns, were found in melanoma patients and melanoma family, but none appeared statistically likely to be a melanoma susceptibility gene.'},\n",
       " {'pubmed': 12821662,\n",
       "  'text': 'B-raf is involved in adhesion-independent ERK1/2 signaling in melanocytes'},\n",
       " {'pubmed': 12824225,\n",
       "  'text': 'Data suggest that BRAF T1796A activating mutation is not common in primary uveal melanoma.'},\n",
       " {'pubmed': 12855697,\n",
       "  'text': 'B-Raf has a role in extracellular signal-regulated kinase (ERK) signaling in T cells and prevents antigen-presenting cell-induced anergy'},\n",
       " {'pubmed': 12879021,\n",
       "  'text': 'BRAF has a role in in squamous cell carcinoma of the head and neck through uncommon mutations'},\n",
       " {'pubmed': 12881714,\n",
       "  'text': 'The BRAF(V599E) mutation appears to be an alternative event to RET/PTC rearrangement rather than to RAS mutations, which are rare in PTC. BRAF(V599E) may represent an alternative pathway to oncogenic MAPK activation in PTCs without RET/PTC activation.'},\n",
       " {'pubmed': 12893203,\n",
       "  'text': 'Mucinous ovarian cancers without a KRAS mutation have not sustained alternative activation of this signaling pathway through mutation of the BRAF oncogene.'},\n",
       " {'pubmed': 12917419,\n",
       "  'text': '3 cell lines derived from human choroidal melanoma express B-Raf containing the V599E mutation and showed a 10-fold increase in endogenous B-RafV599E kinase activity and a constitutive activation of the MEK/ERK pathway that is independent of Ras'},\n",
       " {'pubmed': 12931219,\n",
       "  'text': 'Mutations are not detectable in plasma cell leukemia and multiple myeloma.'},\n",
       " {'pubmed': 12970315,\n",
       "  'text': 'mutation of BRAF gene could be a potentially useful marker of prognosis of patients with advanced thyroid cancers'},\n",
       " {'pubmed': 14501284,\n",
       "  'text': 'Our findings of a high frequency of BRAF mutations at codon 599 in benign melanocytic lesions of the skin indicate that this mutation is not sufficient by itself for malignant transformation.'},\n",
       " {'pubmed': 14507635,\n",
       "  'text': 'Both BRAF and FBXW7 mutations functionally activate kinase effectors important in pancreatic cancer and extend potential options for therapeutic targeting of kinases in treatment of phenotypically distinct pancreatic adenocarcinoma subsets.'},\n",
       " {'pubmed': 14513361,\n",
       "  'text': 'BRAF mutations, which are present in a variety of other human cancers, do not seem to be involved in gastric cancer development'},\n",
       " {'pubmed': 14522897,\n",
       "  'text': 'Uceal melanomas arise independent of oncogenic BRAF and NRAS mutations.'},\n",
       " {'pubmed': 14534542,\n",
       "  'text': 'BRAF mutations were seen in stomach neoplasms.'},\n",
       " {'pubmed': 14602780,\n",
       "  'text': 'BRAF mutations are restricted to papillary carcinomas and poorly differentiated and anaplastic carcinomas arising from papillary carcinomas'},\n",
       " {'pubmed': 14612909,\n",
       "  'text': 'BRAF is occasionally mutated in NHL, and BRAF mutation may contribute to tumor development in some NHLs'},\n",
       " {'pubmed': 14618633,\n",
       "  'text': 'None of the cases of gastric cancer showed braf mutations'},\n",
       " {'pubmed': 14639609,\n",
       "  'text': 'Mutations of BRAF are associated with extensive hMLH1 promoter methylation in sporadic colorectal carcinomas'},\n",
       " {'pubmed': 14668801,\n",
       "  'text': 'Missense mutation is marker of colonic but not gastric cancer.'},\n",
       " {'pubmed': 14688025,\n",
       "  'text': 'Mutations were found in exon 15 in colorectal adenocarcinoma.'},\n",
       " {'pubmed': 14691295,\n",
       "  'text': 'Our data indicate that BRAF gene mutations are rare to absent events in uveal melanoma of humans.'},\n",
       " {'pubmed': 14695152,\n",
       "  'text': 'NRAS and BRAF mutations arise early during melanoma pathogenesis and are preserved throughout tumor progression'},\n",
       " {'pubmed': 14695993,\n",
       "  'text': 'BRAF mutations are associated with proximal colon tumors with mismatch repair deficiency and MLH1 hypermethylation.'},\n",
       " {'pubmed': 14719068,\n",
       "  'text': 'New enriched PCR-RFLP assay for detecting mutations of BRAF codon 599 mutation in pleural mesotheliomas.'},\n",
       " {'pubmed': 14722037,\n",
       "  'text': 'Observational study of genotype prevalence and gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 14724583,\n",
       "  'text': \"RAS or BRAF mutations are detected in about 32% of all Barrett's adenocarcinomas; the disruption of the Raf/MEK/ERK (MAPK) kinase pathway is a frequent but also early event in the development of Barrett's adenocarcinoma\"},\n",
       " {'pubmed': 14734469,\n",
       "  'text': 'BRAF mutations are frequently present in sporadic colorectal cancer with methylated hMLH1'},\n",
       " {'pubmed': 14961576,\n",
       "  'text': 'Mutations in BRAF gene is associated with malignant melanomas'},\n",
       " {'pubmed': 14966563,\n",
       "  'text': 'These studies identify isoprenylcysteine carboxyl methyltransferase as a potential target for reducing the growth of K-Ras- and B-Raf-induced malignancies.'},\n",
       " {'pubmed': 15001635,\n",
       "  'text': 'The lack or low prevalence of BRAF mutation in other thyroid neoplasms is consistent with the notion that other previously defined genetic alterations on the same signaling pathway are sufficient to cause tumorigenesis in most thyroid neoplasms.'},\n",
       " {'pubmed': 15009714,\n",
       "  'text': 'possible cooperation between BRAF activation and PTEN loss in melanoma development.'},\n",
       " {'pubmed': 15009715,\n",
       "  'text': 'mutations in the BRAF gene and to some extent in the N-ras gene represent early somatic events that occur in melanocytic nevi'},\n",
       " {'pubmed': 15014028,\n",
       "  'text': 'BRAF mutation may be acquired during development of metastasis but is not a significant factor for primary melanoma development and disease outcome.'},\n",
       " {'pubmed': 15077125,\n",
       "  'text': 'ovarian serous cystadenomas do not contain mutations in either BRAF or KRAS genes'},\n",
       " {'pubmed': 15104286,\n",
       "  'text': 'These results suggest that the BRAF mutation is unlikely to be involved in gastric carcinogenesis.'},\n",
       " {'pubmed': 15126572,\n",
       "  'text': 'BRAF(V599E) is more common genetic alteration found to date in adult sporadic papillary thyroid carcinomas (PTCs). It is unique for this thyroid cancer histotype, and it might drive the development of PTCs of classic papillary subtype.'},\n",
       " {'pubmed': 15140228,\n",
       "  'text': 'The finding of tandem mutations in thin melanomas makes it more likely that they arise as a simultaneous rather than sequential event.'},\n",
       " {'pubmed': 15145515,\n",
       "  'text': 'Radiation-induced tumors have a low prevalence of BRAF point mutations and high prevalence of RET/PTC rearrangements'},\n",
       " {'pubmed': 15150271,\n",
       "  'text': 'B-Raf kinase activity regulation by tuberin and Rheb is mammalian target of rapamycin (mTOR)-independent'},\n",
       " {'pubmed': 15161700,\n",
       "  'text': 'mucosal melanomas of the head and neck do not frequently harbor an activating mutation of BRAF'},\n",
       " {'pubmed': 15179189,\n",
       "  'text': 'in contrast to cutaneous melanoma, BRAF does not appear to be involved in the pathogenesis of uveal melanoma'},\n",
       " {'pubmed': 15186612,\n",
       "  'text': 'BRAF mutations are rather rare in solitary cold adenomas and adenomatous nodules and do not explain the molecular etiology of ras mutation-negative cold thyroid nodules.'},\n",
       " {'pubmed': 15191558,\n",
       "  'text': 'activation of this gene may be one of the early events in the pathogenesis of some melanomas.'},\n",
       " {'pubmed': 15263001,\n",
       "  'text': 'B-Raf and ERK are activated by cyclic AMP after calcium restriction'},\n",
       " {'pubmed': 15273715, 'text': 'mutated in papillary thyroid cancer.'},\n",
       " {'pubmed': 15277467,\n",
       "  'text': 'In this study, this BRAF mutation was demonstrated in some conjunctival melanoma tissue samples, suggesting that some conjunctival melanomas may share biological features in common with cutaneous melanoma.'},\n",
       " {'pubmed': 15313890,\n",
       "  'text': 'Data suggest that SPRY2, an inhibitor of ERK signaling, may be bypassed in melanoma cells either by down-regulation of its expression in WT BRAF cells, or by the presence of the BRAF mutation.'},\n",
       " {'pubmed': 15330192,\n",
       "  'text': 'Mutations within the BRAF gene are useful markers for the differential diagnosis between Spitz nevus and malignant melanoma.'},\n",
       " {'pubmed': 15331929,\n",
       "  'text': 'we found 19 cases (38%) to harbor somatic B-raf exon 15 mutations.'},\n",
       " {'pubmed': 15339934,\n",
       "  'text': 'Data provide evidence that B-Raf is a positive regulator of T cell receptor-mediated sustained ERK activation, which is required for NFAT activation and the full production of IL-2.'},\n",
       " {'pubmed': 15373778,\n",
       "  'text': 'BRAF(V599E) mutation is seven times higher in lesions with structural changes and 13 times higher in growing lesions as compared with lesions without changes'},\n",
       " {'pubmed': 15488754,\n",
       "  'text': 'REVIEW: our understanding of B-RAF as an oncogene and of its role in cancer'},\n",
       " {'pubmed': 15489648,\n",
       "  'text': 'Mutations of BRAF or KRAS oncogenes are early events in the serrated polyp neoplasia pathway. CpG island methylation plays a role in serrated polyp progression to colorectal carcinoma.'},\n",
       " {'pubmed': 15538400,\n",
       "  'text': 'mutated in childhood acute lymphoblastic leukemia.'},\n",
       " {'pubmed': 15577314,\n",
       "  'text': 'BRAF mutations are associated with conjunctival neoplasms'},\n",
       " {'pubmed': 15630448,\n",
       "  'text': 'AKAP9-BRAF fusion was preferentially found in radiation-induced papillary carcinomas developing after a short latency, whereas BRAF point mutations were absent in this group'},\n",
       " {'pubmed': 15632082,\n",
       "  'text': 'Data suggest that Rit is involved in a novel pathway of neuronal development and regeneration by coupling specific trophic factor signals to sustained activation of the B-Raf/ERK and p38 MAP kinase cascades.'},\n",
       " {'pubmed': 15653554,\n",
       "  'text': 'a novel Ras-independent ERK1/2 activation system in which p110gamma/Raf-1/MEK1/2 and PKA/B-Raf/MEK1/2 cooperate to activate ERK1/2.'},\n",
       " {'pubmed': 15702478,\n",
       "  'text': 'We found mutations in p53, K-ras, and BRAF genes in 35%, 30%, and 4% of tumors, respectively, and observed a minimal or no co-presence of these gene alterations.'},\n",
       " {'pubmed': 15705790,\n",
       "  'text': 'KSHV-infected cell lines expressed higher levels of B-Raf and VEGF-A; B-Raf-induced VEGF-A expression was demonstrated to be sufficient to enhance tubule formation in endothelial cells'},\n",
       " {'pubmed': 15710605,\n",
       "  'text': 'autoinhibition was negatively regulated by acidic substitutions at phosphorylation sites within the activation loop'},\n",
       " {'pubmed': 15765445,\n",
       "  'text': 'Mutations in the BRAF protooncogene (V599E)may be an alternative pathway of tumorigenesis of familial colorectal cancer.'},\n",
       " {'pubmed': 15782118,\n",
       "  'text': 'BRAF mutations proved to be absent in tumors from hereditary nonpolyposis colorectal cancer syndrome (HNPCC) families with germline mutations in the MMR genes MLH1 and MSH2.'},\n",
       " {'pubmed': 15791479,\n",
       "  'text': 'The data of this study suggest that activating mutations of B-RAF are not a frequent event in gliomas; nevertheless, when present they are associated with high-grade malignant lesions.'},\n",
       " {'pubmed': 15791648,\n",
       "  'text': 'B-raf mutations surrounding Thr439 found in human cancers are unlikely to contribute to increased oncogenic properties of B-raf'},\n",
       " {'pubmed': 15824163,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 15842051,\n",
       "  'text': 'These results suggest that BRAF mutations do not have a role in tumorigenesis of neuroendocrine gastroenteropancreatic tumors.'},\n",
       " {'pubmed': 15880523,\n",
       "  'text': 'Anaplastic thyroid carcinomas which are derived from papillary carcinomas are due to BRAF and p53 mutations'},\n",
       " {'pubmed': 15904951,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 15935100,\n",
       "  'text': 'B-raf V599E and V599K oncogenic mutations are likely to affect melanocyte-specific pathways controlling proliferation and differentiation'},\n",
       " {'pubmed': 15968271,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 15968271,\n",
       "  'text': 'The increasing frequency of BRAF mutations as a function of age could help account for the well documented but poorly understood observation that age is a relevant prognostic indicator for patients with papillary thyroid carcinoma.'},\n",
       " {'pubmed': 15980887,\n",
       "  'text': 'BRAF mutation occurs later in thyroid tumor progression and is restricted mainly to papillary thyroid carcinoma and anaplastic thyroid carcinoma'},\n",
       " {'pubmed': 15994075,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 15998781,\n",
       "  'text': 'Role of BRAF mutation in facilitating metastasis and progression of papillary thyroid cancer in lymph nodes.'},\n",
       " {'pubmed': 16007166,\n",
       "  'text': 'determination of mutation specific gene expression profiles in papillary thyroid carcinoma'},\n",
       " {'pubmed': 16007203,\n",
       "  'text': 'Single-cell clones with efficient knockdown of (V 600 E)B-RAF could be propagated in the presence of basic fibroblast growth factor but underwent apoptosis or senescence-like growth arrest upon withdrawal of this growth factor'},\n",
       " {'pubmed': 16015629,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 16024606,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 16079850,\n",
       "  'text': 'sustained BRAF(V600E) expression in human melanocytes induces cell cycle arrest, which is accompanied by the induction of both p16(INK4a) and senescence-associated acidic beta-galactosidase (SA-beta-Gal) activity, a commonly used senescence marker'},\n",
       " {'pubmed': 16096377,\n",
       "  'text': 'BRAF mutation in melanoma is most likely to occur prior to the development of metastatic disease'},\n",
       " {'pubmed': 16098042,\n",
       "  'text': 'Although BRAF and NRAS mutations are likely to be important for the initiation and maintenance of some melanomas, other factors might be more significant for proliferation and prognosis in subgroups of aggressive melanoma'},\n",
       " {'pubmed': 16098042,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 16123397,\n",
       "  'text': 'The results showed that conjunctival nevi, similar to skin nevi, have a high frequency of oncogenic BRAF mutations.'},\n",
       " {'pubmed': 16129781,\n",
       "  'text': 'These data suggest that MITF is an anti-proliferation factor that is down-regulated by B-RAF signaling and that this is a crucial event for the progression of melanomas that harbor oncogenic B-RAF.'},\n",
       " {'pubmed': 16143028,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 16144912,\n",
       "  'text': 'Mutations of the BRAF gene are partly involved in the malignant transformation of the endometrium.'},\n",
       " {'pubmed': 16144912,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 16172610,\n",
       "  'text': 'selective reduction in catalytic activity and expression of B-Raf but not Raf-1 suggest that B-Raf may be playing an important role in altered ERK signaling in brain of suicide subjects, and thus in the pathophysiology of suicide'},\n",
       " {'pubmed': 16174717,\n",
       "  'text': 'In patients with papillary thyroid cancer, BRAF mutation is associated with poorer clinicopathological outcomes and independently predicts recurrence.'},\n",
       " {'pubmed': 16174717,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 16179867,\n",
       "  'text': 'As the BRAF oncogene is frequently found to be mutated in human cutaneous melanomas, it may constitute a risk factor for melanoma formation within CMN and DMN.'},\n",
       " {'pubmed': 16179870,\n",
       "  'text': 'The oncogenic B-raf mutations V599E and V599K, as early events in melanocyte transformation, persist throughout metastasis with important prognostic implications.'},\n",
       " {'pubmed': 16181240,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 16181547,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 16199894,\n",
       "  'text': 'copy number gain may represent another mechanism of BRAF activation in thyroid tumors'},\n",
       " {'pubmed': 16268813,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 16354196,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 16354196,\n",
       "  'text': 'The estimated proportion of attributable risk of melanoma due to variants in BRAF is 1.6%, but the burden of disease associated with this variant is greater than that associated with the major melanoma locus (CDKN2A) which has a risk of 0.2%.'},\n",
       " {'pubmed': 16354586,\n",
       "  'text': 'Mutation and elevated expression of BRAF is associated with the development of testicular germ cell tumors'},\n",
       " {'pubmed': 16361694,\n",
       "  'text': 'The authors have developed and run a high-throughput screen to find inhibitors of V600E BRAF using an enzyme cascade assay in which oncogenic BRAF activates MEK1, which in turn activates ERK2, which then phosphorylates the transcription factor ELK1.'},\n",
       " {'pubmed': 16364920,\n",
       "  'text': 'Data suggest that B-RAF activates C-RAF through a mechanism involving 14-3-3 mediated heterooligomerization and C-RAF transphosphorylation.'},\n",
       " {'pubmed': 16371460,\n",
       "  'text': 'V600E B-Raf requires the Hsp90 chaperone for stability and is degraded in response to Hsp90 inhibitors.'},\n",
       " {'pubmed': 16373964,\n",
       "  'text': 'activating mutations of PDGFR-alpha, c-kit and B-RAF are absent in gliosarcomas'},\n",
       " {'pubmed': 16376942,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 16376942,\n",
       "  'text': 'V599E BRAF mutation was uncommon in Japanese lung cancer.'},\n",
       " {'pubmed': 16382052,\n",
       "  'text': 'aberrant B-Raf activity in angiomyolipomas leads to abnormal cellular differentiation and migration [review]'},\n",
       " {'pubmed': 16397024,\n",
       "  'text': 'Observational study of genotype prevalence. (HuGE Navigator)'},\n",
       " {'pubmed': 16413100,\n",
       "  'text': 'The most frequent B-RAF gene alterations are not involved in prostate carcinogenesis'},\n",
       " {'pubmed': 16417232,\n",
       "  'text': 'BRAF mutation does not seem to be sufficient to produce MAPK activation in melanocytic nevi.'},\n",
       " {'pubmed': 16424035,\n",
       "  'text': 'gain-of-function BRAF signaling is strongly associated with in vivo tumorigenicity'},\n",
       " {'pubmed': 16439621,\n",
       "  'text': 'findings demonstrate that heterogeneous de novo missense mutations in three genes within the mitogen-activated protein kinase pathway, BRAF, MEK1 and MEK2 cause cardio-facio-cutaneous syndrome'},\n",
       " {'pubmed': 16452469,\n",
       "  'text': 'wild-type B-Raf-mediated ERK1/2 activation plays a major role in proliferation and transformation of uveal melanocytes; Raf-1 is not involved in this activation'},\n",
       " {'pubmed': 16452550,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 16462768,\n",
       "  'text': 'NRAS and BRAF activating mutations can coexist in the same melanoma, but are mutually exclusive at the single-cell level'},\n",
       " {'pubmed': 16474404,\n",
       "  'text': 'Cardio-facio-cutaneous (CFC) syndrome involves dysregulation of the RAS-RAF-ERK pathway.'},\n",
       " {'pubmed': 16487015,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 16537381,\n",
       "  'text': 'Merlin and MLK3 can interact in situ and merlin can disrupt the interactions between B-Raf and Raf-1 or those between MLK3 and either B-Raf or Raf-1.'},\n",
       " {'pubmed': 16547495,\n",
       "  'text': 'Melanoma cells require either B-RAF or phosphoinositide-3 kinase activation for protection from anoikis.'},\n",
       " {'pubmed': 16601293,\n",
       "  'text': 'BRAF V600E is associated with a high risk of recurrence and less differentiated papillary thyroid carcinoma due to the impairment of Na+/I- targeting to the membrane'},\n",
       " {'pubmed': 16601293,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 16618717,\n",
       "  'text': 'Observational study of gene-environment interaction and pharmacogenomic / toxicogenomic. (HuGE Navigator)'},\n",
       " {'pubmed': 16687919,\n",
       "  'text': 'Observational study of genotype prevalence. (HuGE Navigator)'},\n",
       " {'pubmed': 16691193,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 16691193,\n",
       "  'text': 'UV light is not necessarily required for the acquisition of the BRAF(V600E) mutation, and non-mutagenic effects of UV light to melanocytes may be more important in the nevogenesis'},\n",
       " {'pubmed': 16721785,\n",
       "  'text': 'BRAF mutations are as uncommon as KRAS mutations in prostate adenocarcinoma'},\n",
       " {'pubmed': 16728573,\n",
       "  'text': 'B-RAF (V600E) was confirmed to be associated with the papillary growth pattern, but not with poorer differentiated papillary thyroid carcinoma variants.'},\n",
       " {'pubmed': 16728573,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 16773193,\n",
       "  'text': 'among 23 melanomas located at body sites with chronic UV exposure, only a single tumour harboured the B-raf V599E mutation which was a significantly lower frequency in comparison to melanomas from sun-protected body sites'},\n",
       " {'pubmed': 16786134,\n",
       "  'text': 'a BRAFT1799A mutation may have a role in poor differentiation of thyroid carcinoma'},\n",
       " {'pubmed': 16799476,\n",
       "  'text': 'A subset of Spitz nevi, some with atypical histologic features, possess BRAF mutations. The BRAF mutational status does not separate all Spitz nevi from spitzoid melanomas and non-Spitz types of melanocytic proliferations, contrary to previous reports.'},\n",
       " {'pubmed': 16803888,\n",
       "  'text': 'Rheb has a central role in the regulation of the Ras/B-Raf/C-Raf/MEK signaling network'},\n",
       " {'pubmed': 16804544,\n",
       "  'text': 'CpG island methylator phenotype-positive colorectal tumors represent a distinct subset, encompassing almost all cases of tumors with BRAF mutation'},\n",
       " {'pubmed': 16809487,\n",
       "  'text': 'findings show that MC1R variants are strongly associated with BRAF mutations in non-chronic sun-induced damage melanomas; in this subtype, risk for melanoma associated with MC1R is due to increase in risk of developing melanomas with BRAF mutations'},\n",
       " {'pubmed': 16845322,\n",
       "  'text': 'BRAF mutation is associated with melanoma and melanocytic nevi.'},\n",
       " {'pubmed': 16858395,\n",
       "  'text': 'Thus, we propose that the hitherto unidentified function of the B-Raf amino-terminal region is to mediate calcium-dependent activation of B-Raf and the following MEK activation, which may occur in the absence of Ras activation.'},\n",
       " {'pubmed': 16858683,\n",
       "  'text': 'Aberrant methylation and hence silencing of TIMP3, SLC5A8, DAPK and RARbeta2, in association with BRAF mutation, may be an important step in PTC tumorigenesis and progression.'},\n",
       " {'pubmed': 16879389,\n",
       "  'text': 'BRAF mutation was frequent in hyperplastic polyps (67%) and sessile serrated adenomas (81%).'},\n",
       " {'pubmed': 16912199,\n",
       "  'text': 'B-RAF has been identified as the most mutated gene in invasive cells and therefore an attractive therapeutic target in melanoma.'},\n",
       " {'pubmed': 16918136,\n",
       "  'text': 'BRAF mutations are associated with colorectal cancers'},\n",
       " {'pubmed': 16918957,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 16924241,\n",
       "  'text': 'Expression of p27Kip1 in melanoma is regulated by B-RAF at the mRNA level and via B-RAF control of Cks1/Skp2-mediated proteolysis.'},\n",
       " {'pubmed': 16932278,\n",
       "  'text': 'Single nucleotide polymorphism found exclusively in papillary thyroid carcinoma.'},\n",
       " {'pubmed': 16937524,\n",
       "  'text': 'BRAF, K-ras and BAT26 are expressed in colorectal polyps and stool'},\n",
       " {'pubmed': 16937524,\n",
       "  'text': 'BRAF, K-ras and BAT26 are expressed in colorectal polyps and stool [BAT26]'},\n",
       " {'pubmed': 16946010, 'text': 'Braf mutations in thyroid tumorigenesis.'},\n",
       " {'pubmed': 16953233,\n",
       "  'text': 'Concomitant KRAS and BRAF mutations increased along progression of MSS colorectal cancer, suggesting that activation of both genes is likely to harbour a synergistic effect'},\n",
       " {'pubmed': 16959844,\n",
       "  'text': 'BRAFV600E activates not only MAPK but also NF-kappaB signaling pathway in human thyroid cancer cells, leading to an acquisition of apoptotic resistance and promotion of invasion.'},\n",
       " {'pubmed': 16960555,\n",
       "  'text': 'Expression of active mutants of B-Raf induces fibronectin.'},\n",
       " {'pubmed': 16964379,\n",
       "  'text': 'Extracellular signal-regulated kinase-3 (ERK3/MAPK6) is highly expressed in response to BRAF signaling.'},\n",
       " {'pubmed': 16973828,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 16987295,\n",
       "  'text': 'BRAF T1976A mutation is present at high frequency in benign naevi such as Spitz and Reed.'},\n",
       " {'pubmed': 17001349,\n",
       "  'text': 'data support a model in which mutational activation of BRAF in human melanomas contributes to constitutive induction of NF-kappaB activity and to increased survival of melanoma cells'},\n",
       " {'pubmed': 17018604,\n",
       "  'text': 'Normally, BRAF alone is responsible for signaling to MEK. However, when RAS is mutated in melanoma, melanocytes switch their signaling from BRAF to CRAF.'},\n",
       " {'pubmed': 17044028,\n",
       "  'text': 'Activating BRAF mutation is associated with papillary thyroid carcinoma'},\n",
       " {'pubmed': 17060774,\n",
       "  'text': 'BRAF mutation remained a significant prognostic factor for lymph node metastasis (odds ratio = 10.8, 95% confidence interval, 3.5-34.0, P < 0.0001).'},\n",
       " {'pubmed': 17074813,\n",
       "  'text': 'phosphorylation on both S365 and S429 participate in the differential regulation of B-Raf isoforms through distinct mechanisms'},\n",
       " {'pubmed': 17097223,\n",
       "  'text': 'data provide evidence that oncogenic properties of BRAF contribute to the tumorigenesis of intraductal papillary mucinous neoplasm/carcinoma (IPMN/IPMC), but at a lower frequency than KRAS'},\n",
       " {'pubmed': 17119056,\n",
       "  'text': 'BRAF-V600E mutations are mainly involved in colorectal cancer families characterized by an increased risk of other common malignancies'},\n",
       " {'pubmed': 17119447,\n",
       "  'text': 'Association with preexisting nevi and pronounced infiltration of lymphocytes was significantly higher in BRAF mutated melanoma tumours'},\n",
       " {'pubmed': 17148775,\n",
       "  'text': 'Observational study of gene-disease association and gene-environment interaction. (HuGE Navigator)'},\n",
       " {'pubmed': 17148775,\n",
       "  'text': 'Previously identified associations between smoking and colon cancer, whether microsatellite unstable or stable, appear to be explained by the association of smoking with BRAF mutation.'},\n",
       " {'pubmed': 17159915,\n",
       "  'text': 'BRAF(T1799A) mutation is associated with a lower rate of tumor proliferation.'},\n",
       " {'pubmed': 17159915,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 17170014,\n",
       "  'text': 'RASSF1A methylation was observed in a high frequency in endometrioid endometrial carcinoma whereas K-ras and B-raf mutations were observed in a low frequency'},\n",
       " {'pubmed': 17179987,\n",
       "  'text': 'The role for BRAF activation in thyroid cancer development and establishing the potential therapeutic efficacy of BRAF-targeted agents in patients with thyroid cancerwill be reviewed.'},\n",
       " {'pubmed': 17186541,\n",
       "  'text': 'BRAF mutation is associated with thyroid carcinogenesis'},\n",
       " {'pubmed': 17186541,\n",
       "  'text': 'Observational study of gene-disease association and gene-environment interaction. (HuGE Navigator)'},\n",
       " {'pubmed': 17195912,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 17195912,\n",
       "  'text': 'there is a subgroup of colorectal carcinomas which develop via the microsatellite instability pathway that carry an alteration of the BRAF gene'},\n",
       " {'pubmed': 17199737,\n",
       "  'text': 'Absence of association between BRAF mutation and activation of MAPK pathway in papillary thyroid carcinoma suggests the presence of mechanisms that downregulate MAPK activation.'},\n",
       " {'pubmed': 17227125,\n",
       "  'text': 'Copy gain of PDGFB occurs in a subset of tumors showing no evidence of mutated BRAF or rearranged ret, suggesting that copy gain of PDGFB may underlie the increased expression of platelet-derived growth factor described recently in the literature.'},\n",
       " {'pubmed': 17270239,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 17297294,\n",
       "  'text': 'characterization of the T1799-1801del and A1799-1816ins BRAF mutations in papillary thyroid cancer; the two new mutations resulted in constitutive activation of the BRAF kinase and caused NIH3T3 cell transformation'},\n",
       " {'pubmed': 17302867,\n",
       "  'text': 'Overexpression of B-Raf mRNA and protein may be a feature of nonfunctioning pituitary adenomas, highlighting overactivity of the Ras-B-Raf-MAP kinase pathway in these tumors.'},\n",
       " {'pubmed': 17309670,\n",
       "  'text': 'BRAF gene plays a \"gatekeeper\" role but does not act as a predisposition gene in the development of low-grade ovarian serous carcinomas'},\n",
       " {'pubmed': 17309670,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 17312306,\n",
       "  'text': 'Observational study of genetic testing. (HuGE Navigator)'},\n",
       " {'pubmed': 17315191,\n",
       "  'text': 'BRAFV600E represents a detectable marker in the plasma/serum from melanoma patients for monitoring but not diagnostic purposes'},\n",
       " {'pubmed': 17318013,\n",
       "  'text': 'B-RAF mutations are a rare event in pituitary tumorigenesis.'},\n",
       " {'pubmed': 17355635,\n",
       "  'text': 'The aim of this study was to identify the effect that BRAF oncogene has on post-transcriptional regulation in papillary thyroid carcinoma by using microRNA analysis.'},\n",
       " {'pubmed': 17360030,\n",
       "  'text': 'findings show that RASSF1A hypermethylation and KRAS mutations and BRAF mutations are inversely correlated and play an important role in the development of cervical adenocarcinomas'},\n",
       " {'pubmed': 17366577,\n",
       "  'text': 'mutational analysis of KRAS, BRAF, and MAP2K1/2 in 56 patients with CFC syndrome; comparison of the genotype-phenotype correlation of CFC with that of Costello syndrome suggest a significant clinical overlap but not genotype overlap.'},\n",
       " {'pubmed': 17387744,\n",
       "  'text': 'BRAF(V600E) mutation is identified in a subset of cutaneous metastases from papillary thyroid carcinomas'},\n",
       " {'pubmed': 17393356,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 17393356,\n",
       "  'text': 'data suggest that BRAF mutations might be present less frequently than KRAS mutations in Greek patients with colorectal carcinomas'},\n",
       " {'pubmed': 17440063,\n",
       "  'text': 'finding of a strong association between BRAF mutations and serrated histology in hyperplastic aberrant crypt foci supports the idea that these lesions are an early, sentinel, or a potentially initiating step on the serrated pathway to colorectal carcinoma'},\n",
       " {'pubmed': 17453004,\n",
       "  'text': 'BRAF V600E mutation was occasionally observed in anaplastic carcinomas with papillary carcinoma.'},\n",
       " {'pubmed': 17453358,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 17454879,\n",
       "  'text': 'MSI is rare in UC-related neoplasia as well as non-neoplastic lesions, and does not contribute to the development of dysplasia.'},\n",
       " {'pubmed': 17464312,\n",
       "  'text': 'prevalence of BRAF mutation and RET/PTC were determined in diffuse sclerosing variant of papillary thyroid carcinoma; none of the cases showed a BRAF mutation'},\n",
       " {'pubmed': 17483702,\n",
       "  'text': 'Molecular diagnosis and careful observations should be considered in children with Cardio-facio-cutaneous syndrome because they have germline mutations in BRAF and might develop malignancy.'},\n",
       " {'pubmed': 17487277,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 17487504,\n",
       "  'text': 'c-kit expression is not alternative to BRAF and/or KRAS activation.'},\n",
       " {'pubmed': 17488796,\n",
       "  'text': 'BRAF V600E mutation in PTCs is associated with reduced expression of key genes involved in iodine metabolism'},\n",
       " {'pubmed': 17507627,\n",
       "  'text': 'Observational study of gene-disease association and gene-environment interaction. (HuGE Navigator)'},\n",
       " {'pubmed': 17507627,\n",
       "  'text': 'data indicate that both early-life UV exposure and nevus propensity contribute to occurrence of BRAF+ melanoma, whereas nevus propensity and later-life sun exposure influence the occurrence of NRAS+ melanoma'},\n",
       " {'pubmed': 17516929,\n",
       "  'text': 'analysis of a BRAF mutation-associated gene expression signature in melanoma'},\n",
       " {'pubmed': 17518771,\n",
       "  'text': 'low rate of RAS-RAF mutations (2/22, 9.1%) observed in Spitz melanocytic nevi suggests that these lesions harbor as yet undetected activating mutations in other components of the RAS-RAF-MEK-ERK-MAPK pathway'},\n",
       " {'pubmed': 17520704,\n",
       "  'text': 'Meta-analysis of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 17520704,\n",
       "  'text': 'frequency of the BRAF mutation and the associations between BRAF mutation and clinicopathologic parameters in papillary thyroid carcinoma were evaluated by meta-analysis'},\n",
       " {'pubmed': 17525723,\n",
       "  'text': 'T1790A BRAF mutation (L597Q) in childhood acute lymphoblastic leukemia is a functional oncogene'},\n",
       " {'pubmed': 17535994,\n",
       "  'text': 'The heterogeneous distribution of BRAF mutations suggests that discrete tumor foci in multifocal PTC may occur as independent tumors.'},\n",
       " {'pubmed': 17542667,\n",
       "  'text': 'Presence of BRAF V600E in very early stages of papillary thyroid carcinoma.'},\n",
       " {'pubmed': 17548320,\n",
       "  'text': 'influence of B-RAF-specific RNA interference on the proliferation and apoptosis of gastric cancer BGC823 cell line'},\n",
       " {'pubmed': 17566669,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 17566669,\n",
       "  'text': 'We conclude that screening for BRAF 15 exon mutation is an efficient tool in the diagnostic strategy for HNPCC'},\n",
       " {'pubmed': 17635919,\n",
       "  'text': 'In contrast to C-RAF that requires farnesylated H-Ras, cytosolic B-RAF associates effectively and with significantly higher affinity with both farnesylated and nonfarnesylated H-Ras.'},\n",
       " {'pubmed': 17663506,\n",
       "  'text': 'KLF6 and p53 mutations are involved in the development of nonpolypoid colorectal carcinoma, whereas K-ras and B-raf mutations are not'},\n",
       " {'pubmed': 17671688,\n",
       "  'text': 'PPARbeta/delta has a role in growth of RAF-induced lung adenomas'},\n",
       " {'pubmed': 17685465,\n",
       "  'text': 'BRAF V600E mutation in papillary carcinoma of the thyroid may facilitate tumor cell growth and progression once seeded in the lymph nodes.'},\n",
       " {'pubmed': 17693984,\n",
       "  'text': 'Observational study of genotype prevalence, gene-disease association, and genetic testing. (HuGE Navigator)'},\n",
       " {'pubmed': 17693984,\n",
       "  'text': 'There was no coexistence of BRAF (V600E) mutation in papillary thyroid carcinoma.'},\n",
       " {'pubmed': 17696195,\n",
       "  'text': 'data showed differences in gene expression between nevi with and without the V600E BRAF mutation. Moreover, nevi with mutations showed over-expression of genes involved in melanocytic senescence and cell cycle inhibition'},\n",
       " {'pubmed': 17699719,\n",
       "  'text': 'RNA interference and pharmacologic approaches were used to assess the role of B-Raf activation in the growth of human melanomas and additionally determined if a similar role for mutant B-Raf is seen for colorectal carcinoma cell lines.'},\n",
       " {'pubmed': 17704260,\n",
       "  'text': '5 unreported mutations (T241P, Q262R, G464R, E501V, N581K) were found in cardio-facio-cutaneous syndrome. A hotspot in exon 6 at Q257 was found.'},\n",
       " {'pubmed': 17714762,\n",
       "  'text': 'diffuse expression of wild-type and/or mutant B-Raf may be involved in the tumorigenic process'},\n",
       " {'pubmed': 17717450,\n",
       "  'text': 'BRAF V600E mutation is primarily present in conventional papillary thyroid cancer; it is associated with an aggressive tumor phenotype and higher risk of recurrent and persistent disease in patients with conventional papillary thyroid cancer'},\n",
       " {'pubmed': 17717450,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 17721188,\n",
       "  'text': 'Develompment of malignant strumo ovarii with papillary thyroid carcinoma features is associated with BRAF mutations.'},\n",
       " {'pubmed': 17727338,\n",
       "  'text': 'BRAF(V600E) mutation detected on fine-needle aspiration biopsy specimens, more than RET/PTC rearrangements, is highly specific for papillary thyroid carcinoma.'},\n",
       " {'pubmed': 17785355,\n",
       "  'text': 'BRAF V600E mutation is associated with high-risk papillary thyroid carcinoma'},\n",
       " {'pubmed': 17785355,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 17786355,\n",
       "  'text': 'BRAFV600E mutations were found in 41.2% of the papillary thyroid carcinomas'},\n",
       " {'pubmed': 17854396,\n",
       "  'text': 'Papillary thyroid cancers with no 131I uptake had a high frequency of BRAF mutations.'},\n",
       " {'pubmed': 17878251,\n",
       "  'text': 'MEK inhibition is cytostatic in papillary thyroid cancer and anaplastic thyroid cancer cells bearing a BRAF mutation'},\n",
       " {'pubmed': 17911174,\n",
       "  'text': 'effects of a MEK inhibitor, CI-1040, on thyroid cancer cells, some of which, particularly cell proliferation and tumor growth, seemed to be BRAF mutation or RAS mutation selective'},\n",
       " {'pubmed': 17914558,\n",
       "  'text': 'BRAF mutation is associated as early as the hyperplastic polyp stage followed by microsatellite instability at the carcinoma stage'},\n",
       " {'pubmed': 17924122,\n",
       "  'text': 'Examined associations between BRAF mutations, morphology, and apoptosis in early colorectal cancer.'},\n",
       " {'pubmed': 17940185,\n",
       "  'text': 'BRAF mutation represents a novel indicator of the progression and aggressiveness of papillary thyroid cancer (Review)'},\n",
       " {'pubmed': 17942568,\n",
       "  'text': 'BRAF interacts with PLCepsilon1 in nephrotic syndrome type 3. Both proteins are coexpressed and colocalize in developing and mature glomerular podocytes.'},\n",
       " {'pubmed': 17962436,\n",
       "  'text': 'In this small study, the T1799A BRAF mutation was identified in almost half of the iris melanoma tissues samples examined. This finding suggests that there may be genetic as well as clinical differences between iris and posterior uveal melanomas.'},\n",
       " {'pubmed': 17972530,\n",
       "  'text': 'These results suggest that papillary thyroid carcinomas with BRAF (V600E) mutation are more aggressive than those with wildtype BRAF.'},\n",
       " {'pubmed': 18000091,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 18008004,\n",
       "  'text': 'mutation of N-RAS or B-RAF, signature genetic lesions present in most MMs, potently induced the expression of cell-surface CD200, a repressor of DC function.'},\n",
       " {'pubmed': 18024410,\n",
       "  'text': 'no BRAF mutations identified in 65 screened JMML patients; this gene is unlikely to play a role in the pathogenesis of JMML.'},\n",
       " {'pubmed': 18032947,\n",
       "  'text': 'The BRAF mutation is common in melanomas, but variation in rates across melanoma subtypes points to a complex interplay between BRAF activation and other factors (eg, sun exposure).'},\n",
       " {'pubmed': 18042262,\n",
       "  'text': 'the results of HRAS, BRAF and MAP2K1/2 mutation screening in a large cohort of patients with CS and CFC'},\n",
       " {'pubmed': 18045960,\n",
       "  'text': 'Detection of BRAF improves the diagnosis in fine-needle biopsy with cytological findings suspicious for papillary thyroid carcinoma.'},\n",
       " {'pubmed': 18045987,\n",
       "  'text': 'These results identify Rnd3 as a regulator of cross talk between the RAF/MEK/ERK and Rho/ROCK signaling pathways, and a key contributor to oncogene-mediated reorganization of the actin cytoskeleton and focal adhesions.'},\n",
       " {'pubmed': 18060073,\n",
       "  'text': 'BRAF and MEK1/2 mutations may be more common than anticipated in ovarian cancer which could have important implications for treatment of patients with this disease and suggests potential new therapeutic avenues'},\n",
       " {'pubmed': 18061181,\n",
       "  'text': 'Observational study of genetic testing. (HuGE Navigator)'},\n",
       " {'pubmed': 18070147,\n",
       "  'text': \"BRAF(V600E)'alone' does not represent a marker for poor outcome\"},\n",
       " {'pubmed': 18071315,\n",
       "  'text': 'B-Raf(V600E) signaling deregulates the mitotic spindle checkpoint through stabilizing Mps1 levels in melanoma cells.'},\n",
       " {'pubmed': 18098337,\n",
       "  'text': 'BRAF provides proliferation and survival signals in MSI colorectal carcinoma cells displaying BRAF(V600E) but not KRAS mutations.'},\n",
       " {'pubmed': 18172070,\n",
       "  'text': 'Because of the very sensitive pyrophosphorolysis-activated polymerization (PAP)technology, B-RAF mutations were found in cell lines and primary uveal melanomas.'},\n",
       " {'pubmed': 18199160,\n",
       "  'text': 'A worse clinical outcome was found for CIMP-high, microsatellite stable colorectal cancer with KRAS/BRAF mutation but not for those lacking KRAS/BRAF mutation.'},\n",
       " {'pubmed': 18224685,\n",
       "  'text': 'Observational study of gene-disease association and gene-gene interaction. (HuGE Navigator)'},\n",
       " {'pubmed': 18226854,\n",
       "  'text': 'frequency of the occurrence of BRAF mutation and/or RET/PTC in H4-PTEN positive tumors was extremely high (75%) in papillary thyroid carcinoma'},\n",
       " {'pubmed': 18227705,\n",
       "  'text': 'BRAF mutation is not associated with cutaneous melanoma'},\n",
       " {'pubmed': 18228248,\n",
       "  'text': 'Important signalling role in T cell development.'},\n",
       " {'pubmed': 18235983,\n",
       "  'text': 'Follicular histotypes of oncocytic thyroid carcinomas do not carry BRAF mutations'},\n",
       " {'pubmed': 18246127,\n",
       "  'text': 'Mutant B-RAF mediates resistance to anoikis via Bad and Bim.'},\n",
       " {'pubmed': 18267069,\n",
       "  'text': 'A genome-wide RNA-interference screening to identify genes required for an activated BRAF oncogene to block proliferation of fibroblasts and melanocytes revealed that a IGFBP7, has a central role in BRAF-mediated senescence and apoptosis.'},\n",
       " {'pubmed': 18310286,\n",
       "  'text': 'BRAF T1799A mutation is associated with aggressive pathological outcomes of papillary thyroid cancer'},\n",
       " {'pubmed': 18310287,\n",
       "  'text': 'BRAF(V600E) mutation is asscoiated with papillary thyroid cancer'},\n",
       " {'pubmed': 18310288,\n",
       "  'text': 'BRAF-V600E mutation is associated with familial non-medullary thyroid carcinoma'},\n",
       " {'pubmed': 18323787,\n",
       "  'text': 'Mitogen-activated protein kinase (MAPK) activity is subject to regulation even in BRAF/NRAS mutant melanoma cells and that high MAPK pathway signaling may be important only in distinct subsets of tumor cells.'},\n",
       " {'pubmed': 18329792,\n",
       "  'text': 'RKIP could play an important role in the down-regulation of wild-type BRAF, serving thus as an endogenous inhibitor of the MAPK pathway in nasal polyps and their adjacent turbinate mucosa.'},\n",
       " {'pubmed': 18337114,\n",
       "  'text': 'BRAF mutation testing of papillary thyroid carcinoma might improve the diagnosis, prognostic stratification and treatment of these tumors.'},\n",
       " {'pubmed': 18343945,\n",
       "  'text': 'Our data provide evidence that PIK3CA and BRAF contribute to the tumorigenesis of IPMN/IPMC, but at a lower frequency than KRAS.'},\n",
       " {'pubmed': 18368129,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 18368129,\n",
       "  'text': 'This study confirms that the known MC1R-melanoma risk association is confined to subjects whose melanomas harbor BRAF mutations.'},\n",
       " {'pubmed': 18375819,\n",
       "  'text': 'BRAF mutation is associated with disease stabilization in melanoma'},\n",
       " {'pubmed': 18381570,\n",
       "  'text': 'Thyroid cancers with BRAF mutation are preferentially sensitive to MEK inhibitors.'},\n",
       " {'pubmed': 18382358,\n",
       "  'text': 'Detecting BRAF mutation by pyrosequencing is more sensitive, faster, and less expensive than direct DNA sequencing.'},\n",
       " {'pubmed': 18383861,\n",
       "  'text': 'K-RAS and BRAF mutations are a frequent genetic event in our samples of sporadic papillary and medullary thyroid carcinoma.'},\n",
       " {'pubmed': 18383861,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 18397470,\n",
       "  'text': 'is commonly activated by somatic point mutation, it may provide possible diagnostic and therapeutic targets in human malignant tumors.'},\n",
       " {'pubmed': 18398503,\n",
       "  'text': 'Results implicate aberrant activation of the MAPK pathway due to gene duplication or mutation of BRAF as a molecular mechanism of pathogenesis in low-grade astrocytomas and suggest inhibition of the MAPK pathway as a potential treatment.'},\n",
       " {'pubmed': 18402768,\n",
       "  'text': 'Aberrant BRAF and INK4A functionally interact to promote growth and survival of melanoma cells.'},\n",
       " {'pubmed': 18408659,\n",
       "  'text': 'in melanocytic lesions, BRAF(V600E) mutation can affect a subset of the cells and is associated with the type and quantity of sun exposure'},\n",
       " {'pubmed': 18413255,\n",
       "  'text': 'study describes the biochemical characterization of novel BRAF and MEK germline mutations in cardio-facio-cutaneous syndrome'},\n",
       " {'pubmed': 18434602,\n",
       "  'text': 'Cdk1/cyclin B has a role in regulating B-raf activation at mitosis'},\n",
       " {'pubmed': 18435933,\n",
       "  'text': 'CpG island methylator phenotype in colorectal neoplasms may result from activating mutations in either BRAF or KRAS.'},\n",
       " {'pubmed': 18451171,\n",
       "  'text': 'Akt3 and mutant V600E B-Raf cooperate to promote early melanoma development.'},\n",
       " {'pubmed': 18458053,\n",
       "  'text': 'oncogenic BRAF inhibition can have a different effect on cell fate depending on the cellular type'},\n",
       " {'pubmed': 18470905,\n",
       "  'text': 'aberrant methylation of the hMLH1 gene may play a role in BRAF mutation-promoted thyroid tumorigenesis'},\n",
       " {'pubmed': 18509003,\n",
       "  'text': 'study revealed a significant correlation of BRAFV600E mutation with a lower expression of both sodium iodide symporter and thyroperoxidase in papillary thyroid cancer'},\n",
       " {'pubmed': 18509361,\n",
       "  'text': 'Shorter overall survival in primary melanoma was associated with the presence of ulceration and BRAF exon 15 mutations, as well as the absence of nuclear activation of Akt and of cytoplasmic activation of ERK.'},\n",
       " {'pubmed': 18517279,\n",
       "  'text': 'BRAF mutations in colorectal cancer microsatellite-stable cases are associated with high levels of chromosomal instability that are likely responsible for the adverse outcomes in these cases'},\n",
       " {'pubmed': 18519771,\n",
       "  'text': 'a significant relationship in overall survival in colon cancer patients with defective DNA mismatch repair and the presence of a specific mutation in BRAF (V600E)'},\n",
       " {'pubmed': 18532874,\n",
       "  'text': 'Compared to melanomas without BRAF mutations, melanomas with BRAF mutations showed statistically significantly higher degrees of intraepidermal scatter of melanocytes, and a higher proportion of melanocytes arranged in nests.'},\n",
       " {'pubmed': 18567582,\n",
       "  'text': 'the scaffold protein IQGAP1 couples Ca(2+) and calmodulin signaling to B-Raf function'},\n",
       " {'pubmed': 18592405,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 18594528,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 18602919,\n",
       "  'text': 'Rac1b and B-Raf(V600E) functionally cooperate to sustain colorectal cell viability and suggest they constitute an alternative survival pathway to oncogenic K-Ras'},\n",
       " {'pubmed': 18615679,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 18615679,\n",
       "  'text': 'V600E BRAF mutation is associated with imatinib-resistant gastrointestinal stromal tumors'},\n",
       " {'pubmed': 18615680,\n",
       "  'text': 'MLH1 methylation and BRAF mutations are associated with microsatellite unstable colon tumors'},\n",
       " {'pubmed': 18615680,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 18621636,\n",
       "  'text': 'Observational study of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)'},\n",
       " {'pubmed': 18628356,\n",
       "  'text': 'The frequencies of LOHs of 17q21, 17p13, 10q23, and 22q13 were higher in tumors with lymph node metastasis, suggesting that these LOHs may be important in increased lymph node metastasis.'},\n",
       " {'pubmed': 18628431,\n",
       "  'text': 'People of southern European origin had lower risk of colorectal cancers with CIMP and BRAF mutation than people of Anglo-Celtic origin, which may in part be due to genetic factors that are less common in people of southern European origin.'},\n",
       " {'pubmed': 18628967,\n",
       "  'text': 'BRAF regulates melanoma proliferation through the lineage specific factor MITF'},\n",
       " {'pubmed': 18632627,\n",
       "  'text': 'co-overexpression of KIT/CDK4 is a potential mechanism of oncogenic transformation in some BRAF/NRAS wild-type melanomas'},\n",
       " {'pubmed': 18636014,\n",
       "  'text': 'lung adenocarcinoma of mixed type with a high incidence of papillary and lepidic growth may be worthwhile investigating for BRAF-V600E mutation as more genetically oriented drug therapies emerge.'},\n",
       " {'pubmed': 18650848,\n",
       "  'text': 'hyperactivation of the MAPK pathway following activation of an inducible form of oncogenic C-Raf induces a senescence-like proliferation arrest in B-Raf mutant melanoma cells'},\n",
       " {'pubmed': 18668139,\n",
       "  'text': \"N-RAS(Q61K) and B-RAF(V600E) contribute to melanoma's resistance to apoptosis in part by downregulating Bim expression\"},\n",
       " {'pubmed': 18669866,\n",
       "  'text': 'Observational study of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)'},\n",
       " {'pubmed': 18676742,\n",
       "  'text': 'CST6, CXCL14, DHRS3, and SPP1 are regulated by BRAF signaling and may play a role in papillary thyroid carcinoma pathogenesis'},\n",
       " {'pubmed': 18676756,\n",
       "  'text': 'Observational study of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)'},\n",
       " {'pubmed': 18682506,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 18682506,\n",
       "  'text': 'The BRAF(V600E) mutation was demonstrated to be a poor prognostic factor independent from other clinicopathological features.'},\n",
       " {'pubmed': 18697864,\n",
       "  'text': 'Identification and functional characterization of a novel T599I-VKSR(600-603)del BRAF mutation in a patient with follicular variant papillary thyroid carcinoma.'},\n",
       " {'pubmed': 18710471,\n",
       "  'text': 'There is a higher frequency of the BRAF(V600E) mutation in papillary thyroid carcinomas than in normal thyroid tissue.'},\n",
       " {'pubmed': 18715233,\n",
       "  'text': 'These data suggest that regulation of BIM expression by BRAF-->MEK-->ERK signaling is one mechanism by which oncogenic BRAF(V600E) can influence the aberrant physiology of melanoma cells.'},\n",
       " {'pubmed': 18716556,\n",
       "  'text': 'focal gains at chromosome 7q34 and increased BRAF-MEK-ERK signaling are common findings in sporadic pilocytic astrocytomas'},\n",
       " {'pubmed': 18718023,\n",
       "  'text': 'presence of the BRAF (V600E) mutation,the incidence of microsatellite instability high colorectal cancer in populations based study.'},\n",
       " {'pubmed': 18757341,\n",
       "  'text': 'KRAS and BRAF mutations can impair response to anti-EGFR therapy for colorectal neoplasms'},\n",
       " {'pubmed': 18757433,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 18759827,\n",
       "  'text': 'Observational study of genetic testing. (HuGE Navigator)'},\n",
       " {'pubmed': 18778891,\n",
       "  'text': 'BRAF mutation is associated with the CpG island methylator phenotype in colorectal cancer from young patients'},\n",
       " {'pubmed': 18778891,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 18782444,\n",
       "  'text': 'BRAF, KRAS and PIK3CA mutations occur prior to malignant transformation demonstrating that these oncogenic alterations are primary genetic events in colorectal carcinogenesis'},\n",
       " {'pubmed': 18782444,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 18787396,\n",
       "  'text': 'These data implicates a mitotic role for B-Raf in regulating spindle formation and the spindle checkpoint in human somatic cells.'},\n",
       " {'pubmed': 18794094,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 18794803,\n",
       "  'text': 'study identified a group of melanomas with low-activity BRAF mutations (G469E- and D594G) that are reliant upon CRAF-mediated survival activity'},\n",
       " {'pubmed': 18798261,\n",
       "  'text': 'BRAF mutation occurs independently of CpG island methylator phenotype and MSI in all types of serrated polyps and may serve as a marker of serrated pathway of colorectal carcinogenesis'},\n",
       " {'pubmed': 18806830,\n",
       "  'text': 'study concludes a single endogenous BRAF(V600E) allele is sufficient to repress BIM & prevent death from growth factor withdrawal; colorectal cancer cells with V600E mutations are addicted to the ERK1/2 pathway for repression of BIM'},\n",
       " {'pubmed': 18832519,\n",
       "  'text': 'CIMP-high appears to be an independent predictor of a low colon cancer-specific mortality, while BRAF mutation is associated with a high colon cancer-specific mortality.'},\n",
       " {'pubmed': 18834226,\n",
       "  'text': 'With at least 3 markers methylated, new CIMP-positive colorectal cancers were closely associated with proximal tumor location, low frequency of KRAS mutation, and high frequency of BRAF mutation.'},\n",
       " {'pubmed': 18840924,\n",
       "  'text': 'BRAF(V600E) mutation may play some roles in local carcinoma development, there is no evidence that BRAF(V600E) mutation significantly reflects the aggressive characteristics and poor prognosis of patients with papillary carcinoma in Japan.'},\n",
       " {'pubmed': 18840924,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 18945298,\n",
       "  'text': 'BRAF V600E appeared to be the most commonly mutated gene in both the melanocytic aggregate (seven of 18, 39%) and the melanoma (four of 18, 22%)'},\n",
       " {'pubmed': 18946221,\n",
       "  'text': 'Hereditary pancreatitis patients with PRSS1 mutations also had mutations in BRAF and KRAS2.'},\n",
       " {'pubmed': 18953432,\n",
       "  'text': 'study shows high expression of p16(INK4a) or the absence of activated B-RAF correlates with in vivo response of melanoma to cytotoxic drugs'},\n",
       " {'pubmed': 18974108,\n",
       "  'text': 'rearrangement, which was not observed in a series of 244 higher-grade astrocytomas, results in an in-frame fusion gene incorporating the kinase domain of the BRAF oncogene'},\n",
       " {'pubmed': 18980976,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 18985043,\n",
       "  'text': 'the T1799A BRAF mutation is present in a proportion of posterior uveal melanomas but within these tumours the distribution of the mutation is heterogeneous.'},\n",
       " {'pubmed': 18987552,\n",
       "  'text': 'BRAF mutations may not play an important role in the oncogenesis or therapy of prostate adenocarcinoma'},\n",
       " {'pubmed': 18992635,\n",
       "  'text': '8% of sporadic colorectal tumors in this study harbor mutation in the BRAF gene.'},\n",
       " {'pubmed': 18992635,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 19001320,\n",
       "  'text': 'Observational study of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)'},\n",
       " {'pubmed': 19001320,\n",
       "  'text': 'Wild-type BRAF is required for response to panitumumab or cetuximab in metastatic colorectal cancer.'},\n",
       " {'pubmed': 19003996,\n",
       "  'text': 'BRAF-V600E mutation is uncommon in endocrine tumors other than thyroid papillary carcinomas'},\n",
       " {'pubmed': 19012001,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 19012001,\n",
       "  'text': 'The result showed that the mutation rate of PIK3CA in nasopharyngeal carcinomas (n = 73) was 9.6%, whereas both BRAF (n = 65) and RAS (n = 45) were wild type in every specimen with adequate DNA for analysis.'},\n",
       " {'pubmed': 19014278,\n",
       "  'text': 'In Korean patients with papillary thyroid carcinoma, the BRAFV600E mutation is associated with a lower frequency of background Hashimoto thyroiditis and a high frequency of lymph node metastasis.'},\n",
       " {'pubmed': 19014278,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 19016743,\n",
       "  'text': 'Reverse transcription polymerase chain reaction-based sequencing revealed a fusion product between KIAA1549 and BRAF in pediatric low-grade astrocytomas'},\n",
       " {'pubmed': 19018267,\n",
       "  'text': 'Observational study of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)'},\n",
       " {'pubmed': 19018267,\n",
       "  'text': 'ovarian cancer patients with KRAS or BRAF mutations may benefit from CI-1040 treatment'},\n",
       " {'pubmed': 19026650,\n",
       "  'text': 'Observational study of genetic testing. (HuGE Navigator)'},\n",
       " {'pubmed': 19033861,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 19034577,\n",
       "  'text': 'BRAF(V600E) mutation is assocciated with aggressive papillary thyroid microcarcinoma.'},\n",
       " {'pubmed': 19034577,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 19037234,\n",
       "  'text': 'NRAS and BRAF mutations increase from the radial to the vertical growth phase in cutaneous melanoma'},\n",
       " {'pubmed': 19064572,\n",
       "  'text': 'Observational study and meta-analysis of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 19079609,\n",
       "  'text': 'Genetic extinction of BRAF(V600E) in established prostate tumors did not lead to tumor regression, indicating that while sufficient to initiate development of invasive prostate adenocarcinoma, BRAF(V600E) is not required for its maintenance.'},\n",
       " {'pubmed': 19087308,\n",
       "  'text': 'G12D mutation may be more likely selected in a BRAF mutated context'},\n",
       " {'pubmed': 19098310,\n",
       "  'text': 'ERK activation was induced by PKD2 overexpression via B-Raf signaling, providing a possible molecular mechanism of cystogenesis'},\n",
       " {'pubmed': 19107232,\n",
       "  'text': 'BRAF pseudogene activation may play a role in thyroid tumor development.'},\n",
       " {'pubmed': 19126563,\n",
       "  'text': 'Sessile serrated adenomas are encountered commonly in routine endoscopy practice and the histological diagnosis correlates strongly with the presence of BRAF mutation.'},\n",
       " {'pubmed': 19127559,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 19133693,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 19142971,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 19147753,\n",
       "  'text': 'BRAF and RET/PTC dual mutations are associated with recurrent papillary thyroid carcinoma'},\n",
       " {'pubmed': 19147753,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 19152441,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 19159571,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 19164452,\n",
       "  'text': 'MLH1-hypermethylated tumors harbor fewer APC and KRAS mutations and more BRAF mutations, suggesting that they develop distinctly from an MGMT methylator pathway.'},\n",
       " {'pubmed': 19178815,\n",
       "  'text': 'Mutations are absent or rare in the kinase domain of B-RAF in Japanese head and neck squamous cell carcinoma.'},\n",
       " {'pubmed': 19178815,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 19190079,\n",
       "  'text': 'Mutation in BRAF is associated with adrenocortical carcinomas.'},\n",
       " {'pubmed': 19190105,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 19190129,\n",
       "  'text': 'Distinct BRAF (V600E) and KRAS mutations in high microsatellite instability sporadic colorectal cancer in African Americans.'},\n",
       " {'pubmed': 19190129,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 19194051,\n",
       "  'text': 'Expression levels of fibronectin, vimentin and CITED1 were positively correlated with those of BRAFV600E, suggesting pathophysiological links between activated BRAF and overexpression of these genes.'},\n",
       " {'pubmed': 19200582,\n",
       "  'text': '(novel) mutation in the activation kinase domain of the BRAF (A598V), this mutation led to the up-regulation of the BRAF kinase activity and its downstream signaling factors.'},\n",
       " {'pubmed': 19206169,\n",
       "  'text': 'Findings provide evidence for a wide phenotypic diversity associated with mutations affecting BRAF, and occurrence of a clinical continuum associated with these molecular lesions.'},\n",
       " {'pubmed': 19207009,\n",
       "  'text': 'the presence of the braf protein mutation increases prohibitin promoter activity and therefore potentially mediates effects of this mutation on the behavior of BRAF protein'},\n",
       " {'pubmed': 19208736,\n",
       "  'text': 'BRAFT1799A mutation or RET/PTC rearrangement, mainly corresponding to follicular variants, maintain a thyroid differentiation expression level close to that of normal tissue.'},\n",
       " {'pubmed': 19226609,\n",
       "  'text': 'BRAF* melanomas appear to be associated with a specific profile of DNA copy number aberrations that is distinct from those found in NRAS* and BRAF/NRAS(wt/wt) tumors.'},\n",
       " {'pubmed': 19237633,\n",
       "  'text': 'Observational study of gene-disease association and gene-gene interaction. (HuGE Navigator)'},\n",
       " {'pubmed': 19240718,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 19255327,\n",
       "  'text': 'Clinical trial of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)'},\n",
       " {'pubmed': 19274086,\n",
       "  'text': 'oncogenic BRAF(V600E) induces the uncoupling of LKB1-AMPKalpha complexes providing at the same time a possible mechanism in cell proliferation that engages cell growth and cell division in response to mitogenic stimuli'},\n",
       " {'pubmed': 19276360,\n",
       "  'text': 'GDC-0879-mediated efficacy was associated strictly with BRAF(V600E) status, MEK inhibition also attenuated proliferation and tumor growth of cell lines expressing wild-type BRAF.'},\n",
       " {'pubmed': 19282104,\n",
       "  'text': 'study of KRAS/BRAF mutation status in a large and well-documented cohort of primary and metastatic renal cell carcinoma'},\n",
       " {'pubmed': 19289622,\n",
       "  'text': 'Observational study of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)'},\n",
       " {'pubmed': 19289622,\n",
       "  'text': 'a correlation between a gene mutation--BRAF V600E--and cisplatin resistance in nonseminomatous germ cell tumors.'},\n",
       " {'pubmed': 19342899,\n",
       "  'text': 'Both BRAF and RKIP expression levels exhibit a decrease from normal skin tissue and actinic keratosis, going to squamous cell carcinoma.'},\n",
       " {'pubmed': 19344998,\n",
       "  'text': 'In BRAF mutated colorectal carcinoma cells quercetin, luteolin and ursolic acid decreased Akt phosphorylation'},\n",
       " {'pubmed': 19351817,\n",
       "  'text': 'Observational study of gene-disease association and gene-environment interaction. (HuGE Navigator)'},\n",
       " {'pubmed': 19355825,\n",
       "  'text': 'BRAF(V600E) is associated some of the aggressive clinicopathological features of papillary thyroid carcinoma including younger age at diagnosis, larger tumor size, and classic histological type, as well as also extrathyroidal invasion.'},\n",
       " {'pubmed': 19355825,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 19358278,\n",
       "  'text': 'Observational study of gene-disease association and gene-environment interaction. (HuGE Navigator)'},\n",
       " {'pubmed': 19362540,\n",
       "  'text': 'Targets of phosphorylation by B-Raf signaling are investigated in melanoma.'},\n",
       " {'pubmed': 19369630,\n",
       "  'text': 'K-ras, EGFR, and BRAF mutations are disproportionately seen in adenocarcinomas of lung with a dominant micropapillary growth pattern compared with conventional adenocarcinoma in our institutional experience.'},\n",
       " {'pubmed': 19369630,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 19370505,\n",
       "  'text': 'BRAF V600E mutation was significantly found in papillary thyroid carcinoma.'},\n",
       " {'pubmed': 19370505,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 19372556,\n",
       "  'text': 'Mutation in BRAF is associated with ERK1/2 activation and MEK1/2 inhibitor therapy in colorectal cancer.'},\n",
       " {'pubmed': 19378335,\n",
       "  'text': 'proliferation of cells harboring mutations in B-Raf, but not K-Ras, is exquisitely sensitive inhibition of the MAPK pathway'},\n",
       " {'pubmed': 19383313,\n",
       "  'text': 'REVIEW summarizes the literature on NRAS and BRAF activating mutations in melanoma tumors with respect to available data on histogenetic classification as well as body site and presumed UV-exposure.'},\n",
       " {'pubmed': 19383316,\n",
       "  'text': 'The genes whose expression is associated with BRAF mutations are not simply restricted to the MAPK/ERK signaling but also converge to enhanced immune responsiveness, cell motility and melanosomes processing involved in the adaptative UV response'},\n",
       " {'pubmed': 19389934,\n",
       "  'text': 'a subpopulation of melanocytes possesses the ability to survive BRAF(V600E)-induced senescence'},\n",
       " {'pubmed': 19393416,\n",
       "  'text': 'B-RAF mutation was found to be significantly higher in papillary carcinomas when compared to follicular variant of papillary thyroid carcinomas (55.6% vs 14.3%, P = 0.05).'},\n",
       " {'pubmed': 19393416,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 19398955,\n",
       "  'text': 'The murine model of mutant BRAF-induced melanoma formation provides an important tool for identifying further genetic alterations that cooperates with BRAF and that may be useful in enhancing susceptibility to BRAF-targeted therapeutics in melanoma.'},\n",
       " {'pubmed': 19404844,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 19404844,\n",
       "  'text': 'elevated pERK expression occurs in urothelial carcinoma in the absence of B-Raf mutations and is not correlated with FGFR3 over-expression'},\n",
       " {'pubmed': 19404918,\n",
       "  'text': 'Investigated BRAF mutations in 30 bladder tumors. Detected two tumor specimens bearing two different mutations, both of which were found in exon 15. One sample showed the T1799A (V600E) and the other the G1798T (V600L) mutation.'},\n",
       " {'pubmed': 19404918,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 19414674,\n",
       "  'text': 'Observational study of gene-disease association and genetic testing. (HuGE Navigator)'},\n",
       " {'pubmed': 19415957,\n",
       "  'text': 'The T1799A BRAF mutation does not appear to play a role in the tumorigenesis of the cribriform-morular variant of papillary carcinoma.'},\n",
       " {'pubmed': 19416762,\n",
       "  'text': 'Novel BRAF mutation in a patient with LEOPARD syndrome and normal intelligence is reported.'},\n",
       " {'pubmed': 19424571,\n",
       "  'text': 'BRAF V600E mutation is not the target gene for abnormal DNA mismatch repair in patients with sporadic endometrial cancer.'},\n",
       " {'pubmed': 19424639,\n",
       "  'text': \"Report efficient molecular screening of Lynch syndrome by specific 3' promoter methylation of the MLH1 or BRAF mutation in colorectal cancer with high-frequency microsatellite instability.\"},\n",
       " {'pubmed': 19430562,\n",
       "  'text': 'Mutations in BRAF were found 10% patients in the low-grade carcinoma group, however, they were not found in the high-grade carcinoma group. KRAS and BRAF mutations were mutually exclusive, and both mutations were observed in 40%.'},\n",
       " {'pubmed': 19430562,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 19440799,\n",
       "  'text': 'oncogenic properties of KRAS and BRAF but not NRAS, HRAS, and PIK3CA contribute to the tumorigenesis of periampullary and ampullary tumors'},\n",
       " {'pubmed': 19461239,\n",
       "  'text': 'mismatch repair deficiency is not a crucial event for BRAF mutation in melanocytic tumors'},\n",
       " {'pubmed': 19464601,\n",
       "  'text': 'The RAS/RAF/MEK/ERK signaling pathway has emerged as a major player in the induction and maintenance of melanoma, particularly the protein kinase BRAF, mutated in approximately 44% of melanoma cases. Review.'},\n",
       " {'pubmed': 19474002,\n",
       "  'text': 'data confirm that KRAS and BRAF mutations do occur in the same cell and that BRAF V600E mutation is associated with CIMP+ status.'},\n",
       " {'pubmed': 19483722,\n",
       "  'text': 'B-Raf/MKK/ERK provides a permissive environment for melanoma genesis by modulating plexin B1.'},\n",
       " {'pubmed': 19487299,\n",
       "  'text': 'If BRAF is mutated in the primary thyroid neoplasm, it is likely that the metastases will harbor the defect.'},\n",
       " {'pubmed': 19487299,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 19492075,\n",
       "  'text': 'Targeting NRAS alone or both BRAF and CRAF in combination or both BRAF and PIK3CA together showed delay in tumor growth.'},\n",
       " {'pubmed': 19498322,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 19498322,\n",
       "  'text': 'Results show that activating BRAF somatic mutations may be occasionally found in advanced adrenocortical carcinomas, while CTNNB1 activating mutations are early and common events in adrenal tumorigenesis.'},\n",
       " {'pubmed': 19504446,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 19534622,\n",
       "  'text': 'CTNNB1 and BRAF mutations may have roles in the cribriform-morular variant of papillary thyroid carcinoma'},\n",
       " {'pubmed': 19534623,\n",
       "  'text': 'BRAF V600E may have a role in development of papillary thyroid carcinoma'},\n",
       " {'pubmed': 19543740,\n",
       "  'text': 'Pilocytic astrocytomas had BRAF fusions in 70% of cases but not IDH1 or IDH2 mutations. Diffuse astrocytomas had IDH1 mutations in 76% of cases but not IDH2 mutations or BRAF fusions. Analysis of BRAF and IDH1 separates pilocytic from diffuse astrocytoma.'},\n",
       " {'pubmed': 19547661,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 19551857,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 19561230,\n",
       "  'text': 'BRAF mutations represent an alternative molecular pathway in the early tumorigenesis of a subset of KIT/PDGFRA wild-type GISTs and are per se not associated with a high risk of malignancy.'},\n",
       " {'pubmed': 19561230,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 19571295,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 19571295,\n",
       "  'text': 'study concludes that a BRAF mutation is a negative prognostic marker in patients with metastatic colorectal cancer'},\n",
       " {'pubmed': 19571709,\n",
       "  'text': 'BRAF mutated tumors occurred with a much greater frequency in proximal colon tumors than in either distal colon or rectal tumors'},\n",
       " {'pubmed': 19571821,\n",
       "  'text': 'We observed no association between germline MC1R status and somatic BRAF mutations in melanomas'},\n",
       " {'pubmed': 19574281,\n",
       "  'text': 'BRAF V600E mutation analysis can significantly improve FNAB diagnostic accuracy.'},\n",
       " {'pubmed': 19584155,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 19584155,\n",
       "  'text': 'Results suggest that the mutations of EGFR, KRAS, BRAF between primary tumors and corresponding lymph node metastases should be considered whenever mutations are used for the selection of patients for EGFR-directed tyrosine kinase inhibitor therapy.'},\n",
       " {'pubmed': 19603018,\n",
       "  'text': 'Assessing KRAS and BRAF mutations might help optimising the selection of the candidate metastatic colorectal cancer patients to receive anti-EGFR moAbs.'},\n",
       " {'pubmed': 19603018,\n",
       "  'text': 'Observational study of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)'},\n",
       " {'pubmed': 19603024,\n",
       "  'text': 'BRAF (P=0.01) mutations predicted reduced progress free survival in response to cetuximab salvage therapy in patients with metastatic colorectal cancer .'},\n",
       " {'pubmed': 19603024,\n",
       "  'text': 'Observational study of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)'},\n",
       " {'pubmed': 19624312,\n",
       "  'text': 'Mutated BRAF is a target in metastatic melanomas'},\n",
       " {'pubmed': 19626635,\n",
       "  'text': 'In this study, 28 matched tumor and serum samples obtained from patients with both benign and malignant thyroid disorders were analyzed for BRAF mutation.'},\n",
       " {'pubmed': 19626635,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 19628078,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 19633643,\n",
       "  'text': 'Characterization of candidate gene copy number alterations in the 11q13 region along with BRAF and NRAS mutations in human melanoma.'},\n",
       " {'pubmed': 19637313,\n",
       "  'text': 'strong inter-relation between DR4 AND DR5 overexpression and presence of oncogenic KRAS/ BRAF mutations in colon cancer.'},\n",
       " {'pubmed': 19638574,\n",
       "  'text': 'Sorafenib inhibits NSCLC cell growth by targeting B-RAF in cells with wild-type KRAS and C-RAF in those with mutant KRAS.'},\n",
       " {'pubmed': 19644722,\n",
       "  'text': 'BRAFV600E mutation is associated with papillary thyroid carcinoma.'},\n",
       " {'pubmed': 19652585,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 19659611,\n",
       "  'text': 'simultaneous depletion of both MITF and BRAF(V600E) significantly inhibited melanoma growth even for the melanoma cell lines resistant to MITF depletion'},\n",
       " {'pubmed': 19667985,\n",
       "  'text': 'Studies indicate that in pilocytic astrocytomas, the BRAF fusion gene has been identified as a specific and frequent event leading to potentially targetable mitogen-activated protein kinase pathway activation.'},\n",
       " {'pubmed': 19669908,\n",
       "  'text': 'Observational study of gene-disease association and DATA ERROR. (HuGE Navigator)'},\n",
       " {'pubmed': 19679016,\n",
       "  'text': 'Studies indicate that drugs are effective in targeting essential molecular pathways of BRAF, PTEN, Akt and mammalian target of rapamycin.'},\n",
       " {'pubmed': 19679059,\n",
       "  'text': 'Mutations in BRAF protein is associated with Colorectal Carcinoma.'},\n",
       " {'pubmed': 19679059,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 19681119,\n",
       "  'text': 'Investigated the prevalence of PTPN11, HRAS, KRAS, NRAS, BRAF, MEK1, and MEK2 mutations in a relatively large cohort of primary embryonal Rhabdomyosarcoma (RMS) tumors. No mutation was observed in BRAF and MEK genes.'},\n",
       " {'pubmed': 19682280,\n",
       "  'text': 'This study provides a basis for understanding the molecular processes that are regulated by (V600E)BRAF/MEK signalling in melanoma cells.'},\n",
       " {'pubmed': 19686742,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 19690147,\n",
       "  'text': 'a dual mechanism that affects the Sprouty2/B-Raf interaction: Sprouty phosphorylation and B-Raf conformation'},\n",
       " {'pubmed': 19693938,\n",
       "  'text': 'Whenever necessary BRAF testing may be performed on the residual samples of thyroid nodules, without interfering with routine cytology.'},\n",
       " {'pubmed': 19704056,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 19710001,\n",
       "  'text': 'The BRAF(V600E) mutation can be used as a potential prognostic factor in PTMC patients in a BRAF(V600E)-prevalent area.'},\n",
       " {'pubmed': 19710016,\n",
       "  'text': 'DGKeta acts as a novel critical regulatory component of the Ras/B-Raf/C-Raf/MEK/ERK signaling cascade via a previously unidentified mechanism.'},\n",
       " {'pubmed': 19718661,\n",
       "  'text': 'analysis of the effect on the Ras/Raf signaling pathway of post-translational modifications of neurofibromin'},\n",
       " {'pubmed': 19724843,\n",
       "  'text': 'This article focuses on reviewing the impact of the BRAFV600E mutation in the tumorigenesis of Papillary thyroid carcinoma'},\n",
       " {'pubmed': 19725049,\n",
       "  'text': 'EPAC-mediated cellular effects require activation of the B-Raf/ERK and mTOR signaling cascades'},\n",
       " {'pubmed': 19735675,\n",
       "  'text': 'Insights into the molecular function of the inactivating mutations of B-Raf involving the DFG motif.'},\n",
       " {'pubmed': 19738388,\n",
       "  'text': 'Observational study of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)'},\n",
       " {'pubmed': 19738460,\n",
       "  'text': 'Papillary carcinomas of the thyroid with papillary growth and areas of follicular growth have a high frequency of BRAF mutations.'},\n",
       " {'pubmed': 19745699,\n",
       "  'text': 'Beta-catenin nuclear labeling is a common feature of sessile serrated adenomas and correlates with early neoplastic progression after BRAF activation.'},\n",
       " {'pubmed': 19752400,\n",
       "  'text': 'The polyclonality of BRAF mutations in acquired melanocytic nevi suggests that mutation of BRAF may not be an initial event in melanocyte transformation.'},\n",
       " {'pubmed': 19759551,\n",
       "  'text': 'analysis of coexisting NRAS and BRAF mutations in primary familial melanomas with specific CDKN2A germline alterations'},\n",
       " {'pubmed': 19765726,\n",
       "  'text': 'Observational study of gene-disease association and gene-gene interaction. (HuGE Navigator)'},\n",
       " {'pubmed': 19794125,\n",
       "  'text': 'As predicted from the genomic organization at this locus, 22 of 36 patients with sporadic pilocytic astrocytomas and B-Raf gene rearrangement also exhibit corresponding homeodomain interacting protein kinase-2 (HIPK2) gene amplification.'},\n",
       " {'pubmed': 19826477,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 19829302,\n",
       "  'text': 'data argues against obligatory downregulation in IGFBP7 expression in BRAF mutated melanoma cells'},\n",
       " {'pubmed': 19850689,\n",
       "  'text': 'BRAF(T1799A) can be detected in the blood of papillary thyroid carcinoma patients with residual or metastatic disease and may provide diagnostic information'},\n",
       " {'pubmed': 19850689,\n",
       "  'text': 'Observational study of genetic testing. (HuGE Navigator)'},\n",
       " {'pubmed': 19855373,\n",
       "  'text': 'BRAF V600E mutations were seen in 83% of proximal and 74% of distal hyperplastic colonic polyps'},\n",
       " {'pubmed': 19861538,\n",
       "  'text': 'BRAFV600E oncogene induces transforming growth factor beta secretion leading to sodium iodide symporter repression and increased malignancy in thyroid cancer.'},\n",
       " {'pubmed': 19861964,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 19861964,\n",
       "  'text': 'These data demonstrate the feasibility of BRAF mutation detection in cfDNA of patients with advanced melanoma. Future studies should aim to incorporate BRAF mutation testing in cfDNA to further validate this biomarker for patient selection.'},\n",
       " {'pubmed': 19878585,\n",
       "  'text': 'Suppression of BRAF gene expression inhibited cell proliferation in cells with BRAF(V600E) mutation.'},\n",
       " {'pubmed': 19880519,\n",
       "  'text': 'Hyperactivation of BRAF-MEK signaling activates MAP2 expression in melanoma cells by two independent mechanisms, promoter demethylation or down-regulation of neuronal transcription repressor HES1.'},\n",
       " {'pubmed': 19881948,\n",
       "  'text': 'BRAF and KRAS oncogenes have different transforming capability in colon cancer'},\n",
       " {'pubmed': 19883729,\n",
       "  'text': 'The knowledge of BRAF mutation status can facilitate more accurate risk stratification and better decision making at various steps in the management of papillary thyroid cancer.'},\n",
       " {'pubmed': 19884549,\n",
       "  'text': 'Clinical trial of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)'},\n",
       " {'pubmed': 19884549,\n",
       "  'text': 'KRAS and BRAF mutations in advanced colorectal cancer are associated with poor prognosis but do not preclude benefit from oxaliplatin or irinotecan.'},\n",
       " {'pubmed': 19884556,\n",
       "  'text': 'BRAF status, EGFR amplification, and cytoplasmic expression of PTEN were associated with outcome measures in KRAS wild-type patients treated with a cetuximab-based regimen.'},\n",
       " {'pubmed': 19884556,\n",
       "  'text': 'Observational study of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)'},\n",
       " {'pubmed': 19893451,\n",
       "  'text': 'Study identified the previously reported pathogenic mutation of NTRK3 in a KRAS/BRAF wild-type tumor and 2 somatic mutations in the Src family of kinases (YES1 and LYN) that would be expected to cause structural changes.'},\n",
       " {'pubmed': 19903786,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 19908233,\n",
       "  'text': 'BRAF gene mutation is associated with colorectal cancer.'},\n",
       " {'pubmed': 19908233,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 19913317,\n",
       "  'text': 'BRAF mutations are not relevant for rectal carcinogenesis'},\n",
       " {'pubmed': 19913317,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 19917255,\n",
       "  'text': 'Data show that melanoma cells expressing B-Raf(V600E) display a reduced C-Raf:B-Raf ratio, and further suppression of C-Raf increases MAPK activation and proliferation.'},\n",
       " {'pubmed': 19919630,\n",
       "  'text': 'The BRAF V600E mutational status appears to be of limited diagnostic utility in distinguishing genital naevi that exhibit atypia from those that do not.'},\n",
       " {'pubmed': 19919912,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 19935791,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 19955937,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 19955937,\n",
       "  'text': 'v-Raf murine sarcoma viral oncogene mutations are common in ovarian serous bordeline tumors.'},\n",
       " {'pubmed': 19956635,\n",
       "  'text': 'Uncategorized study of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)'},\n",
       " {'pubmed': 19958951,\n",
       "  'text': 'clinical, cytologic, and pathologic parameters of 106 consecutive surgically treated patients with BRAF-positive PTC were compared with a concurrent cohort of 100 patients with BRAF-negative PTC (papillary thyroid carcinoma)'},\n",
       " {'pubmed': 19959686,\n",
       "  'text': '2-fold increased risk of BRAF V600E colonic tumor mutation was observed in current and former cigarette smokers homozygous for the OGG1 polymorphism'},\n",
       " {'pubmed': 19960590,\n",
       "  'text': 'BRAF T1796A mutation was identified in 27% of papillary thyroid cancer samples and its identification may be used to determine this risk factor of the development of papillary thyroid cancer.'},\n",
       " {'pubmed': 19960590,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 20008640,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 20009493,\n",
       "  'text': 'BRAFV600E mutation is associated with high-risk clinicopathological characteristics of papillary thyroid carcinoma and worse prognosis of patients'},\n",
       " {'pubmed': 20009493,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 20012784,\n",
       "  'text': 'Screening for BRAF, RET, KRAS, NRAS, and HRAS mutations, as well as RET-PTC1 and RET-PTC3 rearrangements, was performed on cases of Hashimoto thyroiditis with a dominant nodule'},\n",
       " {'pubmed': 20023270,\n",
       "  'text': 'BRAF V600E detection in the tumor does not induce a higher expression of the B-raf protein or the preferential activation of the p42/44 mitogen-activated protein kinase (MAPK) signaling pathway compared with GISTs without the BRAF mutation.'},\n",
       " {'pubmed': 20027224,\n",
       "  'text': 'CpG island methylator phenotype (CIMP)-specific inactivation of BRAF(V600E)-induced senescence and apoptosis pathways by IGFBP7 DNA hypermethylation might create a favorable context for the acquisition of BRAF(V600E) in CIMP+ colorectal cancer.'},\n",
       " {'pubmed': 20043015,\n",
       "  'text': 'Observational study of gene-disease association and gene-gene interaction. (HuGE Navigator)'},\n",
       " {'pubmed': 20043015,\n",
       "  'text': 'no support for MC1R variants with BRAF mutation for melanoma risk'},\n",
       " {'pubmed': 20044755,\n",
       "  'text': 'BRAF gene rearrangements were more common in cerebellar pilocytic astrocytoma than non-cerebellar tumors; clinical outcome was independent of BRAF status'},\n",
       " {'pubmed': 20049644,\n",
       "  'text': 'BRAF mutations only in metastases is not associated with resistance to anti-EGFR treatment in primary colorectal tumors.'},\n",
       " {'pubmed': 20049644,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 20051945,\n",
       "  'text': 'Observational study of genetic testing. (HuGE Navigator)'},\n",
       " {'pubmed': 20068183,\n",
       "  'text': 'BRAF(V600E) mutation seems to define a subset of malignant astrocytomas in children, in which there is frequent concomitant homozygous deletion of CDKN2A (five of seven cases).'},\n",
       " {'pubmed': 20098682,\n",
       "  'text': 'Observational study of genetic testing. (HuGE Navigator)'},\n",
       " {'pubmed': 20118768,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 20140953,\n",
       "  'text': 'Formalin-fixed primary melanomas from relapsed and nonrelapsed patients were sequenced for common BRAF and NRAS mutations. BRAF/NRAS mutations were detected in 77% of relapsers and 58% of nonrelapsers and did not predict ulceration or mitotic rate.'},\n",
       " {'pubmed': 20146801,\n",
       "  'text': 'Data demonstrate a signaling loop between B-Raf activation and p73 function, and suggest that low expression of TAp73 in colorectal cancer cell lines with mutated B-Raf may lead to lack of response to oxaliplatin/cetuximab.'},\n",
       " {'pubmed': 20156809,\n",
       "  'text': 'BRAF activating mutations are a major genetic alteration in this histologic group of pediatric low-grade brain tumors.'},\n",
       " {'pubmed': 20162668,\n",
       "  'text': 'Observational study of gene-disease association and gene-gene interaction. (HuGE Navigator)'},\n",
       " {'pubmed': 20162668,\n",
       "  'text': 'With MSI, specific KRAS and BRAF mutations, 3 distinct prognostic subgroups were observed: patients with (i) KRAS mutation G12D, G12V or BRAFmutation, (ii) KRAS/BRAFwild-type or KRAS G13D mutations in MSS/MSI-L and (iii) MSI-H and KRAS G13D mutations.'},\n",
       " {'pubmed': 20177422,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 20182446,\n",
       "  'text': 'High oncogenic BRAF levels trigger autophagy, which may have a role in melanoma tumor progression.'},\n",
       " {'pubmed': 20186801,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 20187782,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 20200438,\n",
       "  'text': 'Observational study of gene-disease association and gene-environment interaction. (HuGE Navigator)'},\n",
       " {'pubmed': 20200438,\n",
       "  'text': 'we measured the prevalence and epidemiologic correlates of the BRAF V600E somatic mutation in cases collected as a part of a population-based case-control study of colorectal cancer in northern Israel.'},\n",
       " {'pubmed': 20230995,\n",
       "  'text': 'pathogenesis of papillary thyroid cancer , and the clinical implications of BRAF(V600E) mutation in the diagnosis, prognosis and potential targeted therapeutic strategies for thyroid cancer [review]'},\n",
       " {'pubmed': 20233436,\n",
       "  'text': 'data support the model of BRAF and K-ras mutations arising in distinct colorectal cancer subsets associated with different clinicopathological and dietary factors, acting as mutually exclusive mechanisms of activation of the same signalling pathway'},\n",
       " {'pubmed': 20234366,\n",
       "  'text': 'Observational study of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)'},\n",
       " {'pubmed': 20300843,\n",
       "  'text': 'BRAF mutation is not associated with interval cancers but is a marker of poor prognosis, particularly in microsatellite stable cancers.'},\n",
       " {'pubmed': 20300843,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 20302979,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 20303012,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 20303012,\n",
       "  'text': 'Our study suggests that mutations of KRAS, not BRAF, may play a role in the pathogenesis of prostate carcinoma in Chinese patients.'},\n",
       " {'pubmed': 20305537,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 20332228,\n",
       "  'text': 'Studies show FOXD3 is suppressed by B-RAF, uncover a novel role and mechanism for FOXD3 as a negative cell cycle regulator, and have implications for the repression of melanocytic lineage cells.'},\n",
       " {'pubmed': 20351680, 'text': 'Mutated in melanoma.'},\n",
       " {'pubmed': 20379614,\n",
       "  'text': 'Clinical trial of gene-disease association and gene-environment interaction. (HuGE Navigator)'},\n",
       " {'pubmed': 20381121,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 20406109,\n",
       "  'text': 'The miR-146b expression levels in papillary thyroid carcinoma with BRAF mutation were significantly higher than those without this mutation'},\n",
       " {'pubmed': 20407018,\n",
       "  'text': 'Activated Raf-1 induces focal adhesion kinase expression and regulates neuroendocrine and metastatic phenotypes in gastrointestinal carcinoid cell line BON.'},\n",
       " {'pubmed': 20410389,\n",
       "  'text': 'thyroid carcinoma with the BRAF(V600E) mutation tends to be taller than wide and is not associated with the presence of calcifications on ultrasound.'},\n",
       " {'pubmed': 20413299,\n",
       "  'text': 'Observational study of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)'},\n",
       " {'pubmed': 20444249,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 20445557,\n",
       "  'text': 'B-RAF(V600E) can protect melanocytes from anoikis independently of cell cycle inhibition'},\n",
       " {'pubmed': 20453000,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 20454969,\n",
       "  'text': 'This study identified an exceptionally high frequency of KIAA1549-BRAF fusions in pilocytic astrocytoma.'},\n",
       " {'pubmed': 20460314,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 20460314,\n",
       "  'text': 'These data demonstrate a high prevalence of B-RAF mutations in the present study population, underscoring the possibility of strong regional differences.'},\n",
       " {'pubmed': 20473281,\n",
       "  'text': 'Hypoxia-inducible factor-1alpha is expressed in papillary thyroid carcinomas and is regulated not only by hypoxia but also by BRAF(V600E)-mediated signaling pathway.'},\n",
       " {'pubmed': 20473281,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 20478260,\n",
       "  'text': 'Study concludes that the secreted protein IGFBP7 is dispensable for B-RAF(V600E)-induced senescence in human melanocytes.'},\n",
       " {'pubmed': 20485284,\n",
       "  'text': 'BRAF V600E mutations are associated with MSI-H status and cyclin D1 overexpression and characterize a subgroup of patients with poor prognosis.'},\n",
       " {'pubmed': 20485284,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 20489114,\n",
       "  'text': 'Observational study of genetic testing. (HuGE Navigator)'},\n",
       " {'pubmed': 20495538,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 20496269,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 20498063,\n",
       "  'text': 'Knockdown of B-Raf(V600E) resulted in thrombospondin-1 down-regulation and a reduction of adhesion and migration/invasion of human thyroid cancer cells.'},\n",
       " {'pubmed': 20501503,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 20501503,\n",
       "  'text': 'The V600E BRAF mutation confers a worse prognosis to stage II and stage III colon cancer patients independently of disease stage and therapy.'},\n",
       " {'pubmed': 20501689,\n",
       "  'text': 'Observational study of gene-disease association and genetic testing. (HuGE Navigator)'},\n",
       " {'pubmed': 20514492,\n",
       "  'text': 'BRAF mutation may be used a biomarker for the selection of patients with colorectal cancer patients who might benefit from anti-egf receptor monoclonal antibodies.'},\n",
       " {'pubmed': 20514492,\n",
       "  'text': 'Meta-analysis of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)'},\n",
       " {'pubmed': 20519626,\n",
       "  'text': 'Studies identified the oncogenic BRAF V600E mutation in 35 of 61 archived specimens (57%).'},\n",
       " {'pubmed': 20526288,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 20526288,\n",
       "  'text': 'The BRAF 1799T>A mutation was found in 5 of 19 (26%) of infiltrative follicular variant of papillary thyroid carcinomas and in none of the encapsulated carcinomas'},\n",
       " {'pubmed': 20543023,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 20563851,\n",
       "  'text': 'HER2, but not EGFR gene amplification, is frequently observed in KRAS and BRAF wild type colorectal cancer patients'},\n",
       " {'pubmed': 20563851,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 20569675,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 20569675,\n",
       "  'text': 'reports the low frequency of PIK3CA and B-RAF mutations in astrocytomas, despite the presence of activated ERK and AKT proteins'},\n",
       " {'pubmed': 20570909,\n",
       "  'text': 'Incidence of cancer in FDRs of index CRC patients with the p.V600E BRAF mutation may be explained by a genetic predisposition to develop cancer through the serrated pathway of colorectal carcinogenesis.'},\n",
       " {'pubmed': 20570909,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 20571907,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 20571907,\n",
       "  'text': 'PIK3CA mutations may have a role in KRAS and BRAF wild type colorectal cancer'},\n",
       " {'pubmed': 20573852,\n",
       "  'text': 'BRAF mutational status of metastases is not required when the primary tumour is BRAF wild type.'},\n",
       " {'pubmed': 20576522,\n",
       "  'text': 'allele specific Taqman-based real-time PCR assay allows the sensitive, accurate and reliable measurement of BRAF(V600E) mutated DNA in plasma'},\n",
       " {'pubmed': 20591910,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 20605766,\n",
       "  'text': 'in melanomas activation of the MAPK pathway can occur through signaling pathways operating independently of BRAF T1799A'},\n",
       " {'pubmed': 20607849,\n",
       "  'text': 'V600E BRAF mutation is not associated with seminoma.'},\n",
       " {'pubmed': 20616366,\n",
       "  'text': 'Using traditional PCR and direct sequencing, we found KRAS mutations in 47 (40%) patients and BRAF(V600E) in 10 (8.5%)'},\n",
       " {'pubmed': 20619739,\n",
       "  'text': 'if KRAS is not mutated, assessing BRAF, NRAS, and PIK3CA exon 20 mutations (in that order) gives additional information about the efficacy of cetuximab plus chemotherapy in metastatic colorectal cancer.'},\n",
       " {'pubmed': 20627194,\n",
       "  'text': 'PCR is practically applicable to KRAS/BRAF genotyping using small amounts of biopsied colorectal tumor cells.'},\n",
       " {'pubmed': 20631031,\n",
       "  'text': 'No significant difference in BRAF alterations was found between pT1 tumors and thyroid capsule invasion and pT3 tumors.'},\n",
       " {'pubmed': 20631031,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 20635392,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 20640859,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 20645028,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 20645028,\n",
       "  'text': 'samples of metastatic colorectal cancer were tested for the presence of the seven most common mutations in the KRAS gene and the V600E mutation in the BRAF gene'},\n",
       " {'pubmed': 20647301,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 20647317,\n",
       "  'text': 'Findings delineate how mutant B-RAF protects melanoma cells from apoptosis and provide insight into possible resistance mechanisms to B-RAF inhibitors.'},\n",
       " {'pubmed': 20652941,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 20670148,\n",
       "  'text': 'Traditional DNA sequencing and the somewhat more-sensitive pyrosequencing method can detect multiple alternative BRAF mutations.'},\n",
       " {'pubmed': 20679909,\n",
       "  'text': 'Mutant Braf can be detected in RNA from mixed populations with as few as 0.1% Braf(V600E) mutant cells.'},\n",
       " {'pubmed': 20689758,\n",
       "  'text': 'PLX4032 has robust activity in BRAF mutated melanoma.'},\n",
       " {'pubmed': 20702649,\n",
       "  'text': 'Observational study of gene-disease association and gene-gene interaction. (HuGE Navigator)'},\n",
       " {'pubmed': 20703476,\n",
       "  'text': 'Observational study of genetic testing. (HuGE Navigator)'},\n",
       " {'pubmed': 20720566,\n",
       "  'text': 'Observational study of gene-disease association and gene-gene interaction. (HuGE Navigator)'},\n",
       " {'pubmed': 20720566,\n",
       "  'text': 'association between MC1 receptor germline variation and BRAF/NRAS mutations in melanoma'},\n",
       " {'pubmed': 20736745,\n",
       "  'text': 'Observational study of gene-disease association and gene-gene interaction. (HuGE Navigator)'},\n",
       " {'pubmed': 20802181,\n",
       "  'text': 'BRAF mutation is rare in advanced-stage low-grade ovarian serous carcinomas.'},\n",
       " {'pubmed': 20802181,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 20807807,\n",
       "  'text': 'Mutant protein kinase elicits significant therapeutic responses in mutant BRAF-driven human melanoma xenografts.'},\n",
       " {'pubmed': 20813562,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 20813562,\n",
       "  'text': 'first report implicating BRAF mutation in OSCC. study supports that mutations in the BRAF gene makes at least a minor contribution to OSCC tumorigenesis.'},\n",
       " {'pubmed': 20837233,\n",
       "  'text': 'BRAF mutation detection in fine needle biopsy may be an adjunct tool for preoperative didagnosis of papillary thyroid carcinoma.'},\n",
       " {'pubmed': 20840674,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 20840674,\n",
       "  'text': 'RET rearrangements and BRAF mutation in undifferentiated thyroid carcinomas having papillary carcinoma components'},\n",
       " {'pubmed': 20843808,\n",
       "  'text': 'A BRAF aberrant splice variant with an intact kinase domain and partial loss of the N-terminal autoinhibitory domain was identified in fibroblasts from an additional patient, and fibroblast proliferation was inhibited by BRAF-specific siRNA.'},\n",
       " {'pubmed': 20853079,\n",
       "  'text': 'reduced RKIP mRNA levels and the elevated levels of B-RAF in pT1, grade III tumors vs. normal tissue, corroborate that these genes are involved in the pathogenesis of urinary bladder cancer.'},\n",
       " {'pubmed': 20857202,\n",
       "  'text': 'BRAF V600E mutation is associated with lack of response in wild-type KRAS metastatic colorectal cancer treated with anti-EGFR monoclonal antibodies.'},\n",
       " {'pubmed': 20860430,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 20881644,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 20944096,\n",
       "  'text': 'Determination of the BRAF mutation and the growth fraction of melanomas may add a prognostic value.'},\n",
       " {'pubmed': 20944096,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 20945104,\n",
       "  'text': 'BRAF(V600E) mutation is associated with thyroid nodules.'},\n",
       " {'pubmed': 20945104,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 20947270,\n",
       "  'text': 'In the present series, no BRAF mutation was detected. The presence of KRAS mutations and loss of PTEN expression were not associated with impaired response to cetuximab-based chemoradiotherapy and 3-year disease free survival.'},\n",
       " {'pubmed': 20947270,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 20950194,\n",
       "  'text': 'BRAF is mutated in a low percentage of follicular variant of papillary thyroid carcinoma, and most of these mutated cases are suspicious or positive on fine-needle aspiration.'},\n",
       " {'pubmed': 20953721,\n",
       "  'text': 'BRAF mutation is associated with papillary thyroid microcarcinoma.'},\n",
       " {'pubmed': 20955560,\n",
       "  'text': 'Anti-BRAF autoantibodies from RA patients preferentially recognize one BRAF peptide: P2'},\n",
       " {'pubmed': 20959481,\n",
       "  'text': 'Braf mutation is associated with basal and treatment-induced regulation of the PI3K-AKT pathway as a critical regulator of AZD6244 sensitivity in cutaneous melanoma.'},\n",
       " {'pubmed': 20962618,\n",
       "  'text': 'Describe benign serrated colorectal fibroblastic polyps/intramucosal perineuriomas are true mixed epithelial-stromal polyps (hybrid hyperplastic polyp/mucosal perineurioma) with frequent BRAF mutations.'},\n",
       " {'pubmed': 20975100,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 20979647,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 21048031,\n",
       "  'text': 'Observational study of gene-disease association and gene-environment interaction. (HuGE Navigator)'},\n",
       " {'pubmed': 21049459,\n",
       "  'text': 'Although many studies document BRAF mutation as a prognostic factor in PTC our results underline that it is too early to consider it as a routine clinical predictive factor.'},\n",
       " {'pubmed': 21049459,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 21051183,\n",
       "  'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       " {'pubmed': 21051183,\n",
       "  'text': 'findings indicate that somatic mutations in KRAS and PIK3CA but not BRAF oncogenes are closely associated with the development of cholangiocarcinoma in Chinese population'},\n",
       " {'pubmed': 21068756,\n",
       "  'text': 'The dermoscopical and histopathological patterns of nevi correlate with the frequency of BRAF mutations.'},\n",
       " {'pubmed': 21076620,\n",
       "  'text': 'Data show that BRAF knockdown led to suppression of the expression of the GABPbeta, which involved in regulating HPR1 promoter activity.'},\n",
       " {'pubmed': 21098728,\n",
       "  'text': 'BRAF gene amplification can promote acquired resistance to MEK inhibitors in cancer cells harboring the BRAF V600E mutation.'},\n",
       " {'pubmed': 21102258,\n",
       "  'text': 'Mutations of EGFR, BRAF, and KRAS in adenocarcinoma were mutually exclusive and inversely correlated with RASSF1A methylation'},\n",
       " {'pubmed': 21102416,\n",
       "  'text': 'We show a strong association between concordant methylation of >/= 3 of five 3p22 genes with the CpG island methylator phenotype and the BRAF V600E mutation.'},\n",
       " {'pubmed': 21103049,\n",
       "  'text': 'Data show that among 181 CRC patients, stratified by microsatellite instability status, DNA sequence changes were identified in KRAS (32%), BRAF (16%), PIK3CA (4%), PTEN (14%) and TP53 (51%).'},\n",
       " {'pubmed': 21107320,\n",
       "  'text': 'identification of MAP3K8 (the gene encoding COT/Tpl2) as a MAPK pathway agonist that drives resistance to RAF inhibition in B-RAF(V600E) cell lines'},\n",
       " {'pubmed': 21107323,\n",
       "  'text': 'melanomas escape B-RAF(V600E) targeting not through secondary B-RAF(V600E) mutations but via receptor tyrosine kinase (RTK)-mediated activation of alternative survival pathway(s) or activated RAS-mediated reactivation of the MAPK pathway'},\n",
       " {'pubmed': 21129611,\n",
       "  'text': 'It therefore appears that BRAF mutations may play a strong negative prognostic role and only a slight role in resistance to anti-EGFR Abs.'},\n",
       " {'pubmed': 21131919,\n",
       "  'text': 'Primary esophageal melanomas of Caucasian patients harbor mutations of c-Kit, KRAS and BRAF in varied frequencies.'},\n",
       " {'pubmed': 21134544,\n",
       "  'text': 'BRAF mutation in papillary thyroid carcinoma is associated with an increased risk of palpable nodal recurrence and the need for reoperative surgery.'},\n",
       " {'pubmed': 21134562,\n",
       "  'text': 'BRAF mutations activate the mitogen-activated protein kinase pathway and confer an aggressive thyroid cancer phenotype.'},\n",
       " {'pubmed': 21161938,\n",
       "  'text': 'KRAS mutations arise more frequently than BRAF mutations in Moroccan patients with colorectal carcinomas.'},\n",
       " {'pubmed': 21166657,\n",
       "  'text': 'The BRAF mutation was frequently detected in patients with superficial spreading melanoma (OR=2.021; P<0.001) and in melanomas arising in nonchronic sun-damaged skin (OR=2.043; P=0.001).'},\n",
       " {'pubmed': 21167555,\n",
       "  'text': 'concluded that follicular variant of papillary thyroid carcinoma differs from conventional papillary thyroid carcinoma in the rate of BRAF mutation'},\n",
       " {'pubmed': 21176117,\n",
       "  'text': 'These results show that melanoma cell phenotype is an important factor in MAPK pathway inhibition response, as invasive phenotype cell response is dependent on BRAF mutation status.'},\n",
       " {'pubmed': 21185263,\n",
       "  'text': 'this study has confirmed that the BRAF(T1799A) mutation confers cancer cells sensitivity to PLX4032 and demonstrated its specific potential as an effective and BRAF(T1799A) mutation-selective therapeutic agent for thyroid cancer.'},\n",
       " {'pubmed': 21190184,\n",
       "  'text': 'B-Raf(insT) and B-Raf(V600E) , but not B-Raf(wt) , provoke drastic morphological alterations in human astrocytes.'},\n",
       " {'pubmed': 21203559,\n",
       "  'text': 'BRAF alternative splicing is differentially regulated in human and mouse. BRAF exon 9b is required for learning and memory associated with the hippocampus.'},\n",
       " {'pubmed': 21215707,\n",
       "  'text': 'In melanoma cells, oncogenic (V600E) BRAF signaling downregulates PDE5A through the transcription factor BRN2, leading to increased cGMP and Ca2+ and the induction of invasion through increased cell contractility.'},\n",
       " {'pubmed': 21223556,\n",
       "  'text': 'B-Raf signaling has a key function in the altered expression of contractile receptors in the cerebrovasculature.'},\n",
       " {'pubmed': 21223812,\n",
       "  'text': 'The high expression of activated ERK is not caused by BRAF gene mutation in nasal mucosa malignant melanomas.'},\n",
       " {'pubmed': 21224857,\n",
       "  'text': 'Acquisition of a BRAF mutation is not a founder event, but may be one of the multiple clonal events in melanoma development, which is selected for during the progression.'},\n",
       " {'pubmed': 21239517,\n",
       "  'text': 'We found that performing BRAF(V600E) mutation analysis on the fine-needle aspiration biopsy specimens was of great help to make a therapeutic decision for thyroid nodules when the fine-needle aspiration biopsy results were equivocal'},\n",
       " {'pubmed': 21249150,\n",
       "  'text': 'the oncogenic effect of BRAF(V600E) is associated with the inhibition of MST1 tumor suppressor pathways, and the activity of RASSF1A-MST1-FoxO3 pathways determines the phenotypes of BRAF(V600E) tumors.'},\n",
       " {'pubmed': 21263251,\n",
       "  'text': 'These findings suggest that BRAF mutations may be associated with the pathogenesis of sessile serrated colorectal adenomas.'},\n",
       " {'pubmed': 21270111,\n",
       "  'text': 'Findings suggest inhibition of autophagy in combination with ER stress-inducing agents may represent a means by which to harness autophagy for the therapeutic benefit of B-RAF wild-type melanoma.'},\n",
       " {'pubmed': 21274671,\n",
       "  'text': 'B-Raf mutations, microsatellite instability and p53 protein expression is not associated with sporadic basal cell carcinomas.'},\n",
       " {'pubmed': 21274720,\n",
       "  'text': 'The analysis of BRAF V600E mutation in 1,320 nervous system tumors reveals high mutation frequencies in pleomorphic xanthoastrocytoma, ganglioglioma and extra-cerebellar pilocytic astrocytoma.'},\n",
       " {'pubmed': 21285991,\n",
       "  'text': 'Presence of mutated BRAF is one of the most powerful prognostic factors for advanced and recurrent CRC'},\n",
       " {'pubmed': 21289333,\n",
       "  'text': '803 metastatic colorectal cancer samples studied for KRAS exon 2 and BRAF exon 15 mutations; BRAF mutated samples were characterized for mismatch repair function; 344 tumours were mutated -34 involving BRAF mutations (8 of microsatellite instability type)'},\n",
       " {'pubmed': 21303778,\n",
       "  'text': 'Ras/Raf/MAPK and RhoA/ROCKII signalling pathways are abnormally activated in eutopic endometrial stromal cells of patients with endometriosis'},\n",
       " {'pubmed': 21305640,\n",
       "  'text': '78 colorectal tumor samples were mutant for BRAF.'},\n",
       " {'pubmed': 21307665,\n",
       "  'text': 'analysis of gallbladder carcinomas, gallbladder adenomas, and high-grade dysplastic lesions for the BRAF and the KRAS mutations'},\n",
       " {'pubmed': 21317202,\n",
       "  'text': 'Findings suggest that inhibition of Raf-MEK-Erk pathway might offer a novel therapeutic strategy in neuroendocrine tumors'},\n",
       " {'pubmed': 21317224,\n",
       "  'text': 'Studies showed that siRNA knockdown of BIM significantly blunted the apoptotic response in PTEN+ melanoma cells.'},\n",
       " {'pubmed': 21317286,\n",
       "  'text': 'identified BAD serine 134 to be strongly involved in survival signaling of B-RAF-V600E-containing tumor cells and found that phosphorylation of BAD at this residue is critical for efficient proliferation in these cells.'},\n",
       " {'pubmed': 21321384,\n",
       "  'text': 'identifying downstream events from the BRAFV600E/ERK1/2 pathway will eventually identify novel biomarkers that can be used to correlate with disease outcome and overall survival.'},\n",
       " {'pubmed': 21324100,\n",
       "  'text': 'Data show that BRAF-mutated melanomas occur in a younger age group on skin without marked solar elastosis and less frequently affect the head and neck area, compared to melanomas without BRAF mutations.'},\n",
       " {'pubmed': 21326296,\n",
       "  'text': 'BRAF mutations have a smaller role in the carcinogenesis of malignant melanoma in Chinese Han than in Western patients.'},\n",
       " {'pubmed': 21332555,\n",
       "  'text': 'BRAF mutations were rare in colorectal laterally-spreading tumors.'},\n",
       " {'pubmed': 21343559,\n",
       "  'text': 'The presence of mutant BRAF had no impact on the disease-free interval from diagnosis of first-ever melanoma to first distant metastasis; however, it may have impacted survival thereafter.'},\n",
       " {'pubmed': 21345796,\n",
       "  'text': 'B-Raf associates with and stimulates NHE1 activity and that B-Raf(V600E) also increases NHE1 activity that raises intracellular pH.'},\n",
       " {'pubmed': 21351275,\n",
       "  'text': 'BRAF mutation is associated with selective inhibition of thyroid cancer cells by the novel MEK inhibitor RDEA119 and genetic-potentiated synergism with the mTOR inhibitor temsirolimus'},\n",
       " {'pubmed': 21356389,\n",
       "  'text': 'IDH1 mutation works with other oncogenic mutations and could contribute to the metastasis in melanoma.'},\n",
       " {'pubmed': 21362156,\n",
       "  'text': 'Regulation of NR4A nuclear receptor expression by oncogenic BRAF in melanoma cells.'},\n",
       " {'pubmed': 21383284,\n",
       "  'text': 'BRAF mutational status yielded no useful prognostic information in predicting recurrence and benefits from adjuvant chemotherapy in colorectal cancer.'},\n",
       " {'pubmed': 21383288,\n",
       "  'text': 'Thus, MEK1(C121S) or functionally similar mutations are predicted to confer drug resistance of neoplasms to combined MEK/RAF inhibition.'},\n",
       " {'pubmed': 21383698,\n",
       "  'text': 'tumor initiation by oncogenic BRAF renders thyroid cells susceptible to TGFbeta-induced epithelial-mesenchymal transition, through a MAPK-dependent process'},\n",
       " {'pubmed': 21390154,\n",
       "  'text': 'K-ras gene mutation is a common event in Chinese colorectal cancer (CRC) patients, but may not be a prognostic factor in CRC , while BRAF is rarely mutated in Chinese CRC patients.'},\n",
       " {'pubmed': 21408138,\n",
       "  'text': 'Allele-specific qPCR assays for the most frequent activating mutations in EGFR, KRAS, BRAF and PIK3CA in tumor-positive fine needle cytological aspirates were compared against histological material of primary tumors.'},\n",
       " {'pubmed': 21412762,\n",
       "  'text': 'BRAF mutation is associated with papillary thyroid cancer.'},\n",
       " {'pubmed': 21424126,\n",
       "  'text': 'study suggested that both KRAS and BRAF mutations are exclusive, but KRAS and PIK3CA mutations are coexistent'},\n",
       " {'pubmed': 21424530,\n",
       "  'text': 'This study demonistrated that the role of RAF kinase fusions as a central oncogenic mechanism in the development of pilocytic astrocytoma.'},\n",
       " {'pubmed': 21426297,\n",
       "  'text': 'Mutations at the position V600 of BRAF were described in approximately 8% of all solid tumors, including 50% of melanomas, 30 to 70% of papillary thyroid carcinomas and 5 to 8% of colorectal adenocarcinomas.'},\n",
       " {'pubmed': 21427714,\n",
       "  'text': 'There were no significant differences in the frequency of BRAF mutations among lesions exhibiting the hyperplastic, adenomatous, or mixed patterns.'},\n",
       " {'pubmed': 21430505,\n",
       "  'text': 'The presence of the BRAF(V600E) mutation may play different roles between medium and giant CMNs in melanocytic tumorigenesis.'},\n",
       " {'pubmed': 21431280,\n",
       "  'text': 'BRAF T1799A mutation may be an early and essential carcinogenic event in nearly all Korean papillary thyroid carcinomas'},\n",
       " {'pubmed': 21441079,\n",
       "  'text': 'In papilary thyroid carcinoma, the BRAFT1799A mutation is associated with age over 60 & a tumor size of 1cm or greater, but not with other clinicopathological characteristics, tumor recurrence or persistence.'},\n",
       " {'pubmed': 21441910,\n",
       "  'text': \"KSR interacts with a regulatory Raf molecule in cis to induce a conformational switch of MEK, facilitating MEK's phosphorylation by a separate catalytic Raf molecule in trans\"},\n",
       " {'pubmed': 21447798,\n",
       "  'text': 'Amplification of the driving oncogene, KRAS or BRAF, underpins acquired resistance to MEK1/2 inhibitors in colorectal cancer cells.'},\n",
       " {'pubmed': 21451543,\n",
       "  'text': 'Activated BRAF promotes melanoma cell growth by matrix metalloproteinase-1'},\n",
       " {'pubmed': 21455633,\n",
       "  'text': 'No V600E mutation was identified in the BRAF gene in any sample.'},\n",
       " {'pubmed': 21456008,\n",
       "  'text': 'the impact of BRAF mutation and microsatellite instability on prognosis in metastatic colorectal cancer'},\n",
       " {'pubmed': 21457162,\n",
       "  'text': 'BRAF mutations are specific for serrated adenocarcinoma and identify a subset of serrated adenocarcinomas with gene methylation and a tendency for MSI-H'},\n",
       " {'pubmed': 21479234,\n",
       "  'text': 'BRAF V600E mutations are common in the majority of pleomorphic xanthoastrocytoma.'},\n",
       " {'pubmed': 21483104,\n",
       "  'text': 'Heterogeneity of KRAS and BRAF mutation status intra-tumorally in colorectal cancer was assessed.'},\n",
       " {'pubmed': 21498916,\n",
       "  'text': 'findings support the notion that BRAF(V600E), which can be detected preoperatively in papillary thyroid carcinoma fine-needle aspiration biopsy material, has a potential to contribute to patients stratification into high- and low-risk groups.'},\n",
       " {'pubmed': 21512141,\n",
       "  'text': 'Mutated BRAF is detected in approximately 45% of papillary thyroid carcinomas (PTC).'},\n",
       " {'pubmed': 21514245,\n",
       "  'text': 'Ablation of B-Raf had no significant effect on development of K-Ras oncogene-driven non-small cell lung carcinoma.'},\n",
       " {'pubmed': 21553007,\n",
       "  'text': 'BRAF mutations, but not KRAS mutations, were associated with a worse outcome in Chinese colorectal cancer patients.'},\n",
       " {'pubmed': 21557216,\n",
       "  'text': 'MSS/BRAF mutant cancers were more commonly proximal (38/54, 70.3%).'},\n",
       " {'pubmed': 21570823,\n",
       "  'text': 'Analysis showed that blood samples with PCR evidence for CMC were heterogeneous for BRAF status under limiting-dilution conditions, suggestive of heterogeneity of CMC'},\n",
       " {'pubmed': 21577205,\n",
       "  'text': 'Studies indicate that Raf kinases are excellent molecular targets for anticancer therapy.'},\n",
       " {'pubmed': 21587258,\n",
       "  'text': 'Wnt5a methylation was strongly associated with tumour microsatellite instability tumours after adjustment for age, sex, and tumour location and with BRAF V600E mutation, a marker of CpG island methylator phenotype'},\n",
       " {'pubmed': 21594703,\n",
       "  'text': 'BRAF V600E mutation is associated with recurrent papillary thyroid cancer.'},\n",
       " {'pubmed': 21636552,\n",
       "  'text': 'introduction of constitutively active BRAF V600E into human cortical stem and progenitor cells initially promotes clonogenic growth in soft agar but ultimately results in dramatically reduced proliferation and arrested growth of the culture.'},\n",
       " {'pubmed': 21653734,\n",
       "  'text': 'Compared with BRAF-wt papillary thyroid cancer, those harboring BRAF(V600E) exhibit downregulated VEGFA, VEGFR, and PDGFRbeta expression, suggesting presence of BRAF mutation does not imply stronger response to drugs targeting VEGF and PDGFB signal pathways.'},\n",
       " {'pubmed': 21663470,\n",
       "  'text': 'The BRAF V600E mutation was present in all patients with hairy-cell leukemia who were evaluated.'},\n",
       " {'pubmed': 21681432,\n",
       "  'text': 'The BRAF V600E mutation did not show association with clinical or molecular characteristics of colorectal cancer.'},\n",
       " {'pubmed': 21693616,\n",
       "  'text': 'Eight of 16 primary tumor samples and 4 of 6 metastatic samples showed BRAF V600E gene mutations and no copy number changes were associated exclusively with metastatic cancer'},\n",
       " {'pubmed': 21696415,\n",
       "  'text': 'The frequency of BRAF-KIAA1549 fusion transcripts is significantly lower in adult patients with pilocytic astrocytoma.'},\n",
       " {'pubmed': 21705440,\n",
       "  'text': 'MEK1(F129L) mutation also strengthened binding to c-Raf, suggesting an underlying mechanism of higher intrinsic kinase activity'},\n",
       " {'pubmed': 21707687,\n",
       "  'text': 'The application of BRAF(V600E) mutation analysis in US-guided FNAB can improve the diagnostic accuracy of thyroid nodules.'},\n",
       " {'pubmed': 21716161,\n",
       "  'text': 'We describe a new mutation of BRAF, T599dup, in a case of anaplastic thyroid carcinoma with tall cell papillary thyroid carcinomas component.'},\n",
       " {'pubmed': 21725359,\n",
       "  'text': 'identified concurrent mutational inactivation of the PTEN and RB1 tumor suppressors as a mechanism for loss of BRAF/MEK dependence in melanomas harboring (V600E)BRAF mutations'},\n",
       " {'pubmed': 21750338,\n",
       "  'text': 'BRAF mutation of papillary thyroid carcinoma may have differential predictive values for LN metastasis, according to tumor size.'},\n",
       " {'pubmed': 21774961,\n",
       "  'text': 'BRAF(V600E) mutation analysis using residual liquid-based preparation cytologic samples is, therefore, a powerful additional diagnostic tool for diagnosis of papillary thyroid carcinoma.'},\n",
       " {'pubmed': 21788131,\n",
       "  'text': 'Patients with mutations in BRAF or NRAS gene are frequently present with ulceration, and mutation in BRAF or NRAS gene is indicator for poor prognosis.'},\n",
       " {'pubmed': 21796448,\n",
       "  'text': 'Importance of infiltrative growth pattern and invasiveness over presence of BRAF mutation in classic and follicular variant papillary thyroid carcinoma for development of nodal metastases.'},\n",
       " {'pubmed': 21803329,\n",
       "  'text': 'BRAF mutation is not indicative for predicting papillary thyroid cancer prognosis.'},\n",
       " {'pubmed': 21825258,\n",
       "  'text': 'study reports that V600E and non-V600E BRAF mutations affect different patients with non-small-cell lung cancer; V600E mutations are significantly associated with female sex and represent a negative prognostic factor'},\n",
       " {'pubmed': 21826673,\n",
       "  'text': 'BRAF mutations and llelic loss of susceptibility loci are associated with familial non-medullary thyroid cancer.'},\n",
       " {'pubmed': 21835307,\n",
       "  'text': 'The BRAF/MEK/ERK pathway is upregulated in progressive retinal arterial macroaneurysm patients, caused by mutation in IGFBP7.'},\n",
       " {'pubmed': 21863388,\n",
       "  'text': 'Braf mutation in metastatic melanoma treated with BRAF inhibitor vemurafenib.'},\n",
       " {'pubmed': 21871821,\n",
       "  'text': 'Genetic analysis revealed individual heterozygous mutations in the KRAS (phenotype of CFC/Noonan syndrome) and BRAF genes (phenotype of CFC syndrome)'},\n",
       " {'pubmed': 21875464,\n",
       "  'text': 'BRAF V600E mutation has a significant correlation with papillary thyroid carcinomas.'},\n",
       " {'pubmed': 21882184,\n",
       "  'text': 'the BRAF(V600E) mutation should be considered as a poor prognostic marker in papillary thyroid cancer (Meta-Analysis)'},\n",
       " {'pubmed': 21900390,\n",
       "  'text': 'Studies indicate that BRAF V600E mutation initiates follicular cell transformation.'},\n",
       " {'pubmed': 21901162,\n",
       "  'text': 'In sporadic colorectal tumourspatients, the most frequently mutated gene was APC (68.9% of tumours), followed by KRAS (31.1%), TP53 (27.2%), BRAF (8.7%) and CTNNB1 (1.9%).'},\n",
       " {'pubmed': 21903858,\n",
       "  'text': 'BRAF(V600E) causes upregulation of TIMP-1 via NF-kappaB. TIMP-1 binds then its surface receptor CD63, leading eventually to Akt activation, which in turn confers antiapoptotic behavior and promotion of cell invasion.'},\n",
       " {'pubmed': 21906875,\n",
       "  'text': 'BRAF mutations are of pathogenetic significance in wild type gastrointestinal stromal tumors.'},\n",
       " {'pubmed': 21909080,\n",
       "  'text': \"CXCR4 expression and BRAF mutation status could cooperatively induce and promote a more aggressive phenotype in papillary thyroid carcinoma through several pathways and specifically increase the tumors' spread outside of the thyroid gland.\"},\n",
       " {'pubmed': 21915661,\n",
       "  'text': 'Aberrant CIMP was detected in 16% of chromosomal instable tumors and in 44% of both microsatellite instable and microsatellite and chromosomally stable carcinomas'},\n",
       " {'pubmed': 21936566,\n",
       "  'text': 'this novel B-Raf fusion protein (SND-1 was identified as the B-Raf fusion partner) presents a novel target with potential clinical implications in the treatment of patients resistant to c-Met inhibitors.'},\n",
       " {'pubmed': 21937738,\n",
       "  'text': 'A prominent epigenetic mechanism through which BRAF V600E can promote papillary thyroid cancer tumorigenesis by altering the methylation and hence the expression of numerous important genes.'},\n",
       " {'pubmed': 21943101,\n",
       "  'text': 'BRAF mutation V600E significantly induces cell migration and invasion properties in vitro in colon cancer cells'},\n",
       " {'pubmed': 21948220,\n",
       "  'text': 'In malignant FNABs in papillary thyroid carcinoma, BRAF(V600E) mutation was significantly associated with presence of extra-thyroidal extension and metastases after surgery.'},\n",
       " {'pubmed': 22006538,\n",
       "  'text': 'DNA methylation of each marker was quantified using combined bisulfite restriction analysis (COBRA) and analyzed along with various genetic factors associated with CRC [the BRAF and KRAS mutations, MLH1 methylation and microsatellite instability'},\n",
       " {'pubmed': 22012135,\n",
       "  'text': 'An integrated approach combining both VE1 mutant protein immunohistochemistry and genetic analysis may increase the diagnostic accuracy of BRAF mutation analysis.'},\n",
       " {'pubmed': 22027477,\n",
       "  'text': 'Postmenopausal hormone therapy was associated with borderline statistically significant risk reductions for BRAF-wildtype tumours among women with prolonged exposure to Postmenopausal hormone therapy.'},\n",
       " {'pubmed': 22028477,\n",
       "  'text': 'BRAF V600E mutation is associated with hairy cell leukemia and B-cell neoplasms'},\n",
       " {'pubmed': 22033631,\n",
       "  'text': 'high prevalence of BRAF (V600E) mutation is associated with synchronous bilateral papillary thyroid carcinoma.'},\n",
       " {'pubmed': 22038996,\n",
       "  'text': 'Results support evaluation of BRAF(V600E)-specific inhibitors for treating BRAF(V600E) malignant astrocytomas (MA) patients.'},\n",
       " {'pubmed': 22039425,\n",
       "  'text': 'study examined the clinical characteristics and outcomes of patients with mutant BRAF advanced cancer; conclude that BRAF appears to be a druggable mutation that also defines subgroups of patients with phenotypic overlap, albeit with differences that correlate with histology or site of mutation'},\n",
       " {'pubmed': 22043994,\n",
       "  'text': 'This article reviewes the spectrum of KRAS/BRAF genotype and the impact of KRAS/BRAF mutations on the clinicopathological features and prognosis of patients with colorectal cancer. [review]'},\n",
       " {'pubmed': 22065586,\n",
       "  'text': 'Ras induces DR5 expression through co-activation of ERK/RSK and JNK signaling pathways'},\n",
       " {'pubmed': 22072557,\n",
       "  'text': 'BRAF V600E mutation is associated with hairy cell leukemia and other mature B-cell neoplasms'},\n",
       " {'pubmed': 22072743,\n",
       "  'text': 'BAG3 protein sustains anaplastic thyroid tumor growth in vitro and in vivo. The underlying molecular mechanism appears to rely on BAG3 binding to BRAF, thus protecting it from proteasome-dependent degradation.'},\n",
       " {'pubmed': 22105174,\n",
       "  'text': 'Murine thyroid tumors carrying the human BRAF(V600E) mutations are exquisitely dependent on the oncoprotein for viability.'},\n",
       " {'pubmed': 22105775,\n",
       "  'text': 'BRAF (V600E) is a prevalent genetic alteration in adult sporadic papillary thyroid carcinoma in Indian cohort and it may be responsible for the progression of its classic variant.'},\n",
       " {'pubmed': 22114137,\n",
       "  'text': 'Overall, no difference existed in microsatellite instability or BRAF mutation frequencies between African Americans and Caucasians with colorectal neoplasms.'},\n",
       " {'pubmed': 22133769,\n",
       "  'text': 'BRAF mutations are associated with hairy cell leukemia and related lymphoproliferative disorders.'},\n",
       " {'pubmed': 22136270,\n",
       "  'text': 'Case Report: describe case of follicular thyroid carcinoma with BRAF mutation.'},\n",
       " {'pubmed': 22137342, 'text': 'thieno[2,3-d]pyrimidines are B-Raf inhibitors'},\n",
       " {'pubmed': 22145942,\n",
       "  'text': 'Pyrosequencing of BRAF V600E in routine samples of hairy cell leukaemia identifies CD5+ variant hairy cell leukaemia that lacks V600E.'},\n",
       " {'pubmed': 22147429,\n",
       "  'text': 'V600E mutation of the BRAF gene reported to be associated with poor prognosis of germ cell tumors in adults prognostic biomarkers cannot necessarily be transferred from one age group to the other.'},\n",
       " {'pubmed': 22147942,\n",
       "  'text': 'BRAF mutation is associated with inferior survival in stage III colon cancer.'},\n",
       " {'pubmed': 22150560,\n",
       "  'text': 'papillary thyroid cancers in young patients display a low prevalence of the already identified oncogenic alterations; the increasing prevalence with age is mainly due to V600E BRAF mutation'},\n",
       " {'pubmed': 22156467,\n",
       "  'text': 'The BRAF V600E mutation is associated with a higher pathological stage at surgery and a higher rate of recurrence.'},\n",
       " {'pubmed': 22156468,\n",
       "  'text': 'BRAF mutations enhance the predictability of malignancy in thyroid follicular lesions of undetermined significance.'},\n",
       " {'pubmed': 22157687,\n",
       "  'text': 'BRAF and KRAS mutations were observed in six (46.2%) and four (30.3%) filiform serrated adenomaS, respectively.'},\n",
       " {'pubmed': 22170714,\n",
       "  'text': 'BRAF mutation in papillary thyroid carcinoma is a later subclonal event, its intratumoral heterogeneity may hamper the efficacy of targeted pharmacotherapy, and its association with a more aggressive disease should be reevaluated.'},\n",
       " {'pubmed': 22174938,\n",
       "  'text': 'The antibody response against the catalytic domain of BRAF is not specific for rheumatoid arthritis.'},\n",
       " {'pubmed': 22178589,\n",
       "  'text': 'Report mutations in KRAS, EGFR, and BRAF in cholangiocarcinoma and identify therapeutic targets for tyrosine kinase inhibitors.'},\n",
       " {'pubmed': 22180495,\n",
       "  'text': 'Findings suggest that the BRAF inhibitor vemurafenib in combination with standard-of-care or novel targeted therapies may lead to enhanced and sustained clinical antitumor efficacy in CRCs harboring the BRAF(V600E) mutation.'},\n",
       " {'pubmed': 22189819,\n",
       "  'text': 'Aberrant gene methylation driven by BRAF(V600E) altered expression of the DNA methyltransferase 1 and histone methyltransferase EZH2 profoundly.'},\n",
       " {'pubmed': 22190222,\n",
       "  'text': 'The BRAF(V600E) mutation was associated with high-risk clinicopathologic characteristics in patients with papillary thyroid cancer (PTC). The BRAF(V600E) mutation may be a potential prognostic factor in PTC patients.'},\n",
       " {'pubmed': 22190283,\n",
       "  'text': 'B-Raf gene mutation primarily occurs at two loci--the exon 11 glycine loop and the activation area of exon 15--in surgically resected specimens of hepatocellular carcinoma patients.'},\n",
       " {'pubmed': 22194995,\n",
       "  'text': 'These data support a model where the continuous regenerative process initiated by oncogenic B-RAF-driven alveolar disruption provides a tumor-promoting environment associated with chronic inflammation.'},\n",
       " {'pubmed': 22199277,\n",
       "  'text': 'RET mutations may have a role in medullary thyroid carcinoma, while BRAF, AKT1, and CTNNB1 do not; the role of HRAS, KRAS, and NRAS mutations are not determined'},\n",
       " {'pubmed': 22199339,\n",
       "  'text': 'analysis of BRAF gene mutations in non-small cell lung cancer'},\n",
       " {'pubmed': 22203991,\n",
       "  'text': 'These results provide a functional link between oncogenic BRAF and angiogenesis.'},\n",
       " {'pubmed': 22210186,\n",
       "  'text': 'Patients with microsatellite instability tumor phenotype had favorable prognosis, but in those with the V600E BRAF mutation higher recurrence rate was observed.'},\n",
       " {'pubmed': 22210875,\n",
       "  'text': 'Our results suggest that HCLv and IGHV4-34(+) HCLs have a different pathogenesis than HCLc and that a significant minority of other HCLc are also wild-type for BRAF V600.'},\n",
       " {'pubmed': 22214007,\n",
       "  'text': 'Although it constitutes a poor prognostic factor in colorectal cancer, it is not conclusive if it interferes with a poor therapeutic effect when cetuximab is used.[review]'},\n",
       " {'pubmed': 22227015,\n",
       "  'text': 'The findings show mutant BRAF-induced oncogenic stress manifests itself by DNA damage and growth arrest by activating the pCHK2-p53-p21 pathway.It also confers tumor-promoting phenotypes such as the up-regulation of GLUT1 and enhances glucose metabolism.'},\n",
       " {'pubmed': 22228154,\n",
       "  'text': 'In patients with colorectal adenocarcinoma, there were significant differences between BRAF wild-type and mutant tumors in age, female sex, proximal tumor location, frequency of microsatellite instability, and survival.'},\n",
       " {'pubmed': 22230299,\n",
       "  'text': 'One chronic lymphocytic leukaemia patient and one patient with B-prolymphocytic leukaemia were found to harbour the BRAF V600E mutation'},\n",
       " {'pubmed': 22233696,\n",
       "  'text': 'Sessile serrated adenomas are precursors of sporadic colorectal cancers with microsatellite instability.Identified a novel surface microstructure, the Type II open-shape pit pattern (Type II-O), which was specific to SSAs with BRAF mutation and CIMP.'},\n",
       " {'pubmed': 22235286,\n",
       "  'text': 'evidence for heterogeneity of the BRAF(V600E) mutation within individual melanoma tumor specimens'},\n",
       " {'pubmed': 22245873,\n",
       "  'text': 'No BRAF mutations were found in colon adenocarcinomas from renal transplant recipients.'},\n",
       " {'pubmed': 22246856,\n",
       "  'text': 'BRAF V600E mutation in low and intermediate grade lymphomas is associated with frequent occurrence in hairy cell leukaemia.'},\n",
       " {'pubmed': 22249628,\n",
       "  'text': 'None of the molecular marker mutations that were analyzed in this study, including the BRAF mutation, predicted lymph node metastasis in classic papillary thyroid carcinoma.'},\n",
       " {'pubmed': 22250191,\n",
       "  'text': 'During therapy with selective BRAF inhibitors, panniculitis with arthralgia represents a new adverse effect that can require dose reduction.'},\n",
       " {'pubmed': 22258409,\n",
       "  'text': 'Mutational activation of both BRAF and PIK3CA genes does contribute to hepatocellular tumorigenesis at somatic level in Southern Italian population.'},\n",
       " {'pubmed': 22282465,\n",
       "  'text': 'In naive GISTs carrying activating mutations in KIT or PDGFRA a concomitant activating mutation was detected in KRAS (5%) or BRAF (about 2%) genes. I'},\n",
       " {'pubmed': 22287190,\n",
       "  'text': 'BRAF mutation is associated with colorectal serrated adenocarcinoma.'},\n",
       " {'pubmed': 22294102,\n",
       "  'text': 'No hotspot mutations in Braf were found in oral squamous cell carcinoma in a Greek population.'},\n",
       " {'pubmed': 22314188,\n",
       "  'text': 'Colon adenocarcinomas with BRAF mutations have morphologic characteristics distinct from those with KRAS mutations and BRAF-mutated proximal colonic adenocarcinomas with proficient DNA mismatch repair have an aggressive clinical course.'},\n",
       " {'pubmed': 22317764,\n",
       "  'text': 'Data indicate that 266 (76.2%) tumors harbored EGFR mutations, 16 (4.6%) HER2 mutations, 15 (4.3%) EML4-ALK fusions, 7 (2.0%) KRAS mutations, and 2 (0.6%) BRAF mutations.'},\n",
       " {'pubmed': 22317887,\n",
       "  'text': 'Report of oncogenic BRAF/KRAS mutations in sporadic glomus tumors.'},\n",
       " {'pubmed': 22331186,\n",
       "  'text': 'BRAFmut as a useful marker in hairy cell leukemia.'},\n",
       " {'pubmed': 22331825,\n",
       "  'text': 'BRAF mutation is an independent prognostic biomarker for colorectal liver metastasectomy.'},\n",
       " {'pubmed': 22335197,\n",
       "  'text': 'BRAF V600E mutation-positive papillary thyroid carcinomas (PTCs) displayed infiltrative growth, stromal fibrosis, psammoma bodies, plump eosinophilic tumour cells, and classic fully developed nuclear features of PTC.'},\n",
       " {'pubmed': 22339435,\n",
       "  'text': 'Data suggest that the BRAF V600E mutation does not seem to play a role in myeloid malignant transformation.'},\n",
       " {'pubmed': 22358007,\n",
       "  'text': '(BRAF(V600E))detected in 141/170 malignant thyroid nodules (82.9%) (140 PTCs and one follicular variant of PTC). BRAF status not associated with US features with the exception of a negative relation between BRAF(V600E) and an irregular shape (p = 0.004).'},\n",
       " {'pubmed': 22361037,\n",
       "  'text': 'This is the first reported study of the relationship between CK20/CK7 immunophenotype, BRAF mutations and microsatellite status in colorectal carcinomas'},\n",
       " {'pubmed': 22367297,\n",
       "  'text': 'A distinct subset of atypical Spitz tumors is characterized by BRAF mutation and loss of BAP1 expression.'},\n",
       " {'pubmed': 22368298,\n",
       "  'text': \"review demonstrates that tumour BRAF V600E mutation, and MLH1 promoter 'C region' methylation specifically, are strong predictors of negative MMR mutation status[review]\"},\n",
       " {'pubmed': 22374786,\n",
       "  'text': 'The presence of activating GNAS mutations, in association with KRAS or BRAF mutations, is a characteristic genetic feature of colorectal villous adenoma.'},\n",
       " {'pubmed': 22376079,\n",
       "  'text': 'evidence presented that ERK activation occurs in a K-ras or B-raf -independent manner in the majority of primary colon cancer cases; B-raf mutations are not associated with mismatch-repair deficiency through loss of hMLH1 or hMSH2 expression'},\n",
       " {'pubmed': 22376167,\n",
       "  'text': 'The V600E BRAF mutation in papillary thyroid carcinomas may contribute to the initiation of the glycolytic phenotype and confers growth advantages in cancer'},\n",
       " {'pubmed': 22382362,\n",
       "  'text': 'Eleven patients displayed Durable Disease Control (DDC) of which 55% had BRAF-V600E mutation positive tumors and 45% did not.'},\n",
       " {'pubmed': 22393095,\n",
       "  'text': 'Patient diagnosed with colon cancer shows poor prognosis with BRAF genetic mutation.'},\n",
       " {'pubmed': 22395615,\n",
       "  'text': 'findings show (V600E)B-RAF copy-number gain as a mechanism of acquired B-RAF inhibitor resistance in 4 out of 20 patients treated with B-RAF inhibitor'},\n",
       " {'pubmed': 22398042,\n",
       "  'text': 'In a cohort of Indian patients with ulcerative colitis, with or without neoplasia, none showed the BRAF mutation.'},\n",
       " {'pubmed': 22417847,\n",
       "  'text': 'we have analyzed the prevalence of somatic mutations in the FGFR3, PIK3CA, AKT1, KRAS, HRAS, and BRAF genes in bladder cancers'},\n",
       " {'pubmed': 22426079,\n",
       "  'text': 'Data indicate that TaqMan(R) Mutation Detection assay is an important technology to consider in the field of mutation detection for KRAS, BRAF and EGFR point mutation screening.'},\n",
       " {'pubmed': 22426956,\n",
       "  'text': 'genetic association studies in population in Turkey: Data suggest that a mutation in BRAF (V600E; found in 39.45% of patients) is associated with aggressiveness of papillary thyroid neoplasms; lymph node metastasis increases when mutation is present.'},\n",
       " {'pubmed': 22427190,\n",
       "  'text': 'Investigation the prevalence of mutations in the BRAF gene and its correlation with demographic characteristics, tumor location and stage in 100 colorectal carcinoma patients from India.'},\n",
       " {'pubmed': 22429583,\n",
       "  'text': 'Article reviews the current understanding of BRAF gene, its structure, expression, and signal pathway in non-small cell lung cancer. [Review]'},\n",
       " {'pubmed': 22430133,\n",
       "  'text': 'The prevalence of EGFR, KRAS, BRAF and PIK3CA somatic mutations in 861 randomly selected Chinese patients with non-small cell lung cancer'},\n",
       " {'pubmed': 22430208,\n",
       "  'text': 'We propose that , and that persistent phosphorylation of Mps1 through BRAF(V600E) signaling is a key event in disrupting the control of centrosome duplication and chromosome stability that may contribute to tumorigenesis.'},\n",
       " {'pubmed': 22430215,\n",
       "  'text': 'expression of these oncogenes markedly stimulated ERK1/2 activities and morphologically transformed IECs. Importantly however'},\n",
       " {'pubmed': 22431777,\n",
       "  'text': 'Effective use of PDT in the treatment of BRAF inhibitor-associated KAs and SCCs.'},\n",
       " {'pubmed': 22431868,\n",
       "  'text': 'EFVPTC 1 patient BRAFV600E mutation, NVPTC 2 patients, FVPTC 2 patients.'},\n",
       " {'pubmed': 22435913,\n",
       "  'text': 'analysis of a patient with pancreatic metastasis arising from a BRAF(V600E)-positive papillary thyroid cancer [case report]'},\n",
       " {'pubmed': 22451557,\n",
       "  'text': 'The BRAF(V600E) mutation analysis from FNA specimens for calcified thyroid nodules may be performed for a greater negative predictive value and unveil the malignancy in 25% of indeterminate or nondiagnostic cytology.'},\n",
       " {'pubmed': 22456166,\n",
       "  'text': 'Report marked differences in the genetic pattern of the BRAF or NRAS mutated and wild-type melanoma subgroups.'},\n",
       " {'pubmed': 22459936,\n",
       "  'text': 'BRAF mutations play a limited role in the development of sinonasal cancer.'},\n",
       " {'pubmed': 22471241,\n",
       "  'text': 'Out of 1041 Korean patients with papillary thyroid carcinoma, 0.4% had rare types of BRAF mutation and three new somatic mutations were identified'},\n",
       " {'pubmed': 22471666,\n",
       "  'text': 'An update on malignancies displaying high frequencies of BRAF mutations and the mechanisms underlying the side effects and drug resistance phenomena associated with Raf inhibitors.'},\n",
       " {'pubmed': 22488961,\n",
       "  'text': 'prevalence of the BRAF(V600E) mutation increased with increased tumor size'},\n",
       " {'pubmed': 22492957, 'text': 'BRAF V600E is associated with gliomas.'},\n",
       " {'pubmed': 22498935,\n",
       "  'text': 'No BRAF V600E mutations were indentified in this study of patients with endometrial cancer.'},\n",
       " {'pubmed': 22500044,\n",
       "  'text': 'Highly sensitive and specific molecular assays such as MEMO sequencing are optimal for detecting the BRAF mutations in thyroid FNAC because these techniques can detect PTC that might be missed by cytology or less sensitive molecular assays.'},\n",
       " {'pubmed': 22506009,\n",
       "  'text': 'The (600DLAT)B-RAF and (V600E)B-RAF mutations were found enriched in DNA and mRNA from the CD1a+ fraction of granuloma.'},\n",
       " {'pubmed': 22508706,\n",
       "  'text': 'The analysis of BRAF mutations by pyrosequencing is useful to refine the risk stratification of patients with papillary thyroid carcinoma.'},\n",
       " {'pubmed': 22510757,\n",
       "  'text': 'Patients with serrated polyposis syndrome referred to genetics clinics had a pan-colonic disease with a high polyp burden and a high rate of BRAF mutation.'},\n",
       " {'pubmed': 22510884,\n",
       "  'text': 'It was shown that the dimer interface within the kinase domain plays a pivotal role for the activity of B-Raf and several of its gain-of-function mutants.'},\n",
       " {'pubmed': 22514085,\n",
       "  'text': 'The tumor with T1799A BRAF mutation and tumor sizes of 2 cm or more were clinicopathologic parameters associated with lower STAT1 activity.'},\n",
       " {'pubmed': 22515292,\n",
       "  'text': 'BRAF V600E is common in patients with low-risk papillary thyroid carcinoma but does not predict recurrence.'},\n",
       " {'pubmed': 22515520,\n",
       "  'text': 'Mutation BRAF transforms cells through cross talk with developmental pathways Hedgehog and Wnt, as well as by deregulation of colorectal cancer related kinase pathways.'},\n",
       " {'pubmed': 22516966,\n",
       "  'text': 'Report upregulation of Bim and the splicing factor SRp55 in melanoma cells from patients treated with selective BRAF inhibitors.'},\n",
       " {'pubmed': 22522845,\n",
       "  'text': 'In signet ring cell carcinoma, BRAF V600E mutation adversely affects survival in microsatellite-stable tumors, but not in high-level microsatellite-unstable tumor'},\n",
       " {'pubmed': 22531127,\n",
       "  'text': 'study concludes that generally, overweight increases the risk of colorectal cancer; taller individuals have an increased risk of developing a tumour with a BRAF mutation or microsatellite instability'},\n",
       " {'pubmed': 22531170,\n",
       "  'text': 'Demonstrate that BRAF V600E mutation-specific antibody can be used in immunohistochemical diagnosis of hairy cell leukemia.'},\n",
       " {'pubmed': 22534474,\n",
       "  'text': 'BRAF and KIT mutations have been found in Japanese melanoma patients.'},\n",
       " {'pubmed': 22535154,\n",
       "  'text': 'study shows there are clinically and biologically distinct subtypes of BRAF-mutant metastatic melanoma, defined by genotype, with distinct etiology and behavior; cumulative sun-induced damage in primary cutaneous melanoma and older age are associated with V600K BRAF mutations;it establishes prevalence of the BRAF mutation by age-decade'},\n",
       " {'pubmed': 22535974,\n",
       "  'text': 'The diagnostic sensitivity for thyroid cancer is significantly increased by BRAF V600E mutation analysis, indicating that the screening for BRAF mutation in FNAB samples has a relevant diagnostic potential.'},\n",
       " {'pubmed': 22549559,\n",
       "  'text': 'Recurrent/persistent PTC in the central compartment typically harbors the BRAF mutation'},\n",
       " {'pubmed': 22549727,\n",
       "  'text': 'abrogation of BRAFV600E-induced senescence contributes to melanomagenesis.'},\n",
       " {'pubmed': 22549934,\n",
       "  'text': 'The mTOR pathway could be a good target to enhance therapy effects in certain types of thyroid carcinoma, namely in those harboring the BRAF(V600E) mutation.'},\n",
       " {'pubmed': 22568401,\n",
       "  'text': 'These results suggest that low-grade diffuse gliomas with 1p/19q loss have frequent BRAF gains'},\n",
       " {'pubmed': 22579930,\n",
       "  'text': 'KRAS, BRAF, and PIK3CA mutations in colorectal cancer have sustained prevalence rate in the Taiwanese population.'},\n",
       " {'pubmed': 22581800,\n",
       "  'text': 'BRAF regulates expression of long noncoding RNAs in melanocytes and melanoma cells'},\n",
       " {'pubmed': 22586484,\n",
       "  'text': 'In the present study, we did not find any significant correlations between KRAS, BRAF and PIK3CA mutations and the loss of PTEN expression and various clinicopathological features in Chinese patients with colorectal cancer.'},\n",
       " {'pubmed': 22591444,\n",
       "  'text': 'Our results suggest that in a small fraction of diffuse gliomas, KIAA1549-BRAF fusion gene and BRAF(v600E) mutation may be responsible for deregulation of the Ras-RAF-ERK signaling pathway'},\n",
       " {'pubmed': 22592144,\n",
       "  'text': 'Immunohistochemical detection of the mutated V600E BRAF protein in papillary thyroid carcinoma may facilitate mutational analysis in the clinical setting.'},\n",
       " {'pubmed': 22614711,\n",
       "  'text': 'BRAF p.Val600Lys mutations were present at a relatively high frequency in the cohort of metastatic melanoma patients (27/183, 15%)'},\n",
       " {'pubmed': 22614978,\n",
       "  'text': 'BRAF/NRAS mutations were identified in 58% of primary melanomas (43% BRAF; 15% NRAS)'},\n",
       " {'pubmed': 22628551,\n",
       "  'text': 'Data show that RNF149 (RING finger protein 149) interacts with wild-type BRAF.'},\n",
       " {'pubmed': 22639828,\n",
       "  'text': 'Data suggest that BRAF V600E mutation may not be widespread in hematologic malignancies, excluding hairy-cell leukemia (HCL).'},\n",
       " {'pubmed': 22649091,\n",
       "  'text': \"Patient's BRAF mutation was likely responsible for his tumor's marked response to dasatinib, suggesting that tumors bearing kinase-impaired BRAF mutations may be exquisitely sensitive to dasatinib.\"},\n",
       " {'pubmed': 22681706,\n",
       "  'text': 'BRAFV600E mutation is associated with lymph node metastasis in multiple papillary thyroid carcinoma.'},\n",
       " {'pubmed': 22684223,\n",
       "  'text': 'The presence of BRAF mutations in these adenomatous precursors to colon cancer suggests that they represent sessile serrated adenomas with complete cytologic dysplasia.'},\n",
       " {'pubmed': 22694820,\n",
       "  'text': 'In papillary thyroid cancer, significant correlations between the methylation status of four genes (TIMP3, RASSF1A, RARbeta2 and DCC) and the V600E BRAF mutation were found.'},\n",
       " {'pubmed': 22699145,\n",
       "  'text': 'Data indicate that 14% with pancreatic ductal adenocarcinomas (PDACs) and 7% ampullary adenocarcinomas (A-ACs) had mutations in both KRAS and BRAF.'},\n",
       " {'pubmed': 22702340,\n",
       "  'text': 'In papillary thyroid carcinoma BRAFV600E is associated with increased expression of the urokinase plasminogen activator and its cognate receptor, but not with disease-free interval.'},\n",
       " {'pubmed': 22705994,\n",
       "  'text': 'Hairy cell leukemia cell lines expressing annexin A1 and displaying B-cell receptor signals characteristic of primary tumor cells lack the signature BRAF mutation to reveal unrepresentative origins.'},\n",
       " {'pubmed': 22706026,\n",
       "  'text': 'The combined effects of EGFR downregulation, ligand competition, and immune effector function conspire to inhibit tumor growth in xenograft models of cetuximab-resistant BRAF and KRAS mutant cancers.'},\n",
       " {'pubmed': 22727996,\n",
       "  'text': 'BRAF V600E mutations are present in approximately 90% of all kidney metanephric adenoma cases, serving as a potential valuable diagnostic tool in the differential diagnosis.'},\n",
       " {'pubmed': 22730329,\n",
       "  'text': 'Reactivation of mitogen-activated protein kinase (MAPK) pathway by FGF receptor 3 (FGFR3)/Ras mediates resistance to vemurafenib in human B-RAF V600E mutant melanoma.'},\n",
       " {'pubmed': 22732794,\n",
       "  'text': 'BRAF V600E mutation revealed a strong association with specific histological variants of papillary thyroid carcinoma.'},\n",
       " {'pubmed': 22740704,\n",
       "  'text': 'These results clearly prove that the BRAFV600E mutation is not associated with the development of distant metastases or fatal outcome in papillary thyroid carcinoma'},\n",
       " {'pubmed': 22742884,\n",
       "  'text': 'Vemurafenib is effective for advanced melanomas expressing the BRAF V600E mutations [review]'},\n",
       " {'pubmed': 22743296,\n",
       "  'text': 'BRAF V600E mutation is associated with response to vemurafenib in lung adenocarcinoma.'},\n",
       " {'pubmed': 22751131,\n",
       "  'text': 'B-Raf/MKK/ERK controls key aspects of cancer cell behavior and gene expression by modulating a network of miRNAs with cross-regulatory functions.'},\n",
       " {'pubmed': 22752848,\n",
       "  'text': 'study reports a novel complex BRAF mutation identified in 4/492 Japanese papillary thyroid carcinoma(PTC) cases; findings suggest the BRAF(V600delinsYM)mutation, is a gain-of-function mutation and plays an important role in PTC development'},\n",
       " {'pubmed': 22767446,\n",
       "  'text': 'study found a relatively higher B-Raf serine/threonine-protein kinase (BRAF)(V600E) mutation rate in classical type papillary thyroid carcinomas than in other similar studies'},\n",
       " {'pubmed': 22770943,\n",
       "  'text': 'BRAF mRNA expression may help to identify PTC among thyroid nodules independently of the presence of BRAFV600E mutation.'},\n",
       " {'pubmed': 22772867,\n",
       "  'text': 'BRAF (V600) mutations are are associated with melanomas.'},\n",
       " {'pubmed': 22773810,\n",
       "  'text': 'Lung cancers with acquired resistance to EGFR inhibitors occasionally harbor BRAF gene mutations but lack mutations in KRAS, NRAS, or MEK1.'},\n",
       " {'pubmed': 22797077,\n",
       "  'text': 'RSK regulates activated BRAF signalling to mTORC1 and promotes melanoma growth'},\n",
       " {'pubmed': 22798288,\n",
       "  'text': 'Data show clinical significance to BRAF(L597) mutations in melanoma.'},\n",
       " {'pubmed': 22798500,\n",
       "  'text': 'In CRC patients treated with cetuximab, activating mutation signatures for BRAF (58 genes) were developed.'},\n",
       " {'pubmed': 22799316,\n",
       "  'text': 'Preoperative BRAF mutation was a predictive factor for occult contralateral papillary thyroid microcarcinoma presence.'},\n",
       " {'pubmed': 22809251,\n",
       "  'text': 'As has been reported in other common types of melanoma, V600 BRAF mutation is the most common mutation of those tested in spindle cell melanoma. NRAS or KIT mutation appears to be rare, if not completely absent.'},\n",
       " {'pubmed': 22814862,\n",
       "  'text': 'we found no cases of Rosette-forming glioneuronal tumors of the fourth ventricle showing KIAA1549-BRAF gene fusion or BRAF (V600E) mutation'},\n",
       " {'pubmed': 22820187,\n",
       "  'text': 'these results link epigenetic genes to methylation and suppression of tumor suppressor genes as a mechanism involved in BRAFV600E-promoted melanoma tumorigenesis and uncover a novel molecular signature that predicts a poor prognosis of melanoma.'},\n",
       " {'pubmed': 22820660,\n",
       "  'text': 'No BRAF V600E mutations were detected in nonserous epithelial ovarian tumors.'},\n",
       " {'pubmed': 22824468,\n",
       "  'text': 'Single Nucleotide Polymorphisms in BRAF gene is associated with diseases.'},\n",
       " {'pubmed': 22826122,\n",
       "  'text': 'It was concluded that extracellular kinase-mediated up-regulation of c-myc by K-Ras or B-Raf oncogenes disrupts the establishment of apical/basolateral polarity in colon epithelial cells independently of its effect on proliferation.'},\n",
       " {'pubmed': 22826437,\n",
       "  'text': 'RAF1(D486N), as well as other kinase-impaired RAF1 mutants, showed increased heterodimerization with BRAF, which was necessary and sufficient to promote increased MEK/ERK activation.'},\n",
       " {'pubmed': 22833462,\n",
       "  'text': 'Investigated BRAF and RAF1 alterations in Chinese prostate cancer.Found BRAF truncated in five of 200 informative Chinese cases & RAF1 was truncated in three of 204 informative cases and genomic rearrangements were correlated w/high Gleason scores.'},\n",
       " {'pubmed': 22850568,\n",
       "  'text': 'This study reveals a novel mechanism of immune suppression sensitive to BRAF(V600E) inhibition, and indicates that clinical blockade of IL-1 may benefit patients'},\n",
       " {'pubmed': 22858857,\n",
       "  'text': 'A review summarizes the role of the BRAF V600E mutation in the development and progression of thyroid cancer.'},\n",
       " {'pubmed': 22859608,\n",
       "  'text': 'BRAFV600E mutation is associated with Langerhans cell histiocytosis.'},\n",
       " {'pubmed': 22863493,\n",
       "  'text': 'The BRAFV600E occurs exclusively in papillary thyroid carcinoma and papillary carcinoma-derived anaplastic cancer, rising as a specific diagnostic marker for this tumor when identified in cytological / histological exams'},\n",
       " {'pubmed': 22870241,\n",
       "  'text': 'High-throughput genotyping in metastatic esophageal squamous cell carcinoma identifies phosphoinositide-3-kinase and BRAF mutations.'},\n",
       " {'pubmed': 22876591,\n",
       "  'text': 'Cardio-facio-cutaneous syndrome is caused by heterogeneous mutations in BRAF gene.'},\n",
       " {'pubmed': 22879539,\n",
       "  'text': 'High prevalence of BRAF V600E mutations is associated with Erdheim-Chester disease but not in other non-Langerhans cell histiocytoses.'},\n",
       " {'pubmed': 22880048,\n",
       "  'text': 'This study reveals a novel molecular mechanism underlying the regulation of feedback loops between the MAPK and AKT pathways.'},\n",
       " {'pubmed': 22887810,\n",
       "  'text': 'A K601E BRAF mutation is associated with papillary thyroid carcinoma.'},\n",
       " {'pubmed': 22892521,\n",
       "  'text': 'The results of this study supported an important role for BRAF duplication and MAPK pathway activation in gliomas of the optic nerve proper.'},\n",
       " {'pubmed': 22898351,\n",
       "  'text': 'MSI status, KRAS and BRAF mutation rates varied remarkably among the colonic carcinoma subsites irrespective of right- and left-sided origin.'},\n",
       " {'pubmed': 22899730,\n",
       "  'text': 'The presence of a BRAF c.1799T>A (p.V600E) mutation is associated with significantly poorer prognosis after colorectal cancer diagnosis among subgroups of patients.'},\n",
       " {'pubmed': 22912864,\n",
       "  'text': 'Data indicate that mutation frequency in malanoma patients was found witih BRAF(V600) in 51%, NRAS in 19%, PI3K pathway in 41% and PTEN in 22%.'},\n",
       " {'pubmed': 22918165,\n",
       "  'text': 'BRAF(V600E) mutation is an early event in thyroid carcinogenesis, and is associated with distinctive morphology and aggressive features even in papillary thyroid microcarcinomas'},\n",
       " {'pubmed': 22926515,\n",
       "  'text': 'ARAF seems to stabilize BRAF:CRAF complexes in cells treated with RAF inhibitors and thereby regulate cell signaling in a subtle manner to ensure signaling efficiency'},\n",
       " {'pubmed': 22930283,\n",
       "  'text': 'BRAF mutation is associated with early stage disease and improved outcome in patients with low-grade serous ovarian cancer.'},\n",
       " {'pubmed': 22931913,\n",
       "  'text': 'We conclude that the presence of BRAF mutation, NRAS mutation, and the absence of an immune-related expressed gene profile predict poor outcome in melanoma patients with macroscopic stage III disease.'},\n",
       " {'pubmed': 22932786,\n",
       "  'text': 'Thus, in this meta-analysis, the BRAF mutation in PTC was significantly associated with PTC recurrence, lymph node metastasis, extrathyroidal extension, and advanced stage AJCC III/IV.'},\n",
       " {'pubmed': 22938585,\n",
       "  'text': 'Data indicate that KRAS, BRAF, PIK3CA, and AKT1 mutations can be rapidly and accurately detected for cancer diagnosis.'},\n",
       " {'pubmed': 22941165,\n",
       "  'text': 'The BRAF V600E mutation is the only independent predictor of compartment lymph node metastasis in papillary thyroid carcinoma.'},\n",
       " {'pubmed': 22946697,\n",
       "  'text': 'Data indicate that of the 32 cardio-facio-cutaneous syndrome (CFC) patients, 28 (88%) had a known mutation in a gene that is causative for CFC, including BRAF (n = 21), MEK1 (n = 2), MEK2 (n = 4), and KRAS (n = 1).'},\n",
       " {'pubmed': 22972589,\n",
       "  'text': 'Higher response rates and longer time to progression were observed with selumetinib-containing regimens in patients who had melanoma that harbored a BRAF mutation.'},\n",
       " {'pubmed': 22973979,\n",
       "  'text': 'found a significantly increased risk of papillary thyroid carcinoma attributed to the SNP variants rs17161747, rs1042179, and rs3748093 for those with a family history of cancer, for smokers, and for both those of age <45 years and nondrinkers'},\n",
       " {'pubmed': 22996177,\n",
       "  'text': 'This report is the first to identify the rare, variant BRAF V600D mutation in LCH, and provides support for constitutively activated BRAF oncogene-induced cell senescence as a mechanism of regression in congenital, benign LCH.'},\n",
       " {'pubmed': 23009221,\n",
       "  'text': 'consistent with previous studies, it was concluded that the incidence of BRAF V600E mutation in adult acute lymphoblastic leukemia, if any, is extremely infrequent'},\n",
       " {'pubmed': 23010278,\n",
       "  'text': 'B-RAF upregulates SGLT1 activity, an effect requiring vesicle insertion into the cell membrane.'},\n",
       " {'pubmed': 23010994,\n",
       "  'text': 'BRAF mutation is suggested to be poor prognostic factors in CRLM.'},\n",
       " {'pubmed': 23014346,\n",
       "  'text': 'Braf mutation status is not significantly associated with poor survival for melanoma in Koreans.'},\n",
       " {'pubmed': 23021375,\n",
       "  'text': 'EGFR and downstream genetic alterations in KRAS/BRAF and PI3K/AKT pathways have roles in colorectal cancer and treatment [review]'},\n",
       " {'pubmed': 23026937,\n",
       "  'text': 'Immunohistochemistry is highly sensitive and specific for the detection of V600E BRAF mutation in melanoma.'},\n",
       " {'pubmed': 23033302,\n",
       "  'text': 'the spectrum and frequency distribution of the identified KRAS and BRAF mutations in Serbian patient with colorectal cancer are in good accordance with literature data.'},\n",
       " {'pubmed': 23036672,\n",
       "  'text': 'We describe 3 patients with BRAF V600E mutation metastatic melanoma in whom treatment with vemurafenib resulted in prompt extracranial disease response but progression of metastatic disease in the brain.'},\n",
       " {'pubmed': 23039341,\n",
       "  'text': 'Studied the cytotoxicity and anti-tumour activity of novel MEK inhibitor, E6201, in a panel of melanoma cell lines. Most melanoma cell lines were sensitive or hypersensitive to E6201; the sensitivity correlated with wildtype PTEN and mutant BRAF status.'},\n",
       " {'pubmed': 23041829,\n",
       "  'text': 'Findings support the potential use of immunohistochemistry as an ancillary screening tool to assess the BRAFV600E mutation status in primary cutaneous melanoma.'},\n",
       " {'pubmed': 23051629,\n",
       "  'text': 'Increased BRAF mutation with age along with the lack of a UVR magnitude-BRAF mutation association suggests that duration of exposure rather than UVR exposure dose is the more likely link to acquiring mutations in melanocytic nevi.'},\n",
       " {'pubmed': 23055340,\n",
       "  'text': 'KRAS and BRAF mutations are infrequent or absent, respectively in Intestinal-type sinonasal adenocarcinoma'},\n",
       " {'pubmed': 23055546,\n",
       "  'text': 'BRAF mutation was associated with lymph node metastases (LNM), advanced stage, extrathyroidal extension, tumor size, male gender, multifocality, absence of capsule, classic PTC, and tall-cell variant papillary thyroid cancer.'},\n",
       " {'pubmed': 23056577,\n",
       "  'text': 'A systematic review and meta-analysis revealed that BRAF mutation is an absolute risk factor for patient survival in colorectal cancer and melanoma.'},\n",
       " {'pubmed': 23062653,\n",
       "  'text': 'BRAF mutation was not found to be significantly associated with lymph node metastasis in patients with papillary thyroid cancer'},\n",
       " {'pubmed': 23066120,\n",
       "  'text': 'The BRAF(V600E) mutation was demonstrated to be a poor prognostic factor for the persistence of the disease independent from other clinical-pathological features in low-risk intrathyroid papillary thyroid carcinoma patients.'},\n",
       " {'pubmed': 23069257,\n",
       "  'text': 'Histopathologic changes suggesting prolapsed rectal mucosa should take precedence over BRAF results in diagnosing sessile serrated adenomas in the rectum.'},\n",
       " {'pubmed': 23088640,\n",
       "  'text': 'analysis suggests that BRAF mutations occur at a low frequency in chronic lymphocytic leukemia'},\n",
       " {'pubmed': 23095503,\n",
       "  'text': 'Desmoplastic malignant melanoma: a study of ten cases and status of BRAF mutation.'},\n",
       " {'pubmed': 23096133,\n",
       "  'text': 'BRAF mutation is associated with pleomorphic xanthoastrocytomas with anaplastic features.'},\n",
       " {'pubmed': 23096702,\n",
       "  'text': 'We found that NRAS-mutant melanomas were significantly more likely from older patients and BRAF-mutant melanomas were more frequent in melanomas from the trunk.'},\n",
       " {'pubmed': 23098991,\n",
       "  'text': 'Studied differential miRNA expression in metastatic colorectal cancer by microarrays from primary tumors of 33 patients who had wild-type KRAS/BRAF and third- to sixth-line anti-EGFRmAb treatment, with/without irinotecan.'},\n",
       " {'pubmed': 23110075,\n",
       "  'text': 'Study demonstrates that chromosomal instability commonly occurs in advanced BRAF mutant/MSS colorectal cancers where it may contribute to poorer survival, and further highlights molecular similarities occurring between these and BRAF wild type cancers.'},\n",
       " {'pubmed': 23125007,\n",
       "  'text': 'One hundred and ten patients (51%) were identified who were potentially nonresponders to anti-EGFR therapy:  13/117 (11.1%) had the V600E BRAF mutation.'},\n",
       " {'pubmed': 23132792,\n",
       "  'text': 'BRAFV600E mutation is associated with cervical lymph node metastasis and recurrence in papillary thyroid cancer.'},\n",
       " {'pubmed': 23138171,\n",
       "  'text': 'Clinical characteristics of colorectal cancer with the V600E BRAF mutation.'},\n",
       " {'pubmed': 23153455,\n",
       "  'text': 'These findings indicate that ABCG2 confers resistance to vemurafenib in A375 cells, suggesting involvement of this transporter in acquired resistance to vemurafenib.'},\n",
       " {'pubmed': 23157614,\n",
       "  'text': 'Data indicate that the presence of the BRAF V600E mutation was more frequent in women, but this gender difference was not statistically significant.'},\n",
       " {'pubmed': 23157823,\n",
       "  'text': 'In Chinese colorectal carcinoma patients, BRAF mutation is associated with tumor differentiation and primary tumor sites.'},\n",
       " {'pubmed': 23157824,\n",
       "  'text': 'Codon 12, 13 in KRAS gene and codon 600 in BRAF gene are the most common mutation points in Chinese colorectal cancer. KRAS and BRAF mutations are mutually exclusive. KRAS and BRAF gene mutation is higher in females than that in males.'},\n",
       " {'pubmed': 23158172,\n",
       "  'text': 'BRAF mutational status is predictive of papillary thyroid carcinoma recurrence'},\n",
       " {'pubmed': 23159116,\n",
       "  'text': 'V600E point mutation was identified in the BRAF gene in 3 intramucosal nevi and in 2 melanomas. Only 1 blue nevus harbored the GNAQ209 mutation'},\n",
       " {'pubmed': 23161556,\n",
       "  'text': 'BRAF mutation as a new serum marker for papillary thyroid carcinomas were not detectable in patientts diagnosed with thyroid neoplasms.'},\n",
       " {'pubmed': 23161722,\n",
       "  'text': 'data confirm that among lymphoproliferative disorders, BRAF V600E mutation is restricted to hairy cell leukemia (HCL); no mutations were identified in variant HCL, NMZL, ENMZL, PTLD, PTCL, ALCL, or LGL proliferations'},\n",
       " {'pubmed': 23163107,\n",
       "  'text': 'The BRAF(V600E) mutation might be associated with a more aggressive phenotype and a poor prognosis in classic variant of papillary thyroid carcinomas.'},\n",
       " {'pubmed': 23179992,\n",
       "  'text': 'BRAF (V600E) mutation is associated with papillary thyroid carcinomas.'},\n",
       " {'pubmed': 23188063,\n",
       "  'text': 'BRAF mutations were correlated with poor overall survival in the full patient cohort'},\n",
       " {'pubmed': 23190154,\n",
       "  'text': 'Our findings suggest that RAS pathway activation due to BRAF V600E and KRAS mutations is an important event in a subset of peripheral nerve sheath tumours not related to neurofibromatosis'},\n",
       " {'pubmed': 23190890,\n",
       "  'text': 'Oncogenic B-RAF(V600E) signaling induces the T-Box3 transcriptional repressor to repress E-cadherin and enhance melanoma cell invasion.'},\n",
       " {'pubmed': 23192464,\n",
       "  'text': 'Aim of this work is to provide a detailed comparison of clinical-pathologic features between well-differentiated and poorly differentiated tumors according to their BRAF and RASSF1A status.'},\n",
       " {'pubmed': 23192956,\n",
       "  'text': 'BRAF (V600E) mutation is associated with papillary thyroid microcarcinoma.'},\n",
       " {'pubmed': 23203004,\n",
       "  'text': 'BRAF (V600E) is non-associated with Gal-3 expression, whereas it is associated with cytoplasmatic localization of p27kip1 and higher CK19 expression in papillary thyroid carcinoma.'},\n",
       " {'pubmed': 23207070,\n",
       "  'text': 'The present study revealed that ESCC of Brazilian patients do not present mutations in hot spots of EGFR, K-RAS and BRAF and only a minor proportion present overexpression of EGFR or HER2.'},\n",
       " {'pubmed': 23208503,\n",
       "  'text': 'results suggest that mutant B-RAF signaling downregulates Tiam1/Rac activity resulting in an increase in N-cadherin levels and a decrease in E-cadherin levels and ultimately enhanced invasion'},\n",
       " {'pubmed': 23224067,\n",
       "  'text': 'Mutations affecting BRAF, EGFR, PIK3CA, and KRAS are not associated with sporadic vestibular schwannomas.'},\n",
       " {'pubmed': 23235345,\n",
       "  'text': 'the BRAF V600E mutation is not pathobiologically relevant in primary central nervous system lymphoma'},\n",
       " {'pubmed': 23237741,\n",
       "  'text': 'Patients with V600R BRAF mutations can be treated successfully with oral BRAF inhibitors.'},\n",
       " {'pubmed': 23242808,\n",
       "  'text': 'Data indicate that BRAF and EGF receptor or SRC family kinase inhibition blocked proliferation and invasion of the resistant tumors.'},\n",
       " {'pubmed': 23246082,\n",
       "  'text': 'the role of BRAF mutations in melanoma and colorectal cancer, focusing on similarities and differences of BRAF mutations (Review)'},\n",
       " {'pubmed': 23253715,\n",
       "  'text': 'The status of BRAF(V600E) mutation was more frequent in multifocal PTC patients with lymph node metastasis and diagnosis at later age.'},\n",
       " {'pubmed': 23263826,\n",
       "  'text': 'we deduce that in the absence of mutation activation, B-Raf overexpression or downregulation is a protective event, since it delays the development of both malignant and benign thyroid tumors.'},\n",
       " {'pubmed': 23274581,\n",
       "  'text': 'BRAF mutation is associated with esophageal squamous cell carcinoma.'},\n",
       " {'pubmed': 23280049,\n",
       "  'text': 'Preoperative mutation screening for BRAF(V600E) does not meaningfully improve risk stratification and is unlikely to alter the initial management of patients with indeterminate nodules.'},\n",
       " {'pubmed': 23287985,\n",
       "  'text': 'Pulmonary Langerhans cell histiocytosis appears to be a clonal proliferation that may or may not have BRAF V600E mutations.'},\n",
       " {'pubmed': 23290787,\n",
       "  'text': 'Studies indicate that BRAF mutations are identified in 40-50% of patients with melanoma, and treatment with either of two BRAF inhibitors (vemurafenib, dabrafenib) or the MEK inhibitor trametinib is associated with improved clinical benefit.'},\n",
       " {'pubmed': 23297805,\n",
       "  'text': 'No point mutations were identified in BRAF codon Val600Glu in the studied colorectal adenocarcinomas in the Turkish population.'},\n",
       " {'pubmed': 23307859,\n",
       "  'text': 'High BRAF is associated with metastatic melanoma.'},\n",
       " {'pubmed': 23310942,\n",
       "  'text': 'This study shows that BRAF mutation occurs in Nigerian colorectal cancers.'},\n",
       " {'pubmed': 23317446,\n",
       "  'text': 'Results demonstrated the action of Dabrafenib and the inhibition of MAPK pathway in melanoma cell lines carrying BRAFV600D/R mutations; these results could be helpful to enlarge the number of patients who may benefit of a more effective targeted treatment'},\n",
       " {'pubmed': 23324583,\n",
       "  'text': 'BRAF mutations is associated with colorectal cancer.'},\n",
       " {'pubmed': 23334329,\n",
       "  'text': 'Human neural crest progenitor cells are susceptible to BRAF(V600E)-induced transformation.'},\n",
       " {'pubmed': 23343956,\n",
       "  'text': 'no association with BRAF-V600E mutation in gastroeosophageal tumors'},\n",
       " {'pubmed': 23349307,\n",
       "  'text': 'Data indicate that besides confirming the constant presence of BRAF-V600E in all patients with hairy cell leukemia, phospho-ERK1/ERK2 expression was observed.'},\n",
       " {'pubmed': 23352452,\n",
       "  'text': 'Ras pathway activation via EGF treatment induced strong binding between B-Raf and C-Raf and a low level of binding between B-Raf and A-Raf.'},\n",
       " {'pubmed': 23354951,\n",
       "  'text': 'Alternative splicing of exons 14, 15, 15b, 16b and 16c occurs in a considerable fraction of BRAF mRNA in normal colon and colorectal cancer cells and is independent of the V600E mutational status of the parental allele.'},\n",
       " {'pubmed': 23355004,\n",
       "  'text': 'The detected Merkel cell polyomavirus prevalence in non-small cell lung cancer in combination with the deregulated expression of BRAF and Bcl-2 genes suggests that these events are likely to contribute to the pathogenesis of non-small cell lung cancer.'},\n",
       " {'pubmed': 23359496,\n",
       "  'text': 'Kidins220 is a novel T-cell receptor (TCR)-interacting protein that couples B-Raf to the TCR. Kidins220 is mandatory for sustained Erk signaling and is crucial for TCR-mediated T cell activation.'},\n",
       " {'pubmed': 23370429,\n",
       "  'text': 'This is the first report of BRAF V600E mutation in endometrial cancer, indicating that it may contribute to tumorigenesis of endometrial cancer, although at a low frequency compared with KRAS mutations.'},\n",
       " {'pubmed': 23370668,\n",
       "  'text': 'study suggests that highly aggressive papillary thyroid microcarcinoma may arise in a subset of patients with BRAF(V600E) mutation and tumors greater than 5 mm; multivariate analysis showed that tumor recurrence was not associated with BRAF(V600E)mutation'},\n",
       " ...]"
      ]
     },
     "execution_count": 33,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "braf_info['generif']"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 34,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/plain": [
       "2000"
      ]
     },
     "execution_count": 34,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "len(braf_info['generif'])"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 35,
   "metadata": {},
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "https://www.ncbi.nlm.nih.gov/pubmed/12068308\n"
     ]
    }
   ],
   "source": [
    "print('https://www.ncbi.nlm.nih.gov/pubmed/12068308')"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 36,
   "metadata": {},
   "outputs": [],
   "source": [
    "def gene_search(name):\n",
    "    query = {'q': name}\n",
    "    response = requests.get('http://mygene.info/v3/query',params=query )\n",
    "    entrez_id = response.json()['hits'][0]['_id']\n",
    "    gene_response = requests.get('http://mygene.info/v3/gene/' + entrez_id)\n",
    "    return gene_response.json()\n"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 37,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/plain": [
       "{'HGNC': '1771',\n",
       " 'MIM': '116953',\n",
       " 'Vega': 'OTTHUMG00000170575',\n",
       " '_id': '1017',\n",
       " '_score': 13.168399,\n",
       " 'accession': {'genomic': ['AC025162.48',\n",
       "   'AC034102.32',\n",
       "   'AF512553.1',\n",
       "   'AJ223951.1',\n",
       "   'CH471054.1',\n",
       "   'KT584459.1',\n",
       "   'NC_000012.12',\n",
       "   'NG_034014.1',\n",
       "   'U50730.2'],\n",
       "  'protein': ['AAA35667.1',\n",
       "   'AAH03065.1',\n",
       "   'AAM34794.1',\n",
       "   'AAP35467.1',\n",
       "   'BAA32794.1',\n",
       "   'BAF84630.1',\n",
       "   'BAG56780.1',\n",
       "   'CAA43807.1',\n",
       "   'CAA43985.1',\n",
       "   'EAW96856.1',\n",
       "   'EAW96857.1',\n",
       "   'EAW96858.1',\n",
       "   'EAW96859.1',\n",
       "   'EAW96860.1',\n",
       "   'NP_001277159.1',\n",
       "   'NP_001789.2',\n",
       "   'NP_439892.2',\n",
       "   'P24941.2',\n",
       "   'XP_011536034.1'],\n",
       "  'rna': ['AA789250.1',\n",
       "   'AA810989.1',\n",
       "   'AB012305.1',\n",
       "   'AK291941.1',\n",
       "   'AK293246.1',\n",
       "   'BC003065.2',\n",
       "   'BJ991087.1',\n",
       "   'BT006821.1',\n",
       "   'DA814453.1',\n",
       "   'M68520.1',\n",
       "   'NM_001290230.1',\n",
       "   'NM_001798.4',\n",
       "   'NM_052827.3',\n",
       "   'X61622.1',\n",
       "   'X62071.1',\n",
       "   'XM_011537732.2'],\n",
       "  'translation': [{'protein': 'BAA32794.1', 'rna': 'AB012305.1'},\n",
       "   {'protein': 'BAF84630.1', 'rna': 'AK291941.1'},\n",
       "   {'protein': 'BAG56780.1', 'rna': 'AK293246.1'},\n",
       "   {'protein': 'AAA35667.1', 'rna': 'M68520.1'},\n",
       "   {'protein': 'AAP35467.1', 'rna': 'BT006821.1'},\n",
       "   {'protein': 'CAA43985.1', 'rna': 'X62071.1'},\n",
       "   {'protein': 'AAH03065.1', 'rna': 'BC003065.2'},\n",
       "   {'protein': 'XP_011536034.1', 'rna': 'XM_011537732.2'},\n",
       "   {'protein': 'NP_001277159.1', 'rna': 'NM_001290230.1'},\n",
       "   {'protein': 'NP_001789.2', 'rna': 'NM_001798.4'},\n",
       "   {'protein': 'CAA43807.1', 'rna': 'X61622.1'},\n",
       "   {'protein': 'NP_439892.2', 'rna': 'NM_052827.3'}]},\n",
       " 'alias': ['CDKN2', 'p33(CDK2)'],\n",
       " 'ec': '2.7.11.22',\n",
       " 'ensembl': {'gene': 'ENSG00000123374',\n",
       "  'protein': ['ENSP00000243067',\n",
       "   'ENSP00000266970',\n",
       "   'ENSP00000393605',\n",
       "   'ENSP00000450983',\n",
       "   'ENSP00000452138',\n",
       "   'ENSP00000452514'],\n",
       "  'transcript': ['ENST00000266970',\n",
       "   'ENST00000354056',\n",
       "   'ENST00000440311',\n",
       "   'ENST00000553376',\n",
       "   'ENST00000554545',\n",
       "   'ENST00000554619',\n",
       "   'ENST00000555357',\n",
       "   'ENST00000555408',\n",
       "   'ENST00000556146',\n",
       "   'ENST00000556276',\n",
       "   'ENST00000556464',\n",
       "   'ENST00000556656'],\n",
       "  'translation': [{'protein': 'ENSP00000266970', 'rna': 'ENST00000266970'},\n",
       "   {'protein': 'ENSP00000450983', 'rna': 'ENST00000555408'},\n",
       "   {'protein': 'ENSP00000452514', 'rna': 'ENST00000553376'},\n",
       "   {'protein': 'ENSP00000393605', 'rna': 'ENST00000440311'},\n",
       "   {'protein': 'ENSP00000452138', 'rna': 'ENST00000555357'},\n",
       "   {'protein': 'ENSP00000243067', 'rna': 'ENST00000354056'}],\n",
       "  'type_of_gene': 'protein_coding'},\n",
       " 'entrezgene': '1017',\n",
       " 'exac': {'all': {'exp_lof': 14.064243652,\n",
       "   'exp_mis': 103.582926056,\n",
       "   'exp_syn': 40.3209373824,\n",
       "   'lof_z': 3.45076866809409,\n",
       "   'mis_z': 3.05571457340068,\n",
       "   'mu_lof': 1.02721752647e-06,\n",
       "   'mu_mis': 9.19091133625e-06,\n",
       "   'mu_syn': 3.45583178284e-06,\n",
       "   'n_lof': 1.0,\n",
       "   'n_mis': 40.0,\n",
       "   'n_syn': 40.0,\n",
       "   'p_li': 0.958299189494179,\n",
       "   'p_null': 2.00659367791929e-05,\n",
       "   'p_rec': 0.041680744569042,\n",
       "   'syn_z': 0.0313334362386},\n",
       "  'bp': 897,\n",
       "  'cds_end': 56365409,\n",
       "  'cds_start': 56360792,\n",
       "  'n_exons': 7,\n",
       "  'nonpsych': {'exp_lof': 12.5888844843,\n",
       "   'exp_mis': 93.611933068,\n",
       "   'exp_syn': 36.3537267212,\n",
       "   'lof_z': 3.48454051513261,\n",
       "   'mis_z': 2.89910545322279,\n",
       "   'mu_lof': 1.02721752647e-06,\n",
       "   'mu_mis': 9.19091133625e-06,\n",
       "   'mu_syn': 3.45583178284e-06,\n",
       "   'n_lof': 0.0,\n",
       "   'n_mis': 38.0,\n",
       "   'n_syn': 36.0,\n",
       "   'p_li': 0.987477460052364,\n",
       "   'p_null': 6.18333159581444e-06,\n",
       "   'p_rec': 0.0125163566160399,\n",
       "   'syn_z': 0.0369369403215127},\n",
       "  'nontcga': {'exp_lof': 12.9253985908,\n",
       "   'exp_mis': 95.282592769,\n",
       "   'exp_syn': 37.0815586845,\n",
       "   'lof_z': 3.27214293719079,\n",
       "   'mis_z': 3.02573046413952,\n",
       "   'mu_lof': 1.02721752647e-06,\n",
       "   'mu_mis': 9.19091133625e-06,\n",
       "   'mu_syn': 3.45583178284e-06,\n",
       "   'n_lof': 1.0,\n",
       "   'n_mis': 36.0,\n",
       "   'n_syn': 38.0,\n",
       "   'p_li': 0.939863326722736,\n",
       "   'p_null': 5.01892923357667e-05,\n",
       "   'p_rec': 0.0600864839849285,\n",
       "   'syn_z': -0.0954979610569747},\n",
       "  'transcript': 'ENST00000266970.4'},\n",
       " 'exons': [{'cdsend': 55971625,\n",
       "   'cdsstart': 55967008,\n",
       "   'chr': '12',\n",
       "   'position': [[55966768, 55967124],\n",
       "    [55968048, 55968169],\n",
       "    [55968777, 55968948],\n",
       "    [55971043, 55971247],\n",
       "    [55971520, 55972789]],\n",
       "   'strand': 1,\n",
       "   'transcript': 'NM_001290230',\n",
       "   'txend': 55972789,\n",
       "   'txstart': 55966768},\n",
       "  {'cdsend': 55971625,\n",
       "   'cdsstart': 55967008,\n",
       "   'chr': '12',\n",
       "   'position': [[55966768, 55967124],\n",
       "    [55967856, 55967934],\n",
       "    [55968048, 55968169],\n",
       "    [55968777, 55968948],\n",
       "    [55969474, 55969576],\n",
       "    [55971043, 55971247],\n",
       "    [55971520, 55972789]],\n",
       "   'strand': 1,\n",
       "   'transcript': 'NM_001798',\n",
       "   'txend': 55972789,\n",
       "   'txstart': 55966768},\n",
       "  {'cdsend': 55971625,\n",
       "   'cdsstart': 55967008,\n",
       "   'chr': '12',\n",
       "   'position': [[55966768, 55967124],\n",
       "    [55967856, 55967934],\n",
       "    [55968048, 55968169],\n",
       "    [55968777, 55968948],\n",
       "    [55971043, 55971247],\n",
       "    [55971520, 55972789]],\n",
       "   'strand': 1,\n",
       "   'transcript': 'NM_052827',\n",
       "   'txend': 55972789,\n",
       "   'txstart': 55966768}],\n",
       " 'exons_hg19': [{'cdsend': 56365409,\n",
       "   'cdsstart': 56360792,\n",
       "   'chr': '12',\n",
       "   'position': [[56360552, 56360908],\n",
       "    [56361832, 56361953],\n",
       "    [56362561, 56362732],\n",
       "    [56364827, 56365031],\n",
       "    [56365304, 56366573]],\n",
       "   'strand': 1,\n",
       "   'transcript': 'NM_001290230',\n",
       "   'txend': 56366573,\n",
       "   'txstart': 56360552},\n",
       "  {'cdsend': 56365409,\n",
       "   'cdsstart': 56360792,\n",
       "   'chr': '12',\n",
       "   'position': [[56360552, 56360908],\n",
       "    [56361640, 56361718],\n",
       "    [56361832, 56361953],\n",
       "    [56362561, 56362732],\n",
       "    [56363258, 56363360],\n",
       "    [56364827, 56365031],\n",
       "    [56365304, 56366573]],\n",
       "   'strand': 1,\n",
       "   'transcript': 'NM_001798',\n",
       "   'txend': 56366573,\n",
       "   'txstart': 56360552},\n",
       "  {'cdsend': 56365409,\n",
       "   'cdsstart': 56360792,\n",
       "   'chr': '12',\n",
       "   'position': [[56360552, 56360908],\n",
       "    [56361640, 56361718],\n",
       "    [56361832, 56361953],\n",
       "    [56362561, 56362732],\n",
       "    [56364827, 56365031],\n",
       "    [56365304, 56366573]],\n",
       "   'strand': 1,\n",
       "   'transcript': 'NM_052827',\n",
       "   'txend': 56366573,\n",
       "   'txstart': 56360552}],\n",
       " 'generif': [{'pubmed': 11907280,\n",
       "   'text': 'Cyclin A/Cdk2 and cyclin E/cdk2 continuously shuttle between the nucleus and the cytoplasm'},\n",
       "  {'pubmed': 12049628,\n",
       "   'text': 'results argue that TTK-associated CDK2 may function to maintain target-specific phosphorylation of RNA Pol II that is essential for Tat transactivation of HIV-1 promoter'},\n",
       "  {'pubmed': 12081504,\n",
       "   'text': 'Activation mechanism role of cyclin binding versus phosphorylation'},\n",
       "  {'pubmed': 12114499,\n",
       "   'text': 'CDK2/cyclin E is required for Tat-dependent transcription in vitro.'},\n",
       "  {'pubmed': 12149264,\n",
       "   'text': 'CDK2 binding to cyclin E is required to drive cells from G(1) into S phase'},\n",
       "  {'pubmed': 12531694,\n",
       "   'text': 'Interferon gamma reduces the activity of Cdk4 and Cdk2, inhibiting he G1 cell cycle in human hepatocellular carcinoma cells.'},\n",
       "  {'pubmed': 12676582,\n",
       "   'text': 'CDK2 is not required for sustained cell division.'},\n",
       "  {'pubmed': 12729791,\n",
       "   'text': 'Data suggest that the interaction between PKCeta and cyclin E is carefully regulated, and is correlated with the inactivated form of the cyclin E/Cdk2 complex.'},\n",
       "  {'pubmed': 12732645,\n",
       "   'text': 'IRF1 represses CDK2 gene expression by interfering with SP1-dependent transcriptional activation.'},\n",
       "  {'pubmed': 12801928, 'text': 'role in regulating Cdc25A half life'},\n",
       "  {'pubmed': 12810668,\n",
       "   'text': 'TGF-beta 1 inhibition requires early G(1) induction and stabilization of p21 protein, which binds to & inhibits cyclin E-CDK2 and cyclin A-CDK2 kinase activity rather than direct modulation of cyclin or CDK protein levels as seen in other systems.'},\n",
       "  {'pubmed': 12857729,\n",
       "   'text': 'Cdk2 has a role in phosphorylation of the NF-Y transcription factor'},\n",
       "  {'pubmed': 12912980,\n",
       "   'text': 'CDK2 has a role in the G2 DNA damage checkpoint'},\n",
       "  {'pubmed': 12915577,\n",
       "   'text': \"Kaposi's sarcoma-associated herpesvirus K-bZIP physically associates with cyclin-CDK2 and downmodulates its kinase activity.\"},\n",
       "  {'pubmed': 12947099,\n",
       "   'text': 'it is evident that B-Myb protein may promote cell proliferation by a non-transcriptional mechanism that involves release of active cyclin/cyclin dependent kinase 2 from cyclin-dependent inhibitor 1C p57(KIP2)'},\n",
       "  {'pubmed': 12954644,\n",
       "   'text': 'Inhibition of Cdk2 by 1,25-(OH)2D3 may thus involve two mechanisms: 1) reduced nuclear Cdk2 available for cyclin binding and activation and 2) impairment of cyclin E-Cdk2-dependent p27 degradation through cytoplasmic mislocalization of Cdk2.'},\n",
       "  {'pubmed': 14506259,\n",
       "   'text': 'kinetic insight into the basis for selecting suboptimal specificity determinants for the phosphorylation of cellular substrates'},\n",
       "  {'pubmed': 14536078,\n",
       "   'text': 'multisite phosphorylation by Cdk2 and GSK3 controls cyclin E degradation'},\n",
       "  {'pubmed': 14550307, 'text': 'CDK2 binds to SU9516 at Leu83 and Glu81'},\n",
       "  {'pubmed': 14551212,\n",
       "   'text': 'CDK2 activation process through phosphorylation is examined using 2D PAGE'},\n",
       "  {'pubmed': 14562046,\n",
       "   'text': 'Epstein-Barr virus can inhibit genotoxin-induced G1 arrest downstream of p53 by preventing the inactivation of CDK2'},\n",
       "  {'pubmed': 14612403,\n",
       "   'text': 'p220 is an essential downstream component of the cyclin E/Cdk2 signaling pathway and functions to coordinate multiple elements of the G1/S transition.'},\n",
       "  {'pubmed': 14645251,\n",
       "   'text': 'CDK2-cyclin E, without prior CDK4-cyclin D activity, can phosphorylate and inactivate pRb, activate E2F, and induce DNA synthesis.'},\n",
       "  {'pubmed': 14646596,\n",
       "   'text': 'significant difference in their biochemical properties between CDK4/cyclin D1 and CDK2/cyclin A affecting regulation of cellular RB function'},\n",
       "  {'pubmed': 14694185,\n",
       "   'text': 'cyclin-dependent kinase (CDK)2, -4, and -6 were down-regulated from the myelocytes/metamyelocytes stages and onward'},\n",
       "  {'pubmed': 14701826,\n",
       "   'text': 'CDK2 complexes have roles in G(1)/S deregulation and tumor progression'},\n",
       "  {'pubmed': 14985333,\n",
       "   'text': 'CDK2 regulates beta-catenin phosphorylation/ degradation'},\n",
       "  {'pubmed': 15004027,\n",
       "   'text': 'Cdk2 and Cdk4 phosphorylate human Cdt1 and induce its degradation'},\n",
       "  {'pubmed': 15024385,\n",
       "   'text': 'Binding to Cdk2-cyclin A is accompanied by p27 folding, and kinetic data suggest a sequential mechanism that is initiated by binding to cyclin A'},\n",
       "  {'pubmed': 15063782,\n",
       "   'text': 'We also found that cyclin A/CDK2 phosphorylates Axin, thereby enhancing its association with beta-catenin.'},\n",
       "  {'pubmed': 15159402,\n",
       "   'text': 'study provides evidence that the cyclin A1-cyclin dependent kinase 2 complex plays a role in several signaling pathways important for cell cycle control and meiosis'},\n",
       "  {'pubmed': 15178429, 'text': 'interacts with dephosphorylated NIRF'},\n",
       "  {'pubmed': 15199159,\n",
       "   'text': 'cyclin A-cdk2 plays an ancillary noncatalytic role in the ubiquitination of p27(KIP1) by the SCF(skp2) complex'},\n",
       "  {'pubmed': 15226429,\n",
       "   'text': 'Results identify an important role for CDK2 in the maintenance of genomic stability, acting via an ATM- and ATR-dependent pathway.'},\n",
       "  {'pubmed': 15309028,\n",
       "   'text': 'after CDK4/6 inactivation, the fate of pancreatic tumor cells depends on the ability to modulate CDK2 activity'},\n",
       "  {'pubmed': 15355984,\n",
       "   'text': 'Data suggest that cyclin D1-Cdk2 complexes mediate some of the transforming effects of cyclin D1 and demonstrate that the cyclin D1-Cdk2 fusion protein is a useful model to investigate the biological functions of cyclin D1-Cdk2 complexes.'},\n",
       "  {'pubmed': 15456866,\n",
       "   'text': 'These findings establish a novel function for cyclin A1 and CDK2 in DNA double strand break repair following radiation damage.'},\n",
       "  {'pubmed': 15572662,\n",
       "   'text': 'Phosphborylation of progesterone receptor serine 400 mediates ligand-independent transcriptional activity in response to activation of CDK2.'},\n",
       "  {'pubmed': 15601848,\n",
       "   'text': 'cyclin A/Cdk2 has a role as a progesterone receptor coactivator'},\n",
       "  {'pubmed': 15607961,\n",
       "   'text': 'CDK2 depletion suppressed growth and cell cycle progression in melanoma and may be a suitable drug target in melanoma.'},\n",
       "  {'pubmed': 15611077,\n",
       "   'text': 'Inhibition of CDK2 kinase by indole-3-carbinol is accompanied by selective alterations in cyclin E composition.'},\n",
       "  {'pubmed': 15632290,\n",
       "   'text': 'molecular dynamics study on the complex CDK2 with the peptide substrate HHASPRK'},\n",
       "  {'pubmed': 15649889,\n",
       "   'text': 'Results demonstrate that a peptide derived from the alpha5 helix of cyclin A significantly inhibits kinase activity of complexes harboring CDK2, and forms stable complexes with CDK2-cyclin A.'},\n",
       "  {'pubmed': 15660127,\n",
       "   'text': 'crystal structure of phospho-CDK2 in complex with a truncated cyclin E1 (residues 81-363) at 2.25 A resolution'},\n",
       "  {'pubmed': 15665273,\n",
       "   'text': 'CDK2-BRCA1-Nucleophosmin pathway coordinately functions in cell growth and tumor progression pathways.'},\n",
       "  {'pubmed': 15671017,\n",
       "   'text': 'HTm4 binding to KAP.Cdk2.cyclin A complex enhances the phosphatase activity of KAP, dissociates cyclin A, and facilitates KAP dephosphorylation of Cdk2'},\n",
       "  {'pubmed': 15695825,\n",
       "   'text': 'Results present a comprehensive description of the dynamic behavior of cyclin-dependent kinase 2 in complex with cyclin A.'},\n",
       "  {'pubmed': 15707957,\n",
       "   'text': 'Puralpha has been shown to colocalize with cyclin A/Cdk2 and to coimmunoprecipitate with cyclin A during S-phase and we show that this interaction is mediated by a specific affinity of Puralpha for Cdk2.'},\n",
       "  {'pubmed': 15890360,\n",
       "   'text': 'Rapid binding of p27 domain 1 to cyclin A tethers the inhibitor to the binary Cdk2/cyclin A complex'},\n",
       "  {'pubmed': 15922732,\n",
       "   'text': 'CDK2 translational down-regulation may be a key regulatory event in replicative senescence of endothelial cells.'},\n",
       "  {'pubmed': 15944161,\n",
       "   'text': 'origin recognition complex 2 has an unexpected role in CDK2 activation, a linkage that could be important for maintaining genomic stability'},\n",
       "  {'pubmed': 15964852,\n",
       "   'text': 'Cdk2 destabilizes p21 via the cy2 cyclin-binding motif and p21 phosphorylation'},\n",
       "  {'pubmed': 16036217,\n",
       "   'text': 'Our results demonstrate that differential regulation of Cdc2 and Cdk2 activity by different doses of doxorubicin may contribute to the induction of two modes of cell death in hepatoma cells, either apoptosis or cell death through mitotic catastrophe.'},\n",
       "  {'pubmed': 16082200,\n",
       "   'text': 'CINP is part of the Cdc7-dependent mechanism of origin firing and a functional and physical link between Cdk2 and Cdc7 complexes at the origins'},\n",
       "  {'pubmed': 16082227,\n",
       "   'text': 'CDK2 inhibition modifies the dynamics of chromatin-bound minichromosome maintenance complex and replication protein A'},\n",
       "  {'pubmed': 16085226,\n",
       "   'text': 'results indicate that CDK2 participates in Tat-mediated HIV-1 transcription and may serve as a potential therapeutic target'},\n",
       "  {'pubmed': 16150942,\n",
       "   'text': 'Cdk2 inhibition decreases the efficiency of chemical induction of KSHV lytic transcripts ORF 50 and 26. Importantly, Cdk2 activity is also essential for replication in other human herpesviruses'},\n",
       "  {'pubmed': 16258277,\n",
       "   'text': 'A new concept indicates in this review that both Cdk2 and/or Cdc2 can drive cells through G1/S phase in parallel.'},\n",
       "  {'pubmed': 16262700,\n",
       "   'text': 'Cdk2 dependent phosphorylation(s) cannot be a critical trigger of replicon initiation in response to reoxygenation after several hours of hypoxia, at least in the T24 cells studied'},\n",
       "  {'pubmed': 16343435,\n",
       "   'text': 'We propose that during TNFalpha-induced apoptosis, PKCdelta-mediated phosphorylation of p21(WAF1/CIP1) at (146)Ser attenuates the Cdk2 binding of p21(WAF1/CIP1) and thereby upregulates Cdk2 activity.'},\n",
       "  {'pubmed': 16407256,\n",
       "   'text': 'molecular analysis of the CDK5/p25 and CDK2/cyclin A systems'},\n",
       "  {'pubmed': 16504183,\n",
       "   'text': 'Cyclin-dependent kinases regulate the transcriptional activity of FOXM1c; a combination of three phosphorylation sites mediates the Cyclin E and Cyclin A/CDK2 effects.'},\n",
       "  {'pubmed': 16540140,\n",
       "   'text': 'Here, we show that human papillomavirus type 16 16E1--E4 is also able to associate with cyclin A and Cdk2 during the G2 phase of the cell cycle.'},\n",
       "  {'pubmed': 16575928,\n",
       "   'text': 'The interaction between roscovitine and cyclin-dependent kinase 2 (cdk2) was investigated by performing correlated ab initio quantum-chemical calculations.'},\n",
       "  {'pubmed': 16707497,\n",
       "   'text': 'the phospho-CDK2/cyclin A recruitment site has a role in substrate recognition'},\n",
       "  {'pubmed': 16762841,\n",
       "   'text': 'Phosphorylation of the linker histone H1 by CDK regulates its binding to HP1alpha'},\n",
       "  {'pubmed': 16765349,\n",
       "   'text': 'suggest a novel retinoic acid (RA)-signaling, by which RA-induced p21 induction and complex formation with cyclin E/CDK2 diverts CDK2 function from normally driving proliferation to alternatively promoting apoptosis'},\n",
       "  {'pubmed': 16824683,\n",
       "   'text': 'Membrane depolarization may stimulate cellular proliferation by augmenting the expression of cyclin E leading to increases in Cdk2 activity and RB phosphorylation in a neuroblastoma cell line.'},\n",
       "  {'pubmed': 16912045,\n",
       "   'text': 'the Chk1-mediated S-phase checkpoint targets initiation factor Cdc45 via a Cdc25A/Cdk2-independent mechanism'},\n",
       "  {'pubmed': 16912201,\n",
       "   'text': 'Breast cancer cells lacking cancer predisposition genes BRCA1 are more sensitive to CDK2 inhibitors.'},\n",
       "  {'pubmed': 17001081,\n",
       "   'text': 'analysis of the NBI1-binding site on cyclin A which inhibits the catalytic activity of the complex cyclin-dependent kinase 2-cyclin A'},\n",
       "  {'pubmed': 17013093,\n",
       "   'text': 'progression of melanoma is associated with changes in CDK-2 expression level'},\n",
       "  {'pubmed': 17038621,\n",
       "   'text': 'functional interaction between CDK2 and FOXO1 provides a mechanism that regulates apoptotic cell death after DNA strand breakage'},\n",
       "  {'pubmed': 17095507,\n",
       "   'text': 'Kinetic and crystallographic analyses of CDK2-cyclin A complexes reveal that this inhibitory mechanism operates through steric blockade of peptide substrate binding.'},\n",
       "  {'pubmed': 17207508,\n",
       "   'text': 'Review highlights an alternative role for CDK2 in the regulation of progesterone receptor signaling.'},\n",
       "  {'pubmed': 17293600,\n",
       "   'text': 'TopBP1 necessary for the G(1)/S transition: one for activating cyclin E/CDK2 kinase and the other for loading replication components onto chromatin to initiate DNA synthesis.'},\n",
       "  {'pubmed': 17361108,\n",
       "   'text': 'Our results demonstrate that CDK2 is capable of autophosphorylation at Thr160.'},\n",
       "  {'pubmed': 17371838,\n",
       "   'text': 'results argue that Mdm2 is needed for full inhibition of Cdk2 activity by p21, thereby positively contributing to p53-dependent cell cycle arrest'},\n",
       "  {'pubmed': 17386261,\n",
       "   'text': 'Both Cdk1 and -2 require cyclin binding and T loop phosphorylation for full activity.'},\n",
       "  {'pubmed': 17409409,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 17495531,\n",
       "   'text': 'The structure of phospho-CDK2/cyclin B is reported. pCDK2/cyclin B is less discriminatory in substrate recognition than CDK2/cyclin A & has properties of both an S-phase & an M-phase kinase. CDK2/cyclin B is effective against S phase substrates.'},\n",
       "  {'pubmed': 17638878,\n",
       "   'text': 'ATRIP is a CDK2 substrate, and CDK2-dependent phosphorylation of S224 regulates the ability of ATR-ATRIP to promote cell cycle arrest in response to DNA damage'},\n",
       "  {'pubmed': 17713927,\n",
       "   'text': 'Phosphorylation on a conserved Thr14 can inhibit activities of both the kinases, but phosphorylating another conserved Tyr15, however, can lead to totally opposite inhibition and stimulation consequences in CDK2 and CDK5.'},\n",
       "  {'pubmed': 18042686,\n",
       "   'text': 'The conserved rigid regions are important for nucleotide binding, catalysis, and substrate recognition; most flexible regions correlate with those where large conformational changes occur during CDK2 regulation processes.'},\n",
       "  {'pubmed': 18156799,\n",
       "   'text': 'cdk2 activity is necessary for the survival of human DLBCL.'},\n",
       "  {'pubmed': 18174243,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 18199752,\n",
       "   'text': 'major Cdk2-dependent multiple gene regulatory events are present in pemphigus vulgar'},\n",
       "  {'pubmed': 18202766,\n",
       "   'text': 'serum starvation induces G1 arrest through suppression of Skp2-dependent CDK2 activity and Skp2-independent CDK4 activity in human SK-OV-3 ovarian cancer cells'},\n",
       "  {'pubmed': 18208561,\n",
       "   'text': 'growth arrest by SmE directly correlates with the reduction of cyclin E, CDK2, CDC25C and CDC2 expression, and up-regulation of p27Kip'},\n",
       "  {'pubmed': 18236071,\n",
       "   'text': 'Findings strongly demonstrate that retinoblastoma (RB) and cyclin-dependent kinase 2 (CDK2) on one side and cytokeratin 8 (CK8) and epidermal growth factor receptor 2 (HER2) on the other may affect the clinical course of the disease in 56% of patients.'},\n",
       "  {'pubmed': 18276582,\n",
       "   'text': 'Cyclin E and SV40 small T antigen cooperate to bypass quiescence and contribute to transformation by activating CDK2 in human fibroblasts'},\n",
       "  {'pubmed': 18281541,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 18345036,\n",
       "   'text': 'Bim-mediated apoptosis following actin damage due to deregulation of Cdk2 and the cell cycle by the absence of functional p53.'},\n",
       "  {'pubmed': 18372919,\n",
       "   'text': 'G2 phase cyclin A/cdk2 controls the timing of entry into mitosis by controlling the subsequent activation of cyclin B/cdk1, but also has an unexpected role in coordinating the activation of cyclin B/cdk1 at the centrosome and in the nucleus'},\n",
       "  {'pubmed': 18400748,\n",
       "   'text': 'disruption of the spindle-assembly checkpoint does not directly influence p53 activation, but the shortening of the mitotic arrest allows cyclin E-CDK2 to be activated before the accumulation of p21(CIP1/WAF1).'},\n",
       "  {'pubmed': 18408738,\n",
       "   'text': 'Results suggest that GSK-3 regulates nuclear p27 Kip1 expression through downregulation of Skp2 expression and regulates p27 Kip1 assembly with CDK2, playing a critical role in the G0/G1 arrest associated with intestinal cell differentiation.'},\n",
       "  {'pubmed': 18470542,\n",
       "   'text': 'The structures of fully active cyclin-dependent kinase-2 (CDK2)complexed with ATP and peptide substrate, CDK2 after the catalytic reaction, and CDK2 inhibited by phosphorylation at Thr14/Tyr15 were studied using molecular dynamics simulations.'},\n",
       "  {'pubmed': 18507837,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 18617527,\n",
       "   'text': 'Cdk2-associated complexes, by targeting SHP-1 for proteolysis, counteract the ability of SHP-1 to block cell cycle progression of intestinal epithelial cells'},\n",
       "  {'pubmed': 18635963,\n",
       "   'text': 'Cyclin A-CDK activity during G(1) would result in an inhibition of progression into the S phase.'},\n",
       "  {'pubmed': 18667424,\n",
       "   'text': 'the cyclin A-CDK2 complex may be a potential effector of NFATs, specifically NFATc1, in mediating SMC multiplication leading to neointima formation.'},\n",
       "  {'pubmed': 18784074,\n",
       "   'text': 'Cdk2 negatively regulates the activity of hPXR, and suggest an important role for Cdk2 in regulating hPXR activity and CYP3A4 expression in hepatocytes passing through the cell cycle'},\n",
       "  {'pubmed': 18806832,\n",
       "   'text': 'This suggests an important role for CDK2 in cell cycle regulation in hESCs that are likely to bear significant impacts on the maintenance of their pluripotent phenotype.'},\n",
       "  {'pubmed': 18941885,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 19061641,\n",
       "   'text': 'Cyclin A assembles with Cdk1 only after complex formation with Cdk2 reaches a plateau during late S and G2 phases.'},\n",
       "  {'pubmed': 19066288,\n",
       "   'text': 'These findings establish phosphorylation events by CDKs 1 and 2 as key regulators of Discs Large 1 localisation and function.'},\n",
       "  {'pubmed': 19091404,\n",
       "   'text': 'Notch-1 may be mediated through regulating the expression of cell cycle regulatory proteins cyclin D1, CDK2 and p21 and the activity of Akt signaling'},\n",
       "  {'pubmed': 19101503,\n",
       "   'text': 'These results demonstrate that double phosphorylation of CDK2 peptides increases the stoichiometry of metal ion binding, and hence may contribute to the previously observed regulation of CDK2 activity by metal ions.'},\n",
       "  {'pubmed': 19103742,\n",
       "   'text': 'the pathway of apoptin-induced apoptosis and show that it essentially depends on abnormal phosphatidylinositol 3-kinase (PI3-kinase)/Akt activation, resulting in the activation of the cyclin-dependent kinase CDK2'},\n",
       "  {'pubmed': 19124506,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 19166026,\n",
       "   'text': 'Overexpression of CDK2 was strongly correlated with abnormal proliferation in laryngeal squamous cell carcinoma.'},\n",
       "  {'pubmed': 19197163,\n",
       "   'text': 'Results show that human Cdk2 is a functional homolog for most of Ime2 functions.'},\n",
       "  {'pubmed': 19201832,\n",
       "   'text': 'disruption of Smad2 function by CDK2 phosphorylation acts as a mechanism for TGF-beta resistance in multiple myeloma.'},\n",
       "  {'pubmed': 19258477,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 19258477,\n",
       "   'text': 'Strengthened signals in imputation-based analysis at CDK2 SNPs rs2069391, rs2069414 and rs17528736 lend evidence to the role of cell cycle genes in ovarian cancer etiology.'},\n",
       "  {'pubmed': 19321444,\n",
       "   'text': 'The combination of st and deregulated cyclin E result in cooperative and coordinated activation of both an essential origin licensing factor, CDC6, and an activity required for origin firing, CDK2, resulting in progression from quiescence to S phase.'},\n",
       "  {'pubmed': 19440053,\n",
       "   'text': 'Co-depletion of Cdc6 and p53 in normal cells restored Cdk2 activation and Rb phosphorylation, permitting them to enter S phase with a reduced rate of replication.'},\n",
       "  {'pubmed': 19594747,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 19596857,\n",
       "   'text': 'resistance of oral squamous carcinoma to IFNgamma is not due to deficiency in STAT1-dependent signaling but from a defect in the signaling component that mediates IFNgamma-induced down-regulation of CcnA2 and Cdk2 expression'},\n",
       "  {'pubmed': 19609547,\n",
       "   'text': 'Four genes previously not examined in that respect in laryngeal carcinoma, occurred to be good markers of the neoplasm. They are: metal-proteinase ADAM12, cyclin-dependent kinase 2-CDK2, kinesin 14-KIF14, suppressor 1 of checkpoint-CHES1.'},\n",
       "  {'pubmed': 19631451,\n",
       "   'text': 'Data demonstrate that the novel anticancer mechanism of hinokitiol involves accumulation of p27, down-regulation of pRb, Skp2, and impairment of Cdk2 function.'},\n",
       "  {'pubmed': 19703905,\n",
       "   'text': 'cyclin A/cdk2-dependent phosphorylation of APC affects astral microtubule attachment to the cortical surface in mitosis'},\n",
       "  {'pubmed': 19706521,\n",
       "   'text': 'Results suggest that simple but robust rules encoded in the CDK2 structure play a dominant role in predefining the mechanisms of ligand binding, which may be advantageously exploited in designing inhibitors.'},\n",
       "  {'pubmed': 19723060,\n",
       "   'text': 'Studies indicate that roscovitine arrests the cell cycle is direct inhibition of CDK1, a mitotic regulator, and CDK2, involved in G1/S transition.'},\n",
       "  {'pubmed': 19724860,\n",
       "   'text': 'Overexpression of Notch1 in laryngeal carcinoma cell line was coupled with the downregulation of cdk2'},\n",
       "  {'pubmed': 19738611,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 19797611,\n",
       "   'text': 'results show that the expression of UGT1A1 and CYP2B6 is negatively regulated through a CDK2 signaling pathway linked to cell cycle progression in HepG2 and SW480 cells'},\n",
       "  {'pubmed': 19822658,\n",
       "   'text': 'Results underscore the crucial role of cyclin A2-CDK2 in regulating the PLK1-SCF(beta-TrCP1)-EMI1-APC/C axis and CDC6 to trigger genome reduplication after the activity of CDK1 is suppressed.'},\n",
       "  {'pubmed': 19829063,\n",
       "   'text': 'Since CAC1 interacts with CDK2 and promotes the kinase activity of CDK2 protein, we propose that CAC1 is a novel cell cycle associated protein capable of promoting cell proliferation.'},\n",
       "  {'pubmed': 19838212,\n",
       "   'text': 'Chk1 signalling causes centrosome amplification after ionizing radiation by upregulating Cdk2 activity through activating phosphorylation.'},\n",
       "  {'pubmed': 19838216,\n",
       "   'text': 'Data show that SHP-1 knockdown increases p27stability, decreases the CDK6 levels, inducing retinoblastoma protein hypophosphorylation, downregulation of cyclin E and thereby a decrease in the CDK2 activity.'},\n",
       "  {'pubmed': 19854217,\n",
       "   'text': 'expression upregulation is critical for TLR9-stimulated proliferation of kung cancer cells'},\n",
       "  {'pubmed': 19858290,\n",
       "   'text': 'Export was also reduced by Cdk inhibition or cyclin A RNA interference, suggesting that cyclin A/Cdk complexes contribute to Wee1 export.'},\n",
       "  {'pubmed': 19885547,\n",
       "   'text': 'aberrant regulation of S100P in HCC might activate cyclin D1 and CDK expression and contribute to the mitogenic potential of tumor cells during Hepatocellular carcinoma carcinogenesis.'},\n",
       "  {'pubmed': 19960406,\n",
       "   'text': 'Cellular production of IGFBP-3 leads to G1 cell cycle arrest with inhibition of CDK2 and CDK4.'},\n",
       "  {'pubmed': 19966300,\n",
       "   'text': 'Data show that Myc repressed Ras-induced senescence, and that Cdk2 interacted with Myc at promoters, where it affected Myc-dependent regulation of genes, including those of proteins known to control senescence.'},\n",
       "  {'pubmed': 20017906, 'text': 'FUS-DDIT3 and the normal DDIT3 bind CDK2.'},\n",
       "  {'pubmed': 20062077,\n",
       "   'text': 'Results directly show that the inhibition of Cdk1 activity and the persistence of Cdk2 activity in G2 cells induces endoreplication without mitosis.'},\n",
       "  {'pubmed': 20068231,\n",
       "   'text': 'Results show that most of the up-regulated sites phosphorylated by cyclin-dependent CDK1 or CDK2 were almost fully phosphorylated in mitotic cells.'},\n",
       "  {'pubmed': 20079829,\n",
       "   'text': 'the nitric oxide-mediated biphasic effect was dependent on Cdk2 nitrosylation/activation and the loss of mitochondrial potential'},\n",
       "  {'pubmed': 20147522,\n",
       "   'text': 'central roles for CDK2 nuclear-cytoplasmic trafficking and cyclin E in the mechanism of 1,25-(OH)(2)D(3)-mediated growth inhibition in prostate cancer cells'},\n",
       "  {'pubmed': 20195506,\n",
       "   'text': 'These findings demonstrate that Cdk2 maintains a balance of S-phase regulatory proteins and thereby coordinates subsequent p53-independent G(2)/M checkpoint activation.'},\n",
       "  {'pubmed': 20399812,\n",
       "   'text': 'Data describe the properties of a mutant form of Cdk2 identified during large-scale sequencing of protein kinases from cancerous tissue.'},\n",
       "  {'pubmed': 20422243,\n",
       "   'text': 'Triticum aestivum-5B2 (( Ta ) 5B2) is suggested to be a wheat analogue of human CDK2 enzyme.'},\n",
       "  {'pubmed': 20444741,\n",
       "   'text': 'Conclude that cisplatin likely activates both caspase-dependent and -independent cell death, and Cdk2 is required for both pathways.'},\n",
       "  {'pubmed': 20465575,\n",
       "   'text': 'In addition to having a pivotal role in the up-regulation of IL-2 and IL-2RA gene expression, IKK controls the expression of cyclin D3, cyclin E and CDK2, and the stability SKP2 and its co-factor CKS1B, through mechanisms independent of IL-2.'},\n",
       "  {'pubmed': 20508983,\n",
       "   'text': 'Observational study of gene-disease association. (HuGE Navigator)'},\n",
       "  {'pubmed': 20512928,\n",
       "   'text': 'Hr and VDR interact via multiple protein-protein interfaces, catalyzing histone demethylation to effect chromatin remodeling and repress the transcription of VDR target genes that control the hair cycle.'},\n",
       "  {'pubmed': 20694007,\n",
       "   'text': 'protein phosphatase 1 competition with Cdk-cyclins for retinoblastoma protein(Rb) binding is sufficient to retain Rb activity and block cell-cycle advancement.'},\n",
       "  {'pubmed': 20711190,\n",
       "   'text': 'cyclin-dependent kinases (Cdks), especially Cdk1 and Cdk2, promote interphase nuclear pore complex formation in human dividing cells.'},\n",
       "  {'pubmed': 20844047,\n",
       "   'text': 'Nuclear export of HPV31 E1 is inhibited by Cdk2 phosphorylation at two serines residues, S92 and S106.'},\n",
       "  {'pubmed': 20935635,\n",
       "   'text': 'The results demonstrate that CDK2-mediated phosphorylation is a key mechanism governing EZH2 function and that there is a link between the cell-cycle machinery and epigenetic gene silencing.'},\n",
       "  {'pubmed': 21048031,\n",
       "   'text': 'Observational study of gene-disease association and gene-environment interaction. (HuGE Navigator)'},\n",
       "  {'pubmed': 21062975,\n",
       "   'text': 'Data show that miR-302 simultaneously suppressed both the cyclin E-CDK2 and cyclin D-CDK4/6 pathways to block>70% of the G1-S cell cycle transition.'},\n",
       "  {'pubmed': 21099355,\n",
       "   'text': 'Overexpression of human Cdk2 resulted in a defect in the G1 to S transition and a reduction in viability.'},\n",
       "  {'pubmed': 21233845,\n",
       "   'text': 'MicroRNA miR-885-5p targets CDK2 and MCM5, activates p53 and inhibits proliferation and survival.'},\n",
       "  {'pubmed': 21262353,\n",
       "   'text': 'Cdk2 functions via a Cdk2/SHP-1/beta-catenin/CEACAM1 axis, and show that Cdk2 has the capacity to regulate insulin internalization.'},\n",
       "  {'pubmed': 21264535,\n",
       "   'text': 'XPD may play an important role in cell apoptosis of hepatoma by inducing an over-expression of p53, but suppressing expressions of c-myc and cdk2'},\n",
       "  {'pubmed': 21319273,\n",
       "   'text': 'CDK2 downregulation causes high apoptosis at the early time points'},\n",
       "  {'pubmed': 21325496,\n",
       "   'text': 'Conclude that in cisplatin induced-kidney injury phosphorylation of p21 by Cdk2 limits the effectiveness of p21 to inhibit Cdk2.'},\n",
       "  {'pubmed': 21454540,\n",
       "   'text': 'the ability of Emi1 to inhibit APC/C is negatively regulated by CDKs'},\n",
       "  {'pubmed': 21515670,\n",
       "   'text': 'cyclin E and CDK2 genes are key physiological effectors of the c-ETS1 proto-oncogene. Furthermore, c-ETS1 is indispensable for the hepatotropic action of HBx in cell cycle deregulation.'},\n",
       "  {'pubmed': 21565702,\n",
       "   'text': 'Transient binding of a second catalytic magnesium activates the structure and dynamics of CDK2 kinase for catalysis.'},\n",
       "  {'pubmed': 21596315,\n",
       "   'text': 'The deubiquitinase USP37 binds CDH1 and removes degradative polyubiquitin from cyclin A. USP37 was induced by E2F factors in G1, peaked at G1/S, and was degraded in late mitosis. Phosphorylation of USP37 by CDK2 stimulated its full activity.'},\n",
       "  {'pubmed': 21646351,\n",
       "   'text': 'anti-oncogenic role of miR-372 may be through control of cell growth and cell cycle progression by down-regulating the cell cycle genes CDK2 and cyclin A1'},\n",
       "  {'pubmed': 21658603, 'text': 'Cdk2 is required for cell proliferation.'},\n",
       "  {'pubmed': 21769424,\n",
       "   'text': 'RT-PCR and Western blotting results revealed that both mRNA and protein levels of CDK2 were significantly higher in tumor tissues.'},\n",
       "  {'pubmed': 21871181,\n",
       "   'text': 'NF-Y binds to CCAAT sequences in the Cyclin A promoter, as well as to those in the promoters of cell cycle G2 regulators such as CDC2, Cyclin B and CDC25C.'},\n",
       "  {'pubmed': 21918011,\n",
       "   'text': 'Epstein-Barr virus Rta-mediated transactivation of p21 and 14-3-3sigma arrests cells at the G1/S transition by reducing cyclin E/CDK2 activity.'},\n",
       "  {'pubmed': 21941773,\n",
       "   'text': 'The expression level of CDK2 protein did not change significantly in silica-induced human embryo lung fibroblasts.'},\n",
       "  {'pubmed': 21965652,\n",
       "   'text': 'excess of MCM3 up-regulates the phosphorylation of CHK1 Ser-345 and CDK2 Thr-14.'},\n",
       "  {'pubmed': 22084169,\n",
       "   'text': 'The S-phase-specific cyclin-dependent kinase 2 was required for robust activation of ATR in response to diverse chemotherapeutic agents.'},\n",
       "  {'pubmed': 22231403,\n",
       "   'text': 'The authors show that, in human and mouse, Mre11 controls these events through a direct interaction with CDK2 that is required for CtIP phosphorylation and BRCA1 interaction in normally dividing cells.'},\n",
       "  {'pubmed': 22467868,\n",
       "   'text': 'Lin-28 homologue A (LIN28A) promotes cell cycle progression via regulation of cyclin-dependent kinase 2 (CDK2), cyclin D1 (CCND1), and cell division cycle 25 homolog A (CDC25A) expression in cancer.'},\n",
       "  {'pubmed': 22474407,\n",
       "   'text': 'CDK2 inhibition drastically diminishes anchorage-independent growth of human cancer cells and cells transformed with various oncogenes'},\n",
       "  {'pubmed': 22479189,\n",
       "   'text': 'low molecular weight cyclin E (LMW-E) requires CDK2-associated kinase activity to induce mammary tumor formation by disrupting acinar development'},\n",
       "  {'pubmed': 22673765,\n",
       "   'text': 'The activation of p21(Waf1/Cip1) was significantly up-regulated over time, but there was no change in the level of CDK2 expression by treatment of HEK293 cells with various concentrations of veterinary antibiotics.'},\n",
       "  {'pubmed': 22718829,\n",
       "   'text': 'Human cytomegalovirus IE1/2 expression was downregulated by cyclin A2, CDK1 and CDK2.'},\n",
       "  {'pubmed': 22819841,\n",
       "   'text': 'exposure of cancer cells (such as HeLa and MCF7 cells) to H2O2 increased CDK2 activity with no accompanying change in the PCNA level, leading to cell proliferation.'},\n",
       "  {'pubmed': 22927831,\n",
       "   'text': 'By a chemical-genetic approach study identified Nbs1 as a target of Cdk2, and mapped the phosphorylation to a conserved CDK consensus recognition site.'},\n",
       "  {'pubmed': 22951823,\n",
       "   'text': 'cellular CDK2 phosphorylates the functionally critical S/T-P sites of the hepadnavirus core CTD and is incorporated into viral capsids'},\n",
       "  {'pubmed': 23028682,\n",
       "   'text': 'cyclin A-Cdk2 regulates apoptosis through a mechanism that involves Rad9phosphorylation'},\n",
       "  {'pubmed': 23065011,\n",
       "   'text': 'human papillomavirus E4 proteins can interact with cyclin A and cdk2, which may contribute to viral manipulation of the host cell cycle.'},\n",
       "  {'pubmed': 23082202,\n",
       "   'text': 'Cdk2 also binds the N-terminal domain of Fbw7-gamma as well as SLP-1.'},\n",
       "  {'pubmed': 23140174,\n",
       "   'text': 'CDK2 phosphorylates CDK9 on Ser 90 and thereby contributes to HIV-1 transcription.'},\n",
       "  {'pubmed': 23184662,\n",
       "   'text': 'EEF2 phosphorylation by cyclin A-cyclin-dependent kinase 2 (CDK2) on a novel site, serine 595 (S595), directly regulates T56 phosphorylation by eEF2K.'},\n",
       "  {'pubmed': 23185313,\n",
       "   'text': 'This study aimed to explore the effects of single nucleotide polymorphisms in CDK2 and CCNE1 on breast cancer risk, progression and survival in a Chinese Han population.'},\n",
       "  {'pubmed': 23230143,\n",
       "   'text': 'Findings revealed a novel function of simultaneous p27 and CDK2 cytoplasmic mislocalization in mediating growth-factor-regulated cell proliferation, migration and invasion.'},\n",
       "  {'pubmed': 23300027,\n",
       "   'text': 'possible relationship between the CDK2 deleterious variants and the drug-binding ability'},\n",
       "  {'pubmed': 23321641,\n",
       "   'text': 'Constitutive Cdk2 activity promotes aneuploidy while altering the spindle assembly and tetraploidy checkpoints.'},\n",
       "  {'pubmed': 23390492,\n",
       "   'text': 'Constitutive CCND1/CDK2 expression contributes to neoplastic mammary epithelial cell transformation.'},\n",
       "  {'pubmed': 23390529,\n",
       "   'text': 'The prolyl isomerase Pin1 acts synergistically with CDK2 to regulate the basal activity of estrogen receptor alpha in breast cancer.'},\n",
       "  {'pubmed': 23446853,\n",
       "   'text': 'Aurora-A kinase-induced centrosome amplification was mediated by Cdk2 kinase.'},\n",
       "  {'pubmed': 23479742,\n",
       "   'text': 'the up-regulation of CDK2 by CUL4B is achieved via the repression of miR-372 and miR-373, which target CDK2.'},\n",
       "  {'pubmed': 23532886,\n",
       "   'text': 'Data indicate that TG02 blocked signaling by CDKs 1, 2, 7, and 9 and ERK5, leading to potent and highly consistent antimyeloma activity.'},\n",
       "  {'pubmed': 23643165,\n",
       "   'text': 'The expression of CDK2 mRNA significantly decreased in P(CDK2-siRNA).'},\n",
       "  {'pubmed': 23671119,\n",
       "   'text': 'A specific and essential roles for Cdk2 inhibitory phosphorylation in the successful execution of the replication stress checkpoint response and in maintaining genome integrity.'},\n",
       "  {'pubmed': 23720738,\n",
       "   'text': 'MCM7 is a substrate of cyclin E/Cdk2 and can be phosphorylated on Ser-121.'},\n",
       "  {'pubmed': 23727278,\n",
       "   'text': 'Data indicate that different binding sites of cyclin-dependent kinase (CDK2) contributing towards the binding of inhibitors.'},\n",
       "  {'pubmed': 23737759,\n",
       "   'text': 'CDK7 involved in phosphorylation/activation of CDK4 and CDK6; existence of CDK4-activating kinase(s) other than CDK7; and novel CDK7-dependent positive feedbacks mediated by p21 phosphorylation by CDK4 and CDK2 to sustain CDK4 activation.'},\n",
       "  {'pubmed': 23776131,\n",
       "   'text': 'FBXO28 activity and stability are regulated during the cell cycle by CDK1/2-mediated phosphorylation of FBXO28, which is required for its efficient ubiquitylation of MYC.'},\n",
       "  {'pubmed': 23781148,\n",
       "   'text': 'antitumor effects of DOC-1R may be mediated by negatively regulating G1 phase progression and G1/S transition through inhibiting CDK2 expression and activation'},\n",
       "  {'pubmed': 23787073,\n",
       "   'text': 'This study indicates that genetic polymorphisms of AURKA, BRCA1 and CCNE1 may affect ovarian cancer susceptibility in Chinese Han women.'},\n",
       "  {'pubmed': 24075009,\n",
       "   'text': 'Cells decide at the end of mitosis to either start the next cell cycle by immediately building up CDK2 activity or to enter a transient G0-like state by suppressing CDK2 activity.'},\n",
       "  {'pubmed': 24204256,\n",
       "   'text': 'PKC activation then triggered activation of cdk-2, which became further activated by caspase-3.'},\n",
       "  {'pubmed': 24216307,\n",
       "   'text': 'Two nuclear export signals of Cdc6 work cooperatively and distinctly for the cytoplasmic translocation of Cdc6 phosphorylated by cyclin A/Cdk2.'},\n",
       "  {'pubmed': 24240190,\n",
       "   'text': 'CDK2 knockdown alters the profile of Rb phosphorylation in coronary artery smooth muscle cells, as well as the proliferative response of these cells to mitogenic stimulation.'},\n",
       "  {'pubmed': 24386425,\n",
       "   'text': 'Of the total, the deregulation of several genes (CDK1, CDK2, CDK4, MCM2, MCM3, MCM4, EIF3a and RPN2) were potentially associated with disease development and progression.'},\n",
       "  {'pubmed': 24444383,\n",
       "   'text': 'MYC-dependent breast cancer cells possess high MYC expression and high level of MYC phosphorylation, but are not sensitive to inhibition of CDK2.'},\n",
       "  {'pubmed': 24520316,\n",
       "   'text': 'CRIF1 may play a regulatory role in the BM microenvironment-induced leukemia cell cycle arrest possibly through interacting with CDK2 and acting as a cyclin-dependent kinase inhibitor.'},\n",
       "  {'pubmed': 24623419,\n",
       "   'text': 'Authors identified and validated two additional host proteins interacting with human SAMHD1, namely, cyclin-dependent kinase 2 (CDK2) and S-phase kinase-associated protein 2 (SKP2).'},\n",
       "  {'pubmed': 24671051,\n",
       "   'text': 'Expression of Notch1, -2, and -3, CDK2, and CCNE1 was significantly decreased by upregulation of ALDH1A1 in A549 cells, but increased by its interruption in A549s cells.'},\n",
       "  {'pubmed': 24700371,\n",
       "   'text': 'In the subsequent molecular experiments, western blot analysis and kinase activity detection demonstrated that TAMs can significantly boost the expression levels and activities of CDK2 and CDK4 in SKOV3 cells.'},\n",
       "  {'pubmed': 24820417,\n",
       "   'text': 'Results show that CDK2 phosphorylates Thr-156 in GATA3.'},\n",
       "  {'pubmed': 24911186,\n",
       "   'text': 'Report structure-based discovery of allosteric inhibitors of CDK2.'},\n",
       "  {'pubmed': 24922574,\n",
       "   'text': 'CDK2 Supports HIV-1 Reverse Transcription in CD4+ T Cells.HIV-1 reverse transcriptase Is a Substrate for CDK2-Dependent Phosphorylation'},\n",
       "  {'pubmed': 24935000,\n",
       "   'text': 'It is concluded that non-response to everolimus is characterized by increased cdk2/cyclin A, driving RCC cells into the G2/M-phase. VPA hinders everolimus non-response by diminishing cdk2/cyclin A.'},\n",
       "  {'pubmed': 24947816,\n",
       "   'text': 'More effective packing and interactions between CDK2 and LMW cyclin E isoforms, however, produce more efficient protein-protein complexes that accelerate the cell division processes in cancer cells, where these cyclin E isoforms are overexpressed.'},\n",
       "  {'pubmed': 25015816,\n",
       "   'text': 'CDK2 was strongly linked to cell cycle progression and coordinated SAMHD1 phosphorylation and inactivation.'},\n",
       "  {'pubmed': 25071185,\n",
       "   'text': 'Cdk1 activity blocks lysosomal degradation of HIF-1alpha and increases HIF-1alpha protein stability and transcriptional activity. By contrast, Cdk2 activity promotes lysosomal degradation of HIF-1alpha at the G1/S phase transition.'},\n",
       "  {'pubmed': 25136960,\n",
       "   'text': 'A positive correlation between cdk2/cyclin A expression level and tumor growth. Amygdalin, therefore, may block tumor growth.'},\n",
       "  {'pubmed': 25149358,\n",
       "   'text': 'for both oncogene- and DNA damage-induced cellular senescence, CDK2 transcript and protein are decreased in a p53- and RB-dependent manner, and this repression is necessary for cell-cycle exit during senescence'},\n",
       "  {'pubmed': 25154617,\n",
       "   'text': 'Which is mutated at the CDK2 phosphorylation site.'},\n",
       "  {'pubmed': 25218592,\n",
       "   'text': 'The Cell Cycle Profiling - Risk Score (C2P-RS) based on CDK1 and CDK2 specific activities was significantly associated with relapse in breast cancers.'},\n",
       "  {'pubmed': 25218637,\n",
       "   'text': 'Data indicate that tumour suppressor RASSF1A triggers large tumor suppressor kinase 1 (LATS)-CDK2 interaction and restricts CDK2 kinase activity towards BRCA2.'},\n",
       "  {'pubmed': 25220500,\n",
       "   'text': 'Cyclin A2 and its associated kinase (CDK2) activity are required for optimal induction of progesterone receptor target genes in breast cancer cells.'},\n",
       "  {'pubmed': 25265349,\n",
       "   'text': 'High CDK2 expression is associated with nasopharyngeal carcinoma.'},\n",
       "  {'pubmed': 25271736,\n",
       "   'text': 'observations suggested that androgen suppresses the proliferation of CRPC cells partially through inhibition of Cyclin A, Cdk2, and Skp2'},\n",
       "  {'pubmed': 25303791,\n",
       "   'text': 'TPPII, MYBBP1A and CDK2 form a protein-protein interaction network.'},\n",
       "  {'pubmed': 25410660,\n",
       "   'text': 'Inhibition of CDK2 phosphorylation blocked phosphorylation of hnRNP K, preventing its incorporation into stress granules (SGs). Due to interaction between hnRNP K with TDP-43, the loss of hnRNP K from SGs prevented accumulation of TDP-43.'},\n",
       "  {'pubmed': 25443276,\n",
       "   'text': 'At a median follow-up of 36 months (1-109M), tumor with low CDK2SA-CDK1SA ratio showed significantly better 5-year recurrence-free survival than those with high CDK2SA-CDK1SA ratio (88.7% vs. 54.7%, P = 0.00141).'},\n",
       "  {'pubmed': 25451924,\n",
       "   'text': 'miR-638 regulates proliferation and myeloid differentiation by targeting CDK2 and may serve as a novel target for leukemia therapy or marker for AML diagnosis and prognosis'},\n",
       "  {'pubmed': 25463638,\n",
       "   'text': 'No association of CDK2 polymorphisms with risk of endometrial carcinoma found in Chinese Han women.'},\n",
       "  {'pubmed': 25501982,\n",
       "   'text': 'HOXA7 promotes cell proliferation, and these changes are mediated by cyclin E1/CDK2'},\n",
       "  {'pubmed': 25541464,\n",
       "   'text': 'Using the fact that deletion of the yeast CDC28 gene is functionally complemented by human CDK1 or CDK2, we set up an in vivo screen system to evaluate the inhibitory potency of purine derivatives against these two human Cdks.'},\n",
       "  {'pubmed': 25728284,\n",
       "   'text': 'CDK2 up-regulates the protein level of KLF10 through reducing its association with SIAH1, a KLF10 E3-ubiqutin ligase involved in proteasomal degradation.'},\n",
       "  {'pubmed': 25744732,\n",
       "   'text': 'Diclofenac and curcumin overcome these carcinogenic effects by downregulating telomerase activity, diminishing the expression of TERT, CDK4, CDK2, cyclin D1, and cyclin E.'},\n",
       "  {'pubmed': 25754137,\n",
       "   'text': 'The docking and molecular dynamics investigation performed here led to the identification of the interactions responsible for stabilizing the ligand ChEMBL474807 at the active sites of the glycogen synthase kinase-3beta (GSK-3) and cyclin-dependent kinase-2'},\n",
       "  {'pubmed': 25808870,\n",
       "   'text': 'CP110 plays a mechanistic role in response of lung cancer cells to CDK2 inhibition, especially in the presence of activated KRAS mutations.'},\n",
       "  {'pubmed': 25832654,\n",
       "   'text': 'NUAK2 silencing and inactivation of the PI3K pathway efficiently controlled CDK2 expression, whereas CDK2 inactivation specifically abrogated the growth of NUAK2-amplified and PTEN-deficient melanoma cells.'},\n",
       "  {'pubmed': 25860957,\n",
       "   'text': 'Identified ING5 as a novel CDK2 substrate. ING5 is phosphorylated at a single site, threonine 152, by cyclin E/CDK2 and cyclin A/CDK2. This site is also phosphorylated in cells in a cell cycle dependent manner, consistent with it being a CDK2 substrate.'},\n",
       "  {'pubmed': 25918937,\n",
       "   'text': 'analysis of the conformational characteristics and ligand binding mechanisms of CDK2 [review]'},\n",
       "  {'pubmed': 26026083,\n",
       "   'text': 'G1 arrest induced by SB265610 occurred at concentrations lacking CXCR2 selectivity and revealed cyclin-dependent kinase 2 (CDK2) (Thr160) hypophosphorylation, cyclin D3 gene down-regulation, and p21 post-translational induction'},\n",
       "  {'pubmed': 26028036,\n",
       "   'text': 'our study reveals a novel function of CDK2 in EGF-induced cell transformation and the associated signal transduction pathways. This indicates that CDK2 is a useful molecular target for the chemoprevention and therapy against skin cancer.'},\n",
       "  {'pubmed': 26124340,\n",
       "   'text': 'We found no significant associations for CDKN2 p16 580 C>T and MDM2 SNP309 T>G variants between cases and controls.'},\n",
       "  {'pubmed': 26139602,\n",
       "   'text': 'Sox2 phosphorylation by Cdk2 promotes the establishment but not the maintenance of the pluripotent state.'},\n",
       "  {'pubmed': 26147897,\n",
       "   'text': 'fluspirilene is a potential CDK2 inhibitor and a candidate anti-cancer drug for the treatment of human hepatocellular carcinoma.'},\n",
       "  {'pubmed': 26151768,\n",
       "   'text': 'In G28 cells, a dosedependent induction of CDK2, p21 and cyclin D was observed between 10 and 50 microM roscovitine after 72 h, however, at the highest concentration of 100 microM, all investigated genes were downregulated.'},\n",
       "  {'pubmed': 26204491,\n",
       "   'text': 'ovary tumors with elevated CCNE1 expression may be staged for Cdk2-targeted therapy'},\n",
       "  {'pubmed': 26248649,\n",
       "   'text': 'Results show that miR-200c plays an antioncogenic role in clear cell renal cell carcinomas, through controlling cell growth and cell-cycle progression by downregulating the G1-S regulator CDK2.'},\n",
       "  {'pubmed': 26297806,\n",
       "   'text': 'Centriolar satellites build a centrosomal microcephaly protein complex critical for human neurodevelopment that promotes CDK2 centrosomal localization and centriole duplication.'},\n",
       "  {'pubmed': 26304236,\n",
       "   'text': 'show thata combining cyclin-dependent kinase 2 (CDK2) antagonism and ubiquitin thioesterase 33 (USP33) depletion augments anaphase catastrophe via changes in centrosomal protein of 110 kDa (CP110) protein expression.'},\n",
       "  {'pubmed': 26373553,\n",
       "   'text': 'PIWIL2 has a role in promoting progression of non-small cell lung cancer by inducing CDK2 and Cyclin A expression'},\n",
       "  {'pubmed': 26464264,\n",
       "   'text': 'the results suggest that CK1delta activity can be modulated by the interplay between CK1delta and CDK2/E or CDK5/p35.'},\n",
       "  {'pubmed': 26555773,\n",
       "   'text': 'both cell lines feature a significant reduction of CDK2 expression verified at the RNA and protein level, respectively'},\n",
       "  {'pubmed': 26595527,\n",
       "   'text': 'Inappropriate activation of CDK2 in S phase underlies the sensitivity of a subset of cell lines to Chk1 inhibitors.'},\n",
       "  {'pubmed': 26644182,\n",
       "   'text': 'PHD1 is phosphorylated by CDK2, CDK4 and CDK6 at Serine 130.'},\n",
       "  {'pubmed': 26652902,\n",
       "   'text': 'CDK2 and DNA-PK regulate PR transcriptional activity by distinct mechanisms.'},\n",
       "  {'pubmed': 26677902,\n",
       "   'text': 'Clioquinol suppressed cell cycle progression in the S-phase in SMMC-7721 hepatoma cells via the p21, p27-cyclin E,A/Cdk2 pathway.'},\n",
       "  {'pubmed': 26714749,\n",
       "   'text': 'SATB2 regulates the mitosis of cell cycle and affects G1 cell cycle via interaction with CDK2.'},\n",
       "  {'pubmed': 26730572,\n",
       "   'text': 'A novel link has been discussed between CDK2 expression and cell migration by characterizing the CDK2-mediated phosphorylation of BRMS1.'},\n",
       "  {'pubmed': 26828990,\n",
       "   'text': 'The expression of cdk2 in malignancy of ovarian tumors.'},\n",
       "  {'pubmed': 26857166,\n",
       "   'text': 'CDK2 controls a wide-spread epigenetic program that drives transcription at differentiation-related gene promoters specifically in G1. (Review)'},\n",
       "  {'pubmed': 26861625,\n",
       "   'text': 'Foxo3 circular RNA retards cell cycle progression via forming ternary complexes with p21 and CDK2.'},\n",
       "  {'pubmed': 26876672,\n",
       "   'text': 'CDK2 protects podocytes from apoptosis and reduced expression of CDK2 associates with the development of diabetic nephropathy.'},\n",
       "  {'pubmed': 26890070,\n",
       "   'text': 'Consistent with these findings, a genome-scale pooled RNA interference screen revealed that toxic doses of MK-1775 are suppressed by CDK2 or Cyclin A2 knockdown. These findings support G2 exit as the more significant effect of Wee1 inhibition in pancreatic cancers.'},\n",
       "  {'pubmed': 26960431,\n",
       "   'text': 'Study describes a positive feedback loop centred on cyclin A2-Cdk2 inhibition of interphase APC/C-Cdc20 to allow further cyclin A2 accumulation and mitotic entry.'},\n",
       "  {'pubmed': 27065328,\n",
       "   'text': 'Here, we found that centrosomal protein of 76 kDa (Cep76), previously shown to restrain centriole amplification, interacts with cyclin-dependent kinase 2 (CDK2) and is a bona fide substrate of this kinase. Cep76 is preferentially phosphorylated by cyclin A/CDK2 at a single site S83, and this event is crucial to suppress centriole amplification in S phase'},\n",
       "  {'pubmed': 27100206,\n",
       "   'text': 'These two states are separated by different metastable states that share hybrid structural features with both forms of the kinase. In contrast, the CDK2/ANS complex landscape is compatible with a conformational selection picture where the binding of ANS in proximity of the alphaC helix causes a population shift toward the inactive conformation'},\n",
       "  {'pubmed': 27109354,\n",
       "   'text': 'evidence that CDK1/2 participate in the regulation of constitutive pre-mRNA splicing by EGF stimulation in MDA-MB-468 cells.'},\n",
       "  {'pubmed': 27163259,\n",
       "   'text': 'a SUMO-deficient Rb mutant results in reduced SUMOylation and phosphorylation, weakened CDK2 binding, and attenuated E2F-1 sequestration.'},\n",
       "  {'pubmed': 27166195,\n",
       "   'text': 'Data show that Noxa-mediated MCL-1 phosphorylation and degradation is regulated by CDK2.'},\n",
       "  {'pubmed': 27259234,\n",
       "   'text': \"Findings suggest that ERK1/2-mediated Cdk2/cyclin A signaling pathway is involved in 7-hydroxy-5,4'-dimethoxy-2-arylbenzofuran (Ary) - induced G1/S-phase arrest.\"},\n",
       "  {'pubmed': 27285764,\n",
       "   'text': 'WHSC1L1 and H3K36me2 are enriched in the gene bodies of the cell cycle-related genes CDC6 and CDK2, implying that WHSC1L1 directly regulates the transcription of these gene'},\n",
       "  {'pubmed': 27378523,\n",
       "   'text': 'this study suggests that CDK2 and CDK9 are potential therapeutic targets in Neuroblastoma (NB) and that abrogating CDK2 and CDK9 activity by small molecules like dinaciclib is a promising strategy and a treatment option for NB patients'},\n",
       "  {'pubmed': 27402161,\n",
       "   'text': 'periodic phosphorylation of Ku70 by cyclin-cyclin dependent kinases prevents the interaction of Ku with replication origin after initiation events in S-phase.'},\n",
       "  {'pubmed': 27465546,\n",
       "   'text': 'The upregulation of miR-302b reduced the expression of CDK2, and inhibited ERK signaling pathway, thereby inhibiting cell proliferation and G1/S phase conversion rate.'},\n",
       "  {'pubmed': 27629878,\n",
       "   'text': 'Dsg2 knockdown arrests non-small cell lung cancer cell cycle progression via modulation of p27-CDK2 levels.'},\n",
       "  {'pubmed': 27663592,\n",
       "   'text': 'Analysis of genomic data from TCGA demonstrated coamplification of CCNE1 and AKT2 Overexpression of Cyclin E1 and AKT isoforms, in addition to mutant TP53, imparted malignant characteristics in untransformed fallopian tube secretory cells, the dominant site of origin of high-grade serous ovarian cancer'},\n",
       "  {'pubmed': 27819669,\n",
       "   'text': 'Here, we introduce a transcriptional signature to specifically track CDK2 activity. It responds to genetic and chemical perturbations in the CDK-RB-E2F axis, correlates with mitotic rate in vitro and in vivo and reacts rapidly to changes in CDK2 activity during cell cycle progression'},\n",
       "  {'pubmed': 27831832,\n",
       "   'text': 'The data presented here suggest that the temporal separation of pro- and anti-apoptotic pathways by selective inhibition of CDK2 disrupts coherent signaling modules and may synergize with anti-proliferative drugs, averting toxic side effects from CDK1 inhibition.'},\n",
       "  {'pubmed': 28003546,\n",
       "   'text': 'CDK2 phosphorylates polyQ-AR specifically at Ser(96). Phosphorylation of polyQ-AR by CDK2 increased protein stabilization and toxicity and is negatively regulated by the adenylyl cyclase/protein kinase A signaling pathway in spinobulbar muscular atrophy.'},\n",
       "  {'pubmed': 28030798,\n",
       "   'text': 'Date show that when Wee1 alone is inhibited, Chk1 suppresses CDC45 loading and thereby limits the extent of unscheduled replication initiation and subsequent S-phase DNA damage, despite very high CDK-activity.'},\n",
       "  {'pubmed': 28100774,\n",
       "   'text': 'CDK2 serves as an important nexus linking primary beta-cell dysfunction to progressive beta-cell mass deterioration in diabetes'},\n",
       "  {'pubmed': 28345297,\n",
       "   'text': 'Residual Cdk1/Cdk2 activity after DNA damage promotes cell senescence.'},\n",
       "  {'pubmed': 28350121,\n",
       "   'text': 'Results show that cyclin E1 and CDK2 participate in STC1 promoting cell proliferation of prostate neoplasm cells.'},\n",
       "  {'pubmed': 28430399,\n",
       "   'text': 'These compounds bind CDK2/ Cyclin A, inhibit its kinase activity, compete with substrate binding, but not with ATP, and dock onto the T-loop of CDK2. The best compound also binds CDK4 and CDK4/Cyclin D1, but not CDK1.'},\n",
       "  {'pubmed': 28666995,\n",
       "   'text': 'The authors find that Spy1 confers structural changes to Cdk2 that obviate the requirement of Cdk activation loop phosphorylation.'},\n",
       "  {'pubmed': 28760857,\n",
       "   'text': 'High CDK2 expression is associated with breast cancer.'},\n",
       "  {'pubmed': 28842430,\n",
       "   'text': 'identified a new phosphorylation-based substrate recognition mechanism of PTPN12 by CDK2, which orchestrated signaling crosstalk between the oncogenic CDK2 and HER2 pathways'},\n",
       "  {'pubmed': 29157894,\n",
       "   'text': 'CDK2 contributes to S81-AR phosphorylation and transactivation while CDK4 was not shown to be involved in this process.'},\n",
       "  {'pubmed': 29203878,\n",
       "   'text': 'ATM and CDK2 control the chromatin remodeling activity of CSB in the regulation of double strand break repair pathway choice.'},\n",
       "  {'pubmed': 29254517,\n",
       "   'text': 'The authors show that human Cyclin-Dependent-Kinases (CDKs) target the RAD9 subunit of the 9-1-1 checkpoint clamp on Thr292, to modulate DNA damage checkpoint activation. Thr292 phosphorylation on RAD9 creates a binding site for Polo-Like-Kinase1 (PLK1), which phosphorylates RAD9 on Thr313.'},\n",
       "  {'pubmed': 29323532,\n",
       "   'text': 'Among these genes, STAT3 and CDK2 were significantly associated with recurrence. Further study suggested that inhibition of CDK2 reduced invasion of Pca cell lines. The invasion ability was rescued after reintroduction of CDK2.'},\n",
       "  {'pubmed': 29328425,\n",
       "   'text': 'CDK2 may have key functions in neuroblastoma progression by regulating the expression of neoplastic genes.'},\n",
       "  {'pubmed': 29372687,\n",
       "   'text': 'Our findings provide a rationale for clinical use of Bcl-2 family inhibitors in combination with CDK2 inhibitors for treatment of Mcl-1-dependent colorectal tumours associated with expression of Bcl-2, Bcl-XL and Bcl-w proteins. In addition, we have shown potential of CDK2 inhibitors for treatment of tumours expressing R273H mutant p53.'},\n",
       "  {'pubmed': 29507054,\n",
       "   'text': 'Proteomics and phosphoproteomics analyses identified CDK2 as a driver of resistance to both BRAF and Hsp90 inhibitors and its expression is regulated by the transcription factor MITF upon XL888 treatment of melanoma cells.'},\n",
       "  {'pubmed': 29570358,\n",
       "   'text': 'LINC00958 acts as an oncogenic gene in the gliomagenesis through miR-203-CDK2 regulation, providing a novel insight into glioma tumorigenesis.'},\n",
       "  {'pubmed': 29896817,\n",
       "   'text': 'The roles of the CDK2/SIRT5 axis in gastric cancer.'},\n",
       "  {'pubmed': 30300385,\n",
       "   'text': 'CDK2 gene is a strong candidate gene for type-2 diabetes. CDK2 gene is located in a risk area composed of 4 blocks in strong LD around the type-2 diabetes SNP rs2069408. CDK2 overexpression inhibits the association of insulin receptor to the microtubule components, tubulin alpha and tubulin beta. Physical association of the insulin receptor complex with CDK2 is inhibited by the expression of tyrosine phosphatase PTPLAD1.'}],\n",
       " 'genomic_pos': {'chr': '12',\n",
       "  'end': 55972784,\n",
       "  'ensemblgene': 'ENSG00000123374',\n",
       "  'start': 55966769,\n",
       "  'strand': 1},\n",
       " 'genomic_pos_hg19': {'chr': '12',\n",
       "  'end': 56366568,\n",
       "  'start': 56360553,\n",
       "  'strand': 1},\n",
       " 'go': {'BP': [{'evidence': 'IBA',\n",
       "    'gocategory': 'BP',\n",
       "    'id': 'GO:0000082',\n",
       "    'pubmed': 21873635,\n",
       "    'term': 'G1/S transition of mitotic cell cycle'},\n",
       "   {'evidence': 'TAS',\n",
       "    'gocategory': 'BP',\n",
       "    'id': 'GO:0000082',\n",
       "    'term': 'G1/S transition of mitotic cell cycle'},\n",
       "   {'evidence': 'NAS',\n",
       "    'gocategory': 'BP',\n",
       "    'id': 'GO:0000086',\n",
       "    'pubmed': 1653904,\n",
       "    'term': 'G2/M transition of mitotic cell cycle'},\n",
       "   {'evidence': 'TAS',\n",
       "    'gocategory': 'BP',\n",
       "    'id': 'GO:0000086',\n",
       "    'term': 'G2/M transition of mitotic cell cycle'},\n",
       "   {'evidence': 'IEA',\n",
       "    'gocategory': 'BP',\n",
       "    'id': 'GO:0000122',\n",
       "    'term': 'negative regulation of transcription by RNA polymerase II'},\n",
       "   {'evidence': 'TAS',\n",
       "    'gocategory': 'BP',\n",
       "    'id': 'GO:0006260',\n",
       "    'pubmed': 19238148,\n",
       "    'term': 'DNA replication'},\n",
       "   {'evidence': 'IEA',\n",
       "    'gocategory': 'BP',\n",
       "    'id': 'GO:0006281',\n",
       "    'term': 'DNA repair'},\n",
       "   {'evidence': 'IBA',\n",
       "    'gocategory': 'BP',\n",
       "    'id': 'GO:0006468',\n",
       "    'pubmed': 21873635,\n",
       "    'term': 'protein phosphorylation'},\n",
       "   {'evidence': 'IDA',\n",
       "    'gocategory': 'BP',\n",
       "    'id': 'GO:0006468',\n",
       "    'pubmed': [12944431, 28666995],\n",
       "    'term': 'protein phosphorylation'},\n",
       "   {'evidence': 'IEA',\n",
       "    'gocategory': 'BP',\n",
       "    'id': 'GO:0006813',\n",
       "    'term': 'potassium ion transport'},\n",
       "   {'evidence': 'TAS',\n",
       "    'gocategory': 'BP',\n",
       "    'id': 'GO:0006977',\n",
       "    'term': 'DNA damage response, signal transduction by p53 class mediator resulting in cell cycle arrest'},\n",
       "   {'evidence': 'IMP',\n",
       "    'gocategory': 'BP',\n",
       "    'id': 'GO:0007099',\n",
       "    'pubmed': 26297806,\n",
       "    'term': 'centriole replication'},\n",
       "   {'evidence': 'IEP',\n",
       "    'gocategory': 'BP',\n",
       "    'id': 'GO:0007265',\n",
       "    'pubmed': 9054499,\n",
       "    'term': 'Ras protein signal transduction'},\n",
       "   {'evidence': 'IBA',\n",
       "    'gocategory': 'BP',\n",
       "    'id': 'GO:0008284',\n",
       "    'pubmed': 21873635,\n",
       "    'term': 'positive regulation of cell proliferation'},\n",
       "   {'evidence': 'IDA',\n",
       "    'gocategory': 'BP',\n",
       "    'id': 'GO:0008284',\n",
       "    'pubmed': 10767298,\n",
       "    'term': 'positive regulation of cell proliferation'},\n",
       "   {'evidence': 'IBA',\n",
       "    'gocategory': 'BP',\n",
       "    'id': 'GO:0010389',\n",
       "    'pubmed': 21873635,\n",
       "    'term': 'regulation of G2/M transition of mitotic cell cycle'},\n",
       "   {'evidence': 'IDA',\n",
       "    'gocategory': 'BP',\n",
       "    'id': 'GO:0016572',\n",
       "    'pubmed': 11746698,\n",
       "    'term': 'histone phosphorylation'},\n",
       "   {'evidence': 'IDA',\n",
       "    'gocategory': 'BP',\n",
       "    'id': 'GO:0018105',\n",
       "    'pubmed': 23184662,\n",
       "    'term': 'peptidyl-serine phosphorylation'},\n",
       "   {'evidence': 'TAS',\n",
       "    'gocategory': 'BP',\n",
       "    'id': 'GO:0031145',\n",
       "    'term': 'anaphase-promoting complex-dependent catabolic process'},\n",
       "   {'evidence': 'TAS',\n",
       "    'gocategory': 'BP',\n",
       "    'id': 'GO:0031571',\n",
       "    'pubmed': 21319273,\n",
       "    'term': 'mitotic G1 DNA damage checkpoint'},\n",
       "   {'evidence': 'IEA',\n",
       "    'gocategory': 'BP',\n",
       "    'id': 'GO:0032298',\n",
       "    'term': 'positive regulation of DNA-dependent DNA replication initiation'},\n",
       "   {'evidence': 'IEA',\n",
       "    'gocategory': 'BP',\n",
       "    'id': 'GO:0045893',\n",
       "    'term': 'positive regulation of transcription, DNA-templated'},\n",
       "   {'evidence': 'TAS',\n",
       "    'gocategory': 'BP',\n",
       "    'id': 'GO:0051298',\n",
       "    'pubmed': 19238148,\n",
       "    'term': 'centrosome duplication'},\n",
       "   {'evidence': 'IEA',\n",
       "    'gocategory': 'BP',\n",
       "    'id': 'GO:0051301',\n",
       "    'term': 'cell division'},\n",
       "   {'evidence': 'TAS',\n",
       "    'gocategory': 'BP',\n",
       "    'id': 'GO:0051321',\n",
       "    'pubmed': 19238148,\n",
       "    'term': 'meiotic cell cycle'},\n",
       "   {'evidence': 'IDA',\n",
       "    'gocategory': 'BP',\n",
       "    'id': 'GO:0060968',\n",
       "    'pubmed': 20935635,\n",
       "    'term': 'regulation of gene silencing'},\n",
       "   {'evidence': 'TAS',\n",
       "    'gocategory': 'BP',\n",
       "    'id': 'GO:0071732',\n",
       "    'pubmed': 20079829,\n",
       "    'term': 'cellular response to nitric oxide'},\n",
       "   {'evidence': 'TAS',\n",
       "    'gocategory': 'BP',\n",
       "    'id': 'GO:1901796',\n",
       "    'term': 'regulation of signal transduction by p53 class mediator'}],\n",
       "  'CC': [{'evidence': 'IBA',\n",
       "    'gocategory': 'CC',\n",
       "    'id': 'GO:0000307',\n",
       "    'pubmed': 21873635,\n",
       "    'term': 'cyclin-dependent protein kinase holoenzyme complex'},\n",
       "   {'evidence': 'IDA',\n",
       "    'gocategory': 'CC',\n",
       "    'id': 'GO:0000307',\n",
       "    'pubmed': [1312467, 8692841],\n",
       "    'term': 'cyclin-dependent protein kinase holoenzyme complex'},\n",
       "   {'evidence': 'IEA',\n",
       "    'gocategory': 'CC',\n",
       "    'id': 'GO:0000781',\n",
       "    'term': 'chromosome, telomeric region'},\n",
       "   {'evidence': 'IEA',\n",
       "    'gocategory': 'CC',\n",
       "    'id': 'GO:0000793',\n",
       "    'term': 'condensed chromosome'},\n",
       "   {'evidence': 'IEA',\n",
       "    'gocategory': 'CC',\n",
       "    'id': 'GO:0000805',\n",
       "    'term': 'X chromosome'},\n",
       "   {'evidence': 'IEA',\n",
       "    'gocategory': 'CC',\n",
       "    'id': 'GO:0000806',\n",
       "    'term': 'Y chromosome'},\n",
       "   {'evidence': 'IBA',\n",
       "    'gocategory': 'CC',\n",
       "    'id': 'GO:0005634',\n",
       "    'pubmed': 21873635,\n",
       "    'term': 'nucleus'},\n",
       "   {'evidence': 'IDA',\n",
       "    'gocategory': 'CC',\n",
       "    'id': 'GO:0005634',\n",
       "    'pubmed': 10767298,\n",
       "    'term': 'nucleus'},\n",
       "   {'evidence': 'IDA',\n",
       "    'gocategory': 'CC',\n",
       "    'id': 'GO:0005654',\n",
       "    'pubmed': 8245034,\n",
       "    'term': 'nucleoplasm'},\n",
       "   {'evidence': 'TAS',\n",
       "    'gocategory': 'CC',\n",
       "    'id': 'GO:0005654',\n",
       "    'term': 'nucleoplasm'},\n",
       "   {'evidence': 'IEA',\n",
       "    'gocategory': 'CC',\n",
       "    'id': 'GO:0005667',\n",
       "    'term': 'transcription factor complex'},\n",
       "   {'evidence': 'IBA',\n",
       "    'gocategory': 'CC',\n",
       "    'id': 'GO:0005737',\n",
       "    'pubmed': 21873635,\n",
       "    'term': 'cytoplasm'},\n",
       "   {'evidence': 'IDA',\n",
       "    'gocategory': 'CC',\n",
       "    'id': 'GO:0005737',\n",
       "    'pubmed': 10767298,\n",
       "    'term': 'cytoplasm'},\n",
       "   {'evidence': 'IDA',\n",
       "    'gocategory': 'CC',\n",
       "    'id': 'GO:0005768',\n",
       "    'pubmed': 21262353,\n",
       "    'term': 'endosome'},\n",
       "   {'evidence': 'IDA',\n",
       "    'gocategory': 'CC',\n",
       "    'id': 'GO:0005813',\n",
       "    'term': 'centrosome'},\n",
       "   {'evidence': 'TAS',\n",
       "    'gocategory': 'CC',\n",
       "    'id': 'GO:0005813',\n",
       "    'pubmed': 19238148,\n",
       "    'term': 'centrosome'},\n",
       "   {'evidence': 'TAS',\n",
       "    'gocategory': 'CC',\n",
       "    'id': 'GO:0005829',\n",
       "    'term': 'cytosol'},\n",
       "   {'evidence': 'IDA',\n",
       "    'gocategory': 'CC',\n",
       "    'id': 'GO:0015030',\n",
       "    'pubmed': 10995387,\n",
       "    'term': 'Cajal body'},\n",
       "   {'evidence': 'IEA',\n",
       "    'gocategory': 'CC',\n",
       "    'id': 'GO:0097123',\n",
       "    'term': 'cyclin A1-CDK2 complex'},\n",
       "   {'evidence': 'IDA',\n",
       "    'gocategory': 'CC',\n",
       "    'id': 'GO:0097124',\n",
       "    'pubmed': [1312467, 8876165, 11746698, 15024385],\n",
       "    'term': 'cyclin A2-CDK2 complex'},\n",
       "   {'evidence': 'IEA',\n",
       "    'gocategory': 'CC',\n",
       "    'id': 'GO:0097134',\n",
       "    'term': 'cyclin E1-CDK2 complex'},\n",
       "   {'evidence': 'IEA',\n",
       "    'gocategory': 'CC',\n",
       "    'id': 'GO:0097135',\n",
       "    'term': 'cyclin E2-CDK2 complex'}],\n",
       "  'MF': [{'category': 'MF',\n",
       "    'evidence': 'IEA',\n",
       "    'id': 'GO:0000287',\n",
       "    'term': 'magnesium ion binding'},\n",
       "   {'category': 'MF',\n",
       "    'evidence': 'IGI',\n",
       "    'id': 'GO:0004674',\n",
       "    'pubmed': 26996940,\n",
       "    'term': 'protein serine/threonine kinase activity'},\n",
       "   {'category': 'MF',\n",
       "    'evidence': 'IBA',\n",
       "    'id': 'GO:0004693',\n",
       "    'pubmed': 21873635,\n",
       "    'term': 'cyclin-dependent protein serine/threonine kinase activity'},\n",
       "   {'category': 'MF',\n",
       "    'evidence': 'IDA',\n",
       "    'id': 'GO:0004693',\n",
       "    'pubmed': 21596315,\n",
       "    'term': 'cyclin-dependent protein serine/threonine kinase activity'},\n",
       "   {'category': 'MF',\n",
       "    'evidence': 'TAS',\n",
       "    'id': 'GO:0004693',\n",
       "    'term': 'cyclin-dependent protein serine/threonine kinase activity'},\n",
       "   {'category': 'MF',\n",
       "    'evidence': 'IPI',\n",
       "    'id': 'GO:0005515',\n",
       "    'pubmed': [2227411,\n",
       "     7630397,\n",
       "     8242750,\n",
       "     8521818,\n",
       "     8601310,\n",
       "     8684460,\n",
       "     8756328,\n",
       "     8756624,\n",
       "     9840943,\n",
       "     10330164,\n",
       "     11463386,\n",
       "     11980914,\n",
       "     12244298,\n",
       "     12361598,\n",
       "     12839962,\n",
       "     12941338,\n",
       "     15107404,\n",
       "     15178429,\n",
       "     15189033,\n",
       "     15232106,\n",
       "     15239650,\n",
       "     15530371,\n",
       "     15611625,\n",
       "     15890360,\n",
       "     16061792,\n",
       "     16209941,\n",
       "     16326706,\n",
       "     16327805,\n",
       "     16765349,\n",
       "     16962592,\n",
       "     17053782,\n",
       "     17254966,\n",
       "     17254967,\n",
       "     17418410,\n",
       "     19150984,\n",
       "     19470470,\n",
       "     19829063,\n",
       "     20098747,\n",
       "     20871633,\n",
       "     21092281,\n",
       "     21423803,\n",
       "     21565702,\n",
       "     21596315,\n",
       "     21952639,\n",
       "     22810586,\n",
       "     22940584,\n",
       "     23082202,\n",
       "     23455922,\n",
       "     23602568,\n",
       "     23781148,\n",
       "     23853094,\n",
       "     24218572,\n",
       "     24358021,\n",
       "     25218637,\n",
       "     25241761,\n",
       "     25416956,\n",
       "     25852190,\n",
       "     26496610,\n",
       "     28666995],\n",
       "    'term': 'protein binding'},\n",
       "   {'category': 'MF',\n",
       "    'evidence': 'IEA',\n",
       "    'id': 'GO:0005524',\n",
       "    'term': 'ATP binding'},\n",
       "   {'category': 'MF',\n",
       "    'evidence': 'IPI',\n",
       "    'id': 'GO:0019904',\n",
       "    'pubmed': [8876165, 15024385],\n",
       "    'term': 'protein domain specific binding'},\n",
       "   {'category': 'MF',\n",
       "    'evidence': 'IBA',\n",
       "    'id': 'GO:0030332',\n",
       "    'pubmed': 21873635,\n",
       "    'term': 'cyclin binding'},\n",
       "   {'category': 'MF',\n",
       "    'evidence': 'IDA',\n",
       "    'id': 'GO:0030332',\n",
       "    'pubmed': [1653904, 23781148],\n",
       "    'term': 'cyclin binding'},\n",
       "   {'category': 'MF',\n",
       "    'evidence': 'IPI',\n",
       "    'id': 'GO:0030332',\n",
       "    'pubmed': [1312467, 15024385],\n",
       "    'term': 'cyclin binding'},\n",
       "   {'category': 'MF',\n",
       "    'evidence': 'IDA',\n",
       "    'id': 'GO:0035173',\n",
       "    'pubmed': 8692841,\n",
       "    'qualifier': 'contributes_to',\n",
       "    'term': 'histone kinase activity'},\n",
       "   {'category': 'MF',\n",
       "    'evidence': 'IDA',\n",
       "    'id': 'GO:0097472',\n",
       "    'pubmed': [1312467, 28666995],\n",
       "    'term': 'cyclin-dependent protein kinase activity'}]},\n",
       " 'homologene': {'genes': [[3702, 824036],\n",
       "   [4530, 4328135],\n",
       "   [4530, 4331415],\n",
       "   [4896, 2539869],\n",
       "   [4932, 852457],\n",
       "   [5141, 3876264],\n",
       "   [7165, 3291042],\n",
       "   [7227, 42453],\n",
       "   [7955, 406715],\n",
       "   [8364, 493498],\n",
       "   [9031, 100529062],\n",
       "   [9544, 711002],\n",
       "   [9598, 467032],\n",
       "   [9606, 1017],\n",
       "   [9615, 100855704],\n",
       "   [9913, 519217],\n",
       "   [10090, 12566],\n",
       "   [10116, 362817],\n",
       "   [28985, 2896999],\n",
       "   [33169, 4620303],\n",
       "   [318829, 2679140]],\n",
       "  'id': 74409},\n",
       " 'interpro': [{'desc': 'Protein kinase domain',\n",
       "   'id': 'IPR000719',\n",
       "   'short_desc': 'Prot_kinase_dom'},\n",
       "  {'desc': 'Serine/threonine-protein kinase, active site',\n",
       "   'id': 'IPR008271',\n",
       "   'short_desc': 'Ser/Thr_kinase_AS'},\n",
       "  {'desc': 'Protein kinase-like domain superfamily',\n",
       "   'id': 'IPR011009',\n",
       "   'short_desc': 'Kinase-like_dom_sf'},\n",
       "  {'desc': 'Protein kinase, ATP binding site',\n",
       "   'id': 'IPR017441',\n",
       "   'short_desc': 'Protein_kinase_ATP_BS'}],\n",
       " 'ipi': ['IPI00031681', 'IPI00910650'],\n",
       " 'map_location': '12q13.2',\n",
       " 'name': 'cyclin dependent kinase 2',\n",
       " 'other_names': ['cdc2-related protein kinase',\n",
       "  'cell division protein kinase 2',\n",
       "  'cyclin-dependent kinase 2',\n",
       "  'p33 protein kinase'],\n",
       " 'pantherdb': {'HGNC': '1771',\n",
       "  'ortholog': [{'MGI': '104772',\n",
       "    'ortholog_type': 'LDO',\n",
       "    'panther_family': 'PTHR24056',\n",
       "    'taxid': 10090,\n",
       "    'uniprot_kb': 'P97377'},\n",
       "   {'RGD': '70486',\n",
       "    'ortholog_type': 'LDO',\n",
       "    'panther_family': 'PTHR24056',\n",
       "    'taxid': 10116,\n",
       "    'uniprot_kb': 'Q63699'},\n",
       "   {'Ensembl': 'ENSGALG00000032699',\n",
       "    'ortholog_type': 'LDO',\n",
       "    'panther_family': 'PTHR24056',\n",
       "    'taxid': 9031,\n",
       "    'uniprot_kb': 'A0A1D5PUK9'},\n",
       "   {'ZFIN': 'ZDB-GENE-040426-2741',\n",
       "    'ortholog_type': 'LDO',\n",
       "    'panther_family': 'PTHR24056',\n",
       "    'taxid': 7955,\n",
       "    'uniprot_kb': 'Q7ZWB1'},\n",
       "   {'FlyBase': 'FBgn0004107',\n",
       "    'ortholog_type': 'LDO',\n",
       "    'panther_family': 'PTHR24056',\n",
       "    'taxid': 7227,\n",
       "    'uniprot_kb': 'P23573'},\n",
       "   {'SGD': 'S000000364',\n",
       "    'ortholog_type': 'LDO',\n",
       "    'panther_family': 'PTHR24056',\n",
       "    'taxid': 4932,\n",
       "    'uniprot_kb': 'P00546'},\n",
       "   {'PomBase': 'SPBC11B10.09',\n",
       "    'ortholog_type': 'LDO',\n",
       "    'panther_family': 'PTHR24056',\n",
       "    'taxid': 4896,\n",
       "    'uniprot_kb': 'P04551'},\n",
       "   {'dictyBase': 'DDB_G0272813',\n",
       "    'ortholog_type': 'LDO',\n",
       "    'panther_family': 'PTHR24056',\n",
       "    'taxid': 352472,\n",
       "    'uniprot_kb': 'P34112'},\n",
       "   {'TAIR': 'AT3G48750',\n",
       "    'ortholog_type': 'LDO',\n",
       "    'panther_family': 'PTHR24056',\n",
       "    'taxid': 3702,\n",
       "    'uniprot_kb': 'P24100'},\n",
       "   {'HGNC': '1779',\n",
       "    'ortholog_type': 'P',\n",
       "    'panther_family': 'PTHR24056',\n",
       "    'taxid': 9606,\n",
       "    'uniprot_kb': 'P49336'},\n",
       "   {'HGNC': '19338',\n",
       "    'ortholog_type': 'P',\n",
       "    'panther_family': 'PTHR24056',\n",
       "    'taxid': 9606,\n",
       "    'uniprot_kb': 'Q9BWU1'},\n",
       "   {'HGNC': '1778',\n",
       "    'ortholog_type': 'P',\n",
       "    'panther_family': 'PTHR24056',\n",
       "    'taxid': 9606,\n",
       "    'uniprot_kb': 'P50613'},\n",
       "   {'HGNC': '14434',\n",
       "    'ortholog_type': 'P',\n",
       "    'panther_family': 'PTHR24056',\n",
       "    'taxid': 9606,\n",
       "    'uniprot_kb': 'Q96Q40'},\n",
       "   {'HGNC': '8883',\n",
       "    'ortholog_type': 'P',\n",
       "    'panther_family': 'PTHR24056',\n",
       "    'taxid': 9606,\n",
       "    'uniprot_kb': 'O94921'},\n",
       "   {'HGNC': '8751',\n",
       "    'ortholog_type': 'P',\n",
       "    'panther_family': 'PTHR24056',\n",
       "    'taxid': 9606,\n",
       "    'uniprot_kb': 'Q07002'},\n",
       "   {'HGNC': '8749',\n",
       "    'ortholog_type': 'P',\n",
       "    'panther_family': 'PTHR24056',\n",
       "    'taxid': 9606,\n",
       "    'uniprot_kb': 'Q00536'},\n",
       "   {'HGNC': '8750',\n",
       "    'ortholog_type': 'P',\n",
       "    'panther_family': 'PTHR24056',\n",
       "    'taxid': 9606,\n",
       "    'uniprot_kb': 'Q00537'},\n",
       "   {'HGNC': '1774',\n",
       "    'ortholog_type': 'P',\n",
       "    'panther_family': 'PTHR24056',\n",
       "    'taxid': 9606,\n",
       "    'uniprot_kb': 'Q00535'},\n",
       "   {'HGNC': '1722',\n",
       "    'ortholog_type': 'P',\n",
       "    'panther_family': 'PTHR24056',\n",
       "    'taxid': 9606,\n",
       "    'uniprot_kb': 'P06493'},\n",
       "   {'HGNC': '17346',\n",
       "    'ortholog_type': 'P',\n",
       "    'panther_family': 'PTHR24056',\n",
       "    'taxid': 9606,\n",
       "    'uniprot_kb': 'Q13523'}],\n",
       "  'uniprot_kb': 'P24941'},\n",
       " 'pathway': {'biocarta': [{'id': 'cellcyclepathway',\n",
       "    'name': 'cyclins and cell cycle regulation'},\n",
       "   {'id': 'efppathway',\n",
       "    'name': 'estrogen responsive protein efp controls cell cycle and breast tumors growth'},\n",
       "   {'id': 'fbw7pathway', 'name': 'cyclin e destruction pathway'},\n",
       "   {'id': 'g1pathway', 'name': 'cell cycle: g1/s check point'},\n",
       "   {'id': 'mcmpathway', 'name': 'cdk regulation of dna replication'},\n",
       "   {'id': 'p27pathway',\n",
       "    'name': 'regulation of p27 phosphorylation during cell cycle progression'},\n",
       "   {'id': 'p53pathway', 'name': 'p53 signaling pathway'},\n",
       "   {'id': 'raccycdpathway',\n",
       "    'name': 'influence of ras and rho proteins on g1 to s transition'},\n",
       "   {'id': 'rbpathway',\n",
       "    'name': 'rb tumor suppressor/checkpoint signaling in response to dna damage'},\n",
       "   {'id': 'skp2e2fpathway', 'name': 'e2f1 destruction pathway'}],\n",
       "  'kegg': [{'id': 'hsa04068',\n",
       "    'name': 'FoxO signaling pathway - Homo sapiens (human)'},\n",
       "   {'id': 'hsa04110', 'name': 'Cell cycle - Homo sapiens (human)'},\n",
       "   {'id': 'hsa04114', 'name': 'Oocyte meiosis - Homo sapiens (human)'},\n",
       "   {'id': 'hsa04115', 'name': 'p53 signaling pathway - Homo sapiens (human)'},\n",
       "   {'id': 'hsa04151',\n",
       "    'name': 'PI3K-Akt signaling pathway - Homo sapiens (human)'},\n",
       "   {'id': 'hsa04218', 'name': 'Cellular senescence - Homo sapiens (human)'},\n",
       "   {'id': 'hsa04914',\n",
       "    'name': 'Progesterone-mediated oocyte maturation - Homo sapiens (human)'},\n",
       "   {'id': 'hsa04934', 'name': 'Cushing,s syndrome - Homo sapiens (human)'},\n",
       "   {'id': 'hsa05161', 'name': 'Hepatitis B - Homo sapiens (human)'},\n",
       "   {'id': 'hsa05162', 'name': 'Measles - Homo sapiens (human)'},\n",
       "   {'id': 'hsa05165',\n",
       "    'name': 'Human papillomavirus infection - Homo sapiens (human)'},\n",
       "   {'id': 'hsa05168',\n",
       "    'name': 'Herpes simplex infection - Homo sapiens (human)'},\n",
       "   {'id': 'hsa05169',\n",
       "    'name': 'Epstein-Barr virus infection - Homo sapiens (human)'},\n",
       "   {'id': 'hsa05200', 'name': 'Pathways in cancer - Homo sapiens (human)'},\n",
       "   {'id': 'hsa05203', 'name': 'Viral carcinogenesis - Homo sapiens (human)'},\n",
       "   {'id': 'hsa05215', 'name': 'Prostate cancer - Homo sapiens (human)'},\n",
       "   {'id': 'hsa05222', 'name': 'Small cell lung cancer - Homo sapiens (human)'},\n",
       "   {'id': 'hsa05226', 'name': 'Gastric cancer - Homo sapiens (human)'}],\n",
       "  'netpath': [{'id': 'Pathway_BCR', 'name': 'BCR'},\n",
       "   {'id': 'Pathway_EGFR1', 'name': 'EGFR1'},\n",
       "   {'id': 'Pathway_ID', 'name': 'ID'},\n",
       "   {'id': 'Pathway_IL2', 'name': 'IL2'},\n",
       "   {'id': 'Pathway_KitReceptor', 'name': 'KitReceptor'},\n",
       "   {'id': 'Pathway_RAGE', 'name': 'RAGE'},\n",
       "   {'id': 'Pathway_TGF_beta_Receptor', 'name': 'TGF_beta_Receptor'}],\n",
       "  'pid': [{'id': 'atr_pathway', 'name': 'ATR signaling pathway'},\n",
       "   {'id': 'bard1pathway', 'name': 'BARD1 signaling events'},\n",
       "   {'id': 'e2f_pathway', 'name': 'E2F transcription factor network'},\n",
       "   {'id': 'foxm1pathway', 'name': 'FOXM1 transcription factor network'},\n",
       "   {'id': 'foxopathway', 'name': 'FoxO family signaling'},\n",
       "   {'id': 'il2_1pathway', 'name': 'IL2-mediated signaling events'},\n",
       "   {'id': 'mtor_4pathway', 'name': 'mTOR signaling pathway'},\n",
       "   {'id': 'p53regulationpathway', 'name': 'p53 pathway'},\n",
       "   {'id': 'p73pathway', 'name': 'p73 transcription factor network'},\n",
       "   {'id': 'prlsignalingeventspathway',\n",
       "    'name': 'Signaling events mediated by PRL'},\n",
       "   {'id': 'rb_1pathway', 'name': 'Regulation of retinoblastoma protein'},\n",
       "   {'id': 'smad2_3nuclearpathway',\n",
       "    'name': 'Regulation of nuclear SMAD2/3 signaling'}],\n",
       "  'reactome': [{'id': 'R-HSA-109582', 'name': 'Hemostasis'},\n",
       "   {'id': 'R-HSA-1474165', 'name': 'Reproduction'},\n",
       "   {'id': 'R-HSA-1500620', 'name': 'Meiosis'},\n",
       "   {'id': 'R-HSA-1538133', 'name': 'G0 and Early G1'},\n",
       "   {'id': 'R-HSA-162582', 'name': 'Signal Transduction'},\n",
       "   {'id': 'R-HSA-1640170', 'name': 'Cell Cycle'},\n",
       "   {'id': 'R-HSA-1640170', 'name': 'Cell Cycle'},\n",
       "   {'id': 'R-HSA-174143',\n",
       "    'name': 'APC/C-mediated degradation of cell cycle proteins'},\n",
       "   {'id': 'R-HSA-176187',\n",
       "    'name': 'Activation of ATR in response to replication stress'},\n",
       "   {'id': 'R-HSA-176408',\n",
       "    'name': 'Regulation of APC/C activators between G1/S and early anaphase'},\n",
       "   {'id': 'R-HSA-187577', 'name': 'SCF(Skp2)-mediated degradation of p27/p21'},\n",
       "   {'id': 'R-HSA-212436', 'name': 'Generic Transcription Pathway'},\n",
       "   {'id': 'R-HSA-2262752', 'name': 'Cellular responses to stress'},\n",
       "   {'id': 'R-HSA-2559582',\n",
       "    'name': 'Senescence-Associated Secretory Phenotype (SASP)'},\n",
       "   {'id': 'R-HSA-2559583', 'name': 'Cellular Senescence'},\n",
       "   {'id': 'R-HSA-2559586',\n",
       "    'name': 'DNA Damage/Telomere Stress Induced Senescence'},\n",
       "   {'id': 'R-HSA-3700989', 'name': 'Transcriptional Regulation by TP53'},\n",
       "   {'id': 'R-HSA-453274', 'name': 'Mitotic G2-G2/M phases'},\n",
       "   {'id': 'R-HSA-453276', 'name': 'Regulation of mitotic cell cycle'},\n",
       "   {'id': 'R-HSA-453279', 'name': 'Mitotic G1-G1/S phases'},\n",
       "   {'id': 'R-HSA-5633007', 'name': 'Regulation of TP53 Activity'},\n",
       "   {'id': 'R-HSA-5693532', 'name': 'DNA Double-Strand Break Repair'},\n",
       "   {'id': 'R-HSA-5693538', 'name': 'Homology Directed Repair'},\n",
       "   {'id': 'R-HSA-5693567',\n",
       "    'name': 'HDR through Homologous Recombination (HRR) or Single Strand Annealing (SSA)'},\n",
       "   {'id': 'R-HSA-5693607',\n",
       "    'name': 'Processing of DNA double-strand break ends'},\n",
       "   {'id': 'R-HSA-6791312',\n",
       "    'name': 'TP53 Regulates Transcription of Cell Cycle Genes'},\n",
       "   {'id': 'R-HSA-6804116',\n",
       "    'name': 'TP53 Regulates Transcription of Genes Involved in G1 Cell Cycle Arrest'},\n",
       "   {'id': 'R-HSA-6804756',\n",
       "    'name': 'Regulation of TP53 Activity through Phosphorylation'},\n",
       "   {'id': 'R-HSA-6804757', 'name': 'Regulation of TP53 Degradation'},\n",
       "   {'id': 'R-HSA-6806003',\n",
       "    'name': 'Regulation of TP53 Expression and Degradation'},\n",
       "   {'id': 'R-HSA-68911', 'name': 'G2 Phase'},\n",
       "   {'id': 'R-HSA-68949', 'name': 'Orc1 removal from chromatin'},\n",
       "   {'id': 'R-HSA-68962', 'name': 'Activation of the pre-replicative complex'},\n",
       "   {'id': 'R-HSA-69002', 'name': 'DNA Replication Pre-Initiation'},\n",
       "   {'id': 'R-HSA-69017',\n",
       "    'name': 'CDK-mediated phosphorylation and removal of Cdc6'},\n",
       "   {'id': 'R-HSA-69052',\n",
       "    'name': 'Switching of origins to a post-replicative state'},\n",
       "   {'id': 'R-HSA-69200',\n",
       "    'name': 'Phosphorylation of proteins involved in G1/S transition by active Cyclin E:Cdk2 complexes'},\n",
       "   {'id': 'R-HSA-69202',\n",
       "    'name': 'Cyclin E associated events during G1/S transition '},\n",
       "   {'id': 'R-HSA-69206', 'name': 'G1/S Transition'},\n",
       "   {'id': 'R-HSA-69239', 'name': 'Synthesis of DNA'},\n",
       "   {'id': 'R-HSA-69242', 'name': 'S Phase'},\n",
       "   {'id': 'R-HSA-69273',\n",
       "    'name': 'Cyclin A/B1/B2 associated events during G2/M transition'},\n",
       "   {'id': 'R-HSA-69275', 'name': 'G2/M Transition'},\n",
       "   {'id': 'R-HSA-69278', 'name': 'Cell Cycle, Mitotic'},\n",
       "   {'id': 'R-HSA-69306', 'name': 'DNA Replication'},\n",
       "   {'id': 'R-HSA-69481', 'name': 'G2/M Checkpoints'},\n",
       "   {'id': 'R-HSA-69563', 'name': 'p53-Dependent G1 DNA Damage Response'},\n",
       "   {'id': 'R-HSA-69580', 'name': 'p53-Dependent G1/S DNA damage checkpoint'},\n",
       "   {'id': 'R-HSA-69615', 'name': 'G1/S DNA Damage Checkpoints'},\n",
       "   {'id': 'R-HSA-69620', 'name': 'Cell Cycle Checkpoints'},\n",
       "   {'id': 'R-HSA-69656',\n",
       "    'name': 'Cyclin A:Cdk2-associated events at S phase entry'},\n",
       "   {'id': 'R-HSA-73857', 'name': 'RNA Polymerase II Transcription'},\n",
       "   {'id': 'R-HSA-73894', 'name': 'DNA Repair'},\n",
       "   {'id': 'R-HSA-74160', 'name': 'Gene expression (Transcription)'},\n",
       "   {'id': 'R-HSA-8848021', 'name': 'Signaling by PTK6'},\n",
       "   {'id': 'R-HSA-8849470', 'name': 'PTK6 Regulates Cell Cycle'},\n",
       "   {'id': 'R-HSA-8953897', 'name': 'Cellular responses to external stimuli'},\n",
       "   {'id': 'R-HSA-9006927',\n",
       "    'name': 'Signaling by Non-Receptor Tyrosine Kinases'},\n",
       "   {'id': 'R-HSA-912446', 'name': 'Meiotic recombination'},\n",
       "   {'id': 'R-HSA-983231',\n",
       "    'name': 'Factors involved in megakaryocyte development and platelet production'}],\n",
       "  'wikipathways': [{'id': 'WP1530',\n",
       "    'name': 'miRNA Regulation of DNA Damage Response'},\n",
       "   {'id': 'WP179', 'name': 'Cell Cycle'},\n",
       "   {'id': 'WP2032',\n",
       "    'name': 'Human Thyroid Stimulating Hormone (TSH) signaling pathway'},\n",
       "   {'id': 'WP2261', 'name': 'Signaling Pathways in Glioblastoma'},\n",
       "   {'id': 'WP2374', 'name': 'Oncostatin M Signaling Pathway'},\n",
       "   {'id': 'WP2431', 'name': 'Spinal Cord Injury'},\n",
       "   {'id': 'WP2446', 'name': 'Retinoblastoma (RB) in Cancer'},\n",
       "   {'id': 'WP2586', 'name': 'Aryl Hydrocarbon Receptor'},\n",
       "   {'id': 'WP2877', 'name': 'Vitamin D Receptor Pathway'},\n",
       "   {'id': 'WP4172', 'name': 'PI3K-Akt Signaling Pathway'},\n",
       "   {'id': 'WP45', 'name': 'G1 to S cell cycle control'},\n",
       "   {'id': 'WP466', 'name': 'DNA Replication'},\n",
       "   {'id': 'WP53', 'name': 'ID signaling pathway'},\n",
       "   {'id': 'WP707', 'name': 'DNA Damage Response'}]},\n",
       " 'pdb': ['1AQ1',\n",
       "  '1B38',\n",
       "  '1B39',\n",
       "  '1BUH',\n",
       "  '1CKP',\n",
       "  '1DI8',\n",
       "  '1DM2',\n",
       "  '1E1V',\n",
       "  '1E1X',\n",
       "  '1E9H',\n",
       "  '1F5Q',\n",
       "  '1FIN',\n",
       "  '1FQ1',\n",
       "  '1FVT',\n",
       "  '1FVV',\n",
       "  '1G5S',\n",
       "  '1GIH',\n",
       "  '1GII',\n",
       "  '1GIJ',\n",
       "  '1GY3',\n",
       "  '1GZ8',\n",
       "  '1H00',\n",
       "  '1H01',\n",
       "  '1H07',\n",
       "  '1H08',\n",
       "  '1H0V',\n",
       "  '1H0W',\n",
       "  '1H1P',\n",
       "  '1H1Q',\n",
       "  '1H1R',\n",
       "  '1H1S',\n",
       "  '1H24',\n",
       "  '1H25',\n",
       "  '1H26',\n",
       "  '1H27',\n",
       "  '1H28',\n",
       "  '1HCK',\n",
       "  '1HCL',\n",
       "  '1JST',\n",
       "  '1JSU',\n",
       "  '1JSV',\n",
       "  '1JVP',\n",
       "  '1KE5',\n",
       "  '1KE6',\n",
       "  '1KE7',\n",
       "  '1KE8',\n",
       "  '1KE9',\n",
       "  '1OGU',\n",
       "  '1OI9',\n",
       "  '1OIQ',\n",
       "  '1OIR',\n",
       "  '1OIT',\n",
       "  '1OIU',\n",
       "  '1OIY',\n",
       "  '1OKV',\n",
       "  '1OKW',\n",
       "  '1OL1',\n",
       "  '1OL2',\n",
       "  '1P2A',\n",
       "  '1P5E',\n",
       "  '1PF8',\n",
       "  '1PKD',\n",
       "  '1PW2',\n",
       "  '1PXI',\n",
       "  '1PXJ',\n",
       "  '1PXK',\n",
       "  '1PXL',\n",
       "  '1PXM',\n",
       "  '1PXN',\n",
       "  '1PXO',\n",
       "  '1PXP',\n",
       "  '1PYE',\n",
       "  '1QMZ',\n",
       "  '1R78',\n",
       "  '1URC',\n",
       "  '1URW',\n",
       "  '1V1K',\n",
       "  '1VYW',\n",
       "  '1VYZ',\n",
       "  '1W0X',\n",
       "  '1W8C',\n",
       "  '1W98',\n",
       "  '1WCC',\n",
       "  '1Y8Y',\n",
       "  '1Y91',\n",
       "  '1YKR',\n",
       "  '2A0C',\n",
       "  '2A4L',\n",
       "  '2B52',\n",
       "  '2B53',\n",
       "  '2B54',\n",
       "  '2B55',\n",
       "  '2BHE',\n",
       "  '2BHH',\n",
       "  '2BKZ',\n",
       "  '2BPM',\n",
       "  '2BTR',\n",
       "  '2BTS',\n",
       "  '2C4G',\n",
       "  '2C5N',\n",
       "  '2C5O',\n",
       "  '2C5V',\n",
       "  '2C5X',\n",
       "  '2C5Y',\n",
       "  '2C68',\n",
       "  '2C69',\n",
       "  '2C6I',\n",
       "  '2C6K',\n",
       "  '2C6L',\n",
       "  '2C6M',\n",
       "  '2C6O',\n",
       "  '2C6T',\n",
       "  '2CCH',\n",
       "  '2CCI',\n",
       "  '2CJM',\n",
       "  '2CLX',\n",
       "  '2DS1',\n",
       "  '2DUV',\n",
       "  '2EXM',\n",
       "  '2FVD',\n",
       "  '2G9X',\n",
       "  '2HIC',\n",
       "  '2I40',\n",
       "  '2IW6',\n",
       "  '2IW8',\n",
       "  '2IW9',\n",
       "  '2J9M',\n",
       "  '2JGZ',\n",
       "  '2R3F',\n",
       "  '2R3G',\n",
       "  '2R3H',\n",
       "  '2R3I',\n",
       "  '2R3J',\n",
       "  '2R3K',\n",
       "  '2R3L',\n",
       "  '2R3M',\n",
       "  '2R3N',\n",
       "  '2R3O',\n",
       "  '2R3P',\n",
       "  '2R3Q',\n",
       "  '2R3R',\n",
       "  '2R64',\n",
       "  '2UUE',\n",
       "  '2UZB',\n",
       "  '2UZD',\n",
       "  '2UZE',\n",
       "  '2UZL',\n",
       "  '2UZN',\n",
       "  '2UZO',\n",
       "  '2V0D',\n",
       "  '2V22',\n",
       "  '2VTA',\n",
       "  '2VTH',\n",
       "  '2VTI',\n",
       "  '2VTJ',\n",
       "  '2VTL',\n",
       "  '2VTM',\n",
       "  '2VTN',\n",
       "  '2VTO',\n",
       "  '2VTP',\n",
       "  '2VTQ',\n",
       "  '2VTR',\n",
       "  '2VTS',\n",
       "  '2VTT',\n",
       "  '2VU3',\n",
       "  '2VV9',\n",
       "  '2W05',\n",
       "  '2W06',\n",
       "  '2W17',\n",
       "  '2W1H',\n",
       "  '2WEV',\n",
       "  '2WFY',\n",
       "  '2WHB',\n",
       "  '2WIH',\n",
       "  '2WIP',\n",
       "  '2WMA',\n",
       "  '2WMB',\n",
       "  '2WPA',\n",
       "  '2WXV',\n",
       "  '2X1N',\n",
       "  '2XMY',\n",
       "  '2XNB',\n",
       "  '3BHT',\n",
       "  '3BHU',\n",
       "  '3BHV',\n",
       "  '3DDP',\n",
       "  '3DDQ',\n",
       "  '3DOG',\n",
       "  '3EID',\n",
       "  '3EJ1',\n",
       "  '3EOC',\n",
       "  '3EZR',\n",
       "  '3EZV',\n",
       "  '3F5X',\n",
       "  '3FZ1',\n",
       "  '3IG7',\n",
       "  '3IGG',\n",
       "  '3LE6',\n",
       "  '3LFN',\n",
       "  '3LFQ',\n",
       "  '3LFS',\n",
       "  '3MY5',\n",
       "  '3NS9',\n",
       "  '3PJ8',\n",
       "  '3PXF',\n",
       "  '3PXQ',\n",
       "  '3PXR',\n",
       "  '3PXY',\n",
       "  '3PXZ',\n",
       "  '3PY0',\n",
       "  '3PY1',\n",
       "  '3QHR',\n",
       "  '3QHW',\n",
       "  '3QL8',\n",
       "  '3QQF',\n",
       "  '3QQG',\n",
       "  '3QQH',\n",
       "  '3QQJ',\n",
       "  '3QQK',\n",
       "  '3QQL',\n",
       "  '3QRT',\n",
       "  '3QRU',\n",
       "  '3QTQ',\n",
       "  '3QTR',\n",
       "  '3QTS',\n",
       "  '3QTU',\n",
       "  '3QTW',\n",
       "  '3QTX',\n",
       "  '3QTZ',\n",
       "  '3QU0',\n",
       "  '3QWJ',\n",
       "  '3QWK',\n",
       "  '3QX2',\n",
       "  '3QX4',\n",
       "  '3QXO',\n",
       "  '3QXP',\n",
       "  '3QZF',\n",
       "  '3QZG',\n",
       "  '3QZH',\n",
       "  '3QZI',\n",
       "  '3R1Q',\n",
       "  '3R1S',\n",
       "  '3R1Y',\n",
       "  '3R28',\n",
       "  '3R6X',\n",
       "  '3R71',\n",
       "  '3R73',\n",
       "  '3R7E',\n",
       "  '3R7I',\n",
       "  '3R7U',\n",
       "  '3R7V',\n",
       "  '3R7Y',\n",
       "  '3R83',\n",
       "  '3R8L',\n",
       "  '3R8M',\n",
       "  '3R8P',\n",
       "  '3R8U',\n",
       "  '3R8V',\n",
       "  '3R8Z',\n",
       "  '3R9D',\n",
       "  '3R9H',\n",
       "  '3R9N',\n",
       "  '3R9O',\n",
       "  '3RAH',\n",
       "  '3RAI',\n",
       "  '3RAK',\n",
       "  '3RAL',\n",
       "  '3RJC',\n",
       "  '3RK5',\n",
       "  '3RK7',\n",
       "  '3RK9',\n",
       "  '3RKB',\n",
       "  '3RM6',\n",
       "  '3RM7',\n",
       "  '3RMF',\n",
       "  '3RNI',\n",
       "  '3ROY',\n",
       "  '3RPO',\n",
       "  '3RPR',\n",
       "  '3RPV',\n",
       "  '3RPY',\n",
       "  '3RZB',\n",
       "  '3S00',\n",
       "  '3S0O',\n",
       "  '3S1H',\n",
       "  '3S2P',\n",
       "  '3SQQ',\n",
       "  '3SW4',\n",
       "  '3SW7',\n",
       "  '3TI1',\n",
       "  '3TIY',\n",
       "  '3TIZ',\n",
       "  '3TNW',\n",
       "  '3ULI',\n",
       "  '3UNJ',\n",
       "  '3UNK',\n",
       "  '3WBL',\n",
       "  '4ACM',\n",
       "  '4BCK',\n",
       "  '4BCM',\n",
       "  '4BCN',\n",
       "  '4BCO',\n",
       "  '4BCP',\n",
       "  '4BCQ',\n",
       "  '4BGH',\n",
       "  '4BZD',\n",
       "  '4CFM',\n",
       "  '4CFN',\n",
       "  '4CFU',\n",
       "  '4CFV',\n",
       "  '4CFW',\n",
       "  '4CFX',\n",
       "  '4D1X',\n",
       "  '4D1Z',\n",
       "  '4EK3',\n",
       "  '4EK4',\n",
       "  '4EK5',\n",
       "  '4EK6',\n",
       "  '4EK8',\n",
       "  '4EOI',\n",
       "  '4EOJ',\n",
       "  '4EOK',\n",
       "  '4EOL',\n",
       "  '4EOM',\n",
       "  '4EON',\n",
       "  '4EOO',\n",
       "  '4EOP',\n",
       "  '4EOQ',\n",
       "  '4EOR',\n",
       "  '4EOS',\n",
       "  '4ERW',\n",
       "  '4EZ3',\n",
       "  '4EZ7',\n",
       "  '4FKG',\n",
       "  '4FKI',\n",
       "  '4FKJ',\n",
       "  '4FKL',\n",
       "  '4FKO',\n",
       "  '4FKP',\n",
       "  '4FKQ',\n",
       "  '4FKR',\n",
       "  '4FKS',\n",
       "  '4FKT',\n",
       "  '4FKU',\n",
       "  '4FKV',\n",
       "  '4FKW',\n",
       "  '4FX3',\n",
       "  '4GCJ',\n",
       "  '4I3Z',\n",
       "  '4II5',\n",
       "  '4KD1',\n",
       "  '4LYN',\n",
       "  '4NJ3',\n",
       "  '4RJ3',\n",
       "  '5A14',\n",
       "  '5AND',\n",
       "  '5ANE',\n",
       "  '5ANG',\n",
       "  '5ANI',\n",
       "  '5ANJ',\n",
       "  '5ANK',\n",
       "  '5ANO',\n",
       "  '5CYI',\n",
       "  '5D1J',\n",
       "  '5FP5',\n",
       "  '5FP6',\n",
       "  '5IEV',\n",
       "  '5IEX',\n",
       "  '5IEY',\n",
       "  '5IF1',\n",
       "  '5JQ5',\n",
       "  '5JQ8',\n",
       "  '5K4J',\n",
       "  '5L2W',\n",
       "  '5LMK',\n",
       "  '5MHQ',\n",
       "  '5NEV',\n",
       "  '5OO0',\n",
       "  '5OO1',\n",
       "  '5OO3',\n",
       "  '5OSJ',\n",
       "  '5OSM',\n",
       "  '5UQ1',\n",
       "  '5UQ2',\n",
       "  '5UQ3'],\n",
       " 'pfam': 'PF00069',\n",
       " 'pharmgkb': 'PA101',\n",
       " 'pharos': {'target_id': 10687},\n",
       " 'pir': 'A41227',\n",
       " 'prosite': 'PS50011',\n",
       " 'reagent': {'GNF_Qia_hs-genome_v1_siRNA': [{'id': 'GNF247215',\n",
       "    'relationship': 'is'},\n",
       "   {'id': 'GNF247216', 'relationship': 'is'},\n",
       "   {'id': 'GNF247217', 'relationship': 'is'},\n",
       "   {'id': 'GNF247218', 'relationship': 'is'}],\n",
       "  'GNF_hs-ORFeome1_1_reads': {'id': 'GNF161504', 'relationship': 'is'},\n",
       "  'GNF_hs-Origene': [{'id': 'GNF035860', 'relationship': 'similar to'},\n",
       "   {'id': 'GNF037258', 'relationship': 'is'},\n",
       "   {'id': 'GNF048982', 'relationship': 'is'}],\n",
       "  'GNF_hs-druggable_lenti-shRNA': [{'id': 'GNF081385', 'relationship': 'is'},\n",
       "   {'id': 'GNF081386', 'relationship': 'is'},\n",
       "   {'id': 'GNF081387', 'relationship': 'is'}],\n",
       "  'GNF_hs-druggable_plasmid-shRNA': [{'id': 'GNF051995', 'relationship': 'is'},\n",
       "   {'id': 'GNF056761', 'relationship': 'is'},\n",
       "   {'id': 'GNF061563', 'relationship': 'is'},\n",
       "   {'id': 'GNF078683', 'relationship': 'is'}],\n",
       "  'GNF_hs-druggable_siRNA': [{'id': 'GNF066537', 'relationship': 'is'},\n",
       "   {'id': 'GNF066538', 'relationship': 'is'}],\n",
       "  'GNF_hs-pkinase_IDT-siRNA': [{'id': 'GNF166768', 'relationship': 'is'},\n",
       "   {'id': 'GNF166769', 'relationship': 'is'},\n",
       "   {'id': 'GNF166770', 'relationship': 'is'},\n",
       "   {'id': 'GNF166771', 'relationship': 'is'}],\n",
       "  'GNF_hs_LentiORF-HA-MYC': {'id': 'GNF282834', 'relationship': 'is'},\n",
       "  'GNF_hs_LentiORF-Jred': {'id': 'GNF283761', 'relationship': 'is'},\n",
       "  'GNF_mm+hs-MGC': {'id': 'GNF002384', 'relationship': 'is'},\n",
       "  'Invitrogen_IVTHSSIPKv2': [{'id': 'GNF324610', 'relationship': 'is'},\n",
       "   {'id': 'GNF324611', 'relationship': 'is'}],\n",
       "  'NIBRI_hs-Secretome_pDEST': {'id': 'GNF337962', 'relationship': 'is'},\n",
       "  'NOVART_hs-genome_siRNA': [{'id': 'GNF093028', 'relationship': 'is'},\n",
       "   {'id': 'GNF132726', 'relationship': 'is'}]},\n",
       " 'refseq': {'genomic': ['NC_000012.12', 'NG_034014.1'],\n",
       "  'protein': ['NP_001277159.1',\n",
       "   'NP_001789.2',\n",
       "   'NP_439892.2',\n",
       "   'XP_011536034.1'],\n",
       "  'rna': ['NM_001290230.1', 'NM_001798.4', 'NM_052827.3', 'XM_011537732.2'],\n",
       "  'translation': [{'protein': 'NP_001789.2', 'rna': 'NM_001798.4'},\n",
       "   {'protein': 'NP_001277159.1', 'rna': 'NM_001290230.1'},\n",
       "   {'protein': 'NP_439892.2', 'rna': 'NM_052827.3'},\n",
       "   {'protein': 'XP_011536034.1', 'rna': 'XM_011537732.2'}]},\n",
       " 'reporter': {'HG-U133_Plus_2': ['204252_at', '211803_at', '211804_s_at'],\n",
       "  'HG-U95Av2': ['1792_g_at', '1833_at'],\n",
       "  'HTA-2_0': 'TC12000496.hg.1',\n",
       "  'HuEx-1_0': '3417146',\n",
       "  'HuGene-1_1': '7956076',\n",
       "  'HuGene-2_1': '16752305'},\n",
       " 'summary': 'This gene encodes a member of a family of serine/threonine protein kinases that participate in cell cycle regulation. The encoded protein is the catalytic subunit of the cyclin-dependent protein kinase complex, which regulates progression through the cell cycle. Activity of this protein is especially critical during the G1 to S phase transition. This protein associates with and regulated by other subunits of the complex including cyclin A or E, CDK inhibitor p21Cip1 (CDKN1A), and p27Kip1 (CDKN1B). Alternative splicing results in multiple transcript variants. [provided by RefSeq, Mar 2014].',\n",
       " 'symbol': 'CDK2',\n",
       " 'taxid': 9606,\n",
       " 'type_of_gene': 'protein-coding',\n",
       " 'umls': {'cui': 'C1332733'},\n",
       " 'unigene': ['Hs.689624', 'Hs.19192'],\n",
       " 'uniprot': {'Swiss-Prot': 'P24941',\n",
       "  'TrEMBL': ['A0A024RB10',\n",
       "   'G3V5T9',\n",
       "   'E7ESI2',\n",
       "   'B4DDL9',\n",
       "   'A0A024RB77',\n",
       "   'G3V317']},\n",
       " 'wikipedia': {'url_stub': 'Cyclin-dependent kinase 2'}}"
      ]
     },
     "execution_count": 37,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "cdk2_info = gene_search('CDK2')\n",
    "cdk2_info"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 38,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/plain": [
       "{'pubmed': 17960421,\n",
       " 'text': 'Recombination and transcription analyses indicate that THO/TREX mutants share a moderate but significant effect on gene conversion and ectopic recombination, as well as transcription impairment of even short and low GC-content genes.'}"
      ]
     },
     "execution_count": 38,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "gene_info = gene_search('THP2')\n",
    "len(gene_info['generif'])\n",
    "gene_info['generif'][0]"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 39,
   "metadata": {},
   "outputs": [],
   "source": [
    "def print_pubmeds(gene_name):\n",
    "    gene_info = gene_search(gene_name)\n",
    "    for reference in gene_info['generif']:\n",
    "        print('https://www.ncbi.nlm.nih.gov/pubmed/' + str(reference['pubmed']))\n",
    "        print(reference['text'])\n"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 40,
   "metadata": {},
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "https://www.ncbi.nlm.nih.gov/pubmed/19151352\n",
      "peptides are 36 amino acids long including a highly conserved region with 6 invariant cysteines forming the 3 disulfide bonds characteristic of defensins\n"
     ]
    }
   ],
   "source": [
    "print_pubmeds('THP2')"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 41,
   "metadata": {},
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "https://www.ncbi.nlm.nih.gov/pubmed/8621729\n",
      "MEK1 interacts with B-Raf.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/12068308\n",
      "somatic missense mutations in 66% of malignant melanomas and at lower frequency in a wide range of human cancers\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/12198537\n",
      "BRAF mutations in colorectal cancers occur only in tumours that do not carry mutations in a RAS gene known as KRAS, and BRAF mutation is linked to the proficiency of these tumours in repairing mismatched bases in DNA\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/12447372\n",
      "High frequency of BRAF mutations in nevi\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/12619120\n",
      "The V599E BRAF mutation appears to be a somatic mutation associated with melanoma development and/or progression in a proportion of affected individuals.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/12644542\n",
      "results demonstrate that the mutational status of BRAF and KRAS is distinctly different among histologic types of ovarian serous carcinoma, occurring most frequently in invasive micropapillary serous carcinomas and its precursors, serous borderline tumors\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/12670889\n",
      "High prevalence of BRAF mutations in thyroid cancer is genetic evidence for constitutive activation of the RET/PTC-RAS-BRAF signaling pathway in papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/12697856\n",
      "activating BRAF mutations may be an important event in the development of papillary thyroid cancer\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/12753285\n",
      "cAMP activates ERK and increases proliferation of autosomal dominant polycystic kindey epithelial cells through the sequential phosphorylation of PKA, B-Raf and MAPK in a pathway separate from the classical receptor tyrosine kinase cascade\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/12778069\n",
      "gene is mutated in skin melanoma, but not in uveal melanomas\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/12810628\n",
      "13 germline BRAF variants, 4 of which were silent mutations in coding regions & 9 nucleotide substitutions in introns, were found in melanoma patients and melanoma family, but none appeared statistically likely to be a melanoma susceptibility gene.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/12821662\n",
      "B-raf is involved in adhesion-independent ERK1/2 signaling in melanocytes\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/12824225\n",
      "Data suggest that BRAF T1796A activating mutation is not common in primary uveal melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/12855697\n",
      "B-Raf has a role in extracellular signal-regulated kinase (ERK) signaling in T cells and prevents antigen-presenting cell-induced anergy\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/12879021\n",
      "BRAF has a role in in squamous cell carcinoma of the head and neck through uncommon mutations\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/12881714\n",
      "The BRAF(V599E) mutation appears to be an alternative event to RET/PTC rearrangement rather than to RAS mutations, which are rare in PTC. BRAF(V599E) may represent an alternative pathway to oncogenic MAPK activation in PTCs without RET/PTC activation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/12893203\n",
      "Mucinous ovarian cancers without a KRAS mutation have not sustained alternative activation of this signaling pathway through mutation of the BRAF oncogene.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/12917419\n",
      "3 cell lines derived from human choroidal melanoma express B-Raf containing the V599E mutation and showed a 10-fold increase in endogenous B-RafV599E kinase activity and a constitutive activation of the MEK/ERK pathway that is independent of Ras\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/12931219\n",
      "Mutations are not detectable in plasma cell leukemia and multiple myeloma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/12970315\n",
      "mutation of BRAF gene could be a potentially useful marker of prognosis of patients with advanced thyroid cancers\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/14501284\n",
      "Our findings of a high frequency of BRAF mutations at codon 599 in benign melanocytic lesions of the skin indicate that this mutation is not sufficient by itself for malignant transformation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/14507635\n",
      "Both BRAF and FBXW7 mutations functionally activate kinase effectors important in pancreatic cancer and extend potential options for therapeutic targeting of kinases in treatment of phenotypically distinct pancreatic adenocarcinoma subsets.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/14513361\n",
      "BRAF mutations, which are present in a variety of other human cancers, do not seem to be involved in gastric cancer development\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/14522897\n",
      "Uceal melanomas arise independent of oncogenic BRAF and NRAS mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/14534542\n",
      "BRAF mutations were seen in stomach neoplasms.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/14602780\n",
      "BRAF mutations are restricted to papillary carcinomas and poorly differentiated and anaplastic carcinomas arising from papillary carcinomas\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/14612909\n",
      "BRAF is occasionally mutated in NHL, and BRAF mutation may contribute to tumor development in some NHLs\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/14618633\n",
      "None of the cases of gastric cancer showed braf mutations\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/14639609\n",
      "Mutations of BRAF are associated with extensive hMLH1 promoter methylation in sporadic colorectal carcinomas\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/14668801\n",
      "Missense mutation is marker of colonic but not gastric cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/14688025\n",
      "Mutations were found in exon 15 in colorectal adenocarcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/14691295\n",
      "Our data indicate that BRAF gene mutations are rare to absent events in uveal melanoma of humans.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/14695152\n",
      "NRAS and BRAF mutations arise early during melanoma pathogenesis and are preserved throughout tumor progression\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/14695993\n",
      "BRAF mutations are associated with proximal colon tumors with mismatch repair deficiency and MLH1 hypermethylation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/14719068\n",
      "New enriched PCR-RFLP assay for detecting mutations of BRAF codon 599 mutation in pleural mesotheliomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/14722037\n",
      "Observational study of genotype prevalence and gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/14724583\n",
      "RAS or BRAF mutations are detected in about 32% of all Barrett's adenocarcinomas; the disruption of the Raf/MEK/ERK (MAPK) kinase pathway is a frequent but also early event in the development of Barrett's adenocarcinoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/14734469\n",
      "BRAF mutations are frequently present in sporadic colorectal cancer with methylated hMLH1\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/14961576\n",
      "Mutations in BRAF gene is associated with malignant melanomas\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/14966563\n",
      "These studies identify isoprenylcysteine carboxyl methyltransferase as a potential target for reducing the growth of K-Ras- and B-Raf-induced malignancies.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15001635\n",
      "The lack or low prevalence of BRAF mutation in other thyroid neoplasms is consistent with the notion that other previously defined genetic alterations on the same signaling pathway are sufficient to cause tumorigenesis in most thyroid neoplasms.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15009714\n",
      "possible cooperation between BRAF activation and PTEN loss in melanoma development.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15009715\n",
      "mutations in the BRAF gene and to some extent in the N-ras gene represent early somatic events that occur in melanocytic nevi\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15014028\n",
      "BRAF mutation may be acquired during development of metastasis but is not a significant factor for primary melanoma development and disease outcome.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15077125\n",
      "ovarian serous cystadenomas do not contain mutations in either BRAF or KRAS genes\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15104286\n",
      "These results suggest that the BRAF mutation is unlikely to be involved in gastric carcinogenesis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15126572\n",
      "BRAF(V599E) is more common genetic alteration found to date in adult sporadic papillary thyroid carcinomas (PTCs). It is unique for this thyroid cancer histotype, and it might drive the development of PTCs of classic papillary subtype.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15140228\n",
      "The finding of tandem mutations in thin melanomas makes it more likely that they arise as a simultaneous rather than sequential event.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15145515\n",
      "Radiation-induced tumors have a low prevalence of BRAF point mutations and high prevalence of RET/PTC rearrangements\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15150271\n",
      "B-Raf kinase activity regulation by tuberin and Rheb is mammalian target of rapamycin (mTOR)-independent\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15161700\n",
      "mucosal melanomas of the head and neck do not frequently harbor an activating mutation of BRAF\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15179189\n",
      "in contrast to cutaneous melanoma, BRAF does not appear to be involved in the pathogenesis of uveal melanoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15186612\n",
      "BRAF mutations are rather rare in solitary cold adenomas and adenomatous nodules and do not explain the molecular etiology of ras mutation-negative cold thyroid nodules.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15191558\n",
      "activation of this gene may be one of the early events in the pathogenesis of some melanomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15263001\n",
      "B-Raf and ERK are activated by cyclic AMP after calcium restriction\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15273715\n",
      "mutated in papillary thyroid cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15277467\n",
      "In this study, this BRAF mutation was demonstrated in some conjunctival melanoma tissue samples, suggesting that some conjunctival melanomas may share biological features in common with cutaneous melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15313890\n",
      "Data suggest that SPRY2, an inhibitor of ERK signaling, may be bypassed in melanoma cells either by down-regulation of its expression in WT BRAF cells, or by the presence of the BRAF mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15330192\n",
      "Mutations within the BRAF gene are useful markers for the differential diagnosis between Spitz nevus and malignant melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15331929\n",
      "we found 19 cases (38%) to harbor somatic B-raf exon 15 mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15339934\n",
      "Data provide evidence that B-Raf is a positive regulator of T cell receptor-mediated sustained ERK activation, which is required for NFAT activation and the full production of IL-2.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15373778\n",
      "BRAF(V599E) mutation is seven times higher in lesions with structural changes and 13 times higher in growing lesions as compared with lesions without changes\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15488754\n",
      "REVIEW: our understanding of B-RAF as an oncogene and of its role in cancer\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15489648\n",
      "Mutations of BRAF or KRAS oncogenes are early events in the serrated polyp neoplasia pathway. CpG island methylation plays a role in serrated polyp progression to colorectal carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15538400\n",
      "mutated in childhood acute lymphoblastic leukemia.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15577314\n",
      "BRAF mutations are associated with conjunctival neoplasms\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15630448\n",
      "AKAP9-BRAF fusion was preferentially found in radiation-induced papillary carcinomas developing after a short latency, whereas BRAF point mutations were absent in this group\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15632082\n",
      "Data suggest that Rit is involved in a novel pathway of neuronal development and regeneration by coupling specific trophic factor signals to sustained activation of the B-Raf/ERK and p38 MAP kinase cascades.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15653554\n",
      "a novel Ras-independent ERK1/2 activation system in which p110gamma/Raf-1/MEK1/2 and PKA/B-Raf/MEK1/2 cooperate to activate ERK1/2.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15702478\n",
      "We found mutations in p53, K-ras, and BRAF genes in 35%, 30%, and 4% of tumors, respectively, and observed a minimal or no co-presence of these gene alterations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15705790\n",
      "KSHV-infected cell lines expressed higher levels of B-Raf and VEGF-A; B-Raf-induced VEGF-A expression was demonstrated to be sufficient to enhance tubule formation in endothelial cells\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15710605\n",
      "autoinhibition was negatively regulated by acidic substitutions at phosphorylation sites within the activation loop\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15765445\n",
      "Mutations in the BRAF protooncogene (V599E)may be an alternative pathway of tumorigenesis of familial colorectal cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15782118\n",
      "BRAF mutations proved to be absent in tumors from hereditary nonpolyposis colorectal cancer syndrome (HNPCC) families with germline mutations in the MMR genes MLH1 and MSH2.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15791479\n",
      "The data of this study suggest that activating mutations of B-RAF are not a frequent event in gliomas; nevertheless, when present they are associated with high-grade malignant lesions.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15791648\n",
      "B-raf mutations surrounding Thr439 found in human cancers are unlikely to contribute to increased oncogenic properties of B-raf\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15824163\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15842051\n",
      "These results suggest that BRAF mutations do not have a role in tumorigenesis of neuroendocrine gastroenteropancreatic tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15880523\n",
      "Anaplastic thyroid carcinomas which are derived from papillary carcinomas are due to BRAF and p53 mutations\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15904951\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15935100\n",
      "B-raf V599E and V599K oncogenic mutations are likely to affect melanocyte-specific pathways controlling proliferation and differentiation\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15968271\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15968271\n",
      "The increasing frequency of BRAF mutations as a function of age could help account for the well documented but poorly understood observation that age is a relevant prognostic indicator for patients with papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15980887\n",
      "BRAF mutation occurs later in thyroid tumor progression and is restricted mainly to papillary thyroid carcinoma and anaplastic thyroid carcinoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15994075\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15998781\n",
      "Role of BRAF mutation in facilitating metastasis and progression of papillary thyroid cancer in lymph nodes.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16007166\n",
      "determination of mutation specific gene expression profiles in papillary thyroid carcinoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16007203\n",
      "Single-cell clones with efficient knockdown of (V 600 E)B-RAF could be propagated in the presence of basic fibroblast growth factor but underwent apoptosis or senescence-like growth arrest upon withdrawal of this growth factor\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16015629\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16024606\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16079850\n",
      "sustained BRAF(V600E) expression in human melanocytes induces cell cycle arrest, which is accompanied by the induction of both p16(INK4a) and senescence-associated acidic beta-galactosidase (SA-beta-Gal) activity, a commonly used senescence marker\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16096377\n",
      "BRAF mutation in melanoma is most likely to occur prior to the development of metastatic disease\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16098042\n",
      "Although BRAF and NRAS mutations are likely to be important for the initiation and maintenance of some melanomas, other factors might be more significant for proliferation and prognosis in subgroups of aggressive melanoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16098042\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16123397\n",
      "The results showed that conjunctival nevi, similar to skin nevi, have a high frequency of oncogenic BRAF mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16129781\n",
      "These data suggest that MITF is an anti-proliferation factor that is down-regulated by B-RAF signaling and that this is a crucial event for the progression of melanomas that harbor oncogenic B-RAF.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16143028\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16144912\n",
      "Mutations of the BRAF gene are partly involved in the malignant transformation of the endometrium.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16144912\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16172610\n",
      "selective reduction in catalytic activity and expression of B-Raf but not Raf-1 suggest that B-Raf may be playing an important role in altered ERK signaling in brain of suicide subjects, and thus in the pathophysiology of suicide\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16174717\n",
      "In patients with papillary thyroid cancer, BRAF mutation is associated with poorer clinicopathological outcomes and independently predicts recurrence.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16174717\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16179867\n",
      "As the BRAF oncogene is frequently found to be mutated in human cutaneous melanomas, it may constitute a risk factor for melanoma formation within CMN and DMN.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16179870\n",
      "The oncogenic B-raf mutations V599E and V599K, as early events in melanocyte transformation, persist throughout metastasis with important prognostic implications.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16181240\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16181547\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16199894\n",
      "copy number gain may represent another mechanism of BRAF activation in thyroid tumors\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16268813\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16354196\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16354196\n",
      "The estimated proportion of attributable risk of melanoma due to variants in BRAF is 1.6%, but the burden of disease associated with this variant is greater than that associated with the major melanoma locus (CDKN2A) which has a risk of 0.2%.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16354586\n",
      "Mutation and elevated expression of BRAF is associated with the development of testicular germ cell tumors\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16361694\n",
      "The authors have developed and run a high-throughput screen to find inhibitors of V600E BRAF using an enzyme cascade assay in which oncogenic BRAF activates MEK1, which in turn activates ERK2, which then phosphorylates the transcription factor ELK1.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16364920\n",
      "Data suggest that B-RAF activates C-RAF through a mechanism involving 14-3-3 mediated heterooligomerization and C-RAF transphosphorylation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16371460\n",
      "V600E B-Raf requires the Hsp90 chaperone for stability and is degraded in response to Hsp90 inhibitors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16373964\n",
      "activating mutations of PDGFR-alpha, c-kit and B-RAF are absent in gliosarcomas\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16376942\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16376942\n",
      "V599E BRAF mutation was uncommon in Japanese lung cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16382052\n",
      "aberrant B-Raf activity in angiomyolipomas leads to abnormal cellular differentiation and migration [review]\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16397024\n",
      "Observational study of genotype prevalence. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16413100\n",
      "The most frequent B-RAF gene alterations are not involved in prostate carcinogenesis\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16417232\n",
      "BRAF mutation does not seem to be sufficient to produce MAPK activation in melanocytic nevi.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16424035\n",
      "gain-of-function BRAF signaling is strongly associated with in vivo tumorigenicity\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16439621\n",
      "findings demonstrate that heterogeneous de novo missense mutations in three genes within the mitogen-activated protein kinase pathway, BRAF, MEK1 and MEK2 cause cardio-facio-cutaneous syndrome\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16452469\n",
      "wild-type B-Raf-mediated ERK1/2 activation plays a major role in proliferation and transformation of uveal melanocytes; Raf-1 is not involved in this activation\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16452550\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16462768\n",
      "NRAS and BRAF activating mutations can coexist in the same melanoma, but are mutually exclusive at the single-cell level\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16474404\n",
      "Cardio-facio-cutaneous (CFC) syndrome involves dysregulation of the RAS-RAF-ERK pathway.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16487015\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16537381\n",
      "Merlin and MLK3 can interact in situ and merlin can disrupt the interactions between B-Raf and Raf-1 or those between MLK3 and either B-Raf or Raf-1.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16547495\n",
      "Melanoma cells require either B-RAF or phosphoinositide-3 kinase activation for protection from anoikis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16601293\n",
      "BRAF V600E is associated with a high risk of recurrence and less differentiated papillary thyroid carcinoma due to the impairment of Na+/I- targeting to the membrane\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16601293\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16618717\n",
      "Observational study of gene-environment interaction and pharmacogenomic / toxicogenomic. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16687919\n",
      "Observational study of genotype prevalence. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16691193\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16691193\n",
      "UV light is not necessarily required for the acquisition of the BRAF(V600E) mutation, and non-mutagenic effects of UV light to melanocytes may be more important in the nevogenesis\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16721785\n",
      "BRAF mutations are as uncommon as KRAS mutations in prostate adenocarcinoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16728573\n",
      "B-RAF (V600E) was confirmed to be associated with the papillary growth pattern, but not with poorer differentiated papillary thyroid carcinoma variants.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16728573\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16773193\n",
      "among 23 melanomas located at body sites with chronic UV exposure, only a single tumour harboured the B-raf V599E mutation which was a significantly lower frequency in comparison to melanomas from sun-protected body sites\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16786134\n",
      "a BRAFT1799A mutation may have a role in poor differentiation of thyroid carcinoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16799476\n",
      "A subset of Spitz nevi, some with atypical histologic features, possess BRAF mutations. The BRAF mutational status does not separate all Spitz nevi from spitzoid melanomas and non-Spitz types of melanocytic proliferations, contrary to previous reports.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16803888\n",
      "Rheb has a central role in the regulation of the Ras/B-Raf/C-Raf/MEK signaling network\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16804544\n",
      "CpG island methylator phenotype-positive colorectal tumors represent a distinct subset, encompassing almost all cases of tumors with BRAF mutation\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16809487\n",
      "findings show that MC1R variants are strongly associated with BRAF mutations in non-chronic sun-induced damage melanomas; in this subtype, risk for melanoma associated with MC1R is due to increase in risk of developing melanomas with BRAF mutations\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16845322\n",
      "BRAF mutation is associated with melanoma and melanocytic nevi.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16858395\n",
      "Thus, we propose that the hitherto unidentified function of the B-Raf amino-terminal region is to mediate calcium-dependent activation of B-Raf and the following MEK activation, which may occur in the absence of Ras activation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16858683\n",
      "Aberrant methylation and hence silencing of TIMP3, SLC5A8, DAPK and RARbeta2, in association with BRAF mutation, may be an important step in PTC tumorigenesis and progression.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16879389\n",
      "BRAF mutation was frequent in hyperplastic polyps (67%) and sessile serrated adenomas (81%).\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16912199\n",
      "B-RAF has been identified as the most mutated gene in invasive cells and therefore an attractive therapeutic target in melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16918136\n",
      "BRAF mutations are associated with colorectal cancers\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16918957\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16924241\n",
      "Expression of p27Kip1 in melanoma is regulated by B-RAF at the mRNA level and via B-RAF control of Cks1/Skp2-mediated proteolysis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16932278\n",
      "Single nucleotide polymorphism found exclusively in papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16937524\n",
      "BRAF, K-ras and BAT26 are expressed in colorectal polyps and stool\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16937524\n",
      "BRAF, K-ras and BAT26 are expressed in colorectal polyps and stool [BAT26]\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16946010\n",
      "Braf mutations in thyroid tumorigenesis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16953233\n",
      "Concomitant KRAS and BRAF mutations increased along progression of MSS colorectal cancer, suggesting that activation of both genes is likely to harbour a synergistic effect\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16959844\n",
      "BRAFV600E activates not only MAPK but also NF-kappaB signaling pathway in human thyroid cancer cells, leading to an acquisition of apoptotic resistance and promotion of invasion.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16960555\n",
      "Expression of active mutants of B-Raf induces fibronectin.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16964379\n",
      "Extracellular signal-regulated kinase-3 (ERK3/MAPK6) is highly expressed in response to BRAF signaling.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16973828\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16987295\n",
      "BRAF T1976A mutation is present at high frequency in benign naevi such as Spitz and Reed.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17001349\n",
      "data support a model in which mutational activation of BRAF in human melanomas contributes to constitutive induction of NF-kappaB activity and to increased survival of melanoma cells\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17018604\n",
      "Normally, BRAF alone is responsible for signaling to MEK. However, when RAS is mutated in melanoma, melanocytes switch their signaling from BRAF to CRAF.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17044028\n",
      "Activating BRAF mutation is associated with papillary thyroid carcinoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17060774\n",
      "BRAF mutation remained a significant prognostic factor for lymph node metastasis (odds ratio = 10.8, 95% confidence interval, 3.5-34.0, P < 0.0001).\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17074813\n",
      "phosphorylation on both S365 and S429 participate in the differential regulation of B-Raf isoforms through distinct mechanisms\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17097223\n",
      "data provide evidence that oncogenic properties of BRAF contribute to the tumorigenesis of intraductal papillary mucinous neoplasm/carcinoma (IPMN/IPMC), but at a lower frequency than KRAS\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17119056\n",
      "BRAF-V600E mutations are mainly involved in colorectal cancer families characterized by an increased risk of other common malignancies\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17119447\n",
      "Association with preexisting nevi and pronounced infiltration of lymphocytes was significantly higher in BRAF mutated melanoma tumours\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17148775\n",
      "Observational study of gene-disease association and gene-environment interaction. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17148775\n",
      "Previously identified associations between smoking and colon cancer, whether microsatellite unstable or stable, appear to be explained by the association of smoking with BRAF mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17159915\n",
      "BRAF(T1799A) mutation is associated with a lower rate of tumor proliferation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17159915\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17170014\n",
      "RASSF1A methylation was observed in a high frequency in endometrioid endometrial carcinoma whereas K-ras and B-raf mutations were observed in a low frequency\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17179987\n",
      "The role for BRAF activation in thyroid cancer development and establishing the potential therapeutic efficacy of BRAF-targeted agents in patients with thyroid cancerwill be reviewed.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17186541\n",
      "BRAF mutation is associated with thyroid carcinogenesis\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17186541\n",
      "Observational study of gene-disease association and gene-environment interaction. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17195912\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17195912\n",
      "there is a subgroup of colorectal carcinomas which develop via the microsatellite instability pathway that carry an alteration of the BRAF gene\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17199737\n",
      "Absence of association between BRAF mutation and activation of MAPK pathway in papillary thyroid carcinoma suggests the presence of mechanisms that downregulate MAPK activation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17227125\n",
      "Copy gain of PDGFB occurs in a subset of tumors showing no evidence of mutated BRAF or rearranged ret, suggesting that copy gain of PDGFB may underlie the increased expression of platelet-derived growth factor described recently in the literature.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17270239\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17297294\n",
      "characterization of the T1799-1801del and A1799-1816ins BRAF mutations in papillary thyroid cancer; the two new mutations resulted in constitutive activation of the BRAF kinase and caused NIH3T3 cell transformation\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17302867\n",
      "Overexpression of B-Raf mRNA and protein may be a feature of nonfunctioning pituitary adenomas, highlighting overactivity of the Ras-B-Raf-MAP kinase pathway in these tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17309670\n",
      "BRAF gene plays a \"gatekeeper\" role but does not act as a predisposition gene in the development of low-grade ovarian serous carcinomas\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17309670\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17312306\n",
      "Observational study of genetic testing. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17315191\n",
      "BRAFV600E represents a detectable marker in the plasma/serum from melanoma patients for monitoring but not diagnostic purposes\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17318013\n",
      "B-RAF mutations are a rare event in pituitary tumorigenesis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17355635\n",
      "The aim of this study was to identify the effect that BRAF oncogene has on post-transcriptional regulation in papillary thyroid carcinoma by using microRNA analysis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17360030\n",
      "findings show that RASSF1A hypermethylation and KRAS mutations and BRAF mutations are inversely correlated and play an important role in the development of cervical adenocarcinomas\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17366577\n",
      "mutational analysis of KRAS, BRAF, and MAP2K1/2 in 56 patients with CFC syndrome; comparison of the genotype-phenotype correlation of CFC with that of Costello syndrome suggest a significant clinical overlap but not genotype overlap.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17387744\n",
      "BRAF(V600E) mutation is identified in a subset of cutaneous metastases from papillary thyroid carcinomas\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17393356\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17393356\n",
      "data suggest that BRAF mutations might be present less frequently than KRAS mutations in Greek patients with colorectal carcinomas\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17440063\n",
      "finding of a strong association between BRAF mutations and serrated histology in hyperplastic aberrant crypt foci supports the idea that these lesions are an early, sentinel, or a potentially initiating step on the serrated pathway to colorectal carcinoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17453004\n",
      "BRAF V600E mutation was occasionally observed in anaplastic carcinomas with papillary carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17453358\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17454879\n",
      "MSI is rare in UC-related neoplasia as well as non-neoplastic lesions, and does not contribute to the development of dysplasia.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17464312\n",
      "prevalence of BRAF mutation and RET/PTC were determined in diffuse sclerosing variant of papillary thyroid carcinoma; none of the cases showed a BRAF mutation\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17483702\n",
      "Molecular diagnosis and careful observations should be considered in children with Cardio-facio-cutaneous syndrome because they have germline mutations in BRAF and might develop malignancy.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17487277\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17487504\n",
      "c-kit expression is not alternative to BRAF and/or KRAS activation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17488796\n",
      "BRAF V600E mutation in PTCs is associated with reduced expression of key genes involved in iodine metabolism\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17507627\n",
      "Observational study of gene-disease association and gene-environment interaction. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17507627\n",
      "data indicate that both early-life UV exposure and nevus propensity contribute to occurrence of BRAF+ melanoma, whereas nevus propensity and later-life sun exposure influence the occurrence of NRAS+ melanoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17516929\n",
      "analysis of a BRAF mutation-associated gene expression signature in melanoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17518771\n",
      "low rate of RAS-RAF mutations (2/22, 9.1%) observed in Spitz melanocytic nevi suggests that these lesions harbor as yet undetected activating mutations in other components of the RAS-RAF-MEK-ERK-MAPK pathway\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17520704\n",
      "Meta-analysis of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17520704\n",
      "frequency of the BRAF mutation and the associations between BRAF mutation and clinicopathologic parameters in papillary thyroid carcinoma were evaluated by meta-analysis\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17525723\n",
      "T1790A BRAF mutation (L597Q) in childhood acute lymphoblastic leukemia is a functional oncogene\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17535994\n",
      "The heterogeneous distribution of BRAF mutations suggests that discrete tumor foci in multifocal PTC may occur as independent tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17542667\n",
      "Presence of BRAF V600E in very early stages of papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17548320\n",
      "influence of B-RAF-specific RNA interference on the proliferation and apoptosis of gastric cancer BGC823 cell line\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17566669\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17566669\n",
      "We conclude that screening for BRAF 15 exon mutation is an efficient tool in the diagnostic strategy for HNPCC\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17635919\n",
      "In contrast to C-RAF that requires farnesylated H-Ras, cytosolic B-RAF associates effectively and with significantly higher affinity with both farnesylated and nonfarnesylated H-Ras.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17663506\n",
      "KLF6 and p53 mutations are involved in the development of nonpolypoid colorectal carcinoma, whereas K-ras and B-raf mutations are not\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17671688\n",
      "PPARbeta/delta has a role in growth of RAF-induced lung adenomas\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17685465\n",
      "BRAF V600E mutation in papillary carcinoma of the thyroid may facilitate tumor cell growth and progression once seeded in the lymph nodes.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17693984\n",
      "Observational study of genotype prevalence, gene-disease association, and genetic testing. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17693984\n",
      "There was no coexistence of BRAF (V600E) mutation in papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17696195\n",
      "data showed differences in gene expression between nevi with and without the V600E BRAF mutation. Moreover, nevi with mutations showed over-expression of genes involved in melanocytic senescence and cell cycle inhibition\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17699719\n",
      "RNA interference and pharmacologic approaches were used to assess the role of B-Raf activation in the growth of human melanomas and additionally determined if a similar role for mutant B-Raf is seen for colorectal carcinoma cell lines.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17704260\n",
      "5 unreported mutations (T241P, Q262R, G464R, E501V, N581K) were found in cardio-facio-cutaneous syndrome. A hotspot in exon 6 at Q257 was found.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17714762\n",
      "diffuse expression of wild-type and/or mutant B-Raf may be involved in the tumorigenic process\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17717450\n",
      "BRAF V600E mutation is primarily present in conventional papillary thyroid cancer; it is associated with an aggressive tumor phenotype and higher risk of recurrent and persistent disease in patients with conventional papillary thyroid cancer\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17717450\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17721188\n",
      "Develompment of malignant strumo ovarii with papillary thyroid carcinoma features is associated with BRAF mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17727338\n",
      "BRAF(V600E) mutation detected on fine-needle aspiration biopsy specimens, more than RET/PTC rearrangements, is highly specific for papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17785355\n",
      "BRAF V600E mutation is associated with high-risk papillary thyroid carcinoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17785355\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17786355\n",
      "BRAFV600E mutations were found in 41.2% of the papillary thyroid carcinomas\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17854396\n",
      "Papillary thyroid cancers with no 131I uptake had a high frequency of BRAF mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17878251\n",
      "MEK inhibition is cytostatic in papillary thyroid cancer and anaplastic thyroid cancer cells bearing a BRAF mutation\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17911174\n",
      "effects of a MEK inhibitor, CI-1040, on thyroid cancer cells, some of which, particularly cell proliferation and tumor growth, seemed to be BRAF mutation or RAS mutation selective\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17914558\n",
      "BRAF mutation is associated as early as the hyperplastic polyp stage followed by microsatellite instability at the carcinoma stage\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17924122\n",
      "Examined associations between BRAF mutations, morphology, and apoptosis in early colorectal cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17940185\n",
      "BRAF mutation represents a novel indicator of the progression and aggressiveness of papillary thyroid cancer (Review)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17942568\n",
      "BRAF interacts with PLCepsilon1 in nephrotic syndrome type 3. Both proteins are coexpressed and colocalize in developing and mature glomerular podocytes.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17962436\n",
      "In this small study, the T1799A BRAF mutation was identified in almost half of the iris melanoma tissues samples examined. This finding suggests that there may be genetic as well as clinical differences between iris and posterior uveal melanomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17972530\n",
      "These results suggest that papillary thyroid carcinomas with BRAF (V600E) mutation are more aggressive than those with wildtype BRAF.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18000091\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18008004\n",
      "mutation of N-RAS or B-RAF, signature genetic lesions present in most MMs, potently induced the expression of cell-surface CD200, a repressor of DC function.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18024410\n",
      "no BRAF mutations identified in 65 screened JMML patients; this gene is unlikely to play a role in the pathogenesis of JMML.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18032947\n",
      "The BRAF mutation is common in melanomas, but variation in rates across melanoma subtypes points to a complex interplay between BRAF activation and other factors (eg, sun exposure).\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18042262\n",
      "the results of HRAS, BRAF and MAP2K1/2 mutation screening in a large cohort of patients with CS and CFC\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18045960\n",
      "Detection of BRAF improves the diagnosis in fine-needle biopsy with cytological findings suspicious for papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18045987\n",
      "These results identify Rnd3 as a regulator of cross talk between the RAF/MEK/ERK and Rho/ROCK signaling pathways, and a key contributor to oncogene-mediated reorganization of the actin cytoskeleton and focal adhesions.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18060073\n",
      "BRAF and MEK1/2 mutations may be more common than anticipated in ovarian cancer which could have important implications for treatment of patients with this disease and suggests potential new therapeutic avenues\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18061181\n",
      "Observational study of genetic testing. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18070147\n",
      "BRAF(V600E)'alone' does not represent a marker for poor outcome\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18071315\n",
      "B-Raf(V600E) signaling deregulates the mitotic spindle checkpoint through stabilizing Mps1 levels in melanoma cells.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18098337\n",
      "BRAF provides proliferation and survival signals in MSI colorectal carcinoma cells displaying BRAF(V600E) but not KRAS mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18172070\n",
      "Because of the very sensitive pyrophosphorolysis-activated polymerization (PAP)technology, B-RAF mutations were found in cell lines and primary uveal melanomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18199160\n",
      "A worse clinical outcome was found for CIMP-high, microsatellite stable colorectal cancer with KRAS/BRAF mutation but not for those lacking KRAS/BRAF mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18224685\n",
      "Observational study of gene-disease association and gene-gene interaction. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18226854\n",
      "frequency of the occurrence of BRAF mutation and/or RET/PTC in H4-PTEN positive tumors was extremely high (75%) in papillary thyroid carcinoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18227705\n",
      "BRAF mutation is not associated with cutaneous melanoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18228248\n",
      "Important signalling role in T cell development.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18235983\n",
      "Follicular histotypes of oncocytic thyroid carcinomas do not carry BRAF mutations\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18246127\n",
      "Mutant B-RAF mediates resistance to anoikis via Bad and Bim.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18267069\n",
      "A genome-wide RNA-interference screening to identify genes required for an activated BRAF oncogene to block proliferation of fibroblasts and melanocytes revealed that a IGFBP7, has a central role in BRAF-mediated senescence and apoptosis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18310286\n",
      "BRAF T1799A mutation is associated with aggressive pathological outcomes of papillary thyroid cancer\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18310287\n",
      "BRAF(V600E) mutation is asscoiated with papillary thyroid cancer\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18310288\n",
      "BRAF-V600E mutation is associated with familial non-medullary thyroid carcinoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18323787\n",
      "Mitogen-activated protein kinase (MAPK) activity is subject to regulation even in BRAF/NRAS mutant melanoma cells and that high MAPK pathway signaling may be important only in distinct subsets of tumor cells.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18329792\n",
      "RKIP could play an important role in the down-regulation of wild-type BRAF, serving thus as an endogenous inhibitor of the MAPK pathway in nasal polyps and their adjacent turbinate mucosa.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18337114\n",
      "BRAF mutation testing of papillary thyroid carcinoma might improve the diagnosis, prognostic stratification and treatment of these tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18343945\n",
      "Our data provide evidence that PIK3CA and BRAF contribute to the tumorigenesis of IPMN/IPMC, but at a lower frequency than KRAS.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18368129\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18368129\n",
      "This study confirms that the known MC1R-melanoma risk association is confined to subjects whose melanomas harbor BRAF mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18375819\n",
      "BRAF mutation is associated with disease stabilization in melanoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18381570\n",
      "Thyroid cancers with BRAF mutation are preferentially sensitive to MEK inhibitors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18382358\n",
      "Detecting BRAF mutation by pyrosequencing is more sensitive, faster, and less expensive than direct DNA sequencing.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18383861\n",
      "K-RAS and BRAF mutations are a frequent genetic event in our samples of sporadic papillary and medullary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18383861\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18397470\n",
      "is commonly activated by somatic point mutation, it may provide possible diagnostic and therapeutic targets in human malignant tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18398503\n",
      "Results implicate aberrant activation of the MAPK pathway due to gene duplication or mutation of BRAF as a molecular mechanism of pathogenesis in low-grade astrocytomas and suggest inhibition of the MAPK pathway as a potential treatment.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18402768\n",
      "Aberrant BRAF and INK4A functionally interact to promote growth and survival of melanoma cells.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18408659\n",
      "in melanocytic lesions, BRAF(V600E) mutation can affect a subset of the cells and is associated with the type and quantity of sun exposure\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18413255\n",
      "study describes the biochemical characterization of novel BRAF and MEK germline mutations in cardio-facio-cutaneous syndrome\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18434602\n",
      "Cdk1/cyclin B has a role in regulating B-raf activation at mitosis\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18435933\n",
      "CpG island methylator phenotype in colorectal neoplasms may result from activating mutations in either BRAF or KRAS.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18451171\n",
      "Akt3 and mutant V600E B-Raf cooperate to promote early melanoma development.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18458053\n",
      "oncogenic BRAF inhibition can have a different effect on cell fate depending on the cellular type\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18470905\n",
      "aberrant methylation of the hMLH1 gene may play a role in BRAF mutation-promoted thyroid tumorigenesis\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18509003\n",
      "study revealed a significant correlation of BRAFV600E mutation with a lower expression of both sodium iodide symporter and thyroperoxidase in papillary thyroid cancer\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18509361\n",
      "Shorter overall survival in primary melanoma was associated with the presence of ulceration and BRAF exon 15 mutations, as well as the absence of nuclear activation of Akt and of cytoplasmic activation of ERK.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18517279\n",
      "BRAF mutations in colorectal cancer microsatellite-stable cases are associated with high levels of chromosomal instability that are likely responsible for the adverse outcomes in these cases\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18519771\n",
      "a significant relationship in overall survival in colon cancer patients with defective DNA mismatch repair and the presence of a specific mutation in BRAF (V600E)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18532874\n",
      "Compared to melanomas without BRAF mutations, melanomas with BRAF mutations showed statistically significantly higher degrees of intraepidermal scatter of melanocytes, and a higher proportion of melanocytes arranged in nests.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18567582\n",
      "the scaffold protein IQGAP1 couples Ca(2+) and calmodulin signaling to B-Raf function\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18592405\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18594528\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18602919\n",
      "Rac1b and B-Raf(V600E) functionally cooperate to sustain colorectal cell viability and suggest they constitute an alternative survival pathway to oncogenic K-Ras\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18615679\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18615679\n",
      "V600E BRAF mutation is associated with imatinib-resistant gastrointestinal stromal tumors\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18615680\n",
      "MLH1 methylation and BRAF mutations are associated with microsatellite unstable colon tumors\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18615680\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18621636\n",
      "Observational study of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18628356\n",
      "The frequencies of LOHs of 17q21, 17p13, 10q23, and 22q13 were higher in tumors with lymph node metastasis, suggesting that these LOHs may be important in increased lymph node metastasis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18628431\n",
      "People of southern European origin had lower risk of colorectal cancers with CIMP and BRAF mutation than people of Anglo-Celtic origin, which may in part be due to genetic factors that are less common in people of southern European origin.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18628967\n",
      "BRAF regulates melanoma proliferation through the lineage specific factor MITF\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18632627\n",
      "co-overexpression of KIT/CDK4 is a potential mechanism of oncogenic transformation in some BRAF/NRAS wild-type melanomas\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18636014\n",
      "lung adenocarcinoma of mixed type with a high incidence of papillary and lepidic growth may be worthwhile investigating for BRAF-V600E mutation as more genetically oriented drug therapies emerge.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18650848\n",
      "hyperactivation of the MAPK pathway following activation of an inducible form of oncogenic C-Raf induces a senescence-like proliferation arrest in B-Raf mutant melanoma cells\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18668139\n",
      "N-RAS(Q61K) and B-RAF(V600E) contribute to melanoma's resistance to apoptosis in part by downregulating Bim expression\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18669866\n",
      "Observational study of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18676742\n",
      "CST6, CXCL14, DHRS3, and SPP1 are regulated by BRAF signaling and may play a role in papillary thyroid carcinoma pathogenesis\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18676756\n",
      "Observational study of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18682506\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18682506\n",
      "The BRAF(V600E) mutation was demonstrated to be a poor prognostic factor independent from other clinicopathological features.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18697864\n",
      "Identification and functional characterization of a novel T599I-VKSR(600-603)del BRAF mutation in a patient with follicular variant papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18710471\n",
      "There is a higher frequency of the BRAF(V600E) mutation in papillary thyroid carcinomas than in normal thyroid tissue.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18715233\n",
      "These data suggest that regulation of BIM expression by BRAF-->MEK-->ERK signaling is one mechanism by which oncogenic BRAF(V600E) can influence the aberrant physiology of melanoma cells.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18716556\n",
      "focal gains at chromosome 7q34 and increased BRAF-MEK-ERK signaling are common findings in sporadic pilocytic astrocytomas\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18718023\n",
      "presence of the BRAF (V600E) mutation,the incidence of microsatellite instability high colorectal cancer in populations based study.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18757341\n",
      "KRAS and BRAF mutations can impair response to anti-EGFR therapy for colorectal neoplasms\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18757433\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18759827\n",
      "Observational study of genetic testing. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18778891\n",
      "BRAF mutation is associated with the CpG island methylator phenotype in colorectal cancer from young patients\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18778891\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18782444\n",
      "BRAF, KRAS and PIK3CA mutations occur prior to malignant transformation demonstrating that these oncogenic alterations are primary genetic events in colorectal carcinogenesis\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18782444\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18787396\n",
      "These data implicates a mitotic role for B-Raf in regulating spindle formation and the spindle checkpoint in human somatic cells.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18794094\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18794803\n",
      "study identified a group of melanomas with low-activity BRAF mutations (G469E- and D594G) that are reliant upon CRAF-mediated survival activity\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18798261\n",
      "BRAF mutation occurs independently of CpG island methylator phenotype and MSI in all types of serrated polyps and may serve as a marker of serrated pathway of colorectal carcinogenesis\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18806830\n",
      "study concludes a single endogenous BRAF(V600E) allele is sufficient to repress BIM & prevent death from growth factor withdrawal; colorectal cancer cells with V600E mutations are addicted to the ERK1/2 pathway for repression of BIM\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18832519\n",
      "CIMP-high appears to be an independent predictor of a low colon cancer-specific mortality, while BRAF mutation is associated with a high colon cancer-specific mortality.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18834226\n",
      "With at least 3 markers methylated, new CIMP-positive colorectal cancers were closely associated with proximal tumor location, low frequency of KRAS mutation, and high frequency of BRAF mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18840924\n",
      "BRAF(V600E) mutation may play some roles in local carcinoma development, there is no evidence that BRAF(V600E) mutation significantly reflects the aggressive characteristics and poor prognosis of patients with papillary carcinoma in Japan.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18840924\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18945298\n",
      "BRAF V600E appeared to be the most commonly mutated gene in both the melanocytic aggregate (seven of 18, 39%) and the melanoma (four of 18, 22%)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18946221\n",
      "Hereditary pancreatitis patients with PRSS1 mutations also had mutations in BRAF and KRAS2.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18953432\n",
      "study shows high expression of p16(INK4a) or the absence of activated B-RAF correlates with in vivo response of melanoma to cytotoxic drugs\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18974108\n",
      "rearrangement, which was not observed in a series of 244 higher-grade astrocytomas, results in an in-frame fusion gene incorporating the kinase domain of the BRAF oncogene\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18980976\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18985043\n",
      "the T1799A BRAF mutation is present in a proportion of posterior uveal melanomas but within these tumours the distribution of the mutation is heterogeneous.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18987552\n",
      "BRAF mutations may not play an important role in the oncogenesis or therapy of prostate adenocarcinoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18992635\n",
      "8% of sporadic colorectal tumors in this study harbor mutation in the BRAF gene.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18992635\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19001320\n",
      "Observational study of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19001320\n",
      "Wild-type BRAF is required for response to panitumumab or cetuximab in metastatic colorectal cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19003996\n",
      "BRAF-V600E mutation is uncommon in endocrine tumors other than thyroid papillary carcinomas\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19012001\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19012001\n",
      "The result showed that the mutation rate of PIK3CA in nasopharyngeal carcinomas (n = 73) was 9.6%, whereas both BRAF (n = 65) and RAS (n = 45) were wild type in every specimen with adequate DNA for analysis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19014278\n",
      "In Korean patients with papillary thyroid carcinoma, the BRAFV600E mutation is associated with a lower frequency of background Hashimoto thyroiditis and a high frequency of lymph node metastasis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19014278\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19016743\n",
      "Reverse transcription polymerase chain reaction-based sequencing revealed a fusion product between KIAA1549 and BRAF in pediatric low-grade astrocytomas\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19018267\n",
      "Observational study of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19018267\n",
      "ovarian cancer patients with KRAS or BRAF mutations may benefit from CI-1040 treatment\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19026650\n",
      "Observational study of genetic testing. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19033861\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19034577\n",
      "BRAF(V600E) mutation is assocciated with aggressive papillary thyroid microcarcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19034577\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19037234\n",
      "NRAS and BRAF mutations increase from the radial to the vertical growth phase in cutaneous melanoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19064572\n",
      "Observational study and meta-analysis of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19079609\n",
      "Genetic extinction of BRAF(V600E) in established prostate tumors did not lead to tumor regression, indicating that while sufficient to initiate development of invasive prostate adenocarcinoma, BRAF(V600E) is not required for its maintenance.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19087308\n",
      "G12D mutation may be more likely selected in a BRAF mutated context\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19098310\n",
      "ERK activation was induced by PKD2 overexpression via B-Raf signaling, providing a possible molecular mechanism of cystogenesis\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19107232\n",
      "BRAF pseudogene activation may play a role in thyroid tumor development.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19126563\n",
      "Sessile serrated adenomas are encountered commonly in routine endoscopy practice and the histological diagnosis correlates strongly with the presence of BRAF mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19127559\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19133693\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19142971\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19147753\n",
      "BRAF and RET/PTC dual mutations are associated with recurrent papillary thyroid carcinoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19147753\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19152441\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19159571\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19164452\n",
      "MLH1-hypermethylated tumors harbor fewer APC and KRAS mutations and more BRAF mutations, suggesting that they develop distinctly from an MGMT methylator pathway.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19178815\n",
      "Mutations are absent or rare in the kinase domain of B-RAF in Japanese head and neck squamous cell carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19178815\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19190079\n",
      "Mutation in BRAF is associated with adrenocortical carcinomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19190105\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19190129\n",
      "Distinct BRAF (V600E) and KRAS mutations in high microsatellite instability sporadic colorectal cancer in African Americans.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19190129\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19194051\n",
      "Expression levels of fibronectin, vimentin and CITED1 were positively correlated with those of BRAFV600E, suggesting pathophysiological links between activated BRAF and overexpression of these genes.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19200582\n",
      "(novel) mutation in the activation kinase domain of the BRAF (A598V), this mutation led to the up-regulation of the BRAF kinase activity and its downstream signaling factors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19206169\n",
      "Findings provide evidence for a wide phenotypic diversity associated with mutations affecting BRAF, and occurrence of a clinical continuum associated with these molecular lesions.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19207009\n",
      "the presence of the braf protein mutation increases prohibitin promoter activity and therefore potentially mediates effects of this mutation on the behavior of BRAF protein\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19208736\n",
      "BRAFT1799A mutation or RET/PTC rearrangement, mainly corresponding to follicular variants, maintain a thyroid differentiation expression level close to that of normal tissue.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19226609\n",
      "BRAF* melanomas appear to be associated with a specific profile of DNA copy number aberrations that is distinct from those found in NRAS* and BRAF/NRAS(wt/wt) tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19237633\n",
      "Observational study of gene-disease association and gene-gene interaction. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19240718\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19255327\n",
      "Clinical trial of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19274086\n",
      "oncogenic BRAF(V600E) induces the uncoupling of LKB1-AMPKalpha complexes providing at the same time a possible mechanism in cell proliferation that engages cell growth and cell division in response to mitogenic stimuli\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19276360\n",
      "GDC-0879-mediated efficacy was associated strictly with BRAF(V600E) status, MEK inhibition also attenuated proliferation and tumor growth of cell lines expressing wild-type BRAF.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19282104\n",
      "study of KRAS/BRAF mutation status in a large and well-documented cohort of primary and metastatic renal cell carcinoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19289622\n",
      "Observational study of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19289622\n",
      "a correlation between a gene mutation--BRAF V600E--and cisplatin resistance in nonseminomatous germ cell tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19342899\n",
      "Both BRAF and RKIP expression levels exhibit a decrease from normal skin tissue and actinic keratosis, going to squamous cell carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19344998\n",
      "In BRAF mutated colorectal carcinoma cells quercetin, luteolin and ursolic acid decreased Akt phosphorylation\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19351817\n",
      "Observational study of gene-disease association and gene-environment interaction. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19355825\n",
      "BRAF(V600E) is associated some of the aggressive clinicopathological features of papillary thyroid carcinoma including younger age at diagnosis, larger tumor size, and classic histological type, as well as also extrathyroidal invasion.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19355825\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19358278\n",
      "Observational study of gene-disease association and gene-environment interaction. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19362540\n",
      "Targets of phosphorylation by B-Raf signaling are investigated in melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19369630\n",
      "K-ras, EGFR, and BRAF mutations are disproportionately seen in adenocarcinomas of lung with a dominant micropapillary growth pattern compared with conventional adenocarcinoma in our institutional experience.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19369630\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19370505\n",
      "BRAF V600E mutation was significantly found in papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19370505\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19372556\n",
      "Mutation in BRAF is associated with ERK1/2 activation and MEK1/2 inhibitor therapy in colorectal cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19378335\n",
      "proliferation of cells harboring mutations in B-Raf, but not K-Ras, is exquisitely sensitive inhibition of the MAPK pathway\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19383313\n",
      "REVIEW summarizes the literature on NRAS and BRAF activating mutations in melanoma tumors with respect to available data on histogenetic classification as well as body site and presumed UV-exposure.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19383316\n",
      "The genes whose expression is associated with BRAF mutations are not simply restricted to the MAPK/ERK signaling but also converge to enhanced immune responsiveness, cell motility and melanosomes processing involved in the adaptative UV response\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19389934\n",
      "a subpopulation of melanocytes possesses the ability to survive BRAF(V600E)-induced senescence\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19393416\n",
      "B-RAF mutation was found to be significantly higher in papillary carcinomas when compared to follicular variant of papillary thyroid carcinomas (55.6% vs 14.3%, P = 0.05).\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19393416\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19398955\n",
      "The murine model of mutant BRAF-induced melanoma formation provides an important tool for identifying further genetic alterations that cooperates with BRAF and that may be useful in enhancing susceptibility to BRAF-targeted therapeutics in melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19404844\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19404844\n",
      "elevated pERK expression occurs in urothelial carcinoma in the absence of B-Raf mutations and is not correlated with FGFR3 over-expression\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19404918\n",
      "Investigated BRAF mutations in 30 bladder tumors. Detected two tumor specimens bearing two different mutations, both of which were found in exon 15. One sample showed the T1799A (V600E) and the other the G1798T (V600L) mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19404918\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19414674\n",
      "Observational study of gene-disease association and genetic testing. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19415957\n",
      "The T1799A BRAF mutation does not appear to play a role in the tumorigenesis of the cribriform-morular variant of papillary carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19416762\n",
      "Novel BRAF mutation in a patient with LEOPARD syndrome and normal intelligence is reported.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19424571\n",
      "BRAF V600E mutation is not the target gene for abnormal DNA mismatch repair in patients with sporadic endometrial cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19424639\n",
      "Report efficient molecular screening of Lynch syndrome by specific 3' promoter methylation of the MLH1 or BRAF mutation in colorectal cancer with high-frequency microsatellite instability.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19430562\n",
      "Mutations in BRAF were found 10% patients in the low-grade carcinoma group, however, they were not found in the high-grade carcinoma group. KRAS and BRAF mutations were mutually exclusive, and both mutations were observed in 40%.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19430562\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19440799\n",
      "oncogenic properties of KRAS and BRAF but not NRAS, HRAS, and PIK3CA contribute to the tumorigenesis of periampullary and ampullary tumors\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19461239\n",
      "mismatch repair deficiency is not a crucial event for BRAF mutation in melanocytic tumors\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19464601\n",
      "The RAS/RAF/MEK/ERK signaling pathway has emerged as a major player in the induction and maintenance of melanoma, particularly the protein kinase BRAF, mutated in approximately 44% of melanoma cases. Review.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19474002\n",
      "data confirm that KRAS and BRAF mutations do occur in the same cell and that BRAF V600E mutation is associated with CIMP+ status.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19483722\n",
      "B-Raf/MKK/ERK provides a permissive environment for melanoma genesis by modulating plexin B1.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19487299\n",
      "If BRAF is mutated in the primary thyroid neoplasm, it is likely that the metastases will harbor the defect.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19487299\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19492075\n",
      "Targeting NRAS alone or both BRAF and CRAF in combination or both BRAF and PIK3CA together showed delay in tumor growth.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19498322\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19498322\n",
      "Results show that activating BRAF somatic mutations may be occasionally found in advanced adrenocortical carcinomas, while CTNNB1 activating mutations are early and common events in adrenal tumorigenesis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19504446\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19534622\n",
      "CTNNB1 and BRAF mutations may have roles in the cribriform-morular variant of papillary thyroid carcinoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19534623\n",
      "BRAF V600E may have a role in development of papillary thyroid carcinoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19543740\n",
      "Pilocytic astrocytomas had BRAF fusions in 70% of cases but not IDH1 or IDH2 mutations. Diffuse astrocytomas had IDH1 mutations in 76% of cases but not IDH2 mutations or BRAF fusions. Analysis of BRAF and IDH1 separates pilocytic from diffuse astrocytoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19547661\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19551857\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19561230\n",
      "BRAF mutations represent an alternative molecular pathway in the early tumorigenesis of a subset of KIT/PDGFRA wild-type GISTs and are per se not associated with a high risk of malignancy.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19561230\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19571295\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19571295\n",
      "study concludes that a BRAF mutation is a negative prognostic marker in patients with metastatic colorectal cancer\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19571709\n",
      "BRAF mutated tumors occurred with a much greater frequency in proximal colon tumors than in either distal colon or rectal tumors\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19571821\n",
      "We observed no association between germline MC1R status and somatic BRAF mutations in melanomas\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19574281\n",
      "BRAF V600E mutation analysis can significantly improve FNAB diagnostic accuracy.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19584155\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19584155\n",
      "Results suggest that the mutations of EGFR, KRAS, BRAF between primary tumors and corresponding lymph node metastases should be considered whenever mutations are used for the selection of patients for EGFR-directed tyrosine kinase inhibitor therapy.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19603018\n",
      "Assessing KRAS and BRAF mutations might help optimising the selection of the candidate metastatic colorectal cancer patients to receive anti-EGFR moAbs.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19603018\n",
      "Observational study of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19603024\n",
      "BRAF (P=0.01) mutations predicted reduced progress free survival in response to cetuximab salvage therapy in patients with metastatic colorectal cancer .\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19603024\n",
      "Observational study of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19624312\n",
      "Mutated BRAF is a target in metastatic melanomas\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19626635\n",
      "In this study, 28 matched tumor and serum samples obtained from patients with both benign and malignant thyroid disorders were analyzed for BRAF mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19626635\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19628078\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19633643\n",
      "Characterization of candidate gene copy number alterations in the 11q13 region along with BRAF and NRAS mutations in human melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19637313\n",
      "strong inter-relation between DR4 AND DR5 overexpression and presence of oncogenic KRAS/ BRAF mutations in colon cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19638574\n",
      "Sorafenib inhibits NSCLC cell growth by targeting B-RAF in cells with wild-type KRAS and C-RAF in those with mutant KRAS.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19644722\n",
      "BRAFV600E mutation is associated with papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19652585\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19659611\n",
      "simultaneous depletion of both MITF and BRAF(V600E) significantly inhibited melanoma growth even for the melanoma cell lines resistant to MITF depletion\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19667985\n",
      "Studies indicate that in pilocytic astrocytomas, the BRAF fusion gene has been identified as a specific and frequent event leading to potentially targetable mitogen-activated protein kinase pathway activation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19669908\n",
      "Observational study of gene-disease association and DATA ERROR. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19679016\n",
      "Studies indicate that drugs are effective in targeting essential molecular pathways of BRAF, PTEN, Akt and mammalian target of rapamycin.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19679059\n",
      "Mutations in BRAF protein is associated with Colorectal Carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19679059\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19681119\n",
      "Investigated the prevalence of PTPN11, HRAS, KRAS, NRAS, BRAF, MEK1, and MEK2 mutations in a relatively large cohort of primary embryonal Rhabdomyosarcoma (RMS) tumors. No mutation was observed in BRAF and MEK genes.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19682280\n",
      "This study provides a basis for understanding the molecular processes that are regulated by (V600E)BRAF/MEK signalling in melanoma cells.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19686742\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19690147\n",
      "a dual mechanism that affects the Sprouty2/B-Raf interaction: Sprouty phosphorylation and B-Raf conformation\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19693938\n",
      "Whenever necessary BRAF testing may be performed on the residual samples of thyroid nodules, without interfering with routine cytology.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19704056\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19710001\n",
      "The BRAF(V600E) mutation can be used as a potential prognostic factor in PTMC patients in a BRAF(V600E)-prevalent area.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19710016\n",
      "DGKeta acts as a novel critical regulatory component of the Ras/B-Raf/C-Raf/MEK/ERK signaling cascade via a previously unidentified mechanism.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19718661\n",
      "analysis of the effect on the Ras/Raf signaling pathway of post-translational modifications of neurofibromin\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19724843\n",
      "This article focuses on reviewing the impact of the BRAFV600E mutation in the tumorigenesis of Papillary thyroid carcinoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19725049\n",
      "EPAC-mediated cellular effects require activation of the B-Raf/ERK and mTOR signaling cascades\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19735675\n",
      "Insights into the molecular function of the inactivating mutations of B-Raf involving the DFG motif.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19738388\n",
      "Observational study of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19738460\n",
      "Papillary carcinomas of the thyroid with papillary growth and areas of follicular growth have a high frequency of BRAF mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19745699\n",
      "Beta-catenin nuclear labeling is a common feature of sessile serrated adenomas and correlates with early neoplastic progression after BRAF activation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19752400\n",
      "The polyclonality of BRAF mutations in acquired melanocytic nevi suggests that mutation of BRAF may not be an initial event in melanocyte transformation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19759551\n",
      "analysis of coexisting NRAS and BRAF mutations in primary familial melanomas with specific CDKN2A germline alterations\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19765726\n",
      "Observational study of gene-disease association and gene-gene interaction. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19794125\n",
      "As predicted from the genomic organization at this locus, 22 of 36 patients with sporadic pilocytic astrocytomas and B-Raf gene rearrangement also exhibit corresponding homeodomain interacting protein kinase-2 (HIPK2) gene amplification.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19826477\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19829302\n",
      "data argues against obligatory downregulation in IGFBP7 expression in BRAF mutated melanoma cells\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19850689\n",
      "BRAF(T1799A) can be detected in the blood of papillary thyroid carcinoma patients with residual or metastatic disease and may provide diagnostic information\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19850689\n",
      "Observational study of genetic testing. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19855373\n",
      "BRAF V600E mutations were seen in 83% of proximal and 74% of distal hyperplastic colonic polyps\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19861538\n",
      "BRAFV600E oncogene induces transforming growth factor beta secretion leading to sodium iodide symporter repression and increased malignancy in thyroid cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19861964\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19861964\n",
      "These data demonstrate the feasibility of BRAF mutation detection in cfDNA of patients with advanced melanoma. Future studies should aim to incorporate BRAF mutation testing in cfDNA to further validate this biomarker for patient selection.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19878585\n",
      "Suppression of BRAF gene expression inhibited cell proliferation in cells with BRAF(V600E) mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19880519\n",
      "Hyperactivation of BRAF-MEK signaling activates MAP2 expression in melanoma cells by two independent mechanisms, promoter demethylation or down-regulation of neuronal transcription repressor HES1.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19881948\n",
      "BRAF and KRAS oncogenes have different transforming capability in colon cancer\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19883729\n",
      "The knowledge of BRAF mutation status can facilitate more accurate risk stratification and better decision making at various steps in the management of papillary thyroid cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19884549\n",
      "Clinical trial of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19884549\n",
      "KRAS and BRAF mutations in advanced colorectal cancer are associated with poor prognosis but do not preclude benefit from oxaliplatin or irinotecan.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19884556\n",
      "BRAF status, EGFR amplification, and cytoplasmic expression of PTEN were associated with outcome measures in KRAS wild-type patients treated with a cetuximab-based regimen.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19884556\n",
      "Observational study of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19893451\n",
      "Study identified the previously reported pathogenic mutation of NTRK3 in a KRAS/BRAF wild-type tumor and 2 somatic mutations in the Src family of kinases (YES1 and LYN) that would be expected to cause structural changes.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19903786\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19908233\n",
      "BRAF gene mutation is associated with colorectal cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19908233\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19913317\n",
      "BRAF mutations are not relevant for rectal carcinogenesis\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19913317\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19917255\n",
      "Data show that melanoma cells expressing B-Raf(V600E) display a reduced C-Raf:B-Raf ratio, and further suppression of C-Raf increases MAPK activation and proliferation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19919630\n",
      "The BRAF V600E mutational status appears to be of limited diagnostic utility in distinguishing genital naevi that exhibit atypia from those that do not.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19919912\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19935791\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19955937\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19955937\n",
      "v-Raf murine sarcoma viral oncogene mutations are common in ovarian serous bordeline tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19956635\n",
      "Uncategorized study of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19958951\n",
      "clinical, cytologic, and pathologic parameters of 106 consecutive surgically treated patients with BRAF-positive PTC were compared with a concurrent cohort of 100 patients with BRAF-negative PTC (papillary thyroid carcinoma)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19959686\n",
      "2-fold increased risk of BRAF V600E colonic tumor mutation was observed in current and former cigarette smokers homozygous for the OGG1 polymorphism\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19960590\n",
      "BRAF T1796A mutation was identified in 27% of papillary thyroid cancer samples and its identification may be used to determine this risk factor of the development of papillary thyroid cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19960590\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20008640\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20009493\n",
      "BRAFV600E mutation is associated with high-risk clinicopathological characteristics of papillary thyroid carcinoma and worse prognosis of patients\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20009493\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20012784\n",
      "Screening for BRAF, RET, KRAS, NRAS, and HRAS mutations, as well as RET-PTC1 and RET-PTC3 rearrangements, was performed on cases of Hashimoto thyroiditis with a dominant nodule\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20023270\n",
      "BRAF V600E detection in the tumor does not induce a higher expression of the B-raf protein or the preferential activation of the p42/44 mitogen-activated protein kinase (MAPK) signaling pathway compared with GISTs without the BRAF mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20027224\n",
      "CpG island methylator phenotype (CIMP)-specific inactivation of BRAF(V600E)-induced senescence and apoptosis pathways by IGFBP7 DNA hypermethylation might create a favorable context for the acquisition of BRAF(V600E) in CIMP+ colorectal cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20043015\n",
      "Observational study of gene-disease association and gene-gene interaction. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20043015\n",
      "no support for MC1R variants with BRAF mutation for melanoma risk\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20044755\n",
      "BRAF gene rearrangements were more common in cerebellar pilocytic astrocytoma than non-cerebellar tumors; clinical outcome was independent of BRAF status\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20049644\n",
      "BRAF mutations only in metastases is not associated with resistance to anti-EGFR treatment in primary colorectal tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20049644\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20051945\n",
      "Observational study of genetic testing. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20068183\n",
      "BRAF(V600E) mutation seems to define a subset of malignant astrocytomas in children, in which there is frequent concomitant homozygous deletion of CDKN2A (five of seven cases).\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20098682\n",
      "Observational study of genetic testing. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20118768\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20140953\n",
      "Formalin-fixed primary melanomas from relapsed and nonrelapsed patients were sequenced for common BRAF and NRAS mutations. BRAF/NRAS mutations were detected in 77% of relapsers and 58% of nonrelapsers and did not predict ulceration or mitotic rate.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20146801\n",
      "Data demonstrate a signaling loop between B-Raf activation and p73 function, and suggest that low expression of TAp73 in colorectal cancer cell lines with mutated B-Raf may lead to lack of response to oxaliplatin/cetuximab.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20156809\n",
      "BRAF activating mutations are a major genetic alteration in this histologic group of pediatric low-grade brain tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20162668\n",
      "Observational study of gene-disease association and gene-gene interaction. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20162668\n",
      "With MSI, specific KRAS and BRAF mutations, 3 distinct prognostic subgroups were observed: patients with (i) KRAS mutation G12D, G12V or BRAFmutation, (ii) KRAS/BRAFwild-type or KRAS G13D mutations in MSS/MSI-L and (iii) MSI-H and KRAS G13D mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20177422\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20182446\n",
      "High oncogenic BRAF levels trigger autophagy, which may have a role in melanoma tumor progression.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20186801\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20187782\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20200438\n",
      "Observational study of gene-disease association and gene-environment interaction. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20200438\n",
      "we measured the prevalence and epidemiologic correlates of the BRAF V600E somatic mutation in cases collected as a part of a population-based case-control study of colorectal cancer in northern Israel.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20230995\n",
      "pathogenesis of papillary thyroid cancer , and the clinical implications of BRAF(V600E) mutation in the diagnosis, prognosis and potential targeted therapeutic strategies for thyroid cancer [review]\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20233436\n",
      "data support the model of BRAF and K-ras mutations arising in distinct colorectal cancer subsets associated with different clinicopathological and dietary factors, acting as mutually exclusive mechanisms of activation of the same signalling pathway\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20234366\n",
      "Observational study of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20300843\n",
      "BRAF mutation is not associated with interval cancers but is a marker of poor prognosis, particularly in microsatellite stable cancers.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20300843\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20302979\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20303012\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20303012\n",
      "Our study suggests that mutations of KRAS, not BRAF, may play a role in the pathogenesis of prostate carcinoma in Chinese patients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20305537\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20332228\n",
      "Studies show FOXD3 is suppressed by B-RAF, uncover a novel role and mechanism for FOXD3 as a negative cell cycle regulator, and have implications for the repression of melanocytic lineage cells.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20351680\n",
      "Mutated in melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20379614\n",
      "Clinical trial of gene-disease association and gene-environment interaction. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20381121\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20406109\n",
      "The miR-146b expression levels in papillary thyroid carcinoma with BRAF mutation were significantly higher than those without this mutation\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20407018\n",
      "Activated Raf-1 induces focal adhesion kinase expression and regulates neuroendocrine and metastatic phenotypes in gastrointestinal carcinoid cell line BON.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20410389\n",
      "thyroid carcinoma with the BRAF(V600E) mutation tends to be taller than wide and is not associated with the presence of calcifications on ultrasound.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20413299\n",
      "Observational study of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20444249\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20445557\n",
      "B-RAF(V600E) can protect melanocytes from anoikis independently of cell cycle inhibition\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20453000\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20454969\n",
      "This study identified an exceptionally high frequency of KIAA1549-BRAF fusions in pilocytic astrocytoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20460314\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20460314\n",
      "These data demonstrate a high prevalence of B-RAF mutations in the present study population, underscoring the possibility of strong regional differences.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20473281\n",
      "Hypoxia-inducible factor-1alpha is expressed in papillary thyroid carcinomas and is regulated not only by hypoxia but also by BRAF(V600E)-mediated signaling pathway.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20473281\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20478260\n",
      "Study concludes that the secreted protein IGFBP7 is dispensable for B-RAF(V600E)-induced senescence in human melanocytes.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20485284\n",
      "BRAF V600E mutations are associated with MSI-H status and cyclin D1 overexpression and characterize a subgroup of patients with poor prognosis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20485284\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20489114\n",
      "Observational study of genetic testing. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20495538\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20496269\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20498063\n",
      "Knockdown of B-Raf(V600E) resulted in thrombospondin-1 down-regulation and a reduction of adhesion and migration/invasion of human thyroid cancer cells.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20501503\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20501503\n",
      "The V600E BRAF mutation confers a worse prognosis to stage II and stage III colon cancer patients independently of disease stage and therapy.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20501689\n",
      "Observational study of gene-disease association and genetic testing. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20514492\n",
      "BRAF mutation may be used a biomarker for the selection of patients with colorectal cancer patients who might benefit from anti-egf receptor monoclonal antibodies.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20514492\n",
      "Meta-analysis of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20519626\n",
      "Studies identified the oncogenic BRAF V600E mutation in 35 of 61 archived specimens (57%).\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20526288\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20526288\n",
      "The BRAF 1799T>A mutation was found in 5 of 19 (26%) of infiltrative follicular variant of papillary thyroid carcinomas and in none of the encapsulated carcinomas\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20543023\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20563851\n",
      "HER2, but not EGFR gene amplification, is frequently observed in KRAS and BRAF wild type colorectal cancer patients\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20563851\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20569675\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20569675\n",
      "reports the low frequency of PIK3CA and B-RAF mutations in astrocytomas, despite the presence of activated ERK and AKT proteins\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20570909\n",
      "Incidence of cancer in FDRs of index CRC patients with the p.V600E BRAF mutation may be explained by a genetic predisposition to develop cancer through the serrated pathway of colorectal carcinogenesis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20570909\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20571907\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20571907\n",
      "PIK3CA mutations may have a role in KRAS and BRAF wild type colorectal cancer\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20573852\n",
      "BRAF mutational status of metastases is not required when the primary tumour is BRAF wild type.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20576522\n",
      "allele specific Taqman-based real-time PCR assay allows the sensitive, accurate and reliable measurement of BRAF(V600E) mutated DNA in plasma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20591910\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20605766\n",
      "in melanomas activation of the MAPK pathway can occur through signaling pathways operating independently of BRAF T1799A\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20607849\n",
      "V600E BRAF mutation is not associated with seminoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20616366\n",
      "Using traditional PCR and direct sequencing, we found KRAS mutations in 47 (40%) patients and BRAF(V600E) in 10 (8.5%)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20619739\n",
      "if KRAS is not mutated, assessing BRAF, NRAS, and PIK3CA exon 20 mutations (in that order) gives additional information about the efficacy of cetuximab plus chemotherapy in metastatic colorectal cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20627194\n",
      "PCR is practically applicable to KRAS/BRAF genotyping using small amounts of biopsied colorectal tumor cells.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20631031\n",
      "No significant difference in BRAF alterations was found between pT1 tumors and thyroid capsule invasion and pT3 tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20631031\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20635392\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20640859\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20645028\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20645028\n",
      "samples of metastatic colorectal cancer were tested for the presence of the seven most common mutations in the KRAS gene and the V600E mutation in the BRAF gene\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20647301\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20647317\n",
      "Findings delineate how mutant B-RAF protects melanoma cells from apoptosis and provide insight into possible resistance mechanisms to B-RAF inhibitors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20652941\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20670148\n",
      "Traditional DNA sequencing and the somewhat more-sensitive pyrosequencing method can detect multiple alternative BRAF mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20679909\n",
      "Mutant Braf can be detected in RNA from mixed populations with as few as 0.1% Braf(V600E) mutant cells.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20689758\n",
      "PLX4032 has robust activity in BRAF mutated melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20702649\n",
      "Observational study of gene-disease association and gene-gene interaction. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20703476\n",
      "Observational study of genetic testing. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20720566\n",
      "Observational study of gene-disease association and gene-gene interaction. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20720566\n",
      "association between MC1 receptor germline variation and BRAF/NRAS mutations in melanoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20736745\n",
      "Observational study of gene-disease association and gene-gene interaction. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20802181\n",
      "BRAF mutation is rare in advanced-stage low-grade ovarian serous carcinomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20802181\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20807807\n",
      "Mutant protein kinase elicits significant therapeutic responses in mutant BRAF-driven human melanoma xenografts.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20813562\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20813562\n",
      "first report implicating BRAF mutation in OSCC. study supports that mutations in the BRAF gene makes at least a minor contribution to OSCC tumorigenesis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20837233\n",
      "BRAF mutation detection in fine needle biopsy may be an adjunct tool for preoperative didagnosis of papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20840674\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20840674\n",
      "RET rearrangements and BRAF mutation in undifferentiated thyroid carcinomas having papillary carcinoma components\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20843808\n",
      "A BRAF aberrant splice variant with an intact kinase domain and partial loss of the N-terminal autoinhibitory domain was identified in fibroblasts from an additional patient, and fibroblast proliferation was inhibited by BRAF-specific siRNA.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20853079\n",
      "reduced RKIP mRNA levels and the elevated levels of B-RAF in pT1, grade III tumors vs. normal tissue, corroborate that these genes are involved in the pathogenesis of urinary bladder cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20857202\n",
      "BRAF V600E mutation is associated with lack of response in wild-type KRAS metastatic colorectal cancer treated with anti-EGFR monoclonal antibodies.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20860430\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20881644\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20944096\n",
      "Determination of the BRAF mutation and the growth fraction of melanomas may add a prognostic value.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20944096\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20945104\n",
      "BRAF(V600E) mutation is associated with thyroid nodules.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20945104\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20947270\n",
      "In the present series, no BRAF mutation was detected. The presence of KRAS mutations and loss of PTEN expression were not associated with impaired response to cetuximab-based chemoradiotherapy and 3-year disease free survival.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20947270\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20950194\n",
      "BRAF is mutated in a low percentage of follicular variant of papillary thyroid carcinoma, and most of these mutated cases are suspicious or positive on fine-needle aspiration.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20953721\n",
      "BRAF mutation is associated with papillary thyroid microcarcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20955560\n",
      "Anti-BRAF autoantibodies from RA patients preferentially recognize one BRAF peptide: P2\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20959481\n",
      "Braf mutation is associated with basal and treatment-induced regulation of the PI3K-AKT pathway as a critical regulator of AZD6244 sensitivity in cutaneous melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20962618\n",
      "Describe benign serrated colorectal fibroblastic polyps/intramucosal perineuriomas are true mixed epithelial-stromal polyps (hybrid hyperplastic polyp/mucosal perineurioma) with frequent BRAF mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20975100\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20979647\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21048031\n",
      "Observational study of gene-disease association and gene-environment interaction. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21049459\n",
      "Although many studies document BRAF mutation as a prognostic factor in PTC our results underline that it is too early to consider it as a routine clinical predictive factor.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21049459\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21051183\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21051183\n",
      "findings indicate that somatic mutations in KRAS and PIK3CA but not BRAF oncogenes are closely associated with the development of cholangiocarcinoma in Chinese population\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21068756\n",
      "The dermoscopical and histopathological patterns of nevi correlate with the frequency of BRAF mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21076620\n",
      "Data show that BRAF knockdown led to suppression of the expression of the GABPbeta, which involved in regulating HPR1 promoter activity.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21098728\n",
      "BRAF gene amplification can promote acquired resistance to MEK inhibitors in cancer cells harboring the BRAF V600E mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21102258\n",
      "Mutations of EGFR, BRAF, and KRAS in adenocarcinoma were mutually exclusive and inversely correlated with RASSF1A methylation\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21102416\n",
      "We show a strong association between concordant methylation of >/= 3 of five 3p22 genes with the CpG island methylator phenotype and the BRAF V600E mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21103049\n",
      "Data show that among 181 CRC patients, stratified by microsatellite instability status, DNA sequence changes were identified in KRAS (32%), BRAF (16%), PIK3CA (4%), PTEN (14%) and TP53 (51%).\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21107320\n",
      "identification of MAP3K8 (the gene encoding COT/Tpl2) as a MAPK pathway agonist that drives resistance to RAF inhibition in B-RAF(V600E) cell lines\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21107323\n",
      "melanomas escape B-RAF(V600E) targeting not through secondary B-RAF(V600E) mutations but via receptor tyrosine kinase (RTK)-mediated activation of alternative survival pathway(s) or activated RAS-mediated reactivation of the MAPK pathway\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21129611\n",
      "It therefore appears that BRAF mutations may play a strong negative prognostic role and only a slight role in resistance to anti-EGFR Abs.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21131919\n",
      "Primary esophageal melanomas of Caucasian patients harbor mutations of c-Kit, KRAS and BRAF in varied frequencies.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21134544\n",
      "BRAF mutation in papillary thyroid carcinoma is associated with an increased risk of palpable nodal recurrence and the need for reoperative surgery.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21134562\n",
      "BRAF mutations activate the mitogen-activated protein kinase pathway and confer an aggressive thyroid cancer phenotype.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21161938\n",
      "KRAS mutations arise more frequently than BRAF mutations in Moroccan patients with colorectal carcinomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21166657\n",
      "The BRAF mutation was frequently detected in patients with superficial spreading melanoma (OR=2.021; P<0.001) and in melanomas arising in nonchronic sun-damaged skin (OR=2.043; P=0.001).\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21167555\n",
      "concluded that follicular variant of papillary thyroid carcinoma differs from conventional papillary thyroid carcinoma in the rate of BRAF mutation\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21176117\n",
      "These results show that melanoma cell phenotype is an important factor in MAPK pathway inhibition response, as invasive phenotype cell response is dependent on BRAF mutation status.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21185263\n",
      "this study has confirmed that the BRAF(T1799A) mutation confers cancer cells sensitivity to PLX4032 and demonstrated its specific potential as an effective and BRAF(T1799A) mutation-selective therapeutic agent for thyroid cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21190184\n",
      "B-Raf(insT) and B-Raf(V600E) , but not B-Raf(wt) , provoke drastic morphological alterations in human astrocytes.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21203559\n",
      "BRAF alternative splicing is differentially regulated in human and mouse. BRAF exon 9b is required for learning and memory associated with the hippocampus.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21215707\n",
      "In melanoma cells, oncogenic (V600E) BRAF signaling downregulates PDE5A through the transcription factor BRN2, leading to increased cGMP and Ca2+ and the induction of invasion through increased cell contractility.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21223556\n",
      "B-Raf signaling has a key function in the altered expression of contractile receptors in the cerebrovasculature.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21223812\n",
      "The high expression of activated ERK is not caused by BRAF gene mutation in nasal mucosa malignant melanomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21224857\n",
      "Acquisition of a BRAF mutation is not a founder event, but may be one of the multiple clonal events in melanoma development, which is selected for during the progression.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21239517\n",
      "We found that performing BRAF(V600E) mutation analysis on the fine-needle aspiration biopsy specimens was of great help to make a therapeutic decision for thyroid nodules when the fine-needle aspiration biopsy results were equivocal\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21249150\n",
      "the oncogenic effect of BRAF(V600E) is associated with the inhibition of MST1 tumor suppressor pathways, and the activity of RASSF1A-MST1-FoxO3 pathways determines the phenotypes of BRAF(V600E) tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21263251\n",
      "These findings suggest that BRAF mutations may be associated with the pathogenesis of sessile serrated colorectal adenomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21270111\n",
      "Findings suggest inhibition of autophagy in combination with ER stress-inducing agents may represent a means by which to harness autophagy for the therapeutic benefit of B-RAF wild-type melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21274671\n",
      "B-Raf mutations, microsatellite instability and p53 protein expression is not associated with sporadic basal cell carcinomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21274720\n",
      "The analysis of BRAF V600E mutation in 1,320 nervous system tumors reveals high mutation frequencies in pleomorphic xanthoastrocytoma, ganglioglioma and extra-cerebellar pilocytic astrocytoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21285991\n",
      "Presence of mutated BRAF is one of the most powerful prognostic factors for advanced and recurrent CRC\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21289333\n",
      "803 metastatic colorectal cancer samples studied for KRAS exon 2 and BRAF exon 15 mutations; BRAF mutated samples were characterized for mismatch repair function; 344 tumours were mutated -34 involving BRAF mutations (8 of microsatellite instability type)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21303778\n",
      "Ras/Raf/MAPK and RhoA/ROCKII signalling pathways are abnormally activated in eutopic endometrial stromal cells of patients with endometriosis\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21305640\n",
      "78 colorectal tumor samples were mutant for BRAF.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21307665\n",
      "analysis of gallbladder carcinomas, gallbladder adenomas, and high-grade dysplastic lesions for the BRAF and the KRAS mutations\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21317202\n",
      "Findings suggest that inhibition of Raf-MEK-Erk pathway might offer a novel therapeutic strategy in neuroendocrine tumors\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21317224\n",
      "Studies showed that siRNA knockdown of BIM significantly blunted the apoptotic response in PTEN+ melanoma cells.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21317286\n",
      "identified BAD serine 134 to be strongly involved in survival signaling of B-RAF-V600E-containing tumor cells and found that phosphorylation of BAD at this residue is critical for efficient proliferation in these cells.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21321384\n",
      "identifying downstream events from the BRAFV600E/ERK1/2 pathway will eventually identify novel biomarkers that can be used to correlate with disease outcome and overall survival.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21324100\n",
      "Data show that BRAF-mutated melanomas occur in a younger age group on skin without marked solar elastosis and less frequently affect the head and neck area, compared to melanomas without BRAF mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21326296\n",
      "BRAF mutations have a smaller role in the carcinogenesis of malignant melanoma in Chinese Han than in Western patients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21332555\n",
      "BRAF mutations were rare in colorectal laterally-spreading tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21343559\n",
      "The presence of mutant BRAF had no impact on the disease-free interval from diagnosis of first-ever melanoma to first distant metastasis; however, it may have impacted survival thereafter.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21345796\n",
      "B-Raf associates with and stimulates NHE1 activity and that B-Raf(V600E) also increases NHE1 activity that raises intracellular pH.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21351275\n",
      "BRAF mutation is associated with selective inhibition of thyroid cancer cells by the novel MEK inhibitor RDEA119 and genetic-potentiated synergism with the mTOR inhibitor temsirolimus\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21356389\n",
      "IDH1 mutation works with other oncogenic mutations and could contribute to the metastasis in melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21362156\n",
      "Regulation of NR4A nuclear receptor expression by oncogenic BRAF in melanoma cells.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21383284\n",
      "BRAF mutational status yielded no useful prognostic information in predicting recurrence and benefits from adjuvant chemotherapy in colorectal cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21383288\n",
      "Thus, MEK1(C121S) or functionally similar mutations are predicted to confer drug resistance of neoplasms to combined MEK/RAF inhibition.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21383698\n",
      "tumor initiation by oncogenic BRAF renders thyroid cells susceptible to TGFbeta-induced epithelial-mesenchymal transition, through a MAPK-dependent process\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21390154\n",
      "K-ras gene mutation is a common event in Chinese colorectal cancer (CRC) patients, but may not be a prognostic factor in CRC , while BRAF is rarely mutated in Chinese CRC patients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21408138\n",
      "Allele-specific qPCR assays for the most frequent activating mutations in EGFR, KRAS, BRAF and PIK3CA in tumor-positive fine needle cytological aspirates were compared against histological material of primary tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21412762\n",
      "BRAF mutation is associated with papillary thyroid cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21424126\n",
      "study suggested that both KRAS and BRAF mutations are exclusive, but KRAS and PIK3CA mutations are coexistent\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21424530\n",
      "This study demonistrated that the role of RAF kinase fusions as a central oncogenic mechanism in the development of pilocytic astrocytoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21426297\n",
      "Mutations at the position V600 of BRAF were described in approximately 8% of all solid tumors, including 50% of melanomas, 30 to 70% of papillary thyroid carcinomas and 5 to 8% of colorectal adenocarcinomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21427714\n",
      "There were no significant differences in the frequency of BRAF mutations among lesions exhibiting the hyperplastic, adenomatous, or mixed patterns.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21430505\n",
      "The presence of the BRAF(V600E) mutation may play different roles between medium and giant CMNs in melanocytic tumorigenesis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21431280\n",
      "BRAF T1799A mutation may be an early and essential carcinogenic event in nearly all Korean papillary thyroid carcinomas\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21441079\n",
      "In papilary thyroid carcinoma, the BRAFT1799A mutation is associated with age over 60 & a tumor size of 1cm or greater, but not with other clinicopathological characteristics, tumor recurrence or persistence.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21441910\n",
      "KSR interacts with a regulatory Raf molecule in cis to induce a conformational switch of MEK, facilitating MEK's phosphorylation by a separate catalytic Raf molecule in trans\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21447798\n",
      "Amplification of the driving oncogene, KRAS or BRAF, underpins acquired resistance to MEK1/2 inhibitors in colorectal cancer cells.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21451543\n",
      "Activated BRAF promotes melanoma cell growth by matrix metalloproteinase-1\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21455633\n",
      "No V600E mutation was identified in the BRAF gene in any sample.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21456008\n",
      "the impact of BRAF mutation and microsatellite instability on prognosis in metastatic colorectal cancer\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21457162\n",
      "BRAF mutations are specific for serrated adenocarcinoma and identify a subset of serrated adenocarcinomas with gene methylation and a tendency for MSI-H\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21479234\n",
      "BRAF V600E mutations are common in the majority of pleomorphic xanthoastrocytoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21483104\n",
      "Heterogeneity of KRAS and BRAF mutation status intra-tumorally in colorectal cancer was assessed.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21498916\n",
      "findings support the notion that BRAF(V600E), which can be detected preoperatively in papillary thyroid carcinoma fine-needle aspiration biopsy material, has a potential to contribute to patients stratification into high- and low-risk groups.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21512141\n",
      "Mutated BRAF is detected in approximately 45% of papillary thyroid carcinomas (PTC).\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21514245\n",
      "Ablation of B-Raf had no significant effect on development of K-Ras oncogene-driven non-small cell lung carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21553007\n",
      "BRAF mutations, but not KRAS mutations, were associated with a worse outcome in Chinese colorectal cancer patients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21557216\n",
      "MSS/BRAF mutant cancers were more commonly proximal (38/54, 70.3%).\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21570823\n",
      "Analysis showed that blood samples with PCR evidence for CMC were heterogeneous for BRAF status under limiting-dilution conditions, suggestive of heterogeneity of CMC\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21577205\n",
      "Studies indicate that Raf kinases are excellent molecular targets for anticancer therapy.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21587258\n",
      "Wnt5a methylation was strongly associated with tumour microsatellite instability tumours after adjustment for age, sex, and tumour location and with BRAF V600E mutation, a marker of CpG island methylator phenotype\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21594703\n",
      "BRAF V600E mutation is associated with recurrent papillary thyroid cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21636552\n",
      "introduction of constitutively active BRAF V600E into human cortical stem and progenitor cells initially promotes clonogenic growth in soft agar but ultimately results in dramatically reduced proliferation and arrested growth of the culture.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21653734\n",
      "Compared with BRAF-wt papillary thyroid cancer, those harboring BRAF(V600E) exhibit downregulated VEGFA, VEGFR, and PDGFRbeta expression, suggesting presence of BRAF mutation does not imply stronger response to drugs targeting VEGF and PDGFB signal pathways.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21663470\n",
      "The BRAF V600E mutation was present in all patients with hairy-cell leukemia who were evaluated.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21681432\n",
      "The BRAF V600E mutation did not show association with clinical or molecular characteristics of colorectal cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21693616\n",
      "Eight of 16 primary tumor samples and 4 of 6 metastatic samples showed BRAF V600E gene mutations and no copy number changes were associated exclusively with metastatic cancer\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21696415\n",
      "The frequency of BRAF-KIAA1549 fusion transcripts is significantly lower in adult patients with pilocytic astrocytoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21705440\n",
      "MEK1(F129L) mutation also strengthened binding to c-Raf, suggesting an underlying mechanism of higher intrinsic kinase activity\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21707687\n",
      "The application of BRAF(V600E) mutation analysis in US-guided FNAB can improve the diagnostic accuracy of thyroid nodules.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21716161\n",
      "We describe a new mutation of BRAF, T599dup, in a case of anaplastic thyroid carcinoma with tall cell papillary thyroid carcinomas component.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21725359\n",
      "identified concurrent mutational inactivation of the PTEN and RB1 tumor suppressors as a mechanism for loss of BRAF/MEK dependence in melanomas harboring (V600E)BRAF mutations\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21750338\n",
      "BRAF mutation of papillary thyroid carcinoma may have differential predictive values for LN metastasis, according to tumor size.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21774961\n",
      "BRAF(V600E) mutation analysis using residual liquid-based preparation cytologic samples is, therefore, a powerful additional diagnostic tool for diagnosis of papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21788131\n",
      "Patients with mutations in BRAF or NRAS gene are frequently present with ulceration, and mutation in BRAF or NRAS gene is indicator for poor prognosis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21796448\n",
      "Importance of infiltrative growth pattern and invasiveness over presence of BRAF mutation in classic and follicular variant papillary thyroid carcinoma for development of nodal metastases.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21803329\n",
      "BRAF mutation is not indicative for predicting papillary thyroid cancer prognosis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21825258\n",
      "study reports that V600E and non-V600E BRAF mutations affect different patients with non-small-cell lung cancer; V600E mutations are significantly associated with female sex and represent a negative prognostic factor\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21826673\n",
      "BRAF mutations and llelic loss of susceptibility loci are associated with familial non-medullary thyroid cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21835307\n",
      "The BRAF/MEK/ERK pathway is upregulated in progressive retinal arterial macroaneurysm patients, caused by mutation in IGFBP7.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21863388\n",
      "Braf mutation in metastatic melanoma treated with BRAF inhibitor vemurafenib.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21871821\n",
      "Genetic analysis revealed individual heterozygous mutations in the KRAS (phenotype of CFC/Noonan syndrome) and BRAF genes (phenotype of CFC syndrome)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21875464\n",
      "BRAF V600E mutation has a significant correlation with papillary thyroid carcinomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21882184\n",
      "the BRAF(V600E) mutation should be considered as a poor prognostic marker in papillary thyroid cancer (Meta-Analysis)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21900390\n",
      "Studies indicate that BRAF V600E mutation initiates follicular cell transformation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21901162\n",
      "In sporadic colorectal tumourspatients, the most frequently mutated gene was APC (68.9% of tumours), followed by KRAS (31.1%), TP53 (27.2%), BRAF (8.7%) and CTNNB1 (1.9%).\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21903858\n",
      "BRAF(V600E) causes upregulation of TIMP-1 via NF-kappaB. TIMP-1 binds then its surface receptor CD63, leading eventually to Akt activation, which in turn confers antiapoptotic behavior and promotion of cell invasion.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21906875\n",
      "BRAF mutations are of pathogenetic significance in wild type gastrointestinal stromal tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21909080\n",
      "CXCR4 expression and BRAF mutation status could cooperatively induce and promote a more aggressive phenotype in papillary thyroid carcinoma through several pathways and specifically increase the tumors' spread outside of the thyroid gland.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21915661\n",
      "Aberrant CIMP was detected in 16% of chromosomal instable tumors and in 44% of both microsatellite instable and microsatellite and chromosomally stable carcinomas\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21936566\n",
      "this novel B-Raf fusion protein (SND-1 was identified as the B-Raf fusion partner) presents a novel target with potential clinical implications in the treatment of patients resistant to c-Met inhibitors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21937738\n",
      "A prominent epigenetic mechanism through which BRAF V600E can promote papillary thyroid cancer tumorigenesis by altering the methylation and hence the expression of numerous important genes.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21943101\n",
      "BRAF mutation V600E significantly induces cell migration and invasion properties in vitro in colon cancer cells\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21948220\n",
      "In malignant FNABs in papillary thyroid carcinoma, BRAF(V600E) mutation was significantly associated with presence of extra-thyroidal extension and metastases after surgery.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22006538\n",
      "DNA methylation of each marker was quantified using combined bisulfite restriction analysis (COBRA) and analyzed along with various genetic factors associated with CRC [the BRAF and KRAS mutations, MLH1 methylation and microsatellite instability\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22012135\n",
      "An integrated approach combining both VE1 mutant protein immunohistochemistry and genetic analysis may increase the diagnostic accuracy of BRAF mutation analysis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22027477\n",
      "Postmenopausal hormone therapy was associated with borderline statistically significant risk reductions for BRAF-wildtype tumours among women with prolonged exposure to Postmenopausal hormone therapy.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22028477\n",
      "BRAF V600E mutation is associated with hairy cell leukemia and B-cell neoplasms\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22033631\n",
      "high prevalence of BRAF (V600E) mutation is associated with synchronous bilateral papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22038996\n",
      "Results support evaluation of BRAF(V600E)-specific inhibitors for treating BRAF(V600E) malignant astrocytomas (MA) patients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22039425\n",
      "study examined the clinical characteristics and outcomes of patients with mutant BRAF advanced cancer; conclude that BRAF appears to be a druggable mutation that also defines subgroups of patients with phenotypic overlap, albeit with differences that correlate with histology or site of mutation\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22043994\n",
      "This article reviewes the spectrum of KRAS/BRAF genotype and the impact of KRAS/BRAF mutations on the clinicopathological features and prognosis of patients with colorectal cancer. [review]\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22065586\n",
      "Ras induces DR5 expression through co-activation of ERK/RSK and JNK signaling pathways\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22072557\n",
      "BRAF V600E mutation is associated with hairy cell leukemia and other mature B-cell neoplasms\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22072743\n",
      "BAG3 protein sustains anaplastic thyroid tumor growth in vitro and in vivo. The underlying molecular mechanism appears to rely on BAG3 binding to BRAF, thus protecting it from proteasome-dependent degradation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22105174\n",
      "Murine thyroid tumors carrying the human BRAF(V600E) mutations are exquisitely dependent on the oncoprotein for viability.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22105775\n",
      "BRAF (V600E) is a prevalent genetic alteration in adult sporadic papillary thyroid carcinoma in Indian cohort and it may be responsible for the progression of its classic variant.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22114137\n",
      "Overall, no difference existed in microsatellite instability or BRAF mutation frequencies between African Americans and Caucasians with colorectal neoplasms.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22133769\n",
      "BRAF mutations are associated with hairy cell leukemia and related lymphoproliferative disorders.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22136270\n",
      "Case Report: describe case of follicular thyroid carcinoma with BRAF mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22137342\n",
      "thieno[2,3-d]pyrimidines are B-Raf inhibitors\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22145942\n",
      "Pyrosequencing of BRAF V600E in routine samples of hairy cell leukaemia identifies CD5+ variant hairy cell leukaemia that lacks V600E.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22147429\n",
      "V600E mutation of the BRAF gene reported to be associated with poor prognosis of germ cell tumors in adults prognostic biomarkers cannot necessarily be transferred from one age group to the other.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22147942\n",
      "BRAF mutation is associated with inferior survival in stage III colon cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22150560\n",
      "papillary thyroid cancers in young patients display a low prevalence of the already identified oncogenic alterations; the increasing prevalence with age is mainly due to V600E BRAF mutation\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22156467\n",
      "The BRAF V600E mutation is associated with a higher pathological stage at surgery and a higher rate of recurrence.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22156468\n",
      "BRAF mutations enhance the predictability of malignancy in thyroid follicular lesions of undetermined significance.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22157687\n",
      "BRAF and KRAS mutations were observed in six (46.2%) and four (30.3%) filiform serrated adenomaS, respectively.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22170714\n",
      "BRAF mutation in papillary thyroid carcinoma is a later subclonal event, its intratumoral heterogeneity may hamper the efficacy of targeted pharmacotherapy, and its association with a more aggressive disease should be reevaluated.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22174938\n",
      "The antibody response against the catalytic domain of BRAF is not specific for rheumatoid arthritis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22178589\n",
      "Report mutations in KRAS, EGFR, and BRAF in cholangiocarcinoma and identify therapeutic targets for tyrosine kinase inhibitors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22180495\n",
      "Findings suggest that the BRAF inhibitor vemurafenib in combination with standard-of-care or novel targeted therapies may lead to enhanced and sustained clinical antitumor efficacy in CRCs harboring the BRAF(V600E) mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22189819\n",
      "Aberrant gene methylation driven by BRAF(V600E) altered expression of the DNA methyltransferase 1 and histone methyltransferase EZH2 profoundly.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22190222\n",
      "The BRAF(V600E) mutation was associated with high-risk clinicopathologic characteristics in patients with papillary thyroid cancer (PTC). The BRAF(V600E) mutation may be a potential prognostic factor in PTC patients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22190283\n",
      "B-Raf gene mutation primarily occurs at two loci--the exon 11 glycine loop and the activation area of exon 15--in surgically resected specimens of hepatocellular carcinoma patients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22194995\n",
      "These data support a model where the continuous regenerative process initiated by oncogenic B-RAF-driven alveolar disruption provides a tumor-promoting environment associated with chronic inflammation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22199277\n",
      "RET mutations may have a role in medullary thyroid carcinoma, while BRAF, AKT1, and CTNNB1 do not; the role of HRAS, KRAS, and NRAS mutations are not determined\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22199339\n",
      "analysis of BRAF gene mutations in non-small cell lung cancer\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22203991\n",
      "These results provide a functional link between oncogenic BRAF and angiogenesis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22210186\n",
      "Patients with microsatellite instability tumor phenotype had favorable prognosis, but in those with the V600E BRAF mutation higher recurrence rate was observed.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22210875\n",
      "Our results suggest that HCLv and IGHV4-34(+) HCLs have a different pathogenesis than HCLc and that a significant minority of other HCLc are also wild-type for BRAF V600.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22214007\n",
      "Although it constitutes a poor prognostic factor in colorectal cancer, it is not conclusive if it interferes with a poor therapeutic effect when cetuximab is used.[review]\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22227015\n",
      "The findings show mutant BRAF-induced oncogenic stress manifests itself by DNA damage and growth arrest by activating the pCHK2-p53-p21 pathway.It also confers tumor-promoting phenotypes such as the up-regulation of GLUT1 and enhances glucose metabolism.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22228154\n",
      "In patients with colorectal adenocarcinoma, there were significant differences between BRAF wild-type and mutant tumors in age, female sex, proximal tumor location, frequency of microsatellite instability, and survival.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22230299\n",
      "One chronic lymphocytic leukaemia patient and one patient with B-prolymphocytic leukaemia were found to harbour the BRAF V600E mutation\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22233696\n",
      "Sessile serrated adenomas are precursors of sporadic colorectal cancers with microsatellite instability.Identified a novel surface microstructure, the Type II open-shape pit pattern (Type II-O), which was specific to SSAs with BRAF mutation and CIMP.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22235286\n",
      "evidence for heterogeneity of the BRAF(V600E) mutation within individual melanoma tumor specimens\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22245873\n",
      "No BRAF mutations were found in colon adenocarcinomas from renal transplant recipients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22246856\n",
      "BRAF V600E mutation in low and intermediate grade lymphomas is associated with frequent occurrence in hairy cell leukaemia.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22249628\n",
      "None of the molecular marker mutations that were analyzed in this study, including the BRAF mutation, predicted lymph node metastasis in classic papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22250191\n",
      "During therapy with selective BRAF inhibitors, panniculitis with arthralgia represents a new adverse effect that can require dose reduction.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22258409\n",
      "Mutational activation of both BRAF and PIK3CA genes does contribute to hepatocellular tumorigenesis at somatic level in Southern Italian population.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22282465\n",
      "In naive GISTs carrying activating mutations in KIT or PDGFRA a concomitant activating mutation was detected in KRAS (5%) or BRAF (about 2%) genes. I\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22287190\n",
      "BRAF mutation is associated with colorectal serrated adenocarcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22294102\n",
      "No hotspot mutations in Braf were found in oral squamous cell carcinoma in a Greek population.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22314188\n",
      "Colon adenocarcinomas with BRAF mutations have morphologic characteristics distinct from those with KRAS mutations and BRAF-mutated proximal colonic adenocarcinomas with proficient DNA mismatch repair have an aggressive clinical course.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22317764\n",
      "Data indicate that 266 (76.2%) tumors harbored EGFR mutations, 16 (4.6%) HER2 mutations, 15 (4.3%) EML4-ALK fusions, 7 (2.0%) KRAS mutations, and 2 (0.6%) BRAF mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22317887\n",
      "Report of oncogenic BRAF/KRAS mutations in sporadic glomus tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22331186\n",
      "BRAFmut as a useful marker in hairy cell leukemia.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22331825\n",
      "BRAF mutation is an independent prognostic biomarker for colorectal liver metastasectomy.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22335197\n",
      "BRAF V600E mutation-positive papillary thyroid carcinomas (PTCs) displayed infiltrative growth, stromal fibrosis, psammoma bodies, plump eosinophilic tumour cells, and classic fully developed nuclear features of PTC.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22339435\n",
      "Data suggest that the BRAF V600E mutation does not seem to play a role in myeloid malignant transformation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22358007\n",
      "(BRAF(V600E))detected in 141/170 malignant thyroid nodules (82.9%) (140 PTCs and one follicular variant of PTC). BRAF status not associated with US features with the exception of a negative relation between BRAF(V600E) and an irregular shape (p = 0.004).\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22361037\n",
      "This is the first reported study of the relationship between CK20/CK7 immunophenotype, BRAF mutations and microsatellite status in colorectal carcinomas\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22367297\n",
      "A distinct subset of atypical Spitz tumors is characterized by BRAF mutation and loss of BAP1 expression.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22368298\n",
      "review demonstrates that tumour BRAF V600E mutation, and MLH1 promoter 'C region' methylation specifically, are strong predictors of negative MMR mutation status[review]\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22374786\n",
      "The presence of activating GNAS mutations, in association with KRAS or BRAF mutations, is a characteristic genetic feature of colorectal villous adenoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22376079\n",
      "evidence presented that ERK activation occurs in a K-ras or B-raf -independent manner in the majority of primary colon cancer cases; B-raf mutations are not associated with mismatch-repair deficiency through loss of hMLH1 or hMSH2 expression\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22376167\n",
      "The V600E BRAF mutation in papillary thyroid carcinomas may contribute to the initiation of the glycolytic phenotype and confers growth advantages in cancer\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22382362\n",
      "Eleven patients displayed Durable Disease Control (DDC) of which 55% had BRAF-V600E mutation positive tumors and 45% did not.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22393095\n",
      "Patient diagnosed with colon cancer shows poor prognosis with BRAF genetic mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22395615\n",
      "findings show (V600E)B-RAF copy-number gain as a mechanism of acquired B-RAF inhibitor resistance in 4 out of 20 patients treated with B-RAF inhibitor\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22398042\n",
      "In a cohort of Indian patients with ulcerative colitis, with or without neoplasia, none showed the BRAF mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22417847\n",
      "we have analyzed the prevalence of somatic mutations in the FGFR3, PIK3CA, AKT1, KRAS, HRAS, and BRAF genes in bladder cancers\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22426079\n",
      "Data indicate that TaqMan(R) Mutation Detection assay is an important technology to consider in the field of mutation detection for KRAS, BRAF and EGFR point mutation screening.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22426956\n",
      "genetic association studies in population in Turkey: Data suggest that a mutation in BRAF (V600E; found in 39.45% of patients) is associated with aggressiveness of papillary thyroid neoplasms; lymph node metastasis increases when mutation is present.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22427190\n",
      "Investigation the prevalence of mutations in the BRAF gene and its correlation with demographic characteristics, tumor location and stage in 100 colorectal carcinoma patients from India.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22429583\n",
      "Article reviews the current understanding of BRAF gene, its structure, expression, and signal pathway in non-small cell lung cancer. [Review]\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22430133\n",
      "The prevalence of EGFR, KRAS, BRAF and PIK3CA somatic mutations in 861 randomly selected Chinese patients with non-small cell lung cancer\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22430208\n",
      "We propose that , and that persistent phosphorylation of Mps1 through BRAF(V600E) signaling is a key event in disrupting the control of centrosome duplication and chromosome stability that may contribute to tumorigenesis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22430215\n",
      "expression of these oncogenes markedly stimulated ERK1/2 activities and morphologically transformed IECs. Importantly however\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22431777\n",
      "Effective use of PDT in the treatment of BRAF inhibitor-associated KAs and SCCs.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22431868\n",
      "EFVPTC 1 patient BRAFV600E mutation, NVPTC 2 patients, FVPTC 2 patients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22435913\n",
      "analysis of a patient with pancreatic metastasis arising from a BRAF(V600E)-positive papillary thyroid cancer [case report]\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22451557\n",
      "The BRAF(V600E) mutation analysis from FNA specimens for calcified thyroid nodules may be performed for a greater negative predictive value and unveil the malignancy in 25% of indeterminate or nondiagnostic cytology.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22456166\n",
      "Report marked differences in the genetic pattern of the BRAF or NRAS mutated and wild-type melanoma subgroups.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22459936\n",
      "BRAF mutations play a limited role in the development of sinonasal cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22471241\n",
      "Out of 1041 Korean patients with papillary thyroid carcinoma, 0.4% had rare types of BRAF mutation and three new somatic mutations were identified\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22471666\n",
      "An update on malignancies displaying high frequencies of BRAF mutations and the mechanisms underlying the side effects and drug resistance phenomena associated with Raf inhibitors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22488961\n",
      "prevalence of the BRAF(V600E) mutation increased with increased tumor size\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22492957\n",
      "BRAF V600E is associated with gliomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22498935\n",
      "No BRAF V600E mutations were indentified in this study of patients with endometrial cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22500044\n",
      "Highly sensitive and specific molecular assays such as MEMO sequencing are optimal for detecting the BRAF mutations in thyroid FNAC because these techniques can detect PTC that might be missed by cytology or less sensitive molecular assays.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22506009\n",
      "The (600DLAT)B-RAF and (V600E)B-RAF mutations were found enriched in DNA and mRNA from the CD1a+ fraction of granuloma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22508706\n",
      "The analysis of BRAF mutations by pyrosequencing is useful to refine the risk stratification of patients with papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22510757\n",
      "Patients with serrated polyposis syndrome referred to genetics clinics had a pan-colonic disease with a high polyp burden and a high rate of BRAF mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22510884\n",
      "It was shown that the dimer interface within the kinase domain plays a pivotal role for the activity of B-Raf and several of its gain-of-function mutants.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22514085\n",
      "The tumor with T1799A BRAF mutation and tumor sizes of 2 cm or more were clinicopathologic parameters associated with lower STAT1 activity.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22515292\n",
      "BRAF V600E is common in patients with low-risk papillary thyroid carcinoma but does not predict recurrence.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22515520\n",
      "Mutation BRAF transforms cells through cross talk with developmental pathways Hedgehog and Wnt, as well as by deregulation of colorectal cancer related kinase pathways.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22516966\n",
      "Report upregulation of Bim and the splicing factor SRp55 in melanoma cells from patients treated with selective BRAF inhibitors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22522845\n",
      "In signet ring cell carcinoma, BRAF V600E mutation adversely affects survival in microsatellite-stable tumors, but not in high-level microsatellite-unstable tumor\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22531127\n",
      "study concludes that generally, overweight increases the risk of colorectal cancer; taller individuals have an increased risk of developing a tumour with a BRAF mutation or microsatellite instability\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22531170\n",
      "Demonstrate that BRAF V600E mutation-specific antibody can be used in immunohistochemical diagnosis of hairy cell leukemia.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22534474\n",
      "BRAF and KIT mutations have been found in Japanese melanoma patients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22535154\n",
      "study shows there are clinically and biologically distinct subtypes of BRAF-mutant metastatic melanoma, defined by genotype, with distinct etiology and behavior; cumulative sun-induced damage in primary cutaneous melanoma and older age are associated with V600K BRAF mutations;it establishes prevalence of the BRAF mutation by age-decade\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22535974\n",
      "The diagnostic sensitivity for thyroid cancer is significantly increased by BRAF V600E mutation analysis, indicating that the screening for BRAF mutation in FNAB samples has a relevant diagnostic potential.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22549559\n",
      "Recurrent/persistent PTC in the central compartment typically harbors the BRAF mutation\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22549727\n",
      "abrogation of BRAFV600E-induced senescence contributes to melanomagenesis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22549934\n",
      "The mTOR pathway could be a good target to enhance therapy effects in certain types of thyroid carcinoma, namely in those harboring the BRAF(V600E) mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22568401\n",
      "These results suggest that low-grade diffuse gliomas with 1p/19q loss have frequent BRAF gains\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22579930\n",
      "KRAS, BRAF, and PIK3CA mutations in colorectal cancer have sustained prevalence rate in the Taiwanese population.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22581800\n",
      "BRAF regulates expression of long noncoding RNAs in melanocytes and melanoma cells\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22586484\n",
      "In the present study, we did not find any significant correlations between KRAS, BRAF and PIK3CA mutations and the loss of PTEN expression and various clinicopathological features in Chinese patients with colorectal cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22591444\n",
      "Our results suggest that in a small fraction of diffuse gliomas, KIAA1549-BRAF fusion gene and BRAF(v600E) mutation may be responsible for deregulation of the Ras-RAF-ERK signaling pathway\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22592144\n",
      "Immunohistochemical detection of the mutated V600E BRAF protein in papillary thyroid carcinoma may facilitate mutational analysis in the clinical setting.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22614711\n",
      "BRAF p.Val600Lys mutations were present at a relatively high frequency in the cohort of metastatic melanoma patients (27/183, 15%)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22614978\n",
      "BRAF/NRAS mutations were identified in 58% of primary melanomas (43% BRAF; 15% NRAS)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22628551\n",
      "Data show that RNF149 (RING finger protein 149) interacts with wild-type BRAF.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22639828\n",
      "Data suggest that BRAF V600E mutation may not be widespread in hematologic malignancies, excluding hairy-cell leukemia (HCL).\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22649091\n",
      "Patient's BRAF mutation was likely responsible for his tumor's marked response to dasatinib, suggesting that tumors bearing kinase-impaired BRAF mutations may be exquisitely sensitive to dasatinib.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22681706\n",
      "BRAFV600E mutation is associated with lymph node metastasis in multiple papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22684223\n",
      "The presence of BRAF mutations in these adenomatous precursors to colon cancer suggests that they represent sessile serrated adenomas with complete cytologic dysplasia.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22694820\n",
      "In papillary thyroid cancer, significant correlations between the methylation status of four genes (TIMP3, RASSF1A, RARbeta2 and DCC) and the V600E BRAF mutation were found.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22699145\n",
      "Data indicate that 14% with pancreatic ductal adenocarcinomas (PDACs) and 7% ampullary adenocarcinomas (A-ACs) had mutations in both KRAS and BRAF.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22702340\n",
      "In papillary thyroid carcinoma BRAFV600E is associated with increased expression of the urokinase plasminogen activator and its cognate receptor, but not with disease-free interval.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22705994\n",
      "Hairy cell leukemia cell lines expressing annexin A1 and displaying B-cell receptor signals characteristic of primary tumor cells lack the signature BRAF mutation to reveal unrepresentative origins.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22706026\n",
      "The combined effects of EGFR downregulation, ligand competition, and immune effector function conspire to inhibit tumor growth in xenograft models of cetuximab-resistant BRAF and KRAS mutant cancers.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22727996\n",
      "BRAF V600E mutations are present in approximately 90% of all kidney metanephric adenoma cases, serving as a potential valuable diagnostic tool in the differential diagnosis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22730329\n",
      "Reactivation of mitogen-activated protein kinase (MAPK) pathway by FGF receptor 3 (FGFR3)/Ras mediates resistance to vemurafenib in human B-RAF V600E mutant melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22732794\n",
      "BRAF V600E mutation revealed a strong association with specific histological variants of papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22740704\n",
      "These results clearly prove that the BRAFV600E mutation is not associated with the development of distant metastases or fatal outcome in papillary thyroid carcinoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22742884\n",
      "Vemurafenib is effective for advanced melanomas expressing the BRAF V600E mutations [review]\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22743296\n",
      "BRAF V600E mutation is associated with response to vemurafenib in lung adenocarcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22751131\n",
      "B-Raf/MKK/ERK controls key aspects of cancer cell behavior and gene expression by modulating a network of miRNAs with cross-regulatory functions.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22752848\n",
      "study reports a novel complex BRAF mutation identified in 4/492 Japanese papillary thyroid carcinoma(PTC) cases; findings suggest the BRAF(V600delinsYM)mutation, is a gain-of-function mutation and plays an important role in PTC development\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22767446\n",
      "study found a relatively higher B-Raf serine/threonine-protein kinase (BRAF)(V600E) mutation rate in classical type papillary thyroid carcinomas than in other similar studies\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22770943\n",
      "BRAF mRNA expression may help to identify PTC among thyroid nodules independently of the presence of BRAFV600E mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22772867\n",
      "BRAF (V600) mutations are are associated with melanomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22773810\n",
      "Lung cancers with acquired resistance to EGFR inhibitors occasionally harbor BRAF gene mutations but lack mutations in KRAS, NRAS, or MEK1.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22797077\n",
      "RSK regulates activated BRAF signalling to mTORC1 and promotes melanoma growth\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22798288\n",
      "Data show clinical significance to BRAF(L597) mutations in melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22798500\n",
      "In CRC patients treated with cetuximab, activating mutation signatures for BRAF (58 genes) were developed.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22799316\n",
      "Preoperative BRAF mutation was a predictive factor for occult contralateral papillary thyroid microcarcinoma presence.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22809251\n",
      "As has been reported in other common types of melanoma, V600 BRAF mutation is the most common mutation of those tested in spindle cell melanoma. NRAS or KIT mutation appears to be rare, if not completely absent.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22814862\n",
      "we found no cases of Rosette-forming glioneuronal tumors of the fourth ventricle showing KIAA1549-BRAF gene fusion or BRAF (V600E) mutation\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22820187\n",
      "these results link epigenetic genes to methylation and suppression of tumor suppressor genes as a mechanism involved in BRAFV600E-promoted melanoma tumorigenesis and uncover a novel molecular signature that predicts a poor prognosis of melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22820660\n",
      "No BRAF V600E mutations were detected in nonserous epithelial ovarian tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22824468\n",
      "Single Nucleotide Polymorphisms in BRAF gene is associated with diseases.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22826122\n",
      "It was concluded that extracellular kinase-mediated up-regulation of c-myc by K-Ras or B-Raf oncogenes disrupts the establishment of apical/basolateral polarity in colon epithelial cells independently of its effect on proliferation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22826437\n",
      "RAF1(D486N), as well as other kinase-impaired RAF1 mutants, showed increased heterodimerization with BRAF, which was necessary and sufficient to promote increased MEK/ERK activation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22833462\n",
      "Investigated BRAF and RAF1 alterations in Chinese prostate cancer.Found BRAF truncated in five of 200 informative Chinese cases & RAF1 was truncated in three of 204 informative cases and genomic rearrangements were correlated w/high Gleason scores.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22850568\n",
      "This study reveals a novel mechanism of immune suppression sensitive to BRAF(V600E) inhibition, and indicates that clinical blockade of IL-1 may benefit patients\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22858857\n",
      "A review summarizes the role of the BRAF V600E mutation in the development and progression of thyroid cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22859608\n",
      "BRAFV600E mutation is associated with Langerhans cell histiocytosis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22863493\n",
      "The BRAFV600E occurs exclusively in papillary thyroid carcinoma and papillary carcinoma-derived anaplastic cancer, rising as a specific diagnostic marker for this tumor when identified in cytological / histological exams\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22870241\n",
      "High-throughput genotyping in metastatic esophageal squamous cell carcinoma identifies phosphoinositide-3-kinase and BRAF mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22876591\n",
      "Cardio-facio-cutaneous syndrome is caused by heterogeneous mutations in BRAF gene.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22879539\n",
      "High prevalence of BRAF V600E mutations is associated with Erdheim-Chester disease but not in other non-Langerhans cell histiocytoses.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22880048\n",
      "This study reveals a novel molecular mechanism underlying the regulation of feedback loops between the MAPK and AKT pathways.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22887810\n",
      "A K601E BRAF mutation is associated with papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22892521\n",
      "The results of this study supported an important role for BRAF duplication and MAPK pathway activation in gliomas of the optic nerve proper.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22898351\n",
      "MSI status, KRAS and BRAF mutation rates varied remarkably among the colonic carcinoma subsites irrespective of right- and left-sided origin.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22899730\n",
      "The presence of a BRAF c.1799T>A (p.V600E) mutation is associated with significantly poorer prognosis after colorectal cancer diagnosis among subgroups of patients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22912864\n",
      "Data indicate that mutation frequency in malanoma patients was found witih BRAF(V600) in 51%, NRAS in 19%, PI3K pathway in 41% and PTEN in 22%.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22918165\n",
      "BRAF(V600E) mutation is an early event in thyroid carcinogenesis, and is associated with distinctive morphology and aggressive features even in papillary thyroid microcarcinomas\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22926515\n",
      "ARAF seems to stabilize BRAF:CRAF complexes in cells treated with RAF inhibitors and thereby regulate cell signaling in a subtle manner to ensure signaling efficiency\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22930283\n",
      "BRAF mutation is associated with early stage disease and improved outcome in patients with low-grade serous ovarian cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22931913\n",
      "We conclude that the presence of BRAF mutation, NRAS mutation, and the absence of an immune-related expressed gene profile predict poor outcome in melanoma patients with macroscopic stage III disease.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22932786\n",
      "Thus, in this meta-analysis, the BRAF mutation in PTC was significantly associated with PTC recurrence, lymph node metastasis, extrathyroidal extension, and advanced stage AJCC III/IV.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22938585\n",
      "Data indicate that KRAS, BRAF, PIK3CA, and AKT1 mutations can be rapidly and accurately detected for cancer diagnosis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22941165\n",
      "The BRAF V600E mutation is the only independent predictor of compartment lymph node metastasis in papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22946697\n",
      "Data indicate that of the 32 cardio-facio-cutaneous syndrome (CFC) patients, 28 (88%) had a known mutation in a gene that is causative for CFC, including BRAF (n = 21), MEK1 (n = 2), MEK2 (n = 4), and KRAS (n = 1).\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22972589\n",
      "Higher response rates and longer time to progression were observed with selumetinib-containing regimens in patients who had melanoma that harbored a BRAF mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22973979\n",
      "found a significantly increased risk of papillary thyroid carcinoma attributed to the SNP variants rs17161747, rs1042179, and rs3748093 for those with a family history of cancer, for smokers, and for both those of age <45 years and nondrinkers\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22996177\n",
      "This report is the first to identify the rare, variant BRAF V600D mutation in LCH, and provides support for constitutively activated BRAF oncogene-induced cell senescence as a mechanism of regression in congenital, benign LCH.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23009221\n",
      "consistent with previous studies, it was concluded that the incidence of BRAF V600E mutation in adult acute lymphoblastic leukemia, if any, is extremely infrequent\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23010278\n",
      "B-RAF upregulates SGLT1 activity, an effect requiring vesicle insertion into the cell membrane.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23010994\n",
      "BRAF mutation is suggested to be poor prognostic factors in CRLM.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23014346\n",
      "Braf mutation status is not significantly associated with poor survival for melanoma in Koreans.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23021375\n",
      "EGFR and downstream genetic alterations in KRAS/BRAF and PI3K/AKT pathways have roles in colorectal cancer and treatment [review]\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23026937\n",
      "Immunohistochemistry is highly sensitive and specific for the detection of V600E BRAF mutation in melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23033302\n",
      "the spectrum and frequency distribution of the identified KRAS and BRAF mutations in Serbian patient with colorectal cancer are in good accordance with literature data.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23036672\n",
      "We describe 3 patients with BRAF V600E mutation metastatic melanoma in whom treatment with vemurafenib resulted in prompt extracranial disease response but progression of metastatic disease in the brain.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23039341\n",
      "Studied the cytotoxicity and anti-tumour activity of novel MEK inhibitor, E6201, in a panel of melanoma cell lines. Most melanoma cell lines were sensitive or hypersensitive to E6201; the sensitivity correlated with wildtype PTEN and mutant BRAF status.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23041829\n",
      "Findings support the potential use of immunohistochemistry as an ancillary screening tool to assess the BRAFV600E mutation status in primary cutaneous melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23051629\n",
      "Increased BRAF mutation with age along with the lack of a UVR magnitude-BRAF mutation association suggests that duration of exposure rather than UVR exposure dose is the more likely link to acquiring mutations in melanocytic nevi.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23055340\n",
      "KRAS and BRAF mutations are infrequent or absent, respectively in Intestinal-type sinonasal adenocarcinoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23055546\n",
      "BRAF mutation was associated with lymph node metastases (LNM), advanced stage, extrathyroidal extension, tumor size, male gender, multifocality, absence of capsule, classic PTC, and tall-cell variant papillary thyroid cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23056577\n",
      "A systematic review and meta-analysis revealed that BRAF mutation is an absolute risk factor for patient survival in colorectal cancer and melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23062653\n",
      "BRAF mutation was not found to be significantly associated with lymph node metastasis in patients with papillary thyroid cancer\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23066120\n",
      "The BRAF(V600E) mutation was demonstrated to be a poor prognostic factor for the persistence of the disease independent from other clinical-pathological features in low-risk intrathyroid papillary thyroid carcinoma patients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23069257\n",
      "Histopathologic changes suggesting prolapsed rectal mucosa should take precedence over BRAF results in diagnosing sessile serrated adenomas in the rectum.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23088640\n",
      "analysis suggests that BRAF mutations occur at a low frequency in chronic lymphocytic leukemia\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23095503\n",
      "Desmoplastic malignant melanoma: a study of ten cases and status of BRAF mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23096133\n",
      "BRAF mutation is associated with pleomorphic xanthoastrocytomas with anaplastic features.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23096702\n",
      "We found that NRAS-mutant melanomas were significantly more likely from older patients and BRAF-mutant melanomas were more frequent in melanomas from the trunk.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23098991\n",
      "Studied differential miRNA expression in metastatic colorectal cancer by microarrays from primary tumors of 33 patients who had wild-type KRAS/BRAF and third- to sixth-line anti-EGFRmAb treatment, with/without irinotecan.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23110075\n",
      "Study demonstrates that chromosomal instability commonly occurs in advanced BRAF mutant/MSS colorectal cancers where it may contribute to poorer survival, and further highlights molecular similarities occurring between these and BRAF wild type cancers.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23125007\n",
      "One hundred and ten patients (51%) were identified who were potentially nonresponders to anti-EGFR therapy:  13/117 (11.1%) had the V600E BRAF mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23132792\n",
      "BRAFV600E mutation is associated with cervical lymph node metastasis and recurrence in papillary thyroid cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23138171\n",
      "Clinical characteristics of colorectal cancer with the V600E BRAF mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23153455\n",
      "These findings indicate that ABCG2 confers resistance to vemurafenib in A375 cells, suggesting involvement of this transporter in acquired resistance to vemurafenib.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23157614\n",
      "Data indicate that the presence of the BRAF V600E mutation was more frequent in women, but this gender difference was not statistically significant.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23157823\n",
      "In Chinese colorectal carcinoma patients, BRAF mutation is associated with tumor differentiation and primary tumor sites.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23157824\n",
      "Codon 12, 13 in KRAS gene and codon 600 in BRAF gene are the most common mutation points in Chinese colorectal cancer. KRAS and BRAF mutations are mutually exclusive. KRAS and BRAF gene mutation is higher in females than that in males.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23158172\n",
      "BRAF mutational status is predictive of papillary thyroid carcinoma recurrence\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23159116\n",
      "V600E point mutation was identified in the BRAF gene in 3 intramucosal nevi and in 2 melanomas. Only 1 blue nevus harbored the GNAQ209 mutation\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23161556\n",
      "BRAF mutation as a new serum marker for papillary thyroid carcinomas were not detectable in patientts diagnosed with thyroid neoplasms.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23161722\n",
      "data confirm that among lymphoproliferative disorders, BRAF V600E mutation is restricted to hairy cell leukemia (HCL); no mutations were identified in variant HCL, NMZL, ENMZL, PTLD, PTCL, ALCL, or LGL proliferations\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23163107\n",
      "The BRAF(V600E) mutation might be associated with a more aggressive phenotype and a poor prognosis in classic variant of papillary thyroid carcinomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23179992\n",
      "BRAF (V600E) mutation is associated with papillary thyroid carcinomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23188063\n",
      "BRAF mutations were correlated with poor overall survival in the full patient cohort\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23190154\n",
      "Our findings suggest that RAS pathway activation due to BRAF V600E and KRAS mutations is an important event in a subset of peripheral nerve sheath tumours not related to neurofibromatosis\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23190890\n",
      "Oncogenic B-RAF(V600E) signaling induces the T-Box3 transcriptional repressor to repress E-cadherin and enhance melanoma cell invasion.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23192464\n",
      "Aim of this work is to provide a detailed comparison of clinical-pathologic features between well-differentiated and poorly differentiated tumors according to their BRAF and RASSF1A status.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23192956\n",
      "BRAF (V600E) mutation is associated with papillary thyroid microcarcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23203004\n",
      "BRAF (V600E) is non-associated with Gal-3 expression, whereas it is associated with cytoplasmatic localization of p27kip1 and higher CK19 expression in papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23207070\n",
      "The present study revealed that ESCC of Brazilian patients do not present mutations in hot spots of EGFR, K-RAS and BRAF and only a minor proportion present overexpression of EGFR or HER2.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23208503\n",
      "results suggest that mutant B-RAF signaling downregulates Tiam1/Rac activity resulting in an increase in N-cadherin levels and a decrease in E-cadherin levels and ultimately enhanced invasion\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23224067\n",
      "Mutations affecting BRAF, EGFR, PIK3CA, and KRAS are not associated with sporadic vestibular schwannomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23235345\n",
      "the BRAF V600E mutation is not pathobiologically relevant in primary central nervous system lymphoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23237741\n",
      "Patients with V600R BRAF mutations can be treated successfully with oral BRAF inhibitors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23242808\n",
      "Data indicate that BRAF and EGF receptor or SRC family kinase inhibition blocked proliferation and invasion of the resistant tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23246082\n",
      "the role of BRAF mutations in melanoma and colorectal cancer, focusing on similarities and differences of BRAF mutations (Review)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23253715\n",
      "The status of BRAF(V600E) mutation was more frequent in multifocal PTC patients with lymph node metastasis and diagnosis at later age.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23263826\n",
      "we deduce that in the absence of mutation activation, B-Raf overexpression or downregulation is a protective event, since it delays the development of both malignant and benign thyroid tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23274581\n",
      "BRAF mutation is associated with esophageal squamous cell carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23280049\n",
      "Preoperative mutation screening for BRAF(V600E) does not meaningfully improve risk stratification and is unlikely to alter the initial management of patients with indeterminate nodules.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23287985\n",
      "Pulmonary Langerhans cell histiocytosis appears to be a clonal proliferation that may or may not have BRAF V600E mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23290787\n",
      "Studies indicate that BRAF mutations are identified in 40-50% of patients with melanoma, and treatment with either of two BRAF inhibitors (vemurafenib, dabrafenib) or the MEK inhibitor trametinib is associated with improved clinical benefit.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23297805\n",
      "No point mutations were identified in BRAF codon Val600Glu in the studied colorectal adenocarcinomas in the Turkish population.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23307859\n",
      "High BRAF is associated with metastatic melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23310942\n",
      "This study shows that BRAF mutation occurs in Nigerian colorectal cancers.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23317446\n",
      "Results demonstrated the action of Dabrafenib and the inhibition of MAPK pathway in melanoma cell lines carrying BRAFV600D/R mutations; these results could be helpful to enlarge the number of patients who may benefit of a more effective targeted treatment\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23324583\n",
      "BRAF mutations is associated with colorectal cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23334329\n",
      "Human neural crest progenitor cells are susceptible to BRAF(V600E)-induced transformation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23343956\n",
      "no association with BRAF-V600E mutation in gastroeosophageal tumors\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23349307\n",
      "Data indicate that besides confirming the constant presence of BRAF-V600E in all patients with hairy cell leukemia, phospho-ERK1/ERK2 expression was observed.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23352452\n",
      "Ras pathway activation via EGF treatment induced strong binding between B-Raf and C-Raf and a low level of binding between B-Raf and A-Raf.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23354951\n",
      "Alternative splicing of exons 14, 15, 15b, 16b and 16c occurs in a considerable fraction of BRAF mRNA in normal colon and colorectal cancer cells and is independent of the V600E mutational status of the parental allele.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23355004\n",
      "The detected Merkel cell polyomavirus prevalence in non-small cell lung cancer in combination with the deregulated expression of BRAF and Bcl-2 genes suggests that these events are likely to contribute to the pathogenesis of non-small cell lung cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23359496\n",
      "Kidins220 is a novel T-cell receptor (TCR)-interacting protein that couples B-Raf to the TCR. Kidins220 is mandatory for sustained Erk signaling and is crucial for TCR-mediated T cell activation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23370429\n",
      "This is the first report of BRAF V600E mutation in endometrial cancer, indicating that it may contribute to tumorigenesis of endometrial cancer, although at a low frequency compared with KRAS mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23370668\n",
      "study suggests that highly aggressive papillary thyroid microcarcinoma may arise in a subset of patients with BRAF(V600E) mutation and tumors greater than 5 mm; multivariate analysis showed that tumor recurrence was not associated with BRAF(V600E)mutation\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23374602\n",
      "BRAF and codon 12 KRAS mutations predict for adverse outcome of colorectal cancer patients receiving cetuximab.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23388101\n",
      "Report BRAF mutations in ovarian serous carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23401445\n",
      "The role of BRAF V600E as targetable driver mutation in lung adenocarcinoma is strengthened by finding that in vivo expression of V600E in mice leads to development of invasive adenocarcinoma, a phenotype that is reversed when V600E expression is stopped.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23401454\n",
      "Studies identified 21 deleterious mutations MLH1, MSH2, MSH6 and BRAF.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23412871\n",
      "The BRAF gene polymorphism (rs10487888) may not be a genetic determinant for increasing the risk of chronic periodontitis among the Iranian population\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23416158\n",
      "AURKB and WEE1 are targets and biomarkers of therapeutic efficacy, lying downstream of (V600E)B-RAF in melanomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23416953\n",
      "study identified two miRNAs (miR-21* and miR-203 that are differentially expressed in papillary thyroid carcinoma tissues with BRAF(V600E) and revealed their associations with clinicopathological features\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23435375\n",
      "BRAF(V600E) increases migration and invasion of thyroid cancer cells via upregulation of Snail with a concomitant decrease of its target E-cadherin.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23435618\n",
      "BRAF V600E mutation was detected in 41/71 (58 %) gangliogliomas by immunohistochemistry, DNA sequencing was concordant in 60 of 62 analyzed cases, and BRAF V600E-mutated protein was localized predominantly to the neuronal compartment.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23442159\n",
      "This study demonistrated that Dysembryoplastic neuroepithelial tumors share with pleomorphic xanthoastrocytomas and gangliogliomas BRAF(V600E) mutation and expression.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23444215\n",
      "Data indicate that tumor regression was seen in three of five patients with BRAF-mutated, low pAKT melanomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23447565\n",
      "MITF-BCL2A1 as a lineage-specific oncogenic pathway in melanoma and underscore its role for improved response to BRAF-directed therapy.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23448684\n",
      "An analysis of BRAF mutations in fast-growing melanomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23455323\n",
      "The Mcl-1 promoter is dependent on a STAT consensus-site for B-RAF-mediated activation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23463215\n",
      "In this manuscript, we provide an overview of the emerging scientific literature on dermatological adverse events arising out of BRAF inhibition.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23463675\n",
      "V600R mutation and double (V600E -V600M) mutation were identified in two melanomas\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23476074\n",
      "BRAF V600E mutation testing modifies sensitivity or specificity of the Afirma Gene Expression Classifier in cytologically indeterminate thyroid nodules.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23477830\n",
      "melanomas with activation of the BRAF/MAPK pathway have suppressed levels of MITF and PGC1alpha and decreased oxidative metabolism\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23482475\n",
      "BRAF mutation shows clinical significance in the prognosis of thyroid papillary cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23482591\n",
      "Results document the expression of RAC1b in normal thyroid cells as well as overexpression in a subset of PTCs. They suggest a possible interplay between BRAF V600E and RAC1b contributing to poor clinical outcome.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23489693\n",
      "The novel melanoma cell lines were compared to metastatic cell lines (HBL, LND1), wild type (wt) for MC1R and BRAF genes.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23496275\n",
      "This study confirms that the BRAF mutation is differentially detected in each variant of papillary thyroid cancer and is strongly correlated with unfavorable clinicopathologic factors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23505540\n",
      "follow-up BRAFV600E mutation analysis may be helpful in the diagnosis of selected thyroid nodules negative for BRAFV600E mutation on initial analysis, which are assessed as suspicious malignant on ultrasonography.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23511561\n",
      "A BRAF mutation was only detected in a single Japanese gastric cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23517740\n",
      "Aberrant BRAF splice variants with deletions in both kinase and RAS-binding domains in rheumatoid arthritis patients demonstrate that these BRAF splice variants constitutively activate MAPK through CRAF\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23533235\n",
      "genetic association studies in population in Italy: Data suggest that V600E mutation in BRAF in subjects with papillary thyroid carcinomas with/without lymph node metastases is not associated with disease progression.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23533272\n",
      "in cells expressing KIAA1549-BRAF, the fusion kinase functions as a homodimer that is resistant to PLX4720 and accordingly is associated with CRAF-independent paradoxical activation of MAPK signaling\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23534744\n",
      "Molecular analysis of the BRAF T1799A mutation in fine needle aspiration biopsy specimens has high specificity and positive predictive value for papillary thyroid carcinoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23544999\n",
      "In human BRAF papillary thyroid carcinomas, ERK kinase phosphorylation is decreased compared to normal thyroid glands.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23547069\n",
      "BRAF V600E mutation may identify a subset of grade 2 diffuse gliomas that have a distinct phenotype, incl. supratentorial location, chronic seizure disorder, and atypical radiographic and histologic features.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23548132\n",
      "About one fourth of mCRC cases wild-type for KRAS codons 12 and 13 present other mutations either in KRAS, BRAF, or PIK3CA, many of which may explain the lack of response to anti-EGFR therapy observed in a significant proportion of these patients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23549875\n",
      "Data indicate that concurrent BRAF and PI3K/mTOR blockade results in induction of apoptosis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23552385\n",
      "A high percentage of epithelioid giant cell glioblastoma multiformemanifest BRAF V600E mutation\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23569304\n",
      "Antitumor effects of vemurafenib are mediated by inhibiting oncogenic MAPK signaling in BRAF(V600)-mutant metastatic melanoma. Data suggest that inhibition downstream of BRAF should help to overcome acquired resistance.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23571588\n",
      "In this retrospective multicenter study, the presence of the BRAF V600E mutation was significantly associated with increased cancer-related mortality among patients with papillary thyroid carcinom\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23579220\n",
      "Accurate diagnosis of rare BRAF mutations is crucial. Pyrosequencing is accurate, highly sensitive, reliable, and time saving to detect rare BRAF mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23580256\n",
      "The overall BRAF V600E mutation rate was 70.4% and 100% in tall cell variant.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23584600\n",
      "and SSCA followed by Sanger sequencing are effective two-step strategies for the detection of BRAF mutations in the clinical setting.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23588369\n",
      "Our findings confirm that BRAF mutations originate in the serrated epithelium of colonic perineuriomas with crypt serration\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23594689\n",
      "the clinical pathological relevance of BRAF mutation in cancer (Review)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23595630\n",
      "A combination of solid nodules, nodules with irregular contours, symptomatic nodules, and positive BRAF mutation has high predictive value for malignancy in patients with thyroid follicular lesion of undetermined signifi-cance.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23603840\n",
      "We show that (V600E)BRAF upholds the activity of glycolysis and therefore the addiction to glycolysis de facto becomes an addiction to (V600E)BRAF.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23612919\n",
      "BRAF alterations are associated with pediatric low grade gliomas and mixed neuronal-glial tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23613396\n",
      "K-RAS and B-RAF mutations do not seem to be predictive of treatment outcome as potential biomarkers for bevacizumab therapy in metastatic colorectal cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23615046\n",
      "BRAF mutation is associated with poor response to anti-EGFR MoAbs and it is an adverse prognostic biomarker of the survival of patients with metastatic colorectal cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23625203\n",
      "This study demonstrated that either BRAF or RAS mutations were present in two thirds of follicular variants of papillary thyroid carcinomas and these mutations were mutually exclusive.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23633454\n",
      "The presence of NRAS or BRAF mutations in a mutually exclusive pattern in roughly half (47%) of conjunctival melanomas and the pattern of CNAs argue for conjunctival melanoma being closely related to cutaneous and mucosal melanoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23636013\n",
      "Braf mutations were not associated with the risk of lymph node metastasis in papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23650027\n",
      "Detection of the BRAF V600E mutation in colorectal cancer by immunohistochemistry is a viable alternative to molecular methods\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23657789\n",
      "A BRAF mutation-specific (V600E) antibody detected tumors with BRAFV600E mutations and exhibited complete concordance with a DNA-based method.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23660947\n",
      "Establishment of molecular subgroups based on KRAS and BRAF mutation status is important and should be considered in future prognostic studies in colorectal carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23673558\n",
      "low BRAF as well as NRAS expression levels were associated with a longer progression-free survival in the total population\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23687957\n",
      "BRAFV600E mutation is not associated with papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23690527\n",
      "We found BRAF(V600E) mutations in the melanocytic nevi to be fully clonal, strongly suggesting that BRAF-activating mutations typically are early initiating events in melanocytic neoplasia.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23715079\n",
      "Case Report: BRAF mutation documented in folliculotropic metastatic melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23725167\n",
      "BRAF mutations are associated with papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23726842\n",
      "report that Mps1/AKT and B-Raf(WT)/ERK signaling form an auto-regulatory negative feedback loop in melanoma cells\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23735514\n",
      "Selumetinib plus dacarbazine showed clinical activity in patients with BRAF-mutant cutaneous or unknown primary melanoma, reflected by a significant benefit in progression-free survival.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23744164\n",
      "The mutations of EGFR and BRAF genes were not found in HER2-mutated patients with brain metastasis from non-small cell lung cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23752636\n",
      "BRAF mutation in the elderly is also exclusive of papillary carcinoma and is often significant. Furthermore, it is related to the classic variant and possibly to thyroid extravasation\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23755178\n",
      "Both the CRP single nucleotide polymorphism rs7553007 and KRAS/BRAF mutations were independent prognostic factors for colorectal cancer patients with synchronous liver metastasis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23763264\n",
      "Although moderate or strong cytoplasmic staining is specific for BRAF V600E mutations in colorectal adenocarcinoma, the VE1 monoclonal antibody is insufficiently sensitive to serve as an effective screening tool.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23771122\n",
      "We found that inherited variants of CDKN2A have no effect on the prevalence of BRAF/NRAS mutations in melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23773459\n",
      "BRAF mutations are associated with colorectal neoplasms.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23775351\n",
      "demonstrating that the BRAF(T1799A) mutation is a clonal event in thyroid cancer\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23776587\n",
      "The results indicate that BRAF mutant is a predictive biomarker for poor prognosis in mCRC patients undergoing anti-EGFR MoAbs therapy, especially in KRAS WT patients\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23782496\n",
      "BRAF, NRAS, and c-Kit molecular analyses among patients affected by nail apparatus melanoma were investigated.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23782679\n",
      "BRAF mutation rates varied by geographic location but not based on UV radiation\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23791006\n",
      "Sinonasal intestinal-type adenocarcinomas share common alterations of the EGFR pathway with colorectal adenocarcinomas, except for a lower frequency of KRAS and BRAF mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23795354\n",
      "Co-amplification of these candidate genes or the CCND1 amplification along with either BRAF or NRAS mutations might be more important for prognosis than the presence of these alterations alone.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23800934\n",
      "The findings support the hypothesis that BRAF-mutated cells may show resistance to the anticancer effects of aspirin in patients with colorectal cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23802768\n",
      "evaluated the survival impact of MET expression in patients with BRAF(V600E/K) advanced melanoma treated with vemurafenib\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23806056\n",
      "The present study demonstrates that concomitant BRAF mutation and RET/PTC rearrangement is a frequent event in papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23817129\n",
      "an unexpectedly higher frequency of BRAF mutations was observed in mucosal melanomas in Southern Italy.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23817662\n",
      "BRAF mutations are associated with lung cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23821376\n",
      "This study investigated the impact of KRAS, NRAS, BRAF, PI3KCA and TP53 status on outcome of elderly metastatic colorectal cancer patients\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23822828\n",
      "BRAF V600E mutated tumour cells was detected in the cortical tumour component, pronounced leptomeningeal tumoural stroma was predominantly negative for VE1 binding. BRAF V600E mutation affects a subset of desmoplastic infantile astrocytoma/ganglioglioma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23833299\n",
      "Although no melanomas had high-level amplification of BRAF, the two patients with progressive disease as their best response had BRAF copy gain in their tumors\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23833303\n",
      "Melanomas arising in SSD skin have higher mutation loads and contain a spectrum of molecular subtypes compared with BRAF- and NRAS-mutant tumors indicating multigene screening approaches\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23841470\n",
      "BRAF mutations are found in 2 to 4% of non-small cell lung cancers. The mutations harbor non-V600E mutations in 40 to 50% of cases. A phase 2 trial of dabrafenib described 8 responses of 20 patients with BRAF V600E mutant NSCLC\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23845288\n",
      "Although BRAF mutation appears to play a role in local tumour progression, it is not a risk factor for poor prognosis or tumour recurrence in papillary thyroid carcinoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23845441\n",
      "demonstrate dose-dependent effects of oncogenic signaling, with physiologic Braf(V600E) expression being sufficient for hyperplasia induction\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23849768\n",
      "Summing up the results about the KRAS and the BRAF mutation carriers from our study, the portion of potentially non responsive colorectal cancer patients for the anti-EGFR treatment is 28.26%.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23852164\n",
      "Patient-derived tumor xenografts provides 'real-time' results in an animal that phenocopies the biology and expected vemurafenib responses of the tumor in a patient with BRAF V600E melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23855428\n",
      "The study found a high concordance of BRAF mutation status between paired metastases diagnosed at different time points.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23860532\n",
      "Findings show that KIT and BRAF mutations are only rarely present in SNMMs, whereas NRAS mutations seem to be relatively more frequent.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23861977\n",
      "the presence of a BRAF- or NRAS mutation in a nevus was not associated with the risk of malignant transformation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23878352\n",
      "No evidence existed for a differential prognostic role of BRAF mutation by MSI status (P(interaction) > .50). Combined BRAF/MSI status in colorectal cancer is a tumor molecular biomarker for prognosic risk stratification.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23880961\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "BRAF V600E mutations occurs infrequently in endometrial cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23883275\n",
      "Shifted termination assay fragment analysis can detect BRAF V600 mutations in formalin-fixed paraffin-embedded papillary thyroid carcinoma samples.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23887306\n",
      "Classification of serrated lesions using immunohistochemical evaluation of BRAF V600E mutation may identify lesions with higher potential to progression into sessile serrated adenoma/polyp, and further to BRAF V600E-mutated colorectal cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23893334\n",
      "TIMP-1 protein expression is a reliable surrogate marker for BRAF(V600E)-mutated status in papillary thyroid carcinoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23893412\n",
      "Ras-mutant cancer cells display B-Raf binding to Ras that activates extracellular signal-regulated kinase and is inhibited by protein kinase A phosphorylation\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23903755\n",
      "Suppression of TORC1 activity in response to RAF or MEK inhibitors, as measured by decreased phosphorylation of ribosomal protein S6 (P-S6), effectively predicted induction of cell death by the inhibitor in BRAF-mutant melanoma cell lines.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23906414\n",
      "In our Near Eastern cohort, the BRAF mutation rate varied significantly by geographic location. In patients with multiple dysplastic nevi examined, discordant BRAF mutation status potentially negates an underlying constitutional predilection\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23907581\n",
      "Our studies have identified a previously unrecognized regulatory role of Lys63-linked polyubiquitination in BRAF-mediated normal and oncogenic signalings.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23908594\n",
      "Findings support the development of CDK and Raf co-targeting strategies in EGFR/HER-2-overexpressing or RAS/RAF mutant breast cancer (BC).\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23922205\n",
      "These findings demonstrate the presence of mutation-specific clinical differences between different BRAF genotypes in patients with melanoma, and support the incorporation of this information in patient evaluation and clinical trial design.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23930206\n",
      "The frequencies of EGFR, KRAS, BRAF, and HER-2 mutations in BM-NSCLC were 2.6, 38.5, 0, and 0% respectively.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23931769\n",
      "used a mutation-specific antibody for immunohistochemical detection of the BRAF V600E mutation and correlated expression with clinicopathologic features in papillary thyroid carcinoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23938765\n",
      "Report relatively high frequency of BRAF(V600E) and KIT mutations in amelanotic melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23941441\n",
      "BRAF V600E-mutated protein may be valuable in the diagnostic evaluation of these glioneuronal lesions and the observed association with mTOR activation may aid in the development of targeted treatment involving specific pathogenic pathways\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23959801\n",
      "Mortalin mediates a switch in tumor-suppressive signaling of Raf/MEK/extracellular signal-regulated kinase.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23960272\n",
      "BRAF mutation is associated with the serrated morphology of traditional serrated adenoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23963522\n",
      "detection of BRAF V600E in colorectal cancer specimens by immunohistochemistry is sensitive and specific and may help to identify Lynch syndrome patients\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23965740\n",
      "This study demonstrated the absence of consistent recurrent chromosomal alterations in desmoplastic infantile astrocytomas and desmoplastic infantile gangliogliomas and overall rarity of the BRAF mutation in these tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23969188\n",
      "the association between BRAF V600E mutation and aggressive features of papillary thyroid cancer\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23972510\n",
      "BRAF mutations were detected in 2 amelanotic acral melanoma cases\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23981603\n",
      "BRAF(V600E) mutation is predictive for distant metastasis in papillary thyroid carcinoma but not positively.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23987572\n",
      "Prevalence and distribution of pathogenetic mutations in BRAF and NRAS genes were evaluated in multiple melanoma lesions from patients with different geographical origin within the same Italian population.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23993026\n",
      "Mutation occurs at similar frequencies as NRAS in acral lentiginous melanoma of Swedish patients\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23996432\n",
      "Significant difference in Progression-free survival (PFS) and overall survival (OS)between patients with BRAF mutated and BRAF wild-type tumours was not detected\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24006859\n",
      "mutations in KRAS codon 61, KRAS codon 146, BRAF, NRAS, or PIK3CA detected in Asian patients were not predictive of clinical benefits from cetuximab treatment.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24024839\n",
      "BRAF mutations were associated with reduced overall survival among patients with cololectal cancer without KRAS mutations in exon 2 and among those with NRAS mutations in exon 3.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24026210\n",
      "We found BRAF mutations in 13/61 of the melanoma lesions and V600K predominated over V600E.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24030686\n",
      "There was no significant association between BRAF positivity and tumor multicentricity, lymphovascular invasion, extranodal extension, central neck involvement, advanced stage (stage III or IV), and distant metastasis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24039206\n",
      "BRAF protein mutation can be reliably detected in patients diagnosed with papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24052184\n",
      "The BRAF mutation was positive in 37 % of papillary thyroid carcinoma patients. It had no prognostic impact. Cause-specific survival of mutation-positive high-risk patients was poorer than CSS of mutation-negative high-risk patients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24057326\n",
      "High rate of BRAF-KIAA1549 fusion is associated with pilocytic astrocytoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24073892\n",
      "The BRAF mutation represents an additional risk factor only in some subpopulations of colorectal cancers, in others having limited prognostic value.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24094449\n",
      "hypothesize that the level of SPRY2 expression contributes to MAPK/ERK pathway output and accounts for BRAF V600E+ and clinical heterogeneity in papillary thyroid cancer\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24095280\n",
      "Data indicate that phosphorylation of BRAF by AMPK disrupts its association with KSR1.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24104864\n",
      "The low incidence of BRAF mutation limited assessment of its prognostic impact.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24112392\n",
      "BRAF mutation appears to be associated with distinct, unfavourable clinicopathological characteristics in colorectal cancer - systematic review and meta-analysis\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24112705\n",
      "The kinase activity of BRAFV600E/L505H was higher than that of BRAFV600E, resulting in cross-resistance to a MEK inhibitor\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24114843\n",
      "EGF, which signals through CRAF, and an activated BRAF mutant also activate PKC and stimulate cell migration through up-regulating RFFL expression.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24117833\n",
      "BRAF mutational analysis was performed on tissue from 104 patients: 90 with sarcoma only and 14 with sarcoma and melanoma. In the sarcoma-melanoma group, three sarcomas showed BRAF mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24118207\n",
      "BRAF signalling increases Mcl-1 expression in cutaneous metastatic melanoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24122611\n",
      "No mutations were found in the BRAF gene in a cohort of 84 patients affected by squamous cell anal cancer\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24123003\n",
      "HSP60 protein expression may inhibit lymph node metastasis in papillary thyroid carcinomas harboring the BRAF mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24124924\n",
      "evaluated the potential role of XIAP expression as a novel prognostic marker to predict recurrence, in combination with the BRAF(V600E) mutational status in papillary thyroid cancer\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24139215\n",
      "Of 54 intrahepatic cholangiocarcinoma cases, 7.4% were mutant for KRAS, 7.4% were mutant for BRAF, and these were mutually exclusive. These cases were associated with a higher tumor stage and a greater likelihood of lymph node involvement.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24139521\n",
      "When genotypes of BRAF/KRAS mutated s-BOTs and corresponding implants were compared, no patient presented with a fully matching mutation profile of s-BOT and all corresponding implants.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24152792\n",
      "results provide evidence that constitutively activated BRAF(V600E) drives aberrant proliferation of monocyte-lineage cells.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24161954\n",
      "B-Raf mutations are associated with cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24164374\n",
      "Based on this methodology and other published results for the BRAF mutation, we believe that it is now feasible and cost effective for the UK NHS to BRAF co-test all Thy4/Bethesda Class V thyroid FNAs.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24166180\n",
      "Results sugggest that Cdx2 may play a role in the serrated pathway to colorectal cancer with BRAF(V600E), CpG Island Methylator Phenotype (CIMP)-high and mismatch repair (MMR)-deficiency.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24167125\n",
      "When supplemented with other noninvasive test methods, the B-RAF(V600E) test could be a powerful adjunct with extensive clinical applications for diagnosis of thyroid nodules. (review)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24178368\n",
      "study characterized the multiple-dose pharmacokinetics of vemurafenib 240-960 mg twice daily (bid) in BRAF(V600E) mutation-positive metastatic melanoma patients, using the commercial formulation\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24183461\n",
      "Data indicate that the median time to progression (TTP) 8.9 months is close to the promising BRAF- and MEKi combination therapy with median progression-free survival (PFS) 9.4 months.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24196789\n",
      "As heterogeneity with respect to BRAF mutation status is detected in melanoma patients, subsequent testing of initially wild-type patients can yield different results and thus make BRAF inhibitor therapy accessible.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24228637\n",
      "BRAF(V600E) mutation is not associated with papillary thyroid microcarcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24238153\n",
      "The study found a BRAF(V600E) mutation frequency of 54% (seven of 13) in brainstem gangliogliomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24238398\n",
      "Rapidly metastasizing malignant melanoma characterized by a rare BRAF mutation not responding to vemurafenib\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24242331\n",
      "associations were identified between miR-31, BRAF and prognosis in CRC\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24244575\n",
      "BRAF p.V600E colon tumors showed significant MEIS1 promoter methylation, which was associated with decreased MEIS1 gene expression.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24247620\n",
      "BRAF mutation in papillary thyroid carcinoma determined by IHC is associated with significantly increased risk of lymph node recurrence.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24256466\n",
      "Frequency of somatic BRAF mutations in melanocytic lesions from patients in a CDK4 melanoma family.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24258620\n",
      "B-RAF increases the cell surface protein abundance and activity of the type II Na+-coupled phosphate transporters NaPi-IIa and NaPi-IIb.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24265152\n",
      "A novel AKT1 mutant amplifies an adaptive melanoma response to BRAF inhibition.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24267957\n",
      "Detection of BRAF(V600E) in cytology specimens by pyrosequencing is a useful diagnostic adjunctive tool in the evaluation of thyroid nodules also in elderly subjects\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24295088\n",
      "genetic association study in population in Italy: Data suggest rare BRAF variants (found in 1.6% of all thyroid malignancies) cluster around codon V600 in binding pocket named A-loop of kinase domain leading to greater stability of BRAF conformation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24297085\n",
      "The overall survival rate was not significantly different between patients with wild-type BRAF and those with V600E or non-V600E BRAF mutations in an Asian cohort.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24301760\n",
      "We conclude that a high proportion of PTC cases likely harbors the BRAF V600E mutation. This mutation can be used as an independent factor for predicting the recurrence and distal metastasis of PTC tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24309328\n",
      "BRAF V600E mutation is a rare event in biliary tract cancer, accounting for only 1% of all subtypes, and is restricted to intrahepatic cholangiocarcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24311634\n",
      "BRAF-V600E mutation is associated with younger glioblastoma patients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24321241\n",
      "These cases further expand the range of glial neoplasia in which epithelioid morphology is encountered, and add to the growing list of biphasic tumors harboring the BRAF V600E mutation\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24335665\n",
      "Provided there is adequate quantity of viable tumor cells, immunohistochemical testing any melanoma sample from a patient with metastatic disease will accurately determine BRAF status.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24345274\n",
      "This study demonstrated that temporal location, reticulin deposition and CD34 expression are associated with BRAF mutation in pleomorphic xanthoastrocytoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24345920\n",
      "BRAF fusions define a new molecular subset of melanoma, potentially comprising 4% to 8% of \"pan-negative\" cases.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24353007\n",
      "Molecular genetic tests revealed BRAF V600E mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24354346\n",
      "there was no correlation between BRAF-positive primary focus of papillary microcarcinoma and more aggressive or recurrent disease\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24356563\n",
      "The KRAS mutation is not present in about one-third of CRC patients, and therefore other gene mutations need to be investigated to better understand the molecular mechanisms of CRC and its treatment.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24362353\n",
      "Braf(V600E)-driven tumors become addicted to autophagy as a means to preserve mitochondrial function and glutamine metabolism\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24366910\n",
      "The study identifies the BRAFV600E mutation as a significant molecular alteration in malignant peripheral nerve sheath tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24367680\n",
      "BRAF V600E-mutation in metastatic colorectal cancer characterizes a subgroup of patients with distinct biologic, clinical and pathological features and is associated with very poor patients' prognosis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24372748\n",
      "correlation between KRAS or BRAF mutations and prognosis was not observed\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24374844\n",
      "Report clinical consequences of high frequency of BRAF mutations in ameloblastoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24375920\n",
      "Response to vemurafenib suggests that BRAFV600 is an oncogenic driver in pediatric gliomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24382015\n",
      "study found CYP24A1 expression was increased in papillary thyroid carcinoma compared to benign multinodular goitre; expression was further increased in stage III and IV tumours; a strong correlation found between CYP24A1 overexpression and BRAF(V600E) mutation\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24389984\n",
      "meta-analysis suggested that extrathyroidal extension, lymph node metastasis, disease recurrence, and advanced TNM stage were associated with BRAF(V600E) mutation in papillary thyroid carcinoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24390240\n",
      "BRAF mutation decreases tumor response in first-line treatment whether cetuximab was given or not in patients with KRAS wild-type, and anti-EGFR MoAb produces a clear benefit in response rate in patients with BRAF and KRAS wild-type.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24397598\n",
      "the first BRAF V600/601 and KRAS G12-K16 screening study in primary mediastinal B-cell lymphoma that failed to identify hotspot mutations in this specific subtype\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24398428\n",
      "Data indicate that dual targeting of heat-shock proteins 90 (Hsp90) and BRAF(V600E) kinase provided combinatorial benefit in vemurafenib-sensitive melanoma cells in vitro and in vivo.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24402044\n",
      "Despite being an independent predictor of central node metastasis in small papillary thyroid carcinoma, BRAF did not add substantially to the overall prediction of occult central node metastasis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24410877\n",
      "Report detection of BRAF mutations eligible for therapy with vemurafenib in melanoma patients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24413733\n",
      "Targeted genotyping revealed BRAF p.Val600Glu in 95% of papillary craniopharyngiomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24417615\n",
      "BRAF mutational analysis by melt curve analysis is feasible in routine thyroid cytology, and in our series had a 100% specificity for PTC in subsequent histology. The application of BRAF analysis could be useful for indeterminate cytology\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24424406\n",
      "The B-RafV600E mutation detected in melanoma is not associated with a chronic exposure to the sun.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24425783\n",
      "Data reveal a mechanism by which BRAF(V600E) and PI3K signaling cooperate to regulate melanoma proliferation through AKT-independent effects on protein translation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24433452\n",
      "Two V600E-negative hairy-cell leukemias had new pote mutations in exon 11 (F468C and D449E). Another HCL was BRAF wild-type in exons 2-17. All non-HCL lymphomas lacked BRAF mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24440976\n",
      "The presence of BRAF mutations is positively associated with advanced tumor stage in African American colorectal cancer patients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24442520\n",
      "Mutational events as well as over-expression of BRAF gene are highly implicated, independently, in the pathogenesis of thyroid cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24446311\n",
      "A subset of patients with RAS(wt) CMML harbors BRAF kinase domain mutations that are potentially capable of activating the MAPK signaling pathway.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24463458\n",
      "Resistance mechanisms were identified in 58% progressing tumors and BRAF alterations were common. Gene expression analysis revealed that mitogen-activated protein kinase (MAPK) activity remained inhibited in 21% of resistant tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24471189\n",
      "results probably indicate that BRAF mutation may not be the only key factor in melanoma tumorigenesis, and that there should be multiple alternative genetic pathways related to melanoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24471909\n",
      "Data show that a high proportion of cases of non-pulmonary Langerhans cell histiocytosis (LCH) and pulmonary LCH (PLCH) expressed the proto-oncogene protein B-raf (BRAF) V600E mutant protein.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24475086\n",
      "no significant survival differences were found according to BRAF-V600 tumor mutations in patients with primary melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24475291\n",
      "B-RAF is a powerful regulator of hERG channel activity and cell surface hERG protein abundance.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24484235\n",
      "Suggest that some patients with advanced melanoma who are BRAF-mutation positive may benefit from ipilimumab as the first part of their sequential treatment schedule.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24486585\n",
      "A novel mechanism for response was discovered whereby high expression level of CAV-1 at the plasma membrane disrupts the BRaf/CRaf heterodimer and thus inhibits the activation of MAPK pathway during dasatinib treatment.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24489105\n",
      "BRAF inhibition causes decreased CXCL8 secretion from melanoma cells and induce an immune response against the tumor associated with increased IFN-gamma, CCL4, and TNF-alpha.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24493731\n",
      "The finding of BRAF mutations in meningeal melanocytomas points to a potential initiating role of BRAF in transformation toward malignancy and could have therapeutic implications in these specific melanocytomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24496868\n",
      "we sought to analyze the nature of IC and EC response and progression in patients with melanoma brain metastases treated with dabrafenib, and hypothesized that metastases respond and progress similarly to BRAF inhibitors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24497953\n",
      "B-cell receptor functions differ in hairy cell leukemia displying BRAF V(600)E and mutated IGHV.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24503706\n",
      "Two cases of classic HCL, 1 showing CD5 expression, were truly BRAF V600E-negative based on negative results by PCR and sequencing despite high-level leukemic involvement\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24508103\n",
      "For the 598 (91%) patients with BRAF(V600E) disease, median overall survival in the vemurafenib group was 13.3 months (95% CI 11.9-14.9) compared with 10.0 months (8.0-14.0) in the dacarbazine group (HR 0.75 [95% CI 0.60-0.93]; p=0.0085)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24529209\n",
      "Molecular genetic analysis revealed BRAF duplication and a KIAA1549-BRAF fusion gene in 82% of group II tumors, but in none of the group I tumors, and a BRAF:p.V600E mutation in 43% of group I tumors, but in none of the group II tumors\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24532263\n",
      "we identify KIAA1549-BRAF gene fusions in 45 % of 82 low-grade glioma samples\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24535907\n",
      "Our results demonstrated that the BRAF V600E mutation is a common event in melanomas, representing an important molecular target for novel therapeutic approaches in such tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24548081\n",
      "BRAF mutation in FVPTC is associated with unfavourable clinicopathological characteristics and malignant features on ultrasonography and may be a potential prognostic factor as it is in classical PTC.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24550319\n",
      "Nonsmall cell lung cancer cells with BRAF-V600E, but not other BRAF mutations, initially are sensitive to BRAF-inhibitor treatment, but rapidly acquire resistance to BRAF inhibition.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24552757\n",
      "BRAF-mutation analysis should be part of the subtyping of non-squamous NSCLC.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24559116\n",
      "BRAF mutation was significantly associated with a larger tumor size, extrathyroidal invasion and lymph node metastasis in papillary thyroid cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24560515\n",
      "Although the sensitive pyrosequencing method was used, no EGFR, KRAS or BRAF mutations could be found\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24582505\n",
      "Report safety of vemurafenib in diverse population of patients with BRAF(V600) mutated metastatic melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24586605\n",
      "BRAF-V600 mutations are not associated with response to chemotherapy in stage IV melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24588959\n",
      "analysis of BRAF mutation and DNA methylation markers on fine needle aspiration biopsy specimens may be a useful strategy to facilitate the diagnosis of malignant thyroid neoplasm\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24591408\n",
      "BRAF mutation is associated with atypia of undetermined significance and papillary carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24594804\n",
      "Meta-analysis demonstrated that the BRAF V600E mutation was significantly correlated with adverse pathological features of colorectal cancer and distinct clinical characteristics.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24603591\n",
      "BRAF mutations are virtually absent in melanomas originating from the vulva or vagina\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24604709\n",
      "BRAF V600E mutations may be more prevalent than previously thought in pediatric patients with papillary thyroid carcinoma, but do not correlate with aggressive disease characteristics\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24608435\n",
      "Anti-apoptotic BCL-2 proteins govern cellular outcome following B-RAF(V600E) inhibition and can be targeted to reduce resistance.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24612059\n",
      "Serrated colorectal carcinoma as proposed to arise from serrated adenoma is characterized by mutation of BRAF.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24612623\n",
      "Most of the Korean patients with multifocal papillary thyroid carcinoma (PTC) had the BRAF(V600E) mutation in one or more tumor foci, and all BRAF(V600E)-positive multifocal PTC showed more aggressive features.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24614711\n",
      "Melanomas with associated naevi have a higher frequency of BRAF(V600E) mutations than melanomas unassociated with naevi.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24617711\n",
      "In this large cohort, we found TERT promoter mutations to be common, particularly in Follicular thyroid carcinoma and BRAF mutation-positive papillary thyroid carcinoma, and associated with aggressive clinicopathological characteristics.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24619974\n",
      "findings suggest that subcategorization of AUS by cytomorphology and BRAF V600E mutation status is important for predicting the risk of malignancy\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24625419\n",
      "We evaluated the BRAF V600E expression by immunohistochemistry in pulmonary and extrapulmonary Langerhans cell histiocytosis cases\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24634053\n",
      "V600E mutations in 8/15 bile duct adenomas\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24638167\n",
      "BRAF-V600E expression in tissue dendritic cells did not define specific clinical risk groups but was associated with increased risk of recurrence.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24639117\n",
      "Although it has limitations, the VE1 antibody represents a feasible first-line approach for evaluating BRAF mutation status and may be a valid tool in the selection of samples for molecular analysis\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24642661\n",
      "KRAS and BRAF genes were wild-type in all squamous cell anal carcinoma cases.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24651849\n",
      "BRAF mutant/microsatellite stable (MSS) (BRAFmut/MSS) cancers (n = 33) and BRAF mutant/microsatellite unstable (MSI) (BRAFmut/MSI) cancers (n = 30) were compared for presence of copy number aberrations (CNAs) indicative of chromosomal insatbility.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24659028\n",
      "Increased BRAF mutation is associated with colorectal cancer progression and poor response to therapy.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24664307\n",
      "Studies indicate that the role of proto-cncogene protein B-raf-MEK-ERK pathway in controlling cell fate as a primary target for deregulated activation in cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24666267\n",
      "Mutations in BRAF predict resistance to anti-EGFR therapies.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24671772\n",
      "Data support a central role of BRAF V600E mutation in Erdheim-Chester disease and suggest oncogene-induced senescense as a link to both inflammation and oncogenic mutation in histiocytes playing a role in the disease.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24673746\n",
      "Disruption of mutated BRAF signaling modulates thyroid cancer phenotype.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24677749\n",
      "This analysis suggests that differences in disease course of PTC in children versus adults are not strongly dependent upon the presence of the BRAF(V600E) mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24679337\n",
      "genetic association studies in a population in Iran: Data suggest that a mutation in BRAF (V600E) is associated with prognosis of paritents with papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24684646\n",
      "analysis of a possible association between AID expression and BRAF mutation in melanoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24691006\n",
      "the outcome of 68 patients with advanced colorectal cancer and RAS, BRAF and PI3KCA status according to ALK gene status, is reported.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24703243\n",
      "Near-genomewide RNAi screening for regulators of BRAF(V600E) -induced senescence identifies RASEF, a gene epigenetically silenced in melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24709886\n",
      "A combined inhibition strategy targeting BRAF together with multiple erbB family kinases is potentially beneficial for treating BRAF V600E mutant melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24710085\n",
      "mutations in BRAF and NRAS are not mutually exclusive because they were simultaneously present in the same tumor specimens\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24713734\n",
      "the homebrew dispensation sequence unambiguously identifies all known BRAF mutations in this region, whereas the kit-based dispensation sequence has one unresolvable degeneracy that could be solved with the addition of two injections\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24714776\n",
      "BRAF mutation is associated with melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24715106\n",
      "Study found BRAF V600E mutations in 81 percent of papillary craniopharyngioma sampled\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24717435\n",
      "decreasing the levels of CTR1 (Cu transporter 1), or mutations in MEK1 that disrupt Cu binding, decreased BRAF(V600E)-driven signalling and tumorigenesis in mice and human cell settings\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24720374\n",
      "the BRAF pathway may contribute to the pathogenesis or malignant transformation of histiocytic and dendritic cell neoplasms.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24721322\n",
      "BRAF(V600E) mutation demonstrated to be an adverse prognostic factor indicating aggressiveness of papillary thyroid carcinoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24721513\n",
      "analysis of pro-death autophagic processes responsible for sensitization of BRAF-V600E glioma cells toward UAI-201\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24725538\n",
      "Response to this therapy suggests that BRAF inhibitors can affect primary CNS lesions when a documented and targetable mutation is present.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24733413\n",
      "long-term treatment with BRAF inhibitors can affect the interaction between BRAF/MAPK and Wnt/beta-catenin signaling to affect patient outcomes\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24733801\n",
      "Case Report: patient with V600E BRAF-mutant leptomeningeal melanoma who experienced a complete clinical and radiologic response after dabrafenib treatment.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24735930\n",
      "AKTi combined with BRAFi-based therapy may benefit patients with tumors harboring BRAF mutations and particularly PTEN deletions or AKT mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24737664\n",
      "BRAF-mutant mCRC is associated with worse clinical outcome. Patients with BRAF-mutant tumors develop peritoneal metastases, less frequently present with disease limited to the liver, and have shorter survival after metastasectomy.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24742923\n",
      "From a practical perspective, small biopsies may not adequately represent a tumor's full mutational profile, particularly for later arising but prognostically important mutations such as those in the KRAS and BRAF genes\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24746198\n",
      "discordant BRAF mutation status is rare when samples from individual PTCs are compared or when samples from individual PTCs and lymph node metastasis at thyroidectomy are compared but occurs more when primary and recurrent metastasis are compared\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24748129\n",
      "The percentage of mutant BRAF alleles in papillary thyroid carcinoma is significantly associated with tumor burden and extrathyroidal invasion.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24749938\n",
      "The presence of dermoscopic peppering and thicker Breslow index ulceration suggest a morphological consequence of immune behaviour in BRAF-mutated melanomas\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24764675\n",
      "colorectal cancers with a BRAF mutation have distinct molecular features and resulted in a poor prognosis in Korean patients with advanced colorectal cancer\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24767862\n",
      "We conclude that a V600E BRAF mutation may not be helpful in distinguishing sporadic from MTS-associated sebaceous neoplasms\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24770869\n",
      "Data demonstrate that the BRAF(V600E) cooperates with either PIK3CA(H1074R) or with silencing of the tumor-suppressor PTEN, to promote development of anaplastic thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24774510\n",
      "This study indicated that mutations of KRAS, PIK3CA and NRAS were rare in advanced gastric cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24780046\n",
      "BRAF V600E is heterogeneously distributed in some papillary thyroid carcinomas(PTCs). The large BRAF V600E neoplastic cell subpopulations found in mutated cases is consistent with the view that the BRAF V600E is acquired early during PTC development.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24787545\n",
      "BRAF(V600E) mutation is not a useful prognostic marker, though it does influence the short- and medium-term outcomes of classic papillary thyroid cancer\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24789721\n",
      "BRAF V600E mutation is associated with refractory hairy cell leukemia.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24792487\n",
      "BRAF V600E mutation positive pediatric posterior fossa gangliogliomas exhibit no unique imaging features, are associated with shorter progression-free survival, and carry promising treatment implications by BRAF inhibitors\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24798740\n",
      "analysis of RAS, RET/PTC, and BRAF mutations in advanced stage of papillary thyroid carcinoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24806883\n",
      "Characteristics and prognosis of colorectal cancer with NRAS mutations are different from those with KRAS or BRAF mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24821886\n",
      "Case Report: KRAS mutated pancreatic adenocarcinoma developing on treatment with combined BRAF and MEK inhibition for metastatic melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24828987\n",
      "The present work discusses the most recent and controversial evidence on the BRAF V600E relevance in development and progression of thyroid tumors. [Review]\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24832158\n",
      "Although VE1 antibody can be useful in the screening of colon carcinomas for BRAF V600E-mutant proteins, molecular genetic confirmation is always necessary for mutation diagnosis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24833563\n",
      "RAC1b overexpression constitutes a marker of poor prognosis in KRAS/BRAF WT mCRC patients treated with first-line FOLFOX/XELOX therapy.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24838814\n",
      "The BRAF mutation was significantly associated with persistence/recurrence and a potential predictor in patients with classical PTC >10 mm at a BRAF mutation prevalent area\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24839220\n",
      "BRAF mutation cannot be regarded as a reliable marker of node metastases in patients with PTC.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24848709\n",
      "Overexpression of BRAF(V600E) in normal thyroid epithelial (H tori) cells also reduced the effects of Dkk-1 on cell survival.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24857351\n",
      "report of a new IDH1 mutation associated with BRAF mutation in a very unusual glial tumor.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24859340\n",
      "BRAF mutation is asociated with ameloblastoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24859998\n",
      "The high-resolution melting method developed was shown to be a reliable method for BRAF mutation detection\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24861115\n",
      "12% of KRAS negative colorectal cancer showed BRAF gene mutation. Considering that 42% of samples have a KRAS mutation, 54% of patients should not respond to therapies with monoclonal antibodies directed against epidermic growth factor (EGFR) pathway.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24862939\n",
      "BRAF mutation was not associated with negative prognostic indicators or adverse outcomes in PTC.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24863948\n",
      "Data indicate that BRAF protein overexpression was significantly associated with thyroid extracapsular extension (ECE) and lymph node metastasis (LNM) positive cases.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24866436\n",
      "BRAF mutation is associated with melanoma nodal metastases and an unknown primary site.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24871132\n",
      "Treatment of HCL patients with vemurafenib, an inhibitor of mutated BRAF, resulted in normalization of HSPC frequencies and increased myeloid and erythroid output from HSPCs\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24885594\n",
      "While frequency rates of BRAF mutations were quite identical across the different MPM lesions, a significant increase of cKIT (p<0.001) and CyclinD1 (p=0.002) amplification rates was observed between first and subsequent primary melanomas\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24885690\n",
      "Genetic targeting of BRAF Valine600Aspartate drug resistance mutation identifies dabrafenib as a selective agent against BRAF-resistant colorectal cancer cells.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24893747\n",
      "Our results indicate a cross-talk between Braf and p300 in melanoma and demonstrate the importance Braf and p300 expression in the diagnosis and prognosis of melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24894769\n",
      "Findings suggest a link between Langerhans cell histiocytosis and Erdheim-Chester disease involving the BRAF(V600E) mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24897065\n",
      "suboptimal specificity and PPV limits the diagnostic utility of both antibodies to reliably detect BRAF p.V600E mutations in thyroid carcinoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24901049\n",
      "The B-Raf(V600E) inhibitor dabrafenib selectively inhibits RIP3 and alleviates acetaminophen-induced liver injury.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24906137\n",
      "BET inhibition with I-BET151 appears independent of the BRAF and NRAS mutational status of melanoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24909403\n",
      "BRAF was a significant parameter for predicting multifocality in follicular variant of papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24918610\n",
      "The results from this prospective cohort study further support an influence of sex and lifestyle factors on different pathways of colorectal carcinogenesis, defined by KRAS and BRAF mutation status of the tumours.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24918823\n",
      "BRAF and NRAS mutation status does not influence survival in metastatic melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24921639\n",
      "BRAF V600E immunohistochemistry is reliable for the evaluation of mutational status in colorectal carcinoma regardless of site or prior treatment history, and staining shows a high degree of intratumoral homogeneity.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24922189\n",
      "Using the PCR test with sense allele-specific primers, mutations in V600 were found in 33 of 51 Russian patients (64.7%) with cutaneous melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24926836\n",
      "Results show that BRAF-mutated patients were significantly younger at the time of primary melanoma and first diagnosis of metastasis than BRAF wild-type patients but BRAF mutation is not associated with a more aggressive illness.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24936068\n",
      "a novel role for B-Raf in the selective regulation of alpha4beta1 integrin-mediated adhesion.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24941944\n",
      "Although both, DTIC and TMZ act as alkylating agents through the same intermediate, NRAS and BRAF mutant cells responded differentially only to DTIC.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24942334\n",
      "The 5-year survival rate of colorectal cancer patients with BRAF mutations was significantly decreased.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24947927\n",
      "BRAF mutations are associated with response to chemotherapy in cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24950457\n",
      "amuvatinib has proapoptotic activity against melanoma cell lines, with selectivity observed for those harboring oncogenic NRAS but not BRAF\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24954313\n",
      "Considering the diagnostic performance and low reproducibility of US, the combination of FNA with BRAFV600E is the most reliable and objective method for diagnosing thyroid malignancy.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24958809\n",
      "Although there was large variability between patients, FDG uptake decreased with higher daily doses in patients with BRAFV600 mutation-positive melanoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24958825\n",
      "BRAF(V600) mutation is associated with melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24964758\n",
      "MSI and the BRAF(V600E) mutation have a prognostic impact in colon cancer\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24964857\n",
      "Results suggest tha tthe pathological progression from Serrated adenoma through colon carcinoma required the successive events: mutations in BRAF protein, hypermethylation of MLH1 then hypermethylation in AXIN2.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24978326\n",
      "BRAFV600E mutation in primary tumor might be a promising molecular marker to predict the status of 131I uptake in distal metastases.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24979348\n",
      "BRAF mutations in NSCLC were significantly associated with adenocarcinomas .\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24989827\n",
      "BRAF testing is a useful adjunct to improve PPV for patients with \"suspicious for PTC\" cytology.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24992171\n",
      "The absence of CXCR4 expression and BRAF mutation in cancers with a minor PD component underlined different pathogenic and metastatic processes in comparison with WDCs.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24993163\n",
      "Activating FGFR2-RAS-BRAF mutations play a critical role in the pathogenesis of most cases of ameloblastoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25005754\n",
      "Our results highlight the low incidence of BRAF mutations and CIMP in CRC from Saudi Arabia.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25010701\n",
      "SOX2 expression is partly regulated by BRAF signalling, and an increased SOX2 expression may promote CRC metastasis and mediate a poor patient prognosis\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25013125\n",
      "In tDNA, 50 mutations (36 EGFR, 5 ERBB2, 4 KRAS, 3 BRAF, and 2 PIK3CA) were identified, of which 26 were detected in cfDNA. These data demonstrate the feasibility and potential utility of mutation screening in the detection of a range of tumor biomarkers\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25015869\n",
      "document two rare cases of massively metastatic spinal cord GGs in adult patients who were negative for BRAF V600E mutations via multiple methods\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25024077\n",
      "Coexisting BRAF V600E and TERT C228T mutations form a novel genetic background that defines PTC with the worst clinicopathologic outcomes, providing unique prognostic and therapeutic implications.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25029639\n",
      "Data indicate mutation in the proto-oncogene protein B-raf (BRAF) gene at the time of hairy cell leukemia (HCL) diagnosis in two cases.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25031736\n",
      "No BRAF mutations were detected in the lesions of 18 cases\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25034364\n",
      "Common BRAF mutations are not present in systemic mastocytosis patients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25039399\n",
      "The adenocarcinoma showed expression of CK20 and p53, but CK7 in patches. The molecular profile of the adenocarcinoma showed a mutation in KRAS and wild-type BRAF, which might be associated with malignant transformation of intracranial mature teratomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25046227\n",
      "This study demonstrates that IHC analysis is a very sensitive test for evaluation of BRAF mutations in metastatic malignant melanoma and may be useful as an initial screening test.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25048604\n",
      "BRAF(V600E) mutations in primary cutaneous melanomas were associated with residence in locations with medium and high UV indices in mid-life.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25050586\n",
      "BRAF mutations were found in 8.7% of colorectal cancer precursor lesions, mainly associated with serrated polyps and absent in adenomas. In CRC cases, 6.5% exhibited BRAF mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25051202\n",
      "BRAF V600 mutations are associated with pathological features in Japanese melanoma patients\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25056119\n",
      "Enforced expression of RAC1 P29S in sensitive BRAF-mutant melanoma cell lines confers resistance manifested by increased viability.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25063807\n",
      "NRAS expression and increased MAPK activation drive vemurafenib resistance in V600E BRAF+ve melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25066317\n",
      "BRAF mutation in pilocytic astrocytoma is associated with a more diffuse growth pattern but does not confer a more aggressive clinical behavior\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25070294\n",
      "Data indicate that BRAF mutant status and number of positive lymph nodes as the only independent prognostic factors for recurrence-free (RFS) and disease-specific survival (DSS).\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25073438\n",
      "KRAS, BRAF, and PIK3CA mutations were evaluated in 204 colorectal carcinoma samples; the frequency of KRAS, BRAF, and PIK3CA mutations was 23.5, 9.8, and 5.9 %, respectively.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25073704\n",
      "ETV1 expression is a rare event in human melanoma and seems to be rather based on hyperactivation of MAPK signals, by BRAF (V600E) mutation, than on ETV1 gene amplification.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25076244\n",
      "Prevalence of BRAF mutations in CRC patients is not high but extremely correlated with MSI and risk categories as BG, whereas they are absent in LS patients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25085839\n",
      "The up-regulation of uPA mRNAs was correlated with high-risk clinicopathological features, including extrathyroid invasion, loss of cellular polarity/cohesiveness, and the BRAF(V600E) mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25104559\n",
      "It is a major negative mediator of the extracellular signal-related kinase (ERK)/mitogen-activated protein kinase and a substrate of cdk5 in neurons.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25109331\n",
      "loss of stem cell identity upon induction of BRAF/MAPK activity may represent a novel fail-safe mechanism protecting intestinal tissue from oncogene activation\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25116269\n",
      "Next Generation Sequencing (NGS) assay revealed three genomic alterations: activating BRAF mutation (V600E), loss of CDKN2A/2B, and APC I1307K. After treatment with BRAF inhibitor (dabrafenib), the child's clinical condition improved progressively.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25118810\n",
      "activating V600E BRAF mutation can be frequently demonstrated in pediatric Langerhans cell histiocytosis\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25120313\n",
      "The prevalence of rare BRAF mutations was 0.76% of all BRAF-positive thyroid cancers, and the rare mutations were associated with less aggressive pathologic features.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25139339\n",
      "Our data suggest that the poor prognosis of dMMR is driven by the BRAF(MT) status.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25148578\n",
      "Multiple potential therapeutic targets were identified in metastatic unknown primary and cutaneous melanomas that lacked BRAFV600 and NRAS mutations\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25153715\n",
      "The potential role of combined MMR and BRAF IHC as prognostic markers in CRC.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25154726\n",
      "combination of microsatellite instability and BRAF status serves as both a prognostic and predictive marker and may provide much-needed guidance during the planning of therapeutic strategies\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25155755\n",
      "X-ray crystallography reveals a regulatory role for BRAF in the MAPK pathway independent of its kinase activity but dependent on interaction with MEK.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25156525\n",
      "V600E BRAF mutation is associated with synchronous and metachronous thyroid cancer coexisting with Langerhans cell histiocytosis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25156883\n",
      "BRAF(V600E) mutation is associated with papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25164765\n",
      "Targeted sequencing on primary, metastatic, and normal tissue from colorectal cancer patients found a high degree of concordance for KRAS, NRAS, and BRAF mutations that were identical in both the primary and metastatic tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25165098\n",
      "PTEN loss was significantly associated with OS and time to MBM in patients with BRAF(V600) mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25174651\n",
      "This study suggests that BRAF mutation-related specific transcripts associate with a poor phenotype in melanoma and provide a nest for further investigation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25176643\n",
      "Methylation of MLH1 is strongly associated with BRAF mutations in sporadic colorectal cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25180764\n",
      "Targeted therapy in BRAF mutated melanoma; treatment with BRAF inhibitors and in combination with MEK inhibitors. [Review]\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25188864\n",
      "this study sheds light on the pathogenesis of Serous borderline tumor ovarian tumors by showing that BRAF mutation is associated with cellular senescence\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25194980\n",
      "6 different BRAF missense mutations were found in 9 of 11 patients with cadiofaciocutaneous syndrome.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25202140\n",
      "33% of Langerhans cell histiocytosis cases with wild-type BRAF and none with BRAFV600E harbored somatic mutations in MAP2K1 (6 in-frame deletions and 1 missense mutation) that induced extracellular signal-regulated kinase (ERK) phosphorylation in vitro.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25213729\n",
      "BRAF(V600E) status may help to predict clinical outcome of PTC.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25219500\n",
      "Results reveal a BRAF(V600E)-directed pathway that mediates silencing of MLH1 and, more generally, is responsible for CpG Island Methylator phenotype.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25236573\n",
      "A high discordant rate was found in Braf mutation statuses between primary and metastatic cutaneous melanoma lesions.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25239454\n",
      "dual HSP90/TRAP1 inhibitor HSP990 showed activity against the TRAP1 network and high cytostatic potential in BRAF-mutated colorectal carcinoma cells\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25242093\n",
      "Data suggest that proto-oncogene potein B-raf (BRAF) V600E mutations are present in rare cases of dendritic cell and histiocytic disorders, and their identifi cation off ers a potential therapeutic target for these neoplasms.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25244542\n",
      "The frequency of KRAS and BRAF mutations was low; KRAS mutations were detected in 1.6% and BRAF mutations in 4.7% of the biopsies for anal carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25262755\n",
      "BRAF mutation status was obtained for 146/160 cases. Overall mutation rate was 24/88 (27.3%) in primary and 25/58 (43.1%) in metastatic melanoma. V600E was the predominant mutation in 21/24 (87.5%) of primary and 23/25 (92%) of metastatic melanomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25262966\n",
      "Overexpression of HO-1 in a subset of thyroid cancers is associated with tumour aggressiveness and BRAF V600E expression\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25266729\n",
      "BRAF V600E allele frequency is associated with papillary thyroid cancer progression.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25267307\n",
      "KRAS and BRAF mutation analysis could be used in the selection of patients for anti-EGFR therapy.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25273224\n",
      "BRAF mutations occurred in 2.2% of advanced-stage lung adenocarcinomas, were most commonly V600E, and were associated with distinct clinicopathologic features in comparison with other genomic subtypes and with a high mutation rate in more than 1 gene.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25306614\n",
      "710 melanomas included in the study were located in sun non-exposed regions of the skin; this category of tumors was characterized by the highest occurrence of BRAF mutations\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25314065\n",
      "B-RAF mutations were frequently detected in aberrant crypt foci.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25318602\n",
      "we detected 15 additional mutated melanoma samples and two additional BRAF V600E mutations in metastatic colorectal cancer samples by the LightMix assay compared to Sanger sequencing.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25324352\n",
      "we identify that analysis of plasma and urinary cfDNA provides a reliable method to detect the BRAF(V600E) mutation and monitor response to therapy in these disorders.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25332244\n",
      "Data indicate an independent prognostic value of BRAF V600E mutation for papillary thyroid cancer (PTC) recurrence in various clinicopathologic categories.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25337237\n",
      "Report BRAF mutation status in colorectal neoplasms and neuroendocrine differentiation in primary/metastatic colorectal neoplasms.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25337709\n",
      "The BRAF(V600E)mutation iss significantly associated with several poor clinicopathologic characteristics, but was not associated with sonographic features, regardless of thyroid tumor size.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25346165\n",
      "BRAF V600E mutations are frequent in dysembryoplastic neuroepithelial tumors and subependymal giant cell astrocytomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25351955\n",
      "this study supports the idea that additional NK cell-based immunotherapy (by checkpoint blockade or agonists or cytokines) may combine well with BRAF(V600E) inhibitor therapy to promote more durable responses in melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25363723\n",
      "BRAF and NRAS alterations are preserved during in vitro culture in melanoma in a series of patients in which the c-KIT mutation was not detected\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25367198\n",
      "our study demonstrated the BRAF V600E mutation was an independent prognostic factor for colon cancer patients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25370473\n",
      "our data indicate that preexisting MEK1(P124) mutations are associated with a reduced response to BRAF inhibitor therapy and identify a subset of patients with BRAF-mutant melanoma likely to benefit from combination therapies\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25370533\n",
      "PD-L1 expression in melanocytic lesions does not correlate with the BRAF V600E mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25376477\n",
      "discordancy of BRAF mutation status is not an infrequent finding between primary and metastatic melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25378232\n",
      "BRAF V600E inhibited NIS expression by the upregulation of its promoter methylation.  Specific regions of CpG islands of NIS promoter in BRAF V600E harboring papillary thyroid carcinoma were highly methylated compared with surrounding normal tissue.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25385688\n",
      "Results demonstrate that mutated BRAF is associated with melanomas that are more aggressive.They are also associated with absence of solar elastosis and tumor epitheloid cells\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25389051\n",
      "we describe three interesting cases of paediatric glial and glioneuronal tumours harbouring both BRAF V600E and H3F3A K27M mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25400776\n",
      "Concluded that the presence of BRAF(V600E) mutation in papillary thyroid carcinoma could be preoperatively predictive of extrathyroidal invasion in a Chinese population.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25404749\n",
      "The frequency of the BRAF mutation in cPTCs with suspicious US features was higher than that of cPTCs with negative US features regardless of the BSRTC.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25426645\n",
      "there is a lower incidence of brain metastases in patients with BRAF-mutated tumors who took vemurafenib before the diagnosis of brain metastases\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25427581\n",
      "In this retrospective analysis, triplet chemotherapy with OCX was well tolerated and achieved encouraging efficacy in metastatic colorectal cancer irrespective of RAS/RAF mutation status.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25429742\n",
      "BRAF V600E mutation is related to lack of response and worse survival in wild-type KRAS metastatic colorectal cancer patients treated with anti-EGFR MoAbs.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25430497\n",
      "Preanalytical workflow optimisation may reduce errors in down-stream sequencing in BRAF mutation detection.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25437182\n",
      "Proteomic profile and in silico analysis in metastatic melanoma with and without BRAF mutation\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25437913\n",
      "Together, this work provides formal proof of an allosteric link between the RAF dimer interface, the activation segment and the catalytic infrastructure.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25442222\n",
      "BRAF V600E mutation status did not correlate with any clinicopathological parameters\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25442675\n",
      "The determination of BRAF mutational status is recommended in any cystic sellar lesion and can in most cases be provided by VE1 immunohistochemistry even in specimens of low cellularity.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25450274\n",
      "The consistency of the BRAF gene mutation in peripheral blood and tissue is high.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25456393\n",
      "Lymph node specimens with low tumor cellularity due to numerous adjacent lymphocytes may pose a challenge to clinical detection of BRAF mutations of melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25463315\n",
      "We documented three novel mutations in the BRAF gene in cardio-facio-cutaneous syndrome patients and correlated clinical findings with causative mutations in the BRAF or MEK1/MEK2 genes\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25468810\n",
      "The BRAF(V600E) mutation was significantly associated with lymph node metastasis and poor prognosis in papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25473895\n",
      "truncated RAF1 and BRAF proteins, recently described as products of genomic rearrangements in gastric cancer and other malignancies, have the ability to render neoplastic cells resistant to RTK-targeted therapy\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25479927\n",
      "The combined BAP1-BRAFV600E+ immunoprofile appears to be a constant feature of BAP1 tumor syndrome-associated melanocytic lesions\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25482468\n",
      "did not find a negative prognostic impact of a positive BRAF V600E mutation status on survival in papillary thyroid cancer\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25490715\n",
      "BRAF V600E mutation affects patients with large/giant congenital melanocytic nevi, and with neurocutaneous melanocytosis, a novel finding.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25490969\n",
      "global miRNA expression profiles in fresh-frozen metastatic melanomas in relation to clinical outcome and BRAF mutation, were examined.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25491441\n",
      "The V600E BRAF mutation in a borderline serous tumour of the testis is genotypic evidence of similarity with its phenotypic ovarian counterpart.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25499223\n",
      "These observations led us to conclude that increased TSH signaling overcomes OIS and is essential for B-RafV600E-induced papillary thyroid carcinogenesis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25499274\n",
      "BRAF V600 mutation is associated with melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25515650\n",
      "Missense mutations were identified in the BRAF and KRAS genes in cutaneous melanoma cell line.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25515853\n",
      "This is the first observation of a secondary BRAF mutation in a vemurafenib-resistant patient-derived melanoma sample, which confirms the potential importance of the BRAF L505H mutation in the development of therapy resistance.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25526463\n",
      "BRAFV600E intratumor and intrapatient heterogeneity in melanoma is diminutive, nevertheless, the identified exceptions will have important implications for the clinical management of this disease.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25527633\n",
      "IRS2 copy number gain, IGF-1R, IR-A, and IGFBP6 RNA expression levels, and KRAS and BRAF mutational status were identified as candidate predictive biomarkers for response to BMS-754807.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25537974\n",
      "The association between a host response and lymphovascular invasion and microvessel density in primary cutaneous melanoma with a BRAF mutation suggests that they exhibit potential for strategizing immunotherapies\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25543407\n",
      "To detect whether the V600E mutation is present or absent in the BRAF gene in melanoma patients is an important component in the evaluation of the biological behavior of tumor cells and their performance of biologically significant functions.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25551625\n",
      "in different macroscopic subtypes of colorectal adenoma, BRAF mutation (V600E) was found in 2 of 36 lateral spreading tumors and 1 of 34 polypoid lesions; mutations in KRAS, BRAF or PIK3CA occurred in a mutually exclusive manner\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25576923\n",
      "Data suggest that Sema6A and Mical1 may represent new potential therapeutic targets in BRAFV600E melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25581727\n",
      "Report BRAF VE1 immunoreactivity patterns in epithelioid glioblastomas positive for BRAF V600E mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25584719\n",
      "This is the largest study on the aggressive role of TERT promoter mutations in anaplastic thyroid cancer(ATC), demonstrating an association of TERT C228T with BRAF V600E, older patient age, and tumor distant metastasis in ATC.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25588542\n",
      "BRAF V600E mutation is associated with Anaplastic thyroid cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25593071\n",
      "BRAFV600E-mutation-positive papillary thyroid microcarcinoma are more likely to manifest with aggressive clinicopathological characteristics.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25600339\n",
      "melanoma cell lines selected for resistance to BRAFi+MEKi, but not those to BRAFi alone, displayed robust drug addiction, providing a potentially exploitable therapeutic opportunity.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25602792\n",
      "Data support a role for BRAF V600E immunohistochemistry in diagnostically challenging cases of metanephric adenoma and expand the spectrum of BRAF exon 15 mutations in this uncommon but unique renal neoplasm.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25605225\n",
      "high-resolution melt and allele-specific PCR could detect as low as 1.25% KRAS- or BRAF-mutant alleles.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25616949\n",
      "In the management of thyroid nodules with benign cytology but positive BRAF(V600E) mutation, thyroidectomy should be considered in nodules which have 2 or more suspicious US features and are considered discordant on image-cytology correlation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25618114\n",
      "BRAF overexpression could be an independent factor causing tumorigenesis in gliomas regardless of phospho-EGFR expression.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25627962\n",
      "suggests that PIK3CA mutations account for a small fraction of PI3K pathway activation and have a limited impact in interfering with the BRAF/NRAS-driven growth in melanoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25628445\n",
      "BRAF mutations are associated with response to chemotherapy in colorectal cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25632202\n",
      "KRAS and BRAF mutations are associated with inferior survival, independent of MSI status, in Japanese patients with curatively resected colorectal carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25634750\n",
      "Report predictive value of immunohistochemistry in detecting BRAF mutations in neoplasms.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25643238\n",
      "Case Report: successful (neo)adjuvant BRAF-targeted therapy in a patient with locally advanced BRAF V600E mutant melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25646931\n",
      "These findings suggest that prenylation inhibition may be able to target melanoma cells with mutant NRAS or with mutant BRAF and PTEN.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25647260\n",
      "HPV presence was not associated with age, stage or grade of tumours, MSI or mutations in KRAS, TP53 or BRAF genes.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25663779\n",
      "Report low rates of BRAF mutations in Chinese colorectal carcinoma patients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25666295\n",
      "BRAF mutations are associated with Metastatic Colorectal Cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25667294\n",
      "analysis of BRAF mutation and CDKN2A deletions in childhood secondary high-grade glioma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25673558\n",
      "Review/Meta-analysis: findings support BRAF mutation assessment before initiation of treatment with anti-EGFR monoclonal antibodies.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25674762\n",
      "Aberrant expression of A-, B-, and C-RAF, and COT is frequent in PTC; increased expression of COT is correlated with recurrence of PTC.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25685929\n",
      "analysis of BRAF 3'UTR isoforms in melanoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25688918\n",
      "mutated KRAS and mutated BRAF seem to be prognostic factors in patients with Colorectal cancer who undergo lung metastasectomy.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25689095\n",
      "BRAF mutations in Non-small cell lung cancer are more likely in Adenocarcinoma, and BRAF V600E mutations are more frequent in women and never smokers.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25690538\n",
      "Suggest that continuing vemurafenib treatment beyond progression may be beneficial in BRAF V600 mutated advanced melanoma patients, who prior to progression responded to vemurafenib.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25702102\n",
      "All four tumors that recurred were LN+, with infiltrative borders, and lacked the BRAF mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25704541\n",
      "Mutated BRAF mutant protein was detected in 53% of the bile duct adenomas and in none of the cases of bile duct hamartomas\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25706985\n",
      "Trametinib alone caused upregulation of p-AKT in BRAF non-V600 mutated cells.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25710585\n",
      "mutation is associated with distinct clinical and histopathologic features of colonic carcinomas\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25710724\n",
      "Data show that licochalcone A (LicoA) suppresses solar UV-induced cyclooxygenase (COX-2) expression by acting as a potent inhibitor of enzymes PI3K, MEK1, and B-Raf.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25712893\n",
      "BRAF is minimally prognostic in papillary thyroid carcinoma. However, prevalence of the BRAF mutation is 70% in the general population, providing the opportunity for targeted therapy.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25724524\n",
      "These findings enhance our understanding of factors cooperating with BRAF inhibition that accelerate keratinocyte oncogenesis as well as broaden the knowledge base of multifactorial mediators of cancer in general.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25729732\n",
      "Proto-Oncogene Proteins B-raf V600E mutation analysis is considered to be the most useful diagnostic tool for differentiating hairy cell leukemia from related lymphomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25735579\n",
      "A pathogenic BRAF(V600E) mutation was identified in a patient with Erdheim-Chester disease.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25736029\n",
      "No BRAF V600E mutations were seen in this cohort of non-infiltrative, non-invasive follicular variant of papillary thyroid carcinoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25746038\n",
      "genetic association studies in populations in Ireland and Belgium: Data suggest that frequency of mutations in BRAF (specifically the V600E mutation) vary by demographic location.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25749811\n",
      "BRAF mutation is not associated response to chemotherapy in melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25752325\n",
      "Results suggest that the presence of a BRAF mutation does not necessarily 'drive' more rapid tumour growth but is associated with poorer MSS in patients with early-stage disease\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25752754\n",
      "These tumors showed a markedly better prognosis, with molecularly PXA-like tumors frequently harboring BRAF V600E mutations and 9p21 (CDKN2A) homozygous deletion.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25755776\n",
      "No association was established between BRAF V600E mutation and regional lymph node metastasis in papillary thyroid carcinoma in Chinese patients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25762352\n",
      "Radiotherapy with concomitant BRAF inhibitor therapy is feasible with an acceptable increase in toxicity. Vemurafenib is a more potent radiosensitizer than dabrafenib.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25766129\n",
      "Our results indicate that the mutations of BRAF and KIT exist in Japanese melanoma patients, however, the cell growth signaling may be regulated by not only these mutated genes, but by other unknown regulatory factors, which may affect the prognosis of melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25767048\n",
      "BRAF mutation was frequently detected in younger patients, in thin melanomas, and in melanomas with less ulceration. As BRAF and NRAS mutations are rare in Taiwan, BRAF- or NRAS-targeted therapies may be effective only for selected Taiwanese melanoma patients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25767210\n",
      "The study demonstrates the activating BRAF mutation (V600E), which is found in multiple human cancers, is a driver of canine invasive cell carcinoma of the bladder, and highlights a urine-based test for quick diagnosis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25784606\n",
      "Among the 779 cases, 150 cases were positive for BRAF (V600E) staining, including 38 (of 611, 6%) CRCs, 102 (of 127, 80%) PTCs and 10 (of 41, 24%) malignant melanomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25794135\n",
      "By this integrated approach, we found that patients with BRAF V600E mutation responded very well to broad acting drugs and there was no relation to prognosis in early-stage myeloma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25794445\n",
      "Pediatric oligodendrogliomas (pODGs) can harbor the KIAA1549-BRAF fusion with aberrant MAPK/ERK signaling, and there exists an option of targeting these pathways in such patients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25794798\n",
      "Chitosan nanoparticle-mediated BRAF siRNA interference evidently reduced the invasion capacity of gastric cancers.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25795007\n",
      "oncogenic activation of BRAF allows tumor cells to co-opt an evolutionarily conserved MHC-I trafficking pathway as a strategy to facilitate immune evasion.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25797743\n",
      "Preoperative targeted therapy of advanced BRAF-mutant melanoma is feasible, well tolerated, induces brisk tumor responses, and facilitates correlative science.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25815786\n",
      "No mutations in the BRAF gene were identified in patients with gastric cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25817073\n",
      "This work supports the fact that BRAF V600 mutation is not implicated in meningioma tumorigenesis\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25818616\n",
      "The most important implication of these findings is that we could begin to treat patients with the BRAF V600E and CDKN2A alteration differently when they are first diagnosed than those with a lower risk for secondary high-grade glioma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25819940\n",
      "BRAF mutation in cutaneous malignant melanoma plays an important role in the development of skin cancer in Asians. population.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25820214\n",
      "BRAF V600E mutation is associated with differentiating Rathke's cleft cyst with squamous metaplasia from papillary craniopharyngioma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25832798\n",
      "these results may not only indicate some future applications of inhibitors targeting B-Raf(v600e), but also benefit B-Raf(v600e) harboring cancer patients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25837167\n",
      "findings suggest that the BRAF(V600E) mutation can be detected using a PNA clamp real-time PCR in the blood of PTC[ papillary thyroid carcinoma ] patients with lung metastasis\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25843629\n",
      "Study reports that mice engineered to overexpress either the full-length murine B-Raf pseudogene Braf-rs1 and its human ortholog, BRAFP1, elicit their oncogenic activity, at least in part, as competitive endogenous RNAs (ceRNAs) that elevate BRAF expression and MAPK activation in vitro and in vivo.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25851630\n",
      "BRAF mutations often affect a limited fraction of transformed metastatic colorectal cancer cells.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25854168\n",
      "The SMOF412E mutation was not detected in ameloblastoma. The BRAFV600E-activating mutation is a common event in ameloblastomas, occurring regardless of site or histological type. This mutation is also detected in odontogenic carcinomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25854387\n",
      "The BRAFT1799A mutation was found in 38 cases (42.7%).\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25862899\n",
      "BRAF V600E mutation might be associated with right-sided tumors and subsequently related unexplained iron-deficiency anaemia (IDA) at presentation\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25868080\n",
      "The increased activity of the V600E mutant is twofold: increased flexibility of the A-loop which likely promotes the release of the products following phosphorylation of the substrate and an increased energy barrier between the active and inactive state.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25870252\n",
      "The presence of TC was significantly associated with TERT promoter and BRAF mutations. BRAF did not influence patient outcome.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25870264\n",
      "Multifunctional bioscaffolds for 3D culture of melanoma cells reveal increased MMP activity and migration with BRAF kinase inhibition.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25884297\n",
      "Tumor dissemination in colon cancer patients is less likely to occur with the BRAF mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25885250\n",
      "BRAF V600E mutation is associated with glioblastoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25886136\n",
      "Among 264 patients, mutations in KRAS exon 2, KRAS exons 3 or 4, NRAS, BRAF and PIK3CA were detected in 34.1%, 3.8%, 4.2%, 5.4% and 6.4%, respectively. Thus, a total of 12.1% of patients without KRAS exon 2 mutations had other RAS mutations\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25888143\n",
      "Histopathological prognostic markers (Breslow thickness, mitotic index, ulceration, tumor infiltrating lymphocytes pattern) did not show any differences depending on BRAF V600E mutational status\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25890285\n",
      "A complex mechanism driven by mutation BRAF (V600E) on melanoma tumorigenesis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25899003\n",
      "associate higher expression of the ligand-receptor axis of TFF2 and CXCR4 with BRAF V600E-mutant colon cancer (P = 3.0 x 10(-3) and 0.077, respectively for TCGA; P = 3.0 x 10(-8) and 5.1 x 10(-7) for CIT)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25899612\n",
      "This review will focus on the science and clinical findings related to targeted therapies that inhibit BRAF or MEK as well as the immunotherapies that block the CTLA-4 or PD-1 pathways\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25899783\n",
      "BRAF V600 mutation is associated with melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25900832\n",
      "BRAF-induced tumorigenesis is IKKalpha-dependent but NF-kappaB-independent\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25908244\n",
      "Following B-RAF expression, MIR31HG is located mainly in the cytoplasm.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25911848\n",
      "Report increased frequency of BRAF proto-oncogene hot spot mutation V600E in cohort of colorectal cancer patients from Ahvaz City, southwest Iran.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25916409\n",
      "Results indicated that rs3748093*A single nucleotide polymorphisms (SNPs) of BRAF proto-oncogene (BRAF) was significantly correlated with an increased risk of papillary thyroid carcinoma (PTC) in a Chinese population.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25920006\n",
      "Studies suggest that the role of tumor biomarker V600E mutation of the BRAF proto-oncogene to detect or exclude cancers in patients with fine-needle aspiration (FNA) reports is marginal and should be reconsidered in guidelines.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25922907\n",
      "RNA expression profiles were compared between conventional BRAFwild type and BRAFmutation papillary thyroid carcinomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25929517\n",
      "The aim of this study was to evaluate the prognostic role of MMR status, BRAF mutations and specific KRAS point mutation in 762 patients in Chinese population, and several clinicopathologic features to better stratify colorectal cancer patients\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25937573\n",
      "The patient carrying a concomitant BRAF mutation in temporal gangliogliomas and focal cortical dysplasia fell into Engel Class II.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25937618\n",
      "BRAF V600E Mutation is associated with papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25938346\n",
      "BRAF V600E mutation can be used as a supplementary molecular marker to aid in the diagnosis of Hairy cell leukaemia\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25948295\n",
      "Data show that proto-oncogene protein B-raf (BRAF) inhibition reduces melanoma glucose uptake per cell, but that this change is no longer significant following normalization for cell volume changes\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25950823\n",
      "Somatic BRAF mutation was found in a patient with syringocystadenoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25952101\n",
      "BRAF V600E Mutation is associated with Melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25957797\n",
      "BRAF immunohistochemistry(IHC) was strongly concordant with BRAF mutation test and had high diagnostic accuracy in BRAF mutation analysis of Papillary thyroid carcinoma.[review; meta-analysis]\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25970686\n",
      "KIT-mutated patients had a worse outcome than PDGFRA-mutated or triple-negative (KIT, PDGFRA, BRAF wild-type) cases\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25975986\n",
      "reviews the current knowledge on the use and implications of BRAF mutational status in colorectal tumors, in order to define its present role in the clinical practice\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25985019\n",
      "we identified a new SND1-BRAF fusion that appeared to be present in a subpopulation of tumor cells.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25988212\n",
      "With respect to diagnostic potential, results obtained using the BRAF(V) (600E) mutation test combined with cytological examination were not significantly different from those obtained with cytological examination only.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26014474\n",
      "BRAF V600E immunostaining is a helpful marker for pediatric metanephric adenoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26032958\n",
      "BRAF protein play a role in the mitochondrial fragmentation in melanoma patients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26036358\n",
      "BRAFV600E expression in melanocytes induces Schwannian differentiation in vivo\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26045855\n",
      "Case Report: BRAFV600 mutant non-small-cell lung cancer which progressed on vemurafenib therapy.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26055532\n",
      "Our data lead us to hypothesize that TERT promoter and BRAF mutations cooperate in cutaneous melanoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26066373\n",
      "BRAF-V600E mutations occur predominantly in female smokers with adenocarcinomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26071465\n",
      "detection of BRAF V600E by immunohistochemistry is useful in the distinction of hairy cell leukemias from other splenic-based lymphomas\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26075701\n",
      "According to results, oral benign peripheral nerve sheath tumours have a low LOH rate, but P53 locus alteration is occasionally found. Additionally, BRAF V600E mutation is either not relevant to the molecular pathogenesis of this group of lesions of the oral cavity, or may occur at very low rates.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26080065\n",
      "BRAF protein immunohistochemistry on fine needle aspiration can be important in the diagnosis of papillary thyroid carcinoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26083553\n",
      "BRAFV600E expression is homogeneous in melanoma tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26083571\n",
      "This study confirmed the high frequency of KIAA1549:BRAF fusion in Pilocytic Astrocytomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26084290\n",
      "TRAP1 is a downstream effector of BRAF cytoprotective pathway in mitochondria and TRAP1 targeting may represent a novel strategy to improve the activity of proapoptotic agents in BRAF-driven CRC cells.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26084614\n",
      "LOH and TP53 mutations detected in lip squamous cell carcinoma and actinic cheilitis may be associated with tumorigenesis, whereas BRAF mutation does not seem to significantly contribute to LSCC pathogenesis\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26090869\n",
      "BRAF, NRAS and KRAS gene mutations in plasma cell dyscrasias may have a role MEK-ERK pathway activation\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26102513\n",
      "Given the high prevalence of lung cancer and the availability of targeted therapy, Chinese lung ADC patients without EGFR and KRAS mutations are recommended for HER2 and BRAF mutations detection, especially for those never smokers\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26105190\n",
      "Presence of BRAF V600E associated with aggressive tumor features in Papillary thyroid carcinoma, including invasion, metastasis, advanced TNM stage at presentation, low response to radioiodine treatment, recurrence, and tumor-related mortality.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26110571\n",
      "Report BRAF mutations and PD-L1 expression in disseminated histiocytoses.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26115961\n",
      "BRAF mutations were associated with central nervous system tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26120069\n",
      "The BRAF mutation is a possible indicator for determining the extent of thyroidectomy required but not for the extent of lymph node dissection and prognosis in patients with conventional papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26121270\n",
      "Tissue micro array availability, BRAF mutation and KRAS mutation were all independent prognostic factors for colorectal cancer survival.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26122804\n",
      "We show for the first time that this important pediatric tumor may harbor the oncogenic BRAFV600E mutation, providing the first insights to their personalized treatment.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26123241\n",
      "Case Report: melanoma with BRAF mutation in circulating cell-free DNA despite no detectable mutation in the primary lesion.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26125673\n",
      "In 19 cases of papillary tumor of the pineal region, there was a lack of BRAF-V600E mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26125698\n",
      "BRAF overexpression is associated with BRAF V600E mutation in papillary thyroid carcinomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26138035\n",
      "BRAF mutation frequencies depended on histological subtype and localization of primary melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26143373\n",
      "Data suggest that the two strands of the BRAF promoter region, the G-rich strand and the C-rich strand, fold into a predominant antiparallel G-quadruplex and into an i-motif, respectively, and that they can coexist at nearly physiological conditions.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26143635\n",
      "Studies indicate that concurrent inhibition of proto-oncogene protein B-raf (BRAF) and Map kinase kinase (MEK) improved the most effective therapeutic modality as compared as single BRAF or MEK inhibition for patients with metastatic melanoma (MM).\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26145173\n",
      "Results show that active BRAF upregulates HMGCL via Oct-1 in cancer cells. HMGCL selectively promotes BRAF V600E-dependent phosphorylation and activation of MEK1 pathway by controlling intracellular levels of its product acetoacetate.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26145760\n",
      "v-raf murine sarcoma viral oncogene homolog B (BRAF) is preferentially mutated in proximal colon cancers.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26146664\n",
      "Report 3-fold increased risk of death for higher-risk melanomas harboring NRAS or BRAF mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26153495\n",
      "BRAF mutations are associated with metastatic colorectal cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26154146\n",
      "BRAF mutation detection in cell block material is feasible and highly specific for papillary thyroid carcinoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26160882\n",
      "Colon cancers from Asians have a lower rate of BRAF mutations than blacks or whites.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26165597\n",
      "The RAS-binding domain of human BRAF protein exhibits allosteric conformational changes upon binding HRAS.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26172302\n",
      "BRAF(V600E) mutation induces MGL ligand expression, thereby providing a direct link between oncogenic transformation and aberrant expression of immunosuppressive glycans in colorectal neoplasms.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26181250\n",
      "Retrospective analysis suggesting that nivolumab has similar efficacy and safety outcomes in patients with wild-type or mutant BRAF, regardless of prior BRAF inhibitor or ipilimumab treatment.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26181555\n",
      "real-time PCR cycle threshold values for the BRAFV600E mutation obtained from fine needle aspirates can be associated with central lymph node metastasis in papillary thyroid microcarcinoma patients\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26182194\n",
      "Report acute kidney injury in patients receiving BRAF inhibitors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26182332\n",
      "Letter/Case Reports: BRAF-mutant colorectal cancers with axillary lymph node involvement.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26187369\n",
      "Cytomorphologic features can help select nodules for the BRAF(V600E) mutation test among thyroid nodules read as \"suspicious for malignancy\" on cytology.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26189429\n",
      "Angiogenic/cachectic and pro-inflammatory/immune response factors could play a crucial role in BRAF(V600E)-positive human anaplastic thyroid carcinoma aggressiveness.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26190162\n",
      "Data show that B-Raf proto-oncogene (BRAF) V600E mutation was identified in 4 of 27 thyroid nodule patients with isthmic lesion.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26191315\n",
      "Case Report: oncocytic papillary thyroid carcinoma with lymphoid stroma (Warthin-like tumor) with BRAF V600E and V600K mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26197238\n",
      "Studies indicate that more than half of all Erdheim-Chester disease (ECD) patients carry the proto-oncogene protein B-raf mutation BRAF(V600E) and treated with vemurafenib, a BRAF inhibitor, which has proven highly beneficial.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26202550\n",
      "BRAF Mutations are associated with Lung Adenocarcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26206478\n",
      "Study found that BRAF alterations do not appear to play a prominent role in pediatric oligodendroglioma, and lack of BRAF fusions or BRAF p.V600E separate these tumors from several other pediatric low-grade gliomas\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26208478\n",
      "Findings suggest that triple therapy directed against BRAF/MEK/ErbB3 may be able to provide durable control of BRAF mutated metastatic melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26208946\n",
      "BRAF (V600) -mutation is associated with metastatic melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26214416\n",
      "This study sought to investigate the correlations of V-raf murine sarcoma viral oncogene homolog B1 (BRAF) gene mutations with the clinicopathologic features of papillary thyroid carcinoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26215201\n",
      "BRAFV600E Mutation Status in obese Patient is associated with Papillary Thyroid Cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26215382\n",
      "Data suggest that core-needle biopsy (CNB) + B-Raf proto-oncogene protein BRAF(V600E) mutation analysis can reduce rates of preventable diagnostic surgery.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26223933\n",
      "Results revealed that in patients with papillary thyroid microcarcinoma (PTMC), BRAF mutation is associated with tumor size, multifocality and aggressive features and may be used as a predictive factor for prognosis of PTMC. [meta-analysis]\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26225944\n",
      "BRAF mutations are infrequent, whereas C-KIT and NRAS mutations are seen with higher frequency in vulvar melanomas than melanomas of other sites.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26230187\n",
      "BRAF mutations are associated with follicular variant of thyroid papillary carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26232865\n",
      "Despite its high specificity, our meta-analysis shows that BRAF(V600E) mutation analysis has a low sensitivity in diagnosing papillary thyroid cancer in thyroid nodules\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26240026\n",
      "Combination of mutant-specific BRAF and CD117 ICC with cytopathology may facilitate the PTC-risk stratification in thyroid FNAB specimens.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26258321\n",
      "Compared with RAS or PAX8/PPARG-positive TCs, BRAFV600E or RET/PTC-positive Thyroid cancers were more often associated with stage III/IV disease and recurrence.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26259532\n",
      "BRAF mutations are associated with Papillary Thyroid Cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26268700\n",
      "the predictive value of BRAF mutation for central lymph node metastasis in papillary thyroid carcinoma was found to be related to the tumor size.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26269601\n",
      "neuregulin 1 promotes compensatory ErbB3 receptor signaling in mutant BRAF melanoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26271724\n",
      "BRAF V600E-mutated microcarcinomas represent a distinct biological subtype\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26274032\n",
      "Letter/Case Report: BRAF mutations in metanephric adenofibroma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26282084\n",
      "presence of BRAF mutations in melanoma associated with younger age\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26284586\n",
      "Data suggest that combination of proto-oncogene protein B-raf (BRAF) and mTOR serine-threonine kinase (mTOR) inhibition forms the basis of a treatment regimen of thyroid cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26285159\n",
      "Data indicate that BRAFV600E, P-cadherin and cadherin 6 protein expressions were correlated with one another.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26287849\n",
      "BRAF V600 appears to be a targetable oncogene in some, but not all, nonmelanoma cancers. Preliminary vemurafenib activity was observed in non-small-cell lung cancer and in Erdheim-Chester disease and Langerhans'-cell histiocytosis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26297254\n",
      "NRASQ61R and BRAFV600E immunohistochemistry coupled with next-generation sequencing allow detection of mutations in melanoma challenging samples.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26299074\n",
      "BRAF codon 600 mutations not found in Iranian prostate adenocarcinoma patients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26299805\n",
      "KRAS and BRAF oncogenes have roles in colorectal cancer development and therapy resistance [review]\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26305188\n",
      "Report BRAF mutations in selected cohort of patients with pulmonary metastases of malignant melanoma and prognostic implications.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26306423\n",
      "BRAF mutations seem to occur exclusively in the epithelial, but not in the stromal component\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26314551\n",
      "BRAF fusions are rare driver alterations in a wide variety of malignant neoplasms, but enriched in Spitzoid melanoma, pilocytic astrocytomas, pancreatic acinar and papillary thyroid cancers.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26318033\n",
      "AKT3 has a role in prostate cancer proliferation through regulation of Akt, B-Raf, and TSC1/TSC2\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26319365\n",
      "The lesions designated as KAs and BRAF inhibitor-associated verrucous keratoses had a similar mutational profile.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26321697\n",
      "no BRAF V600E mutations were found in PMSAs, but KIAA1549-BRAF fusion was identified in intermediate pilomyxoid tumors\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26339422\n",
      "Report BRAF V600 mutation detection in a large cohort of clinical samples of cutaneous melanoma metastases to the lymph nodes.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26343582\n",
      "Tumors with non-V600E BRAF mutants are insensitive to these drugs.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26343583\n",
      "LY3009120 also inhibits various forms of RAF dimers including BRAF.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26351322\n",
      "combined pan-RAF and MEK inhibition can overcome intrinsic and acquired resistance to single-agent RAF/MEK inhibition, supporting dual pan-RAF and MEK inhibition as a novel therapeutic strategy for BRAF- and KRAS-mutant cancers\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26353041\n",
      "BRAF mutation is associated with melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26359417\n",
      "BRAF V600E mutation in non-tumoral surrounding tissue in patients with colorectal cancer may be used as a valuable marker to foresee clinical outcome or a possible recurrence.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26362194\n",
      "In three cases of papillary carcinoma arising in struma ovarii (PSCS), novel BRAF and KRAS mutations were identified in two of three tumors suggesting that mutations in PCSO may differ from those commonly identified in papillary carcinoma of the eutopic thyroid.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26376292\n",
      "BRAF and KRAS mutations show together a high prevalence in stage II and III MSI colon cancer and, when combined, are associated with poor survival compared to dWT cancers, which status confers an excellent cancer-specific survival.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26381028\n",
      "Case Report: erythematous rash as a result of BRAF inhibitor therapy in advance melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26384551\n",
      "Dual inhibition of BRAF(V600E) and MEK reduced but did not prevent SW1736 invasion.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26384810\n",
      "BRAF V600E-mutation is associated with response to therapy in glioma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26392102\n",
      "BRAF V600-Mutation is associated with Colorectal Cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26392334\n",
      "A constitutive active MAPK/ERK pathway due to BRAFV600E mutation positively regulates aryl hydrocarbon receptor pathway in papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26399561\n",
      "Driver mutations are rare in mutational hotspots of BRAF, NRAS, KIT, and GNAQ/GNA11 in oral mucosal melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26403329\n",
      "consideration needs to put on multiple targets when deciding molecular target therapies for patients with BRAF V600E mutated thyroid carcinoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26405815\n",
      "Systems Analysis of Adaptive Responses to MAP Kinase Pathway Blockade in BRAF Mutant Melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26414224\n",
      "Case Report: combined \"infiltrating astrocytoma/pleomorphic xanthoastrocytoma\" harboring IDH1 R132H and BRAF V600E mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26422023\n",
      "BRAFK601E mutant thyroid tumors show better clinical outcomes than BRAFV600E positive tumors\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26425792\n",
      "BRAF-mutated conjunctival melanoma (CM) were frequent in younger patients and were rare in tumors involving the extrabulbar conjunctiva.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26426340\n",
      "BRAF Mutation is associated with response to therapy in Advanced Melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26433819\n",
      "Combination of a BRAF inhibitor plus a MEK inhibitor adds a clear benefit over monotherapy with BRAF inhibitor in unresectable or metastatic cutaneous BRAF Val600-mutation-positive melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26438153\n",
      "Among 33 BRAF wild-type colorectal carcinomas, 16 had no or weak staining, whereas 15 (45%) had heterogeneous staining. In contrast with colorectal carcinoma, Bond and Ventana VE1 IHC in melanoma and PTC were highly concordant with sequencing results\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26440707\n",
      "Levels of BRAF(mutant) and NRAS(mutant) ctDNA were determined using droplet digital PCR (ddPCR) assays. Among patients with samples available prior to treatment initiation ctDNA and LDH levels were elevated in 12/15 (80%) and 6/20 (30%) (p = 0.006) patients respectively\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26446234\n",
      "RAS and BRAF wild-type status could help select an elderly and unfit population that could benefit from anti-epidermal growth factor receptor single agent therapy.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26446943\n",
      "BRAF mutations in cfDNA are detectable in >75% of late-stage melanoma patients with BRAF mutation-positive tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26448939\n",
      "Patients with multifocal PTC whose largest tumor is BRAF-negative can have smaller tumors that are BRAF-positive.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26454140\n",
      "Langerhans cell histiocytosis and Erdheim-Chester disease, both with cutaneous presentations, and papillary thyroid carcinoma all harboring the BRAF(V600E) mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26454767\n",
      "PXA in adults PXA may present features distinct from pediatric PXA. Anaplastic features and BRAF mutation may potentially identify specific subgroups with distinct prognoses\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26457492\n",
      "The presence of BRAF mutation in fine-needle aspiration cytology specimens of nodular goitre may be useful in the assessment of oncological risk.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26460303\n",
      "BRAF V600-Mutation is associated with Colorectal Cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26461266\n",
      "The presence or absence of the BRAF mutation and TERT promoter polymorphism was not significantly correlated with survival in Papillary thyroid carcinoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26496026\n",
      "Monoclonal antibody VE1 immunohistochemistry predicts BRAF V600E mutation status and clinical outcome in colorectal cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26496853\n",
      "BRAF-mutated traditional serrated adenoma (TSA) is distinct from KRAS-mutated TSA in predisposing to the acquisition of subsequent serrated neoplasia\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26498143\n",
      "BRAFV600 mutations are associated with response to BRAF inhibitors in metastatic melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26500331\n",
      "BRAF mutation is frequent in early-onset colorectal cancer in Taiwan and is associated with a poorly differentiated histology, a serrated precursor polyp, focal signet ring cell differentiation, lack of microsatellite instability and a poor prognosis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26504080\n",
      "B-Raf(V600E) mutation in metastatic melanoma cells up-regulated tissue factor expression on cell membranes and promoted thrombin production\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26511315\n",
      "Apart from these distinct Cdc37/Hsp90 interfaces, binding of the B-Raf protein kinase to the cochaperone is conserved between mammals and nematodes.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26512781\n",
      "BRAF mutation is associated with poor response to cetuximab in colorectal carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26513490\n",
      "Both Glut1 and GLUT3 are strongly expressed by papillary thyroid carcinomas, and their expressions were significantly associated with the presence of the BRAF V600E mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26521063\n",
      "that BRAF sequencing has been used to discriminate between dedifferentiated papillary thyroid carcinoma and tumor to tumor metastasis\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26521469\n",
      "High frequency and specificity of the V600E BRAF mutation make it a useful biochemical marker for selecting the right surgical strategy for thyroidectomy.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26530529\n",
      "Data indicate that tumors with proto-oncogene proteins BRAF or KRAS mutations were in correlation with elevated serum level of carbohydrate antigen (CA19-9) and carcinoma embryonic antigen (CEA).\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26541605\n",
      "Vitamin C is selectively toxic to cells with mutant KRAS or BRAF alleles.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26562020\n",
      "Data indicate that mutations in PTEN phosphatase A167T and NRAS protein Q61L, and proto-oncogene protein BRAF V600E were detected in melanoma cell line.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26562024\n",
      "Case Report: BRAF kinase domains are a clinically important genomic alteration and therapeutic target.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26563980\n",
      "The vast majority of these tumors harbor the oncogenic BRAF V600E mutation. [review]\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26575115\n",
      "NRAS codon 61 is the most frequent genetic alteration in this acromegaly series with Differentiated Thyroid Cancer . Since acromegalic patients have lower prevalance of BRAF V600E mutation, BRAF V600E mutation may not be a causative factor in development ofDifferentiated Thyroid Cancer in acromegaly.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26575603\n",
      "In the validation-set (508 pts, RAS wt: 262 (51.6%), BRAFV600E mutated: 49 (9.6%)), right-sided primary, female gender and mucinous histology were confirmed as independent predictors of BRAFV600E mutation with high accuracy\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26582644\n",
      "Cooperation of BRAF(F595L) and mutant HRAS is associated with histiocytic sarcoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26582795\n",
      "Characterization of TP53 as a downstream effector of miR-3151 provides evidence for a causal link between BRAF mutations and TP53 inactivation\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26584635\n",
      "Data indicate that among classic and follicular variant papillary thyroid carcinomas (PTCs), mutation of proto-oncogene protein B-raf (BRAF(V600E)) was significantly associated with the smaller size.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26597176\n",
      "The patient's resected brain tumor is BRAF V600E mutated, NRAS wild type (WT), and TERT C250T mutated. The patient is a carrier of germline variants in immunomodulatory loci associated with prolonged survival.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26598713\n",
      "Chronic lymphocytic thyroiditis was an independent predictor for less aggressiveness in conventional papillary thyroid carcinoma patients regardless of BRAF mutation status.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26600396\n",
      "the V600E BRAF mutation occurred in about half of melanoma patients; it was associated with earlier manifestation of melanoma and likely with more aggressive clinical features.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26600545\n",
      "PIK3CA mutations were observed in 32% (8) of the 25 breast cancer tissues examined, Sequencing of exon 2 of KRAS suggested that 20% (5) of the 25 samples harbored a mutation and 16% (4) of BRAF harbored a mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26608120\n",
      "Report incidence and heterogeneity of genetic changes driving BRAF inhibitor resistance in melanomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26613644\n",
      "The findings suggest that the presence of the BRAFV600E mutation and loss of p16 expression accelerate the growth rate of melanomas in vivo leading to larger melanocytes that are more frequently arranged in nests.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26616061\n",
      "Recent reports show a significant radiosensitization of the irradiated healthy tissue in patients with melanoma after the combination of radiotherapy and BRAF(V600) inhibitors, evoking concern in clinical practice\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26616508\n",
      "use of sorafenib has been ineffective in the management of advanced Colorectal cancer (CRC) patients with KRAS mutation, combination of selective BRAF inhibitors plus EGFR inhibitors may represent a good therapeutic strategy in BRAF-mutant CRC.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26623721\n",
      "Data show that dasatinib induced DNA damage and activated DNA repair pathways leading to senescence only in the kinase-inactivating BRAF kinase (BRAF) mutations (KIBRAF) non-small cell lung cancer (NSCLC) cells.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26625260\n",
      "identification of 7 BRAF-induced genes that are specific for BRAF V600E-driven papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26630683\n",
      "BRAF-V600 mutation inconsistencies of up to 14.5% can be seen between the primary and metastatic foci in melanoma cases. These findings should be taken into account when planning targeted therapy and deciding on treatment responsiveness/unresponsiveness.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26632889\n",
      "The presence of the BRAFV600E mutation is independently associated with high F-18 FDG uptake on preoperative PET/CT in patients with overt papillary thyroid cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26643848\n",
      "Twenty-three percent of patients with V600E- and 43% of patients with K601E-mutant melanomas presented with nodal disease at diagnosis compared to just 14% of patients with BRAF wild-type tumors (P = 0.001 and 0.006, respectively). Overall, these mutations represent a significant minority of BRAF mutations, but have distinct clinicopathological phenotypes and clinical behaviors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26646323\n",
      "Data show that Griffipavixanthone (GPX), a dimeric xanthone isolated from Garcinia esculenta, is a B-RAF and C-RAF inhibitor against esophageal cancer cells.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26668268\n",
      "Actin remodeling confers BRAF inhibitor resistance to melanoma cells through YAP/TAZ activation\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26671072\n",
      "BRAF mutational status correlates with recurrence of papillary thyroid microcarcinoma [review; meta-analysis]\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26678033\n",
      "BRAF mutation is associated with melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26684240\n",
      "BRAF V600E mutation is associated with resistance to pazopanib in gastroenteropancreatic neuroendocrine tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26691448\n",
      "These results revealed differences in the genetic profiles of KRAS, NRAS, PIK3CA and BRAF at mutation hotspots between Chinese CRC patients and those of Western countries.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26695089\n",
      "BRAFV600E status during melanoma progression was evaluated in a cohort of 54 patients with at least paired-samples. These findings suggest that only VE1-negative tumours would be genotyped to detect other BRAFV600 mutations, and that either primary melanoma or metastasis can be tested using immunohistochemistry, according to the material available.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26710756\n",
      "BRAF mutation is not associated with pheochromocytoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26711586\n",
      "TERT promoter mutations have a limited role in pediatric thyroid carcinoma, but the BRAFV600E mutation may have a role in recurrence in pediatric patients\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26711930\n",
      "Clinical data suggest that BRAF mutations define specific subsets of patients with NSCLC; while their oncogenic nature is yet to be established in lung cancer, especially for non-V600E mutations, the value of BRAF mutations to predict the efficacy of targeted agents remains unclear.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26718882\n",
      "four cases harbored the BRAF-V600E mutation, one case harbored the BRAF-G606R mutation, and three cases harbored deletions in exon 19 of EGFR\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26718898\n",
      "It was suggested that somatic point mutations in BRAF, CDKN2A and PI3KCA do not participate in the oncogenesis of Medullary thyroid carcinoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26732095\n",
      "This study discovered oncogenic BRAF deletions with a distinct activation mechanism dependent on the BRAF dimer formation in tumor cells.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26733165\n",
      "study suggests an influence of overweight BMI on the status of BRAF (V600E) in patients with PTC, whereas the underlying mechanism need to be further investigated\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26734696\n",
      "BRAF V600E mutation is associated with Langerhans cell histiocytosis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26749005\n",
      "BRAF mutation is associated with thyroid neoplasms.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26750533\n",
      "The significant association of SLP-2 overexpression with unfavorable clinicopathological characteristics and BRAFV600E mutation indicates that SLP-2 may have a role in aggressiveness of BRAF-mutated papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26750638\n",
      "BRAF V600E inhibition stimulates AMP-activated protein kinase-mediated autophagy in colorectal cancer cells.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26753950\n",
      "olfactory neuroepithelial progenitor cells with the genetic heritage of bipolar I disorder were more sensitive to glutamate induced apoptosis. Under expression of the BRAF gene and protein, which plays a role in regulating the pro-survival MEK/ERK signaling pathway, may contribute to this apoptotic sensitivity.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26758762\n",
      "Findings suggested that BRAF-activated noncoding RNA may contribute to hepatocellular carcinoma initiation and progression.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26775732\n",
      "BRAF mutations are associated with response to therapy in metastatic colorectal cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26787892\n",
      "results reveal a common BRAF(V600E)-directed transcriptional regulatory pathway that mediates epigenetic silencing in unrelated solid tumors and provide strong support for an instructive model of oncoprotein-directed epigenetic silencing\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26790143\n",
      "Conclude that PRIMA-1(Met) through its ability to directly reactivate p53, sensitises (V600E/K)BRAF-positive melanoma cells to BRAF inhibitors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26796506\n",
      "Letter: report frequent BRAF V600E mutations in metanephric stromal tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26799289\n",
      "BRAF mutation is associated with colon cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26802240\n",
      "BRAF mutation is playing an important role in the pathogenesis of pyogenic granuloma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26807515\n",
      "MC1R status is associated with BRAF(V600E), BRAF(V600K), and NRAS mutations in cutaneous melanomas\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26808395\n",
      "Alternative pathways through mutations in BRAF gene are associated with the progression of Colorectal polyps to cancer and may provide insights into the genetic characteristics of skirts.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26810070\n",
      "BRAF, FGFR1, and MYB mutations occur at high frequency and align with morphology of low-grade neuroepithelial tumors\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26810733\n",
      "Our findings present EBI-907 as a potent and promising BRAF inhibitor, which might be useful in broader indications.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26814611\n",
      "A BRAF mutation, p.Val600Ala, was identified in 1 of 8,000 peripheral blood lymphocytes and 1 of 6,000 T lymphocytes from rheumatoid arthritis patients and in 1 of 12,500 peripheral blood lymphocytes and 1 of 12,500 T lymphocytes from controls\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26823860\n",
      "We demonstrated that the BRAF (V600E) mutation slightly correlated with the clinicopathological characteristics of papillary thyroid cancer in the Han population\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26825657\n",
      "One of the most cited proteins in melanoma is BRAF (about 50-60 % of melanomas harbors activating BRAF mutations), for these the most common is a substitution of valine to glutamic acid at codon 600 (p.V600E)[review]\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26825960\n",
      "Specific inhibition of BRAF oncogene, MEK or p38 signaling was associated with decreases in DIO3 expression in papillary thyroid cancer cells\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26826419\n",
      "Colorectal poorly differentiated neuroendocrine carcinomas frequently harbor BRAF mutations and are associated with poor overall survival.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26835544\n",
      "BRAF mutation subclonality was associated with earlier disease stage in Papillary Thyroid Carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26838744\n",
      "BRAF(V600E) mutation is correlated with a lower expression of Na(+)/I(-) symporter in papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26848795\n",
      "The BRAF V600 mutations were significantly associated with AQP1 expression (P=0.014). Long-term follow-up indicated a reduced progression-free survival (P=0.036) and overall survival (P=0.017) for the AQP1-positive cutaneous melanoma patients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26857243\n",
      "TERT promoter mutation is an independent predictor for distant metastasis of thyroid neoplasms, but ALK testing is not useful for clinical decision-making in Korean patients with a high prevalence of the BRAF V600E mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26871591\n",
      "Apart from BRAF V(600)E, no other recurrent somatic mutation was identified in these hairy cell leukaemia exomes, thereby excluding additional acquired mutations as also prevalent at a near-universal frequency in this form of the disease.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26871894\n",
      "Positive status of BRAF(V600E) mutation was a significant predictor of multifocality (OR = 1.23; 95%CI = 1.14-1.32), extrathyroidal extension (OR = 2.23; 95%CI = 1.90-2.63), TNM stage (OR = 1.67; 95%CI = 1.53-1.81), lymph node metastasis (OR = 1.67; 95%CI = 1.45-1.93), vascular invasion (OR = 1.47; 95%CI = 1.22-1.79) and recurrence/persistence (OR = 2.33; 95%CI = 1.71-3.18) of Papillary Thyroid Carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26889698\n",
      "The rate of the BRAFV600E mutation increased significantly in papillary thyroid cancer diagnosed in Poland from 2000-2013\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26892442\n",
      "KRAS and, infrequently, BRAF mutations are observed in a subset of small intestinal adenocarcinomas, and are associated with higher pT classification and more frequent pancreatic invasion\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26910217\n",
      "The rate of the BRAF V600E mutation in the pediatric population with papillary thyroid carcinoma is significantly lower than that seen in the adult population\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26910894\n",
      "Mutant BRAF may, in part, drive the histologic progression of colorectal adenomas toward serrated histology\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26912807\n",
      "BRAF V600E mutation predisposes papillary thyroid carcinoma cells toward invasive phenotypes\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26924424\n",
      "BRAF-V600E expression in primary nodular melanoma is associated with aggressive tumour features.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26925640\n",
      "BRAF mutations are associated with poor response to chemptherapy in Colorectal Peritoneal Carcinomatosis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26925650\n",
      "KRAS mutations are not Associated with Metastatic Colorectal Cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26927026\n",
      "BRAF V600E mutations were found in the papillary craniopharyngiomas subgroup and were not detectable in papillary craniopharyngiomas samples.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26927447\n",
      "Braf mutations were extremely rare in pancreatic cancer, suggesting that they play a limited role in PC development.[review]\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26932501\n",
      "Results are the first to describe the presence of Wnt signaling pathway abnormalities, manifested by nuclear beta-catenin, in a subset, as well as the lack of BRAF(V600E) mutation in gliosarcoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26943032\n",
      "This study, the largest on TERT mutation so far, demonstrates a significant role of BRAF V600E and TERT promoter mutations in the aggressiveness of papillary thyroid carcinoma, which is particularly robust and cooperative when the two mutations coexist.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26945035\n",
      "This study demonstrated that when whole chromosome 7 gain accompanies the KIAA1549-BRAF fusion, the fusion likely arises first.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26950846\n",
      "The BRAFV600E mutation was significantly associated with central lymph node metastases in patients undergoing prophylactic central neck dissection when specifically controlling for preoperatively available clinicopathologic variables in all papillary thyroid cancer subtypes.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26951110\n",
      "The present cohort identifies that the classic architecture with multicentricity and local recurrence are correlates of BRAF (V600E) harboring pediatric papillary thyroid carcinomas\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26959608\n",
      "Thus ERK5 signaling is unlikely to play a role in tumor cell proliferation downstream of KRAS or BRAF or in tumor cells with ERK5 amplification. These results have important implications for the role of ERK5 as an anti-cancer drug target\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26959890\n",
      "Growth arrest is accompanied by MAPK-mediated serine/threonine phosphorylation and suppression of a variety of oncogenic drivers that resist treatment by B-Raf(V600E) kinase inhibitors, including ErbB members, c-Met, IGFR, IRS, STAT3 and Akt.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26960768\n",
      "The diagnostic classifier based on profiling of 13 microRNAs was proposed, with total estimated accuracy varying from 82.7 to 99% for different nodule types. Relative expression of six microRNAs appeared significantly different in BRAF(V600E)-positive samples compared to BRAF(V600E)-negative papillary carcinoma samples\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26969876\n",
      "The coexistence of BRAF or RAS mutations enhanced the prognostic effects of telomerase reverse transcriptase (TERT) promoter mutations. Furthermore, TERT promoter mutations strengthened the predictions of mortality and recurrence by the ATA and TNM staging systems, particularly for high-risk patients with differentiated thyroid cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26974965\n",
      "Results indicate that MAPK pathway inhibition leads to changes in the immunological properties of mutant BRAF melanoma cells.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26980021\n",
      "There was no statistically significant association between BRAF or MAP2K1 mutation and anatomic site, unifocal versus multifocal presentation, or clinical outcome in Langerhans cell histiocytosis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26980024\n",
      "Mutant BRAF represses E-cadherin expression, implicating a catalytic role for BRAF in epithelial-mesenchymal transition.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26989027\n",
      "Our data suggest that KRAS, NRAS, and BRAF mutations predict response to cetuximab treatment in metastatic colorectal cancer patients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26991344\n",
      "Our findings indicate that BRAF and KRAS mutations as well as mutation heterogeneity predict poor outcome in CRC patients subsequent to liver resections and might help guide treatment decisions.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26994902\n",
      "Study provides evidence of BRAF-KIAA fusion in disseminated glioneuronal lesions occurring in childhood and the first report of a BRAF V600E mutation in children with this disease, representing a potential therapeutic target.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26996308\n",
      "beta3-alphaC deletions are activating mutations in BRAF. BRAF deltaNVTAP confers CRAF- and dimer-independent activity and is resistant to vemurafenib.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26997441\n",
      "BRAF inhibitor therapy-associated melanocytic lesions lack the BRAF V600E mutation and show increased levels of cyclin D1 expression.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26997442\n",
      "Low incidence of BRAF mutations in adenocarcinomas of the ampulla of Vater suggest no major role in tumorigenesis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27000992\n",
      "The additive effects given by gamma-secretase inhibitor to BRAF inhibitor are due to enhancement of induction of the senescent-like arrest, which is associated with decreased RB phosphorylation and CDK6 expression.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27009410\n",
      "The incidence of conjunctival melanoma increased in Denmark over 50 years. The proportion of BRAF-mutated conjunctival melanoma was constant. BRAF mutations were identified as early events in conjunctival melanoma, associated with a distinct clinicopathological profile.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27028853\n",
      "Data indicate that BRAF inhibitor (BRAFi) have unique paradoxical ERK activation profiles.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27033063\n",
      "The prognostic role of BRAF, PIK3CA mutations and ploidy in advanced CRC.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27034263\n",
      "BRAF mutation may have different prognostic implications in early- and late-stage colorectal cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27036313\n",
      "Increased staining for phosphorylated ERK1/2 does not correlate to BRAF or KRAS mutations in colorectal neoplasms.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27041569\n",
      "These findings identify a key mechanism of tolerance to Ras-Raf pathway inhibitors and suggest that blocking either AMPK or autophagy in combination with these targeted inhibitors could increase tumor regression and decrease the likelihood of eventual recurrence.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27048246\n",
      "we identify recurrent somatic BRAF alterations in high-grade colorectal NET and demonstrate rapid clinical improvement and tumor responses with a combination of BRAF- and MEK-directed therapies.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27062580\n",
      "our results suggest that the mutational spectrum of pediatric AF is more complex than in adult AF, being rich in AKT1 and BRAF, as well as CTNNB1 gene mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27064992\n",
      "the prevalence and clinicopathological associations of BRAF V600E and TERT promoter mutations in Chinese PTC patients\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27080216\n",
      "Dabrafenib showed clinical activity in BRAF(V600E)-positive NSCLC. Our findings suggest that dabrafenib could represent a treatment option for a population of patients with limited therapeutic options\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27082577\n",
      "The BRAF-mutated Colorectal Cancers ,in comparison to KRAS-mutated ones, are associated with a much worse prognosis for the afflicted patients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27084044\n",
      "The BRAFV600E antibody (clone VE1) IHC may show non-specific staining, but molecular assays may be useful for the diagnosis of unicystic ameloblastoma, in conjunction with clinical, radiological and histopathological features.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27085458\n",
      "BRAF mutations occur frequently in testicular germ cell tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27087167\n",
      "the BRAF pathway is activated in endometriotic cells from patients with endometriosis, and inhibition of the BRAF pathway can significantly decrease proliferation in both epithelial and stromal endometriotic cells in vitro and in vivo\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27094161\n",
      "New and highly sensitive method to detect BRAF V600 mutations in Langerhans cell histiocytosis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27098748\n",
      "BRAF mutations were not detected in any of the four IM cases examined. One patient with IM died from metastatic disease: this tumour was disomy 3 with 6p and 8q gains. All other patients were alive with no evidence of metastases at study closure.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27101548\n",
      "The BRAF was mutated in 55% (29/53) and NRAS in 11% (5/45) of the primary melanomas sequenced.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27105117\n",
      "Cdc37 performs a quality control of protein kinases, including b-raf, where induced conformational instability acts as a \"flag\" for Hsp90 dependence and stable cochaperone association.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27111917\n",
      "HRM appears the less sensitive assay for the detection of BRAF V600 mutations. The RT-ASA, IdyllaTM and IHC assays are suitable for routine molecular diagnostics aiming at the prescription of anti-BRAF therapies\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27116958\n",
      "Braf and Kras genes mutation were reveled in gastritis and adenocarcinoma patients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27138801\n",
      "BRAF mutation was significantly related with shorter DFS and OS among stage II/III CRC patients receiving adjuvant chemotherapy after curative resection\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27138882\n",
      "BRAF(V600E) in papillary thyroid cancer predicts an increased risk of lymph node metastasis, extra-thyroidal extension and reduced disease-free survival. It is an additional useful prognostic biomarker.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27147251\n",
      "BRAF mutation is correlated with response to therapy in melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27150060\n",
      "Data show that 514 of 1170 patients (44%) carried a BRAF mutation, and all models indicated age and histological subtype of melanoma as the two major predictive variables.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27165943\n",
      "BRAF mutation is associated with response to chemotherapy in lung cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27167340\n",
      "Data show that long noncoding RNA RMEL3 is required for MAPK and PI3K signaling, and its knockdown decrease BRAFV600E melanoma cell survival and proliferation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27180062\n",
      "Functional Na+/I- symporter activity was higher in BRAF(V600E) mutation-positive cases of classical variant papillary thyroid carcinoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27194447\n",
      "strong correlation between the presence of circulating V600 mutated DNA and overall survival of melanoma patients\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27197524\n",
      "BRAF IHC is strongly concordant with the BRAF mutation test.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27198569\n",
      "PD-L1 expression in colorectal cancer is associated with microsatellite instability and BRAF mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27210749\n",
      "These results provide support for the role of BRAF(V600E) in metastasis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27220764\n",
      "p16 and BRAFV600E are useful to distinguish between sporadic and hereditary (Lynch syndrome-related) microsatellite instable colorectal carcinomas\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27222248\n",
      "The B-Raf inhibitor PLX4032 induces DR5 upregulation exclusively in Ras-mutant cancer cells; this effect is dependent on Ras/c-Raf/MEK/ERK signaling activation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27226552\n",
      "using a kinase-inactive mutant of CK2alpha, that RAF-MEK inhibitor resistance did not rely on CK2alpha kinase catalytic function, and both wild-type and kinase-inactive CK2alpha maintained ERK phosphorylation upon inhibition of BRAF or MEK.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27249714\n",
      "For patients with non-small cell lung cancer with a EGFR mutation and an anaplastic lymphoma kinase mutation(ALK) with brain metastases, several agents have shown intracranial activity. Lapatinib has been tested for patients with brain metastases from breast cancer harboring a HER2 mutation. molecular targeted therapies have shown efficacy in BRAF-positive melanoma brain metastasis\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27253461\n",
      "investigation of MGMT promoter methylation and in particular BRAF V600E mutations represent reliable additional tools to sustain differentiation of Giant Cell Glioblastoma (gcGBM) from Pleomorphic Xanthoastrocytoma (PXA) on a molecular basis. Based on these data specific BRAF kinase inhibitors could represent a promising agent in the therapy of PXA and their use should be emphasized.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27256275\n",
      "The BRAF(V)(600E) mutation is also seen in paediatric cytology and the morphological features showed a high accuracy as both predictive mutational parameters and a helpful aid in management mainly of the aggressive BRAF(V)(600E) mutated carcinomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27261210\n",
      "The association of BRAF mutations with clinical and pathological features was assessed next in a cohort of 840 KRAS exon 2 wild type CRC patients screened with the Real Time PCR assay.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27283860\n",
      "BRAF(V600E)-mutation is associated with metastatic non-small cell lung cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27296272\n",
      "Erdheim-Chester Disease With Cardiovascular Involvement and BRAF V600E Mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27314237\n",
      "Our study provides a rationale to strengthen NK cell immunotherapy through a combination with cetuximab for RAS and BRAF mutant mCRC patients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27325282\n",
      "MET amplification is here identified-clinically and preclinically-as a new mechanism of resistance to EGFR and BRAF dual/triple block combinations in BRAF-mutated colorectal cancer. Switching from EGFR to MET inhibition, while maintaining BRAF inhibition, resulted in clinical benefit after the occurrence of MET-driven acquired resistance.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27329244\n",
      "RNF43 germline and somatic mutation in Serrated Neoplasia pathway associated with BRAF mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27342756\n",
      "Studies indicate the clinical importance of BRAF-V600 mutations and BRAF inhibition in the progression to melanoma brain metastasis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27345584\n",
      "Here we review the current knowledge about the classification of this tumor subtype and its association with five key features: mutation status of the BRAF or KRAS genes, the CpG island methylation phenotype, microsatellite instability, immune cell infiltration, and overexpression of GTPase RAC1b\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27351224\n",
      "Using a panel of BRAF V600E and WT colorectal cancer cell lines and in vitro selected resistant culture, and xenograft models, authors demonstrate here that BRAFV600E confers resistance to mTOR inhibitors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27354468\n",
      "We suggest that BRAF mutant patients should not be considered as having a unique biology and provide an in depth characterization of heterogeneous motifs that may be exploited for drug targeting.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27358379\n",
      "Mutations in KRAS and BRAF were associated with inferior PFS and OS of mCRC patients compared with patients with non-mutated tumors. KRAS exon 2 mutation variants were associated with heterogeneous outcome compared with unmutated tumors with KRAS G12C and G13D (trend) being associated with rather poor survival\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27368419\n",
      "DiRas3 binds to KSR1 independently of its interaction with activated Ras and RAF.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27382031\n",
      "The results demonstrated the lack of activity of anti-EGFRs in RAS(KRAS and NRAS) and BRAF wild-type, right-sided tumors, thus suggesting a potential role for primary tumor location in driving treatment choices\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27387551\n",
      "This study is the first to report BRAF mutations in a pure adult sample of differentiated thyroid cancer of Saudi Arabian ethnicity.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27401113\n",
      "The results establish a link between BRAF(V600E) and NOX4, which is confirmed by a comparative analysis of NOX4 expression in human (TCGA) and mouse thyroid cancers.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27404270\n",
      "colorectal cancers with BRAF D594G mutations are similar to those with BRAF wild-type with regard to clinicopathological features, microsatellite instability status, and prognosis. However, colorectal cancers with BRAF D594G mutations are rare.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27416954\n",
      "BRAFV600E mutation is associated with astroblastoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27433783\n",
      "BRAFV600E mutations were associated with younger patient age and localization of melanoma on sun-protected areas of the skin.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27435270\n",
      "There is association between CpG island methylator phenotype and mutation of BRAF in patients with metastatic Colorectal cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27438990\n",
      "Results indicate that MLH1-hypermethylated BRAF wild-type colorectal carcinomas can harbor KRAS mutations and arise from precursor polyps resembling conventional tubular/tubulovillous adenomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27442672\n",
      "A higher number of suspicious US features classified by the TIRADS, but not the BRAF mutation, are associated with lateral lymph node metastasis in patients with PTC, and can aid in the preoperative identification of patients at increased risk of lateral lymph node metastasis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27449293\n",
      "Results show that promoter mutations render telomerase reverse transcriptase (TERT) expression dependent on MAPK signal pathway activation due to oncogenic BRAF or NRAS mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27454941\n",
      "Study of four cases confirms BRAF V600E mutation as a probable driver in a subset of ciliated muconodular papillary tumors (CMPT) of the lung, along with AKT1 mutation, which further supports that CMPT are indolent pulmonary neoplasms.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27458004\n",
      "Compared with newly diagnosed multiple myeloma, an increased prevalence of mutations in the Ras pathway genes KRAS, NRAS, and/or BRAF (72%), as well as TP53 (26%), CRBN (12%), and CRBN pathway genes (10%) was observed.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27460442\n",
      "BRAF(V600)-mutation is associated with papillary thyroid cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27466810\n",
      "found that BRAF genotyping in weakly and moderately pigmented samples was more efficient when the sample was processed with BSA or purified with a NucleoSpin(R) gDNA Clean-up XS Kit prior to PCR amplification\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27480103\n",
      "BRAF(V600)-mutation is associated with melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27503895\n",
      "miR-579-3p controls melanoma progression and resistance to target therapy by targeting the 3'UTR of two oncoproteins: BRAF and MDM2.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27532222\n",
      "A pointmutation located in exon 5 of the TP53 gene and a point mutation in exon 15 of the BRAF gene (c.1799T>A, V600E) were detected in an anaplastic thyroid carcinoma patient\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27535135\n",
      "Point mutations of BRAF is associated with thyroid cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27542908\n",
      "(V600)BRAF switches on a metabolic reprogramming in melanoma cells, leading to a decreased OXPHOS activity and increased glycolytic ATP, lactate, HIF-1alpha and MCT4 levels.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27545333\n",
      "A report of BRAF mutations in acute myeloid leukemias (AML) found mutations only in de novo AML with monocytic differentiation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27554081\n",
      "The BRAF V600E mutation is now recognized as the causal genetic event of hairy cell leukemia because it is somatic, present in the entire tumor clone, detectable in almost all cases at diagnosis (encompassing the whole disease spectrum), and stable at relapse.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27555670\n",
      "IFNgamma inhibits CXCL8 secretion and in turn the migration of a BRAF V600e mutated thyroid cell line\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27568671\n",
      "Compared to some Asian populations, this study of Filipino papillary thyroid carcinoma patients shows a lower prevalence of BRAF V600E mutation\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27571181\n",
      "r-BRAF are very uncommon in papillary thyroid carcinomas (PTC) and are found almost exclusively in PTC with low-risk clinicopathological features.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27597420\n",
      "The BRAF/MAP2K1-mut LCH cells had a more immature state than BRAF/MAP2K1-wt LCH cells. Authors also found the BRAFV600E and MAP2K1 mutations were significantly associated with pERK expression.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27599148\n",
      "Study found that BRAF alterations are frequent in dysembryoplastic neuroepithelial tumors (DNTs), particularly BRAF copy number gain which is being reported for the first time in these tumors. Evidence of activation of mTOR and MAPK pathways suggests a role for altered signalling in DNT pathogenesis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27600854\n",
      "BRAF mutations are closely associated with aggressive clinicopathological characteristics and poorer prognosis in papillary thyroid cancer. [meta-analysis]\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27608415\n",
      "Study finds infrequent BRAF alterations but enriched FGFR alterations in adults as compared with that reported in pediatric pilocytic astrocytomas. In addition, coexistent BRAF and FGFR alterations and a significant association of FGFR alterations with age and tumor location were noted.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27620500\n",
      "The authors find that the interaction between sB-Raf and the Hsp90 chaperone system is based on contacts with the M domain of Hsp90, which contributes in forming the ternary complex with Cdc37 as long as the kinase is not stabilized by nucleotide.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27630332\n",
      "BRAF-mutant lesions are consistently associated with poor prognosis. Consequently, the indications of colorectal liver metastasis resection in this patient group should be reconsidered.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27634910\n",
      "Mutation analysis Iindicate NRAS as the most commonly mutated gene in myeloma patients followed by KRAS ( and BRAF.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27659822\n",
      "The V600E mutation is associated with a risk of transformation to high-grade glioma and poor response to chemoradiation approaches and outcome.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27666765\n",
      "BRAF V600E mutation in capsular nevi of sentinel lymph nodes may be useful as an adverse predictive biomarker in patients with melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27671879\n",
      "In this report, we describe a 35-year-old female who presented with multifocal ganglioglioma, involving both the conus medullaris and filum terminale. The dominant lesion in the filum terminale was resected, which revealed World Health Organization I grade, p53 mutant, and BRAF wildtype status\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27672042\n",
      "Japanese patients with sporadic colorectal cancer with BRAF V600E mutation exhibited a significantly shorter overall survival.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27681305\n",
      "findings suggest an association of BRAF-V600E with parameters of a more aggressive behaviour of ameloblastoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27689252\n",
      "BRAF-positive thyroid cancers most often demonstrate worrisome sonographic features and are frequently associated with positive or suspicious Bethesda cytology.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27718322\n",
      "BRAF V600E mutation is associated with cerebellar pilocytic astrocytoma recurring as a ganglioglioma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27729324\n",
      "Alternative genetic mechanisms of BRAF activation in Langerhans cell histiocytosis\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27737711\n",
      "No significant impact on prognosis was observed for mutated KRAS, NRAS, and PIK3CA genes or combined RAS mutations\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27760550\n",
      "BRAF(V600E) mutation is a common genetic change in isolated hypothalamic-pituitary Langerhans cell histiocytosis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27764839\n",
      "Incidence of adverse events was similar regardless of RAS/BRAF status.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27765849\n",
      "BRAF(V600E)-mediated MEK/ERK activation can upregulate MCL-1 by phosphorylation/stabilization to confer apoptosis resistance that can be reversed by MCL-1 antagonism combined with cobimetinib, suggesting a novel therapeutic strategy against BRAF(V600E)-mutant CRCs.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27766572\n",
      "BRAF mutations were detected in 54 of 115 (47 %) including 51 of V600E and 3 of V600 K in Japanese melanoma cases.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27769870\n",
      "BRAF V600E mutations wereencountered in most metanephric stromal tumors, supporting a link with other metanephric tumors and suggesting a clonal event possibly affecting primordial renal cells.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27771229\n",
      "BRAF V600E is the predominant mutation in Japanese non-chronically sun-damaged melanoma patients, and that both intra- and inter-tumor mutational heterogeneities exist in primary and metastatic melanomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27775641\n",
      "Findings suggest that the association of HER2 amplification with BRAF(V600E) mutation and telomere shortening may represent a marker of tumor aggressiveness, and, in refractory thyroid cancer, may warrant exploration as a site for targeted therapy.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27775691\n",
      "Data show that BRAF inhibitor (BRAFi) treatment failed to affect Nodal protein levels in melanoma tissues.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27776007\n",
      "Spitzoid neoplasms with BRAF fusion cases were most likely to have high-grade nuclear atypia, to be diagnosed as spitzoid melanoma, to have a positive result by melanoma fluorescence in situ hybridization assay, and to develop copy number gains in the kinase domain of the fusion protein.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27791198\n",
      "A rapid monophyletic evolution of melanoma subpopulations in response to targeted therapy that was not observed in non-targeted therapy was observed. NRAS mutations in BRAF mutated patient treated with a BRAF inhibitor were identified post-resistant samples. Sequence analysis showed that NRAS mutations co-occur with BRAF mutations in single cells, and are not mutually exclusive.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27792249\n",
      "Results indicate that in addition to being present in established BRAF-associated gliomas, BRAF mutations might be associated with epithelial features in high-grade gliomas, including sheet-like arrangement of polygonal tumor cells with a plump cytoplasm and astroblastic rosettes, and thus could potentially serve as a genetic marker for these features.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27813079\n",
      "Increased plasma membrane abundance of PMCA4b in vemurafenib-treated BRAF mutant cells is associated with enhanced Ca2+ clearance.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27815357\n",
      "KRAS mutations were rarely found together and those in codons 12 and 13 conferred poor prognosis. For BRAF, more c.1781A>G (p.D594G) colorectal cancers (CRC)carried RAS mutations [14% (3/21)] compared with c.1799T>A (p.V600E) CRCs.For NRAS, 5% (3/60) of codon 61 mutant colorectal cancers had KRAS mutations compared with 44% (10/23) of codons 12 and 13 mutant colorectal cancers\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27835901\n",
      "Mutational activation of BRAF confers sensitivity to TGFBR1 inhibitors in human melanoma cells.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27860162\n",
      "Desmoplastic infantile astrocytoma/ganglioglioma with rare BRAF V600D mutation\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27860480\n",
      "BRAF gene mutation is confirmed by several studies found in malignant melanoma of the skin. The histopathology findings in our group did not confirmed our theory, that since the uveal melanoma itself has the similar origin as skin melanoma, should also contain a BRAF mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27863403\n",
      "Report targeted analysis of KRAS, BRAF and PIK3CA mutations in circulating tumor cells captured by a label-free platform and compare to expression in primary tumor tissue and metastases.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27863426\n",
      "CSF tumor-derived cell-free DNA has the potential to serve as a diagnostic tool in patients with BRAFV600 mutated malignancies.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27863429\n",
      "the present study identifies the WIPF1 gene as having novel oncogenic functions and playing an important role in the invasiveness and aggressiveness of thyroid cancer when aberrantly up-regulated by the BRAF V600E/MAPK pathway through its promoter demethylation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27863476\n",
      "Data indicate the role of immunohistochemical BRAF V600E expression in patients at the time of progression.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27864688\n",
      "genome analysis of wild-type gastrointestinal stromal tumors for mutations should include the BRAF gene in patients with KIT and PDGFRA wild-type gastrointestinal stromal tumors\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27864876\n",
      "ARMC10-BRAF fusion is associated with melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27865374\n",
      "A high extent more than 25% of BRAF(V600E) alleles may be associated with disease outcome in PTC patients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27866718\n",
      "BRAF protein mutation in metastatic lymph nodes maybe responsible for the recurrence of papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27870159\n",
      "ndings indicate that BRAF V600E is not a consistent squarending in myopericytoma and does not serve as a useful diagnostic immunohistochemistry marker\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27875244\n",
      "This multicenter data analysis establishes a six-genotype genetic prognostic model for poor outcomes of papillary thyroid cancer with a risk order of genetic duet of BRAF V600E/RAS mutation and TERT mutation >>>>BRAF V600E = TERT mutation alone >RAS mutation alone = wild-type genes.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27888823\n",
      "No relation between oropharyngeal squamous cell carcinomas and BRAF gene mutations\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27911099\n",
      "Morphometric variables are predictive markers for papillary thyroid carcinoma cases with positivity for BRAF V600 mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27911794\n",
      "RAS-ERK signaling in BRAF mutant melanomas is critical for regulating active chromatin state and recruitment of RNA polymerase II at mutant TERT promoters. Our study provides evidence that the mutant TERT promoter is a key substrate downstream of the RAS-ERK pathway.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27911979\n",
      "our studies show that BRAFNon-V600 mutations are not prognostic for stage IV melanoma patients, and this information will augment the design and interpretation of current and future clinical trials in this patient population.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27912827\n",
      "This review highlights treatment options, including clinical trials for ROS1 rearrangement, RET fusions, NTRK1 fusions, MET exon skipping, BRAF mutations, and KRAS mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27916952\n",
      "multiregion analysis was performed in 60 spatially separated tumor areas according to the pathological tumor node metastasis (pTNM) staging and KRAS, NRAS and BRAF mutations were tested using pyrosequencing.these results suggest the need for multiple RAS testing in different parts of the same tumor and/or more sensitive techniques.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27919446\n",
      "Immunohistochemistry is an accurate method to evaluate BRAF proto-oncogene is papillary thyroid cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27923591\n",
      "Despite a high specificity for thyroid cancer, BRAF(V600E) mutation has a low overall sensitivity and therefore has a limited diagnostic value as a single screening test.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27923714\n",
      "Acquired BRAF V600E Mutation is associated with resistance to osimertinib in lung cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27928645\n",
      "Our data demonstrate that starvation-trigged autophagy, which is BRAF V600E dependent, promotes cancer cell survival in uveal melanoma. Vemurafenib induces autophagic cell death rather than adaptive cell survival in BRAF V600E-mutant melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27930579\n",
      "BRAF mutation and DNA mutation was associated with serrated polyps and hyperplastic polyps in the carcinogenesis of colorectal cancers.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27936049\n",
      "Extrathyroid invasion, lymph node metastases, and BRAFV600E mutation were the high risk factors of papillary thyroid microcarcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27943267\n",
      "Alcohol intake is associated with an increased risk of KRAS+ and BRAF-/KRAS- tumors originating via specific molecular pathways including the traditional adenoma-carcinoma pathway but not with BRAF+ tumors originating via the serrated pathway\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27965097\n",
      "in response to vemurafenib, BRAF-mutated melanoma and colorectal cancer cells rapidly induced the ISR as a cytoprotective mechanism through activation of general control nonderepressible 2 (GCN2), an eIF2alpha kinase sensing amino acid levels\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27977682\n",
      "we demonstrate that small molecule PERK inhibitors exhibit single agent efficacy against BrafV600E-dependent tumors highlighting the clinical value of targeting PERK\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27984673\n",
      "A series of midline gangliogliomas demonstrate that the H3 K27M mutation can occur in association with the BRAF V600E mutation in grade I glioneuronal tumors. Despite the presence of H3 K27M mutations, these cases should not be graded and treated as grade IV tumors because they have a better spontaneous outcome than classic diffuse midline H3 K27M-mutant glioma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27984807\n",
      "This study demonstrated the presence of BRAF V600E mutation in Chinese epileptic patients with Glioneuronal tumors, which was significantly correlated with gender and multiple seizure types.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27993793\n",
      "these data highlight the poor prognosis of patients with metastatic melanoma and BM, despite a targetable 'driver' oncogene mutation(BRAFv600) and evidence of initial drug-responsiveness\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27993800\n",
      "BRAF-mutant advanced colorectal cancer ( aCRC) confers a markedly worse prognosis independent of associated clinicopathological features. Chemotherapy provides meaningful improvements in outcome throughout treatment lines. Post-progression survival is markedly worse and vigilance is required to ensure appropriate delivery of treatment after first-line progression\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27999210\n",
      "A panRAF inhibitor, LY3009120, potently inhibited proliferation and tumor growth in BRAF/KRAS mutated colorectal tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28000889\n",
      "High BRAF mutation rate is associated between primary colorectal cancer and corresponding metastases.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28002643\n",
      "BRAF mutation is not associated with response to chemotherapy in Melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28006055\n",
      "Mutations in BRAFV600E were significantly associated with worse survival after recurrence (SAR) in patients with recurrent stage III colon cancer, and worse SAR for BRAFV600E or KRAS mutant tumors was more strongly associated with distal cancers.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28025078\n",
      "Report KRAS, NRAS, PIK3CA, and BRAF mutational profile in poorly differentiated clusters of KRAS-mutated colon cancer may depend on tumor histology.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28030835\n",
      "Co-targeting translation and proteasome using the combination of Episilvestrol and Bortezomib promoted strong endoplasmic reticulum stress and rapid killing of colon cancer cells with KRAS/BRAF mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28034324\n",
      "The expression of the nuclear and cytoplasmic forms of p16 represent two independent mechanisms, and both seemed to control proliferation in response to oncogenic stimuli, protecting the cell from malignant transformation in BRAF-mutated gastrointestinal stromal tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28039443\n",
      "Report heterogeneity and frequency of BRAF mutations in primary melanoma samples.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28040692\n",
      "BRAF or KRAS mutations are independently associated with shorter time to recurrence, shorter survival after relapse, and overall survival in patients with microsatellite-stable (MSS) subgroups, but not microsatellite-unstable tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28062544\n",
      "Despite a significant prevalence of BRAF mutation, more than 70% of hobnail variant of papillary thyroid carcinomas (HPTCs) in our series showed concurrent mutations of other genes such as TP53, PIK3CA, CTNNB1 and hTERT, in contrast to classic PTC.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28067893\n",
      "Data show that the expression of Interleukin-8 (IL-8) and connective tissue growth factor (CTGF) was significantly reduced by treatment with vemurafenib and trametinib in (V600E)BRAF protein melanoma cells.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28073844\n",
      "The results of the trial submitted to confirm clinical benefit, which formed the FDA basis for the regular approval of nivolumab for the first-line treatment of patients with BRAFV600 wild-type (WT) unresectable or metastatic melanoma, are described in this article.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28074351\n",
      "review focuses on the genes, which are frequently mutated in various cancers and are known to be important in the advance and progression of colorectal cancer and melanoma, namely KRAS, NRAS and BRAF\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28077340\n",
      "Frequency of BRAF(V600E) mutation was similar in prepubertal and pubertal patients. BRAF(V600E) mutation was found in 14/56 (25%) patients and was high in the classic variant papillary thyroid cancer\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28087644\n",
      "the FDA granted accelerated approval to nivolumab (OPDIVO; Bristol-Myers Squibb) for the treatment of patients with unresectable or metastatic melanoma and disease progression following ipilimumab and, if BRAF V600 mutation positive, a BRAF inhibitor. Approval was based on a clinically meaningful, durable objective response rate (ORR) in a non-comparative analysis of 120 patients who received 3 mg/kg of nivolumab\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28089569\n",
      "These findings reveal a signaling basis underlying a pathogenic role of dietary fat in BRAF V600E-expressing melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28091917\n",
      "Rare mutations in KRAS, NRAS, and BRAF oncogenes have been found in patients with melanoma and colorectal neoplasms.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28092667\n",
      "ZNF767-BRAF fusion is associated with mucosal melanomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28093487\n",
      "One way to potentially improve adoptive T cell therapy is to combine it with the administration of small molecule inhibitors. Vemurafenib specifically inhibits mutated BRAFV600E/K molecules and directs cell death of BRAFV600E/K expressing tumors\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28093501\n",
      "Thus, the quaternary structure of BRAF complexes is shaped by its activation status, the conformation of its kinase domain, and clinically relevant inhibitors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28125730\n",
      "Aspirin use after colon cancer diagnosis was associated with improved overall survival in wild-type BRAF tumors. In contrast, aspirin use in BRAF mutated tumors was not associated with an improved survival.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28134726\n",
      "NRAS and BRAF mutations are independent events and alternative molecular mechanisms in the primary oral mucosal melanoma tumorigenesis\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28135039\n",
      "Study identified BRAF mutations in 1.7% of Chinese patients with non-small-cell lung cancer and seems associated with adenocarcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28159677\n",
      "BRAF mutations are rare events in KIT/PDGFRA wild-type gastrointestinal stromal tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28160058\n",
      "Association of the Bethesda category with BRAF mutation can slightly improve the value of stage prediction in papillary thyroid cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28174173\n",
      "FZR1 inhibits BRAF oncogenic functions via both APC-dependent proteolysis and APC-independent disruption of BRAF dimers, whereas hyperactivated ERK and CDK4 reciprocally suppress APC(FZR1) E3 ligase activity\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28176151\n",
      "pediatric papillary thyroid carcinomas in Japan are characterized by more advanced clinicopathological features, lower BRAF (V600E) frequency, and absence of TERT mutation\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28179313\n",
      "Data suggest that genotyping for KRAS and BRAF mutation status is a gold standard for categorizing colorectal cancer (CRC) for clinical decisions.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28214213\n",
      "The expression levels of BRAFV600E and NF-kappaB were significantly greater in thyroglobuiln antibody-positive than in thyroglobuiln antibody-negative papillary thyroid carcinoma patients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28216139\n",
      "Real-time PCR and pyrosequencing methods were equally excellent in determination of BRAF V600 mutations. The immunohistochemistry method, which is commonly used in routine pathology practice, can also be safely used as a screening test for determination of BRAF V600 mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28216246\n",
      "KRAS and BRAF mutations are negatively associated with overall and relapse-free survival in patients who undergo complete liver resection for colorectal cancer liver metastases\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28219109\n",
      "Authors tested the mutation-specific BRAF V600E monoclonal antibody (clone VE1) in formalin-fixed, paraffin-embedded LCH samples from 26 pediatric patients using allele-specific real-time polymerase chain reaction (PCR) with a limit of detection of 0.5% as the comparative gold standard.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28220299\n",
      "BRAF V600E mutation is frequent in pulmonary Langerhans cell histiocytosis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28232477\n",
      "We show that rosiglitazone increases klotho and decreases Wnt5A in tumor cells, reducing the burden of both BRAF inhibitor-sensitive and BRAF inhibitor-resistant tumors in aged, but not young mice. However, when used in combination with PLX4720, tumor burden was reduced in both young and aged mice, even in resistant tumors\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28234922\n",
      "Our purpose was the evaluation of microsatellite stability status within conventional colon adenomas and also b-catenin, BRAFV600E and p53 contribution.we noted a 10% frequency of MSI events where MSI-H reached a 5% share occurred within the left colon and rectal polyps. b-catenin nuclear overexpression was noted with a 70% frequency and p53 with close to a 24% frequency.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28249840\n",
      "Mutations in KRAS, NRAS, and BRAF together occur in more than half of all colorectal cancer cases and are often associated with negative responses to the EGFR inhibitors cetuximab and panitumumab.guideline is clear that we should not be giving EGFR inhibitors to patients with RAS mutations and that patients with BRAF V600E mutations have a much worse prognosis\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28258306\n",
      "genetic association/nutrigenomic studies in population in Seoul, Republic of Korea: Data suggest that (1) relatively low iodine intake and (2) more than excessive iodine intake are significant risk factors for occurrence of BRAF mutations in thyroid gland and may be risk factors for development of PTC (papillary thyroid cancer) in iodine-replete area.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28268064\n",
      "BRAF mutation is associated with melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28278349\n",
      "summary of the current evidence of non-V600 BRAF mutations and BRAF fusions in melanoma (review).\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28281325\n",
      "IRP2 expression was associated with mutations in BRAF.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28285720\n",
      "we did not observe GNAS or BRAF mutations in urachal adenocarcinomas\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28292959\n",
      "Data suggest that activation of the metalloproteinase ADAM10 by signal peptide peptidase-like 3 (SPPL3) triggered by mutant BRAF(V600E) was a critical transformation event.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28293988\n",
      "analysis of BRAF genetic alterations among the histologic variants of papillary thyroid carcinoma in Korea\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28295004\n",
      "The patients with traditional serrated adenoma showed KRAS and BRAF mutations in 58.4 and 8.3% of cases, respectively. Mutations of these genes were absent.  The study revealed that the subtypes of serrated adenomas substantially differ by sex, age, localization, and molecular genetic characteristics\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28319896\n",
      "BRAF mutations in the genomic DNA extracted from cancer cell lines were tested, allowing sensitive detection of SNM at very low abundances\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28323937\n",
      "BRAF mutations were present in 44.6% of primary papillary thyroid carcinomas, 41.7% of lymph node metastasis, and 23.8% of distant metastasis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28342873\n",
      "These findings demonstrate that the BRAF V600E mutation down-regulates levels of HMGB1, likely through activation of the mitogen-activated protein kinase (MAPK) signaling pathways.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28373167\n",
      "These findings identify a dynamic interplay between FZR1 and BRAF with strong implications for cell-fate determination and the tumor suppressor role of FZR1\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28383426\n",
      "BRAFV600E mutation significantly associated with nonsmall cell lung cancer in females and nonsmokers [meta-analysis]\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28393212\n",
      "these results suggest that SIRT6 enhances cell aggressiveness in PTC via BRAF/ERK/Mcl1 pathway, and thus may be a promising target in the treatment of the disease.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28404629\n",
      "functional analysis of human BRaf disease-linked mutations identified BRaf as the key missing signaling effector in the common synaptic NMDA-R-CaMKII-SynGap-Ras-BRaf-MEK-ERK transduction cascade.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28421232\n",
      "mutations were detected in 8 of the 18 adult Langerhans cell histiocytosis patients analysed.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28423545\n",
      "BRAF mutation is associated with papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28423638\n",
      "Data show that combined therapy using HER2 inhibitor and BRAF/MEK inhibitor presented more significant redifferentiation effect on papillary thyroid cancer cells harboring BRAFV600E than BRAF/MEK inhibitor alone.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28424234\n",
      "the rate of BRAF mutation in Irish cohort (28.8%) was lower than international published rates of 40%-60%.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28444112\n",
      "In the coBRIM phase III trial, the addition of cobimetinib, an MEK inhibitor, to vemurafenib, a BRAF inhibitor, significantly improved progression-free survival [hazard ratio (HR), 0.58; P < 0.0001] and overall survival (HR, 0.70; P = 0.005) in advanced BRAF-mutated melanoma. Here, we report on the incidence, course, and management of key adverse events (AEs) in the coBRIM study\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28448514\n",
      "a new BRAF fusion in pilocytic astrocytoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28454577\n",
      "By shedding light on the repertoire of BRAF mRNA and protein variants, and on the complex regulation of their expression, our work paves the way to a deeper understanding of a crucially important player in human cancer and to a more informed development of new therapeutic strategies\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28455392\n",
      "This study identified two mechanistic subtypes of melanoma: (1) the best responders to clinical BRAF/MEK inhibitors (25%) and (2) nonresponders due to primary resistance mechanisms (9.9%). We identified robust biomarkers that can detect these subtypes in patient samples and predict clinical outcome\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28463756\n",
      "The results show that BRAF mutations are associated with a worse prognosis than expected in patients treated with FOLFIRI protocol plus bevacizumab compared with the BRAF wild-type population.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28468827\n",
      "Data suggest that HMGCS1 (HMG-CoA synthase 1) signals through ketogenesis/acetoacetate to promote cell proliferation and BRAF(V600E)-dependent MEK1 activation in BRAF(V600E)-positive melanoma and colon cancer cells; HMGCS1 co-localizes with HMGCL (HMG-CoA lyase) and BRAF(V600E) in cytosol of melanoma and colon cancer cells. (BRAF = proto-oncogene protein B-raf)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28475671\n",
      "Durable (>/=3 years) survival is achievable with dabrafenib plus trametinib in patients with BRAF V600-mutant metastatic melanoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28488545\n",
      "ytoplasmic immunoexpression of BRAF V600E (VE1) protein was found in three specimens: serous superficial papilloma, serous papillary cystadenoma of borderline malignancy, and partially proliferative serous cystadenoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28500561\n",
      "study to identify the incidence of BRAF and CTNNB1 gene mutations in craniopharyngiomas and correlate it with clinicopathological parameters including histopathology, immunohistochemical expression of proteins BRAF pVal600Glu and beta-catenin and clinical outcome\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28504206\n",
      "Case Reports: pediatric intracranial and cranial juvenile xanthogranuloma with BRAF V600E mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28523274\n",
      "Our model is trained to mimic the predictions of a 64-gene signature, the current definition of BRAF-positive group.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28536307\n",
      "In vemurafenib-treated patients, the cell-cycle gene signature was associated with shorter PFS. However, in cobimetinib combined with vemurafenib-treated patients, both cell cycle and immune signature subgroups had comparable PFS. Cobimetinib combined with vemurafenib may abrogate the adverse impact of the cell-cycle signature.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28539463\n",
      "We report acquisition of a BRAF fusion as a novel mechanism of acquired resistance to vemurafenib in a patient with melanoma harboring a BRAF(V600E) mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28543997\n",
      "Our findings showed BRAF and/or KRAS mutations in three of seven cases of low-grade serous neoplasms of the testis\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28551389\n",
      "The lack of KRAS, NRAS, BRAF, and PIK3CA mutation in our study may suggest that a subset of eyelid sebaceous carcinomas is unlike that of eyelid sebaceous carcinomas of western countries.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28561662\n",
      "Combination BRAF and MEK inhibition has also been shown to improve overall survival in patients with V600E-mutated melanoma. Responses to therapy are often rapid, and treatment is not associated with immune-related adverse events.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28576751\n",
      "Bromodomain and extra-terminal (BET) inhibitors can suppress growth of BRAF-mutant colon cancer cells via repression of MAPK signaling pathway.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28576831\n",
      "Vemurafenib, inhibiting BRAF signaling, shifted the balance of activatory and inhibitory NK ligands on melanoma cells and displayed immunoregulatory effects on NK-cell functional activities\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28576857\n",
      "Braf mutations served as biomarkers for response to anti-EGFR monoclonal antibodies in colorectal cancer.[review]\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28583095\n",
      "BRAF mutation, rather than KRAS, was a significant prognostic factor in Korean colorectal cancer patients at both early and advanced stages.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28595259\n",
      "Our data show that Signet ring cell colorectal cancer (SRCCa) phenotype comprises two distinct genotypes. The MSI(+)/CIMP(+)/BRAF V600E(+)/CD3(+)/PDL1(+) hypermethylated genotype is an ideal candidate for immune checkpoint inhibitor therapy. In addition, one fourth of SRCCa cases can potentially be targeted by KIT inhibitors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28611106\n",
      "we have found that a subgroup of colorectal cancers, defined by having either KRAS or BRAF (KRAS/BRAF) mutations and BCL2L1 (encoding BCL-XL) amplification, can be effectively targeted by simultaneous inhibition of BCL-XL (with ABT-263) and MCL1 (with YM-155).\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28611337\n",
      "meta-analysis revealed that, in patients with colorectal cancer, the BRAF mutation was associated with female, proximal site, poor differentiation, >5 cm size, and advanced AJCC stage\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28623774\n",
      "We found a clinically meaningful discrepancy rate in BRAF status both between primary-metastatic and metastatic-metastatic melanoma lesions.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28625649\n",
      "We have found a higher incidence of axLN metastases in BRAF mutated NSCLC patients than described in non-BRAF mutated NSCLC patients. Examination of the axilla should be a routine part of physical examination in this genetically distinct subgroup of lung cancer patients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28646474\n",
      "the presence of the BRAF (V600E) mutation may be negatively correlated with partial aggressive clinicopathological features of pediatric papillary thyroid cancer (PTC).\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28650561\n",
      "we describe patients with craniosynostosis and Noonan syndrome due to de novo mutations in PTPN11 and patients with craniosynostosis and CFC syndrome due to de novo mutations in BRAF or KRAS. All of these patients had cranial deformities in addition to the typical phenotypes of CFC syndrome and Noonan syndrome.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28650588\n",
      "The BRAF gene has been reported to be mutated in some human cancers. The BRAF mutations have been implicated in ameloblastoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28656062\n",
      "c-Myc, a downstream key effector of BRAF(V600E) signaling, was required for BRAF(V600E)-induced changes in lysine27-trimethylated histone H3 through regulating the components of the polycomb repressive complex 2 (PRC2) genes Ezh2, Suz12 and Jarid2 at both transcriptional levels via direct binding to their regulatory elements and post-transcriptional levels via repressing the miR-26a, miR-200b and miR-155.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28656305\n",
      "Exposure to cetuximab and various concentration of AG490, an inhibitor of JAK2, STAT3 and HSP27 protein levels, except in the KRAS G12V mutant line, SW620...cetuximab may promote SN38 sensitivity via suppression of HSP27, through blocking the JAK/STAT signaling pathway, and shows synergistic effects when combined with SN38 in wild-type RAS CRC cells.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28662062\n",
      "findings should encourage the genetic evaluation of BRAF mutation. This study highlights the potential of RCM as a supplementary tool in the screening of BRAF-mutated melanomas\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28666074\n",
      "Meta-analysis:  The combination of BRAF and TERT promoter mutations could classify PTCs into four distinct risk groups with decreasing aggressiveness as follows: coexisting BRAF and TERT > TERT alone=BRAF alone > no mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28667867\n",
      "Study found that high expression of LC3B protein was associated with the presence of BRAF V600E mutation and temporal lesion in glioneuronal tumors, as well as in gangliogliomas alone. As for Beclin-1 protein, it showed statistically significant correlation with BRAF V600E mutation in glioneuronal tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28679432\n",
      "a new somatic BRAF splicing mutation, was identified.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28685592\n",
      "Knowing the mutation status of KRAS, BRAF or PIK3CA in stage II colorectal cancer can significantly improve the accuracy of prognoses.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28692601\n",
      "BRAF rearrangements were only found in myxoinflammatory fibroblastic sarcomas but not in hemosiderotic fibrolipomatous tumor lacking TGFBR3-MGEA5 fusions.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28718951\n",
      "data are consistent with those of other studies reporting a positive relation between BRAF V600E mutation and poor prognostic factors in PTC; however, the BRAF status did not significantly correlate with a response to therapy.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28727518\n",
      "Patients with BRAF V600E PLGG exhibited poor outcomes after chemotherapy and radiation therapies that resulted in a 10-year progression-free survival of 27% (95% CI, 12.1% to 41.9%) and 60.2% (95% CI, 53.3% to 67.1%) for BRAF V600E and wild-type PLGG, respectively ( P < .001).\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28743501\n",
      "Hypoxic postconditioning attenuates apoptosis via inactivation of adenosine A2a receptor through NDRG3-Raf-ERK pathway.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28753606\n",
      "Short-term treatment of nascent melanoma tumors with PAK inhibitors that block RhoJ signaling halts the growth of BRAF mutant melanoma tumors in vivo and induces apoptosis in melanoma cells in vitro via a BAD-dependent mechanism. As up to 50% of BRAF mutant human melanomas express high levels of RhoJ, these studies nominate the RhoJ-BAD signaling network as a therapeutic vulnerability for fledgling BRAF mutant human tumor\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28756651\n",
      "The rate of EGFR mutation was significantly higher in female and non-smoker patients. In TTF-1 positive cases EGFR mutation was more frequent. Age of the patients over 62-year old was correlated with KRAS mutations. The concordance between ALK IHC and FISH was 58.3%. The MET protein in the cases with MET amplification was 100% positive.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28775171\n",
      "Case Reports: two cases of gliosarcoma harbouring the BRAF V600E mutation, of which one case appears to have arisen de novo, while the other likely arose from ganglioglioma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28787433\n",
      "BRAF mutation was found to be associated with lymph node metastasis as first metastasis and sentinel lymph node positivity. BRAF and NRAS mutations were associated with CNS and liver metastasis and NRAS mutation with lung metastasis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28791997\n",
      "Clinical and morphological data and the results of molecular genetic studies led to the conclusion that there was eosinophilic granuloma of the right parietal bone (the unifocal form of Langerhans cell histiocytosis (LCH), type I, group A1, with the monoossal nature of lesion and with BRAFV600E mutation).\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28810144\n",
      "Mutation in BRAF gene is associated with Pancreatic Ductal Adenocarcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28822769\n",
      "BRAF mutation is associated with melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28829677\n",
      "our study suggests that an activating BRAF I463T mutation was associated with eosinophilic cystitis. Importantly, analysis of ctDNA obtained through \"liquid biopsies\" can identify potentially important genomic alterations in patients for whom biopsy may be difficult in terms of risk or cost.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28834810\n",
      "BRAF V600E mutation was detected in 6% of glomus tumors, all of which were malignant or glomus tumors of uncertain malignant potential. This mutation may be associated with a malignant phenotype.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28842324\n",
      "MC1R genotype is associated with patient phenotypes with BRAF and NRAS mutations in melanoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28850092\n",
      "while telomere length did not correlate with the presence of a mutation in BRAF (V-raf murine sarcoma viral oncogene homolog B), PIK3CA (phosphatidylinositol 3-kinase catalytic subunit), or MSI status, it was significantly associated with the occurrence of a mutation in KRAS\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28858076\n",
      "Authors systematically compared BRAF V600E and V600K skin cutaneous melanoma (SKCM) samples from the Cancer Genome Atlas (TCGA) for differential protein, gene, and microRNA expression genome-wide using the Mann-Whitney U-test. Analyses showed that elements of energy-metabolism and protein-translation pathways were upregulated and that proapoptotic pathways were downregulated in V600K tumors compared with V600E tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28862766\n",
      "This study demonstrates that idiopathic pulmonary fibrosis-associated lung cancer (IPF-LC) is genetically characterized by the presence of somatic mutations reflecting a variety of environmental exposures on the background of specific germline mutations, and is associated with potentially targetable alterations such as BRAF mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28873491\n",
      "Despite the presence of histological findings indicating long-standing gastroesophageal reflux in 25%, as well as symptomatic gastroesophageal reflux in more than 40%, there was no detectable tissue expression of KRAS or BRAF mutations in adult patients treated for esophageal atresia in childhood.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28877062\n",
      "Findings of recurrent BRAF gene rearrangements in spindle cell sarcomas showing morphologic overlap with infantile fibrosarcomas expand the genetic spectrum of fusion-positive spindle cell sarcomas, to include unusual presentations, such as older children and adolescents and predilection for axial location.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28892804\n",
      "Following adjustment for sex, logistic regression analysis showed that BRAFV600E mutation, transforming growth factor beta (TGF-beta) expression, age, and tumor size are risk factors that can affect tumor clinical stage (p < 0.05). Based on the results of this analysis, we generated a matrix that incorporated 4 variables: patient age, tumor size, BRAFV600E mutation, and TGF-beta expression.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28937091\n",
      "results indicate that exposure of the melanoma cell lines to a modified PNA-peptide conjugate complementary to BRAF(V600E) mutation sequence results in a concentration-dependent and time-dependent inhibition of cell growth that is specific for the BRAF(V600E)-mutant melanoma cell lines with inhibition of mRNA and protein expression.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28939558\n",
      "In in vivo xenograft studies, BVD-523 showed dose-dependent growth inhibition and tumor regression. BVD-523 yielded synergistic antiproliferative effects in a BRAF(V600E)-mutant melanoma cell line xenograft model when used in combination with BRAF inhibition. Antitumor activity was also demonstrated in in vitro and in vivo models of acquired resistance to single-agent and combination BRAF/MEK-targeted therapy\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28940307\n",
      "BRAF mutation is associated with colonic neuroendocrine carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28947418\n",
      "KIT knockdown increased RAS/MAPK pathway activation in a BRAF(V600E)-mutant melanoma cell line.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28953955\n",
      "somatic KRAS mutations in polyps represent a potential molecular marker for the risk of developing advanced neoplasia\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28972961\n",
      "Although BRAF(non-V600E) mutations identified were a rare and unestablished molecular subtype, certain BRAF(non-V600E) mutations might contribute to a lesser benefit of anti-EGFR monoclonal antibody treatment in patients with metastatic colorectal cancer\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28986151\n",
      "These data suggest that BRAF V600E can predict the regrowth rate of brainstem gangliogliomas after microsurgery\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29037127\n",
      "BRAF mutations were not associated with an elevated risk for distant metastasis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29039591\n",
      "is is the first series on adult patients with BRAF-mutated malignant glioma and leptomeningeal dissemination treated with dabrafenib monotherapy. All patients showed a dramatic response with one patient showing an ongoing response for more than two years.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29059311\n",
      "Adenocarcinomas or adenomas derived from pigmented ciliary epithelium is distinguished from uveal melanoma by the absence of SOX10 expression and presence of the BRAF V600E mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29061376\n",
      "the mutational status of BRAF, NRAS, and TERT promoter genes in 97 melanomas, was investigated.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29070763\n",
      "genetic association studies in population in China: Data suggest that, in patients with unilateral papillary thyroid carcinoma, a mutation in BRAF (V600E) plus multi-focality are both independently and synergically associated with CLNM (central lymph node metastasis) in the population studied.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29074543\n",
      "The diesel exhaust fumes-exposed patients were diagnosed with a BRAF mutation in 25% of all cases. Given its minimal effects in the subgroups, we conclude that occupational exposure slightly affects the molecular pattern of lung cancers in never-smokers.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29080842\n",
      "Enhanced BRAF-mediated NRF2 gene transcription and Histone Acetyltransferases-mediated NRF2 protein acetylation contributes to ABCC1-mediated chemoresistance and glutathione-mediated survival in acquired topoisomerase II poison-resistant cancer cells.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29094484\n",
      "Proteomic analysis discovers that a novel E3 ligase, RNF44, accounts for ubiquitin-proteasome system of AMPK-alpha1 degradation in BRAF inhibitor-resistant melanoma cells.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29094776\n",
      "Mutated Liquid-based FNAs BRAF, N/HRAS and TERT mutations were significantly associated with malignancy regardless of the cytological classification\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29103753\n",
      "These results indicate that BRAF V600E mutation occurs in OKCs at a high rate and plays an important role in the pathogenesis of OKCs\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29115628\n",
      "Results show BRAFV600E mutation in 42.1% of papillary thyroid cancer (PTC) patients enrolled. In addition, BRAF mutation status was associated with the methylation and expression level of HOXD10 in PTC.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29117154\n",
      "BRAFV600E and RET/PTC and the expression of NF-kappaB promote the proliferation and migration of papillary thyroid carcinoma cells in vitro.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29144823\n",
      "The presence of BRAF(V600E) mutation in PTC confers a higher likelihood of FDG PET avidity and is associated with higher SUV uptake values compared to BRAF(V600E)-mutation negative status. [Review and Meta-Analysis]\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29162506\n",
      "This study is the first to describe the BRAF (L597Q) mutation in malignant peripheral nerve sheath tumors and the first to implicate a BRAF mutation in neurofibroma biology\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29175303\n",
      "Tumor cell content was not associated with mutational rate for EGFR, BRAF and HER2 mutations. DNA quantity was not associated with mutational rate for EGFR, KRAS, BRAF and HER2\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29180316\n",
      "BRAF mutations more frequently affected individuals younger than 61 with phototype II. In contrast, NRAS mutations were more frequent in phototype III cases. Mutations of both genes were more frequent in cases with satellitosis in the first melanoma, and in cases with ulceration in the subsequent lesions.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29187493\n",
      "Data indicate that BRAF, NRAS and C-KIT melanomas constitute distinct clinico-pathological entities.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29199726\n",
      "The result of our study adds to the growing consensus that BRAF V600E mutational status should be analyzed in correlation with other molecular and clinicopathological prognostic factors for a better risk stratification.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29202777\n",
      "Coexistence of BRAF V600E mutation and EZH2 gain is rather prevalent in melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29238890\n",
      "The presence and frequency of BRAF c.1799T > A mutation was investigated in two archival tissue specimens of Hairy cell leukemia and Hairy cell leukemia Variant.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29273082\n",
      "a low frequency of BRAF or KRAS mutation in Chinese patients with low-grade serous carcinoma of the ovary\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29286077\n",
      "CREB1 may activate the transcription of wtBRAF through directly binding to its promoter, increasing BRAF expression and regulating the cell proliferation, migration and invasion of endometriosis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29295999\n",
      "Data show that depletion of SRY (sex determining region Y)-box 10 protein (SOX10) sensitizes mutant proto-oncogene proteins B-raf (BRAF) melanoma cells to RAF inhibitors in vitro and in vivo.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29304767\n",
      "The MLH1-93 AA genotype is significantly associated with promoter hypermethylation and MLH1 loss in the context of Sessile serrated adenoma of dysplasia. BRAF mutant microsatellite stable colorectal cancers with the AA genotype most likely arise in traditional serrated adenomas since the A allele does not predispose to methylation in this context.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29310328\n",
      "Of these 6 patients, 3 had a BRAF mutation positive primary with a BRAF mutation negative metastatic lesion, while the other 3 had a BRAF mutation negative primary with BRAF mutation positive metastasis.There is an important discordance rate in the BRAF mutation status of melanoma primaries versus brain metastases.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29320776\n",
      "In lung adenocarcinomas, BRAF mutations tended to occur in former or current smokers, and BRAF V600E mutations are more common in females. The histologic grade and architecture of these tumors varied significantly in both cytology and histology material, from well to poorly differentiated.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29320991\n",
      "RHEB Y35N expressing cells undergo cancer transformation due to decreased interaction between RHEB and BRAF resulting in overactive RAF/MEK/ERK signaling. Taken together with the previously established function of RHEB to activate mTORC1 signaling, it appears that RHEB performs a dual function; one is to suppress the RAF/MEK/ERK signaling and the other is to activate mTORC1 signaling.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29332123\n",
      "common conjunctival melanocytic nevi have mutually exclusive mutations in BRAF and NRAS. The two conjunctival blue nevi harbored GNAQ mutations. This suggests the driver mutations of conjunctival nevi are similar to those of nevi of the skin. At the molecular level, conjunctival nevi appear more like cutaneous nevi than choroidal nevi\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29335867\n",
      "Identification of KRAS/NRAS/BRAF mutation status is crucial to predict the therapeutic effect and determine individual therapeutic strategies for patients with colorectal cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29433126\n",
      "findings demonstrate that KSR-MEK complexes allosterically activate BRAF through the action of N-terminal regulatory region and kinase domain contacts and challenge the accepted role of KSR as a scaffold for MEK recruitment to RAF\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29464327\n",
      "RNA sequencing identified in both an AKAP9-BRAF gene fusion\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29505523\n",
      "mutations and expression might serve as independent adverse prognostic factors in melanoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29546640\n",
      "mutation profiles of BRAF wild-type craniopharyngiomas and ameloblastomas share mutations of FGFR genes and have additional mutations with potential for targeted therapy\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29562502\n",
      "Lower CA125 serum levels, negative vascular invasion, and wild-type BRAF status were significantly associated with improved 2-year DFS rates among patient with stage III disease who received adjuvant chemotherapy.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29590112\n",
      "Data indicate proto-oncogene protein B-raf (BRAF)-V600E as the sole recurring somatic mutation in sessile serrated polyps (SSPs) with no additional major genetic mutations detected.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29658453\n",
      "Children with Langerhans cell histiocytosis (LCH) tend to have a high overall survival rate and a high incidence rate of BRAF-V600E mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29715113\n",
      "The present case series suggests that the incidence of concomitant KRAS/BRAF mutations in patients with surgically treated colorectal liver metastasis may be higher than previously hypothesized, and associated with more variable survival outcomes than expected.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29762246\n",
      "The BRAFV600E mutation status may not impact the clinical response to radioiodine therapy for papillary thyroid carcinoma patients\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29767243\n",
      "The present findings suggested that miR9 may suppress the viability ofpapillary thyroid carcinoma (PTC) cells and inhibit tumor growth through directly targeting the expression of BRAF in PTC.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29808165\n",
      "Studied frequency of BRAF 1799T>A mutation in Mexican Papillary Thyroid Cancer patients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29974407\n",
      "The frequency of BRAF mutations was significantly higher in Serrated Lesions subgroups with highly methylated epigenotype tumors and microsatellite instability.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/30010109\n",
      "these results indicated that STAT3-mediated downexpression of miR-579-3p caused resistance to vemurafenib. Our findings suggest novel approaches to overcome resistance to vemurafenib by combining vemurafenib with STAT3 sliencing or miR-579-3p overexpression.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/30150413\n",
      "Data show that glycogen synthase kinase 3 (GSK3) and proto-oncogene proteins B-raf (BRAF)/MAPK signaling converges to control microphthalmia-associated transcription factor MITF (MITF) nuclear export.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/30220118\n",
      "The occurrence of BRAF V600E mutations in ganglioglioma is common, and their detection may be valuable for the diagnosis and treatment in ganglioglioma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/30224486\n",
      "MET inactivation in the context of the BRAF-activating mutation is driven through a negative feedback loop involving inactivation of PP2A phosphatase, which in turn leads to phosphorylation on MET inhibitory Ser985.\n"
     ]
    }
   ],
   "source": [
    "print_pubmeds('BRAF')"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 42,
   "metadata": {},
   "outputs": [],
   "source": [
    "def print_pubmeds_recent(gene_name):\n",
    "    gene_info = gene_search(gene_name)\n",
    "    for reference in gene_info['generif'][::-1]:\n",
    "        print('https://www.ncbi.nlm.nih.gov/pubmed/' + str(reference['pubmed']))\n",
    "        print(reference['text'])"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 43,
   "metadata": {},
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "https://www.ncbi.nlm.nih.gov/pubmed/30224486\n",
      "MET inactivation in the context of the BRAF-activating mutation is driven through a negative feedback loop involving inactivation of PP2A phosphatase, which in turn leads to phosphorylation on MET inhibitory Ser985.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/30220118\n",
      "The occurrence of BRAF V600E mutations in ganglioglioma is common, and their detection may be valuable for the diagnosis and treatment in ganglioglioma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/30150413\n",
      "Data show that glycogen synthase kinase 3 (GSK3) and proto-oncogene proteins B-raf (BRAF)/MAPK signaling converges to control microphthalmia-associated transcription factor MITF (MITF) nuclear export.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/30010109\n",
      "these results indicated that STAT3-mediated downexpression of miR-579-3p caused resistance to vemurafenib. Our findings suggest novel approaches to overcome resistance to vemurafenib by combining vemurafenib with STAT3 sliencing or miR-579-3p overexpression.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29974407\n",
      "The frequency of BRAF mutations was significantly higher in Serrated Lesions subgroups with highly methylated epigenotype tumors and microsatellite instability.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29808165\n",
      "Studied frequency of BRAF 1799T>A mutation in Mexican Papillary Thyroid Cancer patients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29767243\n",
      "The present findings suggested that miR9 may suppress the viability ofpapillary thyroid carcinoma (PTC) cells and inhibit tumor growth through directly targeting the expression of BRAF in PTC.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29762246\n",
      "The BRAFV600E mutation status may not impact the clinical response to radioiodine therapy for papillary thyroid carcinoma patients\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29715113\n",
      "The present case series suggests that the incidence of concomitant KRAS/BRAF mutations in patients with surgically treated colorectal liver metastasis may be higher than previously hypothesized, and associated with more variable survival outcomes than expected.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29658453\n",
      "Children with Langerhans cell histiocytosis (LCH) tend to have a high overall survival rate and a high incidence rate of BRAF-V600E mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29590112\n",
      "Data indicate proto-oncogene protein B-raf (BRAF)-V600E as the sole recurring somatic mutation in sessile serrated polyps (SSPs) with no additional major genetic mutations detected.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29562502\n",
      "Lower CA125 serum levels, negative vascular invasion, and wild-type BRAF status were significantly associated with improved 2-year DFS rates among patient with stage III disease who received adjuvant chemotherapy.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29546640\n",
      "mutation profiles of BRAF wild-type craniopharyngiomas and ameloblastomas share mutations of FGFR genes and have additional mutations with potential for targeted therapy\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29505523\n",
      "mutations and expression might serve as independent adverse prognostic factors in melanoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29464327\n",
      "RNA sequencing identified in both an AKAP9-BRAF gene fusion\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29433126\n",
      "findings demonstrate that KSR-MEK complexes allosterically activate BRAF through the action of N-terminal regulatory region and kinase domain contacts and challenge the accepted role of KSR as a scaffold for MEK recruitment to RAF\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29335867\n",
      "Identification of KRAS/NRAS/BRAF mutation status is crucial to predict the therapeutic effect and determine individual therapeutic strategies for patients with colorectal cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29332123\n",
      "common conjunctival melanocytic nevi have mutually exclusive mutations in BRAF and NRAS. The two conjunctival blue nevi harbored GNAQ mutations. This suggests the driver mutations of conjunctival nevi are similar to those of nevi of the skin. At the molecular level, conjunctival nevi appear more like cutaneous nevi than choroidal nevi\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29320991\n",
      "RHEB Y35N expressing cells undergo cancer transformation due to decreased interaction between RHEB and BRAF resulting in overactive RAF/MEK/ERK signaling. Taken together with the previously established function of RHEB to activate mTORC1 signaling, it appears that RHEB performs a dual function; one is to suppress the RAF/MEK/ERK signaling and the other is to activate mTORC1 signaling.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29320776\n",
      "In lung adenocarcinomas, BRAF mutations tended to occur in former or current smokers, and BRAF V600E mutations are more common in females. The histologic grade and architecture of these tumors varied significantly in both cytology and histology material, from well to poorly differentiated.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29310328\n",
      "Of these 6 patients, 3 had a BRAF mutation positive primary with a BRAF mutation negative metastatic lesion, while the other 3 had a BRAF mutation negative primary with BRAF mutation positive metastasis.There is an important discordance rate in the BRAF mutation status of melanoma primaries versus brain metastases.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29304767\n",
      "The MLH1-93 AA genotype is significantly associated with promoter hypermethylation and MLH1 loss in the context of Sessile serrated adenoma of dysplasia. BRAF mutant microsatellite stable colorectal cancers with the AA genotype most likely arise in traditional serrated adenomas since the A allele does not predispose to methylation in this context.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29295999\n",
      "Data show that depletion of SRY (sex determining region Y)-box 10 protein (SOX10) sensitizes mutant proto-oncogene proteins B-raf (BRAF) melanoma cells to RAF inhibitors in vitro and in vivo.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29286077\n",
      "CREB1 may activate the transcription of wtBRAF through directly binding to its promoter, increasing BRAF expression and regulating the cell proliferation, migration and invasion of endometriosis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29273082\n",
      "a low frequency of BRAF or KRAS mutation in Chinese patients with low-grade serous carcinoma of the ovary\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29238890\n",
      "The presence and frequency of BRAF c.1799T > A mutation was investigated in two archival tissue specimens of Hairy cell leukemia and Hairy cell leukemia Variant.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29202777\n",
      "Coexistence of BRAF V600E mutation and EZH2 gain is rather prevalent in melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29199726\n",
      "The result of our study adds to the growing consensus that BRAF V600E mutational status should be analyzed in correlation with other molecular and clinicopathological prognostic factors for a better risk stratification.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29187493\n",
      "Data indicate that BRAF, NRAS and C-KIT melanomas constitute distinct clinico-pathological entities.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29180316\n",
      "BRAF mutations more frequently affected individuals younger than 61 with phototype II. In contrast, NRAS mutations were more frequent in phototype III cases. Mutations of both genes were more frequent in cases with satellitosis in the first melanoma, and in cases with ulceration in the subsequent lesions.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29175303\n",
      "Tumor cell content was not associated with mutational rate for EGFR, BRAF and HER2 mutations. DNA quantity was not associated with mutational rate for EGFR, KRAS, BRAF and HER2\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29162506\n",
      "This study is the first to describe the BRAF (L597Q) mutation in malignant peripheral nerve sheath tumors and the first to implicate a BRAF mutation in neurofibroma biology\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29144823\n",
      "The presence of BRAF(V600E) mutation in PTC confers a higher likelihood of FDG PET avidity and is associated with higher SUV uptake values compared to BRAF(V600E)-mutation negative status. [Review and Meta-Analysis]\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29117154\n",
      "BRAFV600E and RET/PTC and the expression of NF-kappaB promote the proliferation and migration of papillary thyroid carcinoma cells in vitro.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29115628\n",
      "Results show BRAFV600E mutation in 42.1% of papillary thyroid cancer (PTC) patients enrolled. In addition, BRAF mutation status was associated with the methylation and expression level of HOXD10 in PTC.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29103753\n",
      "These results indicate that BRAF V600E mutation occurs in OKCs at a high rate and plays an important role in the pathogenesis of OKCs\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29094776\n",
      "Mutated Liquid-based FNAs BRAF, N/HRAS and TERT mutations were significantly associated with malignancy regardless of the cytological classification\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29094484\n",
      "Proteomic analysis discovers that a novel E3 ligase, RNF44, accounts for ubiquitin-proteasome system of AMPK-alpha1 degradation in BRAF inhibitor-resistant melanoma cells.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29080842\n",
      "Enhanced BRAF-mediated NRF2 gene transcription and Histone Acetyltransferases-mediated NRF2 protein acetylation contributes to ABCC1-mediated chemoresistance and glutathione-mediated survival in acquired topoisomerase II poison-resistant cancer cells.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29074543\n",
      "The diesel exhaust fumes-exposed patients were diagnosed with a BRAF mutation in 25% of all cases. Given its minimal effects in the subgroups, we conclude that occupational exposure slightly affects the molecular pattern of lung cancers in never-smokers.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29070763\n",
      "genetic association studies in population in China: Data suggest that, in patients with unilateral papillary thyroid carcinoma, a mutation in BRAF (V600E) plus multi-focality are both independently and synergically associated with CLNM (central lymph node metastasis) in the population studied.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29061376\n",
      "the mutational status of BRAF, NRAS, and TERT promoter genes in 97 melanomas, was investigated.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29059311\n",
      "Adenocarcinomas or adenomas derived from pigmented ciliary epithelium is distinguished from uveal melanoma by the absence of SOX10 expression and presence of the BRAF V600E mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29039591\n",
      "is is the first series on adult patients with BRAF-mutated malignant glioma and leptomeningeal dissemination treated with dabrafenib monotherapy. All patients showed a dramatic response with one patient showing an ongoing response for more than two years.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29037127\n",
      "BRAF mutations were not associated with an elevated risk for distant metastasis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28986151\n",
      "These data suggest that BRAF V600E can predict the regrowth rate of brainstem gangliogliomas after microsurgery\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28972961\n",
      "Although BRAF(non-V600E) mutations identified were a rare and unestablished molecular subtype, certain BRAF(non-V600E) mutations might contribute to a lesser benefit of anti-EGFR monoclonal antibody treatment in patients with metastatic colorectal cancer\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28953955\n",
      "somatic KRAS mutations in polyps represent a potential molecular marker for the risk of developing advanced neoplasia\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28947418\n",
      "KIT knockdown increased RAS/MAPK pathway activation in a BRAF(V600E)-mutant melanoma cell line.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28940307\n",
      "BRAF mutation is associated with colonic neuroendocrine carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28939558\n",
      "In in vivo xenograft studies, BVD-523 showed dose-dependent growth inhibition and tumor regression. BVD-523 yielded synergistic antiproliferative effects in a BRAF(V600E)-mutant melanoma cell line xenograft model when used in combination with BRAF inhibition. Antitumor activity was also demonstrated in in vitro and in vivo models of acquired resistance to single-agent and combination BRAF/MEK-targeted therapy\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28937091\n",
      "results indicate that exposure of the melanoma cell lines to a modified PNA-peptide conjugate complementary to BRAF(V600E) mutation sequence results in a concentration-dependent and time-dependent inhibition of cell growth that is specific for the BRAF(V600E)-mutant melanoma cell lines with inhibition of mRNA and protein expression.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28892804\n",
      "Following adjustment for sex, logistic regression analysis showed that BRAFV600E mutation, transforming growth factor beta (TGF-beta) expression, age, and tumor size are risk factors that can affect tumor clinical stage (p < 0.05). Based on the results of this analysis, we generated a matrix that incorporated 4 variables: patient age, tumor size, BRAFV600E mutation, and TGF-beta expression.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28877062\n",
      "Findings of recurrent BRAF gene rearrangements in spindle cell sarcomas showing morphologic overlap with infantile fibrosarcomas expand the genetic spectrum of fusion-positive spindle cell sarcomas, to include unusual presentations, such as older children and adolescents and predilection for axial location.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28873491\n",
      "Despite the presence of histological findings indicating long-standing gastroesophageal reflux in 25%, as well as symptomatic gastroesophageal reflux in more than 40%, there was no detectable tissue expression of KRAS or BRAF mutations in adult patients treated for esophageal atresia in childhood.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28862766\n",
      "This study demonstrates that idiopathic pulmonary fibrosis-associated lung cancer (IPF-LC) is genetically characterized by the presence of somatic mutations reflecting a variety of environmental exposures on the background of specific germline mutations, and is associated with potentially targetable alterations such as BRAF mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28858076\n",
      "Authors systematically compared BRAF V600E and V600K skin cutaneous melanoma (SKCM) samples from the Cancer Genome Atlas (TCGA) for differential protein, gene, and microRNA expression genome-wide using the Mann-Whitney U-test. Analyses showed that elements of energy-metabolism and protein-translation pathways were upregulated and that proapoptotic pathways were downregulated in V600K tumors compared with V600E tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28850092\n",
      "while telomere length did not correlate with the presence of a mutation in BRAF (V-raf murine sarcoma viral oncogene homolog B), PIK3CA (phosphatidylinositol 3-kinase catalytic subunit), or MSI status, it was significantly associated with the occurrence of a mutation in KRAS\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28842324\n",
      "MC1R genotype is associated with patient phenotypes with BRAF and NRAS mutations in melanoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28834810\n",
      "BRAF V600E mutation was detected in 6% of glomus tumors, all of which were malignant or glomus tumors of uncertain malignant potential. This mutation may be associated with a malignant phenotype.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28829677\n",
      "our study suggests that an activating BRAF I463T mutation was associated with eosinophilic cystitis. Importantly, analysis of ctDNA obtained through \"liquid biopsies\" can identify potentially important genomic alterations in patients for whom biopsy may be difficult in terms of risk or cost.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28822769\n",
      "BRAF mutation is associated with melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28810144\n",
      "Mutation in BRAF gene is associated with Pancreatic Ductal Adenocarcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28791997\n",
      "Clinical and morphological data and the results of molecular genetic studies led to the conclusion that there was eosinophilic granuloma of the right parietal bone (the unifocal form of Langerhans cell histiocytosis (LCH), type I, group A1, with the monoossal nature of lesion and with BRAFV600E mutation).\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28787433\n",
      "BRAF mutation was found to be associated with lymph node metastasis as first metastasis and sentinel lymph node positivity. BRAF and NRAS mutations were associated with CNS and liver metastasis and NRAS mutation with lung metastasis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28775171\n",
      "Case Reports: two cases of gliosarcoma harbouring the BRAF V600E mutation, of which one case appears to have arisen de novo, while the other likely arose from ganglioglioma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28756651\n",
      "The rate of EGFR mutation was significantly higher in female and non-smoker patients. In TTF-1 positive cases EGFR mutation was more frequent. Age of the patients over 62-year old was correlated with KRAS mutations. The concordance between ALK IHC and FISH was 58.3%. The MET protein in the cases with MET amplification was 100% positive.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28753606\n",
      "Short-term treatment of nascent melanoma tumors with PAK inhibitors that block RhoJ signaling halts the growth of BRAF mutant melanoma tumors in vivo and induces apoptosis in melanoma cells in vitro via a BAD-dependent mechanism. As up to 50% of BRAF mutant human melanomas express high levels of RhoJ, these studies nominate the RhoJ-BAD signaling network as a therapeutic vulnerability for fledgling BRAF mutant human tumor\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28743501\n",
      "Hypoxic postconditioning attenuates apoptosis via inactivation of adenosine A2a receptor through NDRG3-Raf-ERK pathway.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28727518\n",
      "Patients with BRAF V600E PLGG exhibited poor outcomes after chemotherapy and radiation therapies that resulted in a 10-year progression-free survival of 27% (95% CI, 12.1% to 41.9%) and 60.2% (95% CI, 53.3% to 67.1%) for BRAF V600E and wild-type PLGG, respectively ( P < .001).\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28718951\n",
      "data are consistent with those of other studies reporting a positive relation between BRAF V600E mutation and poor prognostic factors in PTC; however, the BRAF status did not significantly correlate with a response to therapy.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28692601\n",
      "BRAF rearrangements were only found in myxoinflammatory fibroblastic sarcomas but not in hemosiderotic fibrolipomatous tumor lacking TGFBR3-MGEA5 fusions.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28685592\n",
      "Knowing the mutation status of KRAS, BRAF or PIK3CA in stage II colorectal cancer can significantly improve the accuracy of prognoses.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28679432\n",
      "a new somatic BRAF splicing mutation, was identified.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28667867\n",
      "Study found that high expression of LC3B protein was associated with the presence of BRAF V600E mutation and temporal lesion in glioneuronal tumors, as well as in gangliogliomas alone. As for Beclin-1 protein, it showed statistically significant correlation with BRAF V600E mutation in glioneuronal tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28666074\n",
      "Meta-analysis:  The combination of BRAF and TERT promoter mutations could classify PTCs into four distinct risk groups with decreasing aggressiveness as follows: coexisting BRAF and TERT > TERT alone=BRAF alone > no mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28662062\n",
      "findings should encourage the genetic evaluation of BRAF mutation. This study highlights the potential of RCM as a supplementary tool in the screening of BRAF-mutated melanomas\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28656305\n",
      "Exposure to cetuximab and various concentration of AG490, an inhibitor of JAK2, STAT3 and HSP27 protein levels, except in the KRAS G12V mutant line, SW620...cetuximab may promote SN38 sensitivity via suppression of HSP27, through blocking the JAK/STAT signaling pathway, and shows synergistic effects when combined with SN38 in wild-type RAS CRC cells.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28656062\n",
      "c-Myc, a downstream key effector of BRAF(V600E) signaling, was required for BRAF(V600E)-induced changes in lysine27-trimethylated histone H3 through regulating the components of the polycomb repressive complex 2 (PRC2) genes Ezh2, Suz12 and Jarid2 at both transcriptional levels via direct binding to their regulatory elements and post-transcriptional levels via repressing the miR-26a, miR-200b and miR-155.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28650588\n",
      "The BRAF gene has been reported to be mutated in some human cancers. The BRAF mutations have been implicated in ameloblastoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28650561\n",
      "we describe patients with craniosynostosis and Noonan syndrome due to de novo mutations in PTPN11 and patients with craniosynostosis and CFC syndrome due to de novo mutations in BRAF or KRAS. All of these patients had cranial deformities in addition to the typical phenotypes of CFC syndrome and Noonan syndrome.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28646474\n",
      "the presence of the BRAF (V600E) mutation may be negatively correlated with partial aggressive clinicopathological features of pediatric papillary thyroid cancer (PTC).\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28625649\n",
      "We have found a higher incidence of axLN metastases in BRAF mutated NSCLC patients than described in non-BRAF mutated NSCLC patients. Examination of the axilla should be a routine part of physical examination in this genetically distinct subgroup of lung cancer patients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28623774\n",
      "We found a clinically meaningful discrepancy rate in BRAF status both between primary-metastatic and metastatic-metastatic melanoma lesions.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28611337\n",
      "meta-analysis revealed that, in patients with colorectal cancer, the BRAF mutation was associated with female, proximal site, poor differentiation, >5 cm size, and advanced AJCC stage\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28611106\n",
      "we have found that a subgroup of colorectal cancers, defined by having either KRAS or BRAF (KRAS/BRAF) mutations and BCL2L1 (encoding BCL-XL) amplification, can be effectively targeted by simultaneous inhibition of BCL-XL (with ABT-263) and MCL1 (with YM-155).\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28595259\n",
      "Our data show that Signet ring cell colorectal cancer (SRCCa) phenotype comprises two distinct genotypes. The MSI(+)/CIMP(+)/BRAF V600E(+)/CD3(+)/PDL1(+) hypermethylated genotype is an ideal candidate for immune checkpoint inhibitor therapy. In addition, one fourth of SRCCa cases can potentially be targeted by KIT inhibitors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28583095\n",
      "BRAF mutation, rather than KRAS, was a significant prognostic factor in Korean colorectal cancer patients at both early and advanced stages.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28576857\n",
      "Braf mutations served as biomarkers for response to anti-EGFR monoclonal antibodies in colorectal cancer.[review]\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28576831\n",
      "Vemurafenib, inhibiting BRAF signaling, shifted the balance of activatory and inhibitory NK ligands on melanoma cells and displayed immunoregulatory effects on NK-cell functional activities\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28576751\n",
      "Bromodomain and extra-terminal (BET) inhibitors can suppress growth of BRAF-mutant colon cancer cells via repression of MAPK signaling pathway.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28561662\n",
      "Combination BRAF and MEK inhibition has also been shown to improve overall survival in patients with V600E-mutated melanoma. Responses to therapy are often rapid, and treatment is not associated with immune-related adverse events.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28551389\n",
      "The lack of KRAS, NRAS, BRAF, and PIK3CA mutation in our study may suggest that a subset of eyelid sebaceous carcinomas is unlike that of eyelid sebaceous carcinomas of western countries.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28543997\n",
      "Our findings showed BRAF and/or KRAS mutations in three of seven cases of low-grade serous neoplasms of the testis\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28539463\n",
      "We report acquisition of a BRAF fusion as a novel mechanism of acquired resistance to vemurafenib in a patient with melanoma harboring a BRAF(V600E) mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28536307\n",
      "In vemurafenib-treated patients, the cell-cycle gene signature was associated with shorter PFS. However, in cobimetinib combined with vemurafenib-treated patients, both cell cycle and immune signature subgroups had comparable PFS. Cobimetinib combined with vemurafenib may abrogate the adverse impact of the cell-cycle signature.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28523274\n",
      "Our model is trained to mimic the predictions of a 64-gene signature, the current definition of BRAF-positive group.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28504206\n",
      "Case Reports: pediatric intracranial and cranial juvenile xanthogranuloma with BRAF V600E mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28500561\n",
      "study to identify the incidence of BRAF and CTNNB1 gene mutations in craniopharyngiomas and correlate it with clinicopathological parameters including histopathology, immunohistochemical expression of proteins BRAF pVal600Glu and beta-catenin and clinical outcome\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28488545\n",
      "ytoplasmic immunoexpression of BRAF V600E (VE1) protein was found in three specimens: serous superficial papilloma, serous papillary cystadenoma of borderline malignancy, and partially proliferative serous cystadenoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28475671\n",
      "Durable (>/=3 years) survival is achievable with dabrafenib plus trametinib in patients with BRAF V600-mutant metastatic melanoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28468827\n",
      "Data suggest that HMGCS1 (HMG-CoA synthase 1) signals through ketogenesis/acetoacetate to promote cell proliferation and BRAF(V600E)-dependent MEK1 activation in BRAF(V600E)-positive melanoma and colon cancer cells; HMGCS1 co-localizes with HMGCL (HMG-CoA lyase) and BRAF(V600E) in cytosol of melanoma and colon cancer cells. (BRAF = proto-oncogene protein B-raf)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28463756\n",
      "The results show that BRAF mutations are associated with a worse prognosis than expected in patients treated with FOLFIRI protocol plus bevacizumab compared with the BRAF wild-type population.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28455392\n",
      "This study identified two mechanistic subtypes of melanoma: (1) the best responders to clinical BRAF/MEK inhibitors (25%) and (2) nonresponders due to primary resistance mechanisms (9.9%). We identified robust biomarkers that can detect these subtypes in patient samples and predict clinical outcome\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28454577\n",
      "By shedding light on the repertoire of BRAF mRNA and protein variants, and on the complex regulation of their expression, our work paves the way to a deeper understanding of a crucially important player in human cancer and to a more informed development of new therapeutic strategies\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28448514\n",
      "a new BRAF fusion in pilocytic astrocytoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28444112\n",
      "In the coBRIM phase III trial, the addition of cobimetinib, an MEK inhibitor, to vemurafenib, a BRAF inhibitor, significantly improved progression-free survival [hazard ratio (HR), 0.58; P < 0.0001] and overall survival (HR, 0.70; P = 0.005) in advanced BRAF-mutated melanoma. Here, we report on the incidence, course, and management of key adverse events (AEs) in the coBRIM study\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28424234\n",
      "the rate of BRAF mutation in Irish cohort (28.8%) was lower than international published rates of 40%-60%.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28423638\n",
      "Data show that combined therapy using HER2 inhibitor and BRAF/MEK inhibitor presented more significant redifferentiation effect on papillary thyroid cancer cells harboring BRAFV600E than BRAF/MEK inhibitor alone.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28423545\n",
      "BRAF mutation is associated with papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28421232\n",
      "mutations were detected in 8 of the 18 adult Langerhans cell histiocytosis patients analysed.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28404629\n",
      "functional analysis of human BRaf disease-linked mutations identified BRaf as the key missing signaling effector in the common synaptic NMDA-R-CaMKII-SynGap-Ras-BRaf-MEK-ERK transduction cascade.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28393212\n",
      "these results suggest that SIRT6 enhances cell aggressiveness in PTC via BRAF/ERK/Mcl1 pathway, and thus may be a promising target in the treatment of the disease.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28383426\n",
      "BRAFV600E mutation significantly associated with nonsmall cell lung cancer in females and nonsmokers [meta-analysis]\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28373167\n",
      "These findings identify a dynamic interplay between FZR1 and BRAF with strong implications for cell-fate determination and the tumor suppressor role of FZR1\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28342873\n",
      "These findings demonstrate that the BRAF V600E mutation down-regulates levels of HMGB1, likely through activation of the mitogen-activated protein kinase (MAPK) signaling pathways.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28323937\n",
      "BRAF mutations were present in 44.6% of primary papillary thyroid carcinomas, 41.7% of lymph node metastasis, and 23.8% of distant metastasis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28319896\n",
      "BRAF mutations in the genomic DNA extracted from cancer cell lines were tested, allowing sensitive detection of SNM at very low abundances\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28295004\n",
      "The patients with traditional serrated adenoma showed KRAS and BRAF mutations in 58.4 and 8.3% of cases, respectively. Mutations of these genes were absent.  The study revealed that the subtypes of serrated adenomas substantially differ by sex, age, localization, and molecular genetic characteristics\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28293988\n",
      "analysis of BRAF genetic alterations among the histologic variants of papillary thyroid carcinoma in Korea\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28292959\n",
      "Data suggest that activation of the metalloproteinase ADAM10 by signal peptide peptidase-like 3 (SPPL3) triggered by mutant BRAF(V600E) was a critical transformation event.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28285720\n",
      "we did not observe GNAS or BRAF mutations in urachal adenocarcinomas\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28281325\n",
      "IRP2 expression was associated with mutations in BRAF.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28278349\n",
      "summary of the current evidence of non-V600 BRAF mutations and BRAF fusions in melanoma (review).\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28268064\n",
      "BRAF mutation is associated with melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28258306\n",
      "genetic association/nutrigenomic studies in population in Seoul, Republic of Korea: Data suggest that (1) relatively low iodine intake and (2) more than excessive iodine intake are significant risk factors for occurrence of BRAF mutations in thyroid gland and may be risk factors for development of PTC (papillary thyroid cancer) in iodine-replete area.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28249840\n",
      "Mutations in KRAS, NRAS, and BRAF together occur in more than half of all colorectal cancer cases and are often associated with negative responses to the EGFR inhibitors cetuximab and panitumumab.guideline is clear that we should not be giving EGFR inhibitors to patients with RAS mutations and that patients with BRAF V600E mutations have a much worse prognosis\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28234922\n",
      "Our purpose was the evaluation of microsatellite stability status within conventional colon adenomas and also b-catenin, BRAFV600E and p53 contribution.we noted a 10% frequency of MSI events where MSI-H reached a 5% share occurred within the left colon and rectal polyps. b-catenin nuclear overexpression was noted with a 70% frequency and p53 with close to a 24% frequency.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28232477\n",
      "We show that rosiglitazone increases klotho and decreases Wnt5A in tumor cells, reducing the burden of both BRAF inhibitor-sensitive and BRAF inhibitor-resistant tumors in aged, but not young mice. However, when used in combination with PLX4720, tumor burden was reduced in both young and aged mice, even in resistant tumors\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28220299\n",
      "BRAF V600E mutation is frequent in pulmonary Langerhans cell histiocytosis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28219109\n",
      "Authors tested the mutation-specific BRAF V600E monoclonal antibody (clone VE1) in formalin-fixed, paraffin-embedded LCH samples from 26 pediatric patients using allele-specific real-time polymerase chain reaction (PCR) with a limit of detection of 0.5% as the comparative gold standard.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28216246\n",
      "KRAS and BRAF mutations are negatively associated with overall and relapse-free survival in patients who undergo complete liver resection for colorectal cancer liver metastases\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28216139\n",
      "Real-time PCR and pyrosequencing methods were equally excellent in determination of BRAF V600 mutations. The immunohistochemistry method, which is commonly used in routine pathology practice, can also be safely used as a screening test for determination of BRAF V600 mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28214213\n",
      "The expression levels of BRAFV600E and NF-kappaB were significantly greater in thyroglobuiln antibody-positive than in thyroglobuiln antibody-negative papillary thyroid carcinoma patients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28179313\n",
      "Data suggest that genotyping for KRAS and BRAF mutation status is a gold standard for categorizing colorectal cancer (CRC) for clinical decisions.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28176151\n",
      "pediatric papillary thyroid carcinomas in Japan are characterized by more advanced clinicopathological features, lower BRAF (V600E) frequency, and absence of TERT mutation\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28174173\n",
      "FZR1 inhibits BRAF oncogenic functions via both APC-dependent proteolysis and APC-independent disruption of BRAF dimers, whereas hyperactivated ERK and CDK4 reciprocally suppress APC(FZR1) E3 ligase activity\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28160058\n",
      "Association of the Bethesda category with BRAF mutation can slightly improve the value of stage prediction in papillary thyroid cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28159677\n",
      "BRAF mutations are rare events in KIT/PDGFRA wild-type gastrointestinal stromal tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28135039\n",
      "Study identified BRAF mutations in 1.7% of Chinese patients with non-small-cell lung cancer and seems associated with adenocarcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28134726\n",
      "NRAS and BRAF mutations are independent events and alternative molecular mechanisms in the primary oral mucosal melanoma tumorigenesis\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28125730\n",
      "Aspirin use after colon cancer diagnosis was associated with improved overall survival in wild-type BRAF tumors. In contrast, aspirin use in BRAF mutated tumors was not associated with an improved survival.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28093501\n",
      "Thus, the quaternary structure of BRAF complexes is shaped by its activation status, the conformation of its kinase domain, and clinically relevant inhibitors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28093487\n",
      "One way to potentially improve adoptive T cell therapy is to combine it with the administration of small molecule inhibitors. Vemurafenib specifically inhibits mutated BRAFV600E/K molecules and directs cell death of BRAFV600E/K expressing tumors\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28092667\n",
      "ZNF767-BRAF fusion is associated with mucosal melanomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28091917\n",
      "Rare mutations in KRAS, NRAS, and BRAF oncogenes have been found in patients with melanoma and colorectal neoplasms.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28089569\n",
      "These findings reveal a signaling basis underlying a pathogenic role of dietary fat in BRAF V600E-expressing melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28087644\n",
      "the FDA granted accelerated approval to nivolumab (OPDIVO; Bristol-Myers Squibb) for the treatment of patients with unresectable or metastatic melanoma and disease progression following ipilimumab and, if BRAF V600 mutation positive, a BRAF inhibitor. Approval was based on a clinically meaningful, durable objective response rate (ORR) in a non-comparative analysis of 120 patients who received 3 mg/kg of nivolumab\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28077340\n",
      "Frequency of BRAF(V600E) mutation was similar in prepubertal and pubertal patients. BRAF(V600E) mutation was found in 14/56 (25%) patients and was high in the classic variant papillary thyroid cancer\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28074351\n",
      "review focuses on the genes, which are frequently mutated in various cancers and are known to be important in the advance and progression of colorectal cancer and melanoma, namely KRAS, NRAS and BRAF\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28073844\n",
      "The results of the trial submitted to confirm clinical benefit, which formed the FDA basis for the regular approval of nivolumab for the first-line treatment of patients with BRAFV600 wild-type (WT) unresectable or metastatic melanoma, are described in this article.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28067893\n",
      "Data show that the expression of Interleukin-8 (IL-8) and connective tissue growth factor (CTGF) was significantly reduced by treatment with vemurafenib and trametinib in (V600E)BRAF protein melanoma cells.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28062544\n",
      "Despite a significant prevalence of BRAF mutation, more than 70% of hobnail variant of papillary thyroid carcinomas (HPTCs) in our series showed concurrent mutations of other genes such as TP53, PIK3CA, CTNNB1 and hTERT, in contrast to classic PTC.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28040692\n",
      "BRAF or KRAS mutations are independently associated with shorter time to recurrence, shorter survival after relapse, and overall survival in patients with microsatellite-stable (MSS) subgroups, but not microsatellite-unstable tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28039443\n",
      "Report heterogeneity and frequency of BRAF mutations in primary melanoma samples.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28034324\n",
      "The expression of the nuclear and cytoplasmic forms of p16 represent two independent mechanisms, and both seemed to control proliferation in response to oncogenic stimuli, protecting the cell from malignant transformation in BRAF-mutated gastrointestinal stromal tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28030835\n",
      "Co-targeting translation and proteasome using the combination of Episilvestrol and Bortezomib promoted strong endoplasmic reticulum stress and rapid killing of colon cancer cells with KRAS/BRAF mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28025078\n",
      "Report KRAS, NRAS, PIK3CA, and BRAF mutational profile in poorly differentiated clusters of KRAS-mutated colon cancer may depend on tumor histology.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28006055\n",
      "Mutations in BRAFV600E were significantly associated with worse survival after recurrence (SAR) in patients with recurrent stage III colon cancer, and worse SAR for BRAFV600E or KRAS mutant tumors was more strongly associated with distal cancers.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28002643\n",
      "BRAF mutation is not associated with response to chemotherapy in Melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/28000889\n",
      "High BRAF mutation rate is associated between primary colorectal cancer and corresponding metastases.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27999210\n",
      "A panRAF inhibitor, LY3009120, potently inhibited proliferation and tumor growth in BRAF/KRAS mutated colorectal tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27993800\n",
      "BRAF-mutant advanced colorectal cancer ( aCRC) confers a markedly worse prognosis independent of associated clinicopathological features. Chemotherapy provides meaningful improvements in outcome throughout treatment lines. Post-progression survival is markedly worse and vigilance is required to ensure appropriate delivery of treatment after first-line progression\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27993793\n",
      "these data highlight the poor prognosis of patients with metastatic melanoma and BM, despite a targetable 'driver' oncogene mutation(BRAFv600) and evidence of initial drug-responsiveness\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27984807\n",
      "This study demonstrated the presence of BRAF V600E mutation in Chinese epileptic patients with Glioneuronal tumors, which was significantly correlated with gender and multiple seizure types.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27984673\n",
      "A series of midline gangliogliomas demonstrate that the H3 K27M mutation can occur in association with the BRAF V600E mutation in grade I glioneuronal tumors. Despite the presence of H3 K27M mutations, these cases should not be graded and treated as grade IV tumors because they have a better spontaneous outcome than classic diffuse midline H3 K27M-mutant glioma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27977682\n",
      "we demonstrate that small molecule PERK inhibitors exhibit single agent efficacy against BrafV600E-dependent tumors highlighting the clinical value of targeting PERK\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27965097\n",
      "in response to vemurafenib, BRAF-mutated melanoma and colorectal cancer cells rapidly induced the ISR as a cytoprotective mechanism through activation of general control nonderepressible 2 (GCN2), an eIF2alpha kinase sensing amino acid levels\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27943267\n",
      "Alcohol intake is associated with an increased risk of KRAS+ and BRAF-/KRAS- tumors originating via specific molecular pathways including the traditional adenoma-carcinoma pathway but not with BRAF+ tumors originating via the serrated pathway\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27936049\n",
      "Extrathyroid invasion, lymph node metastases, and BRAFV600E mutation were the high risk factors of papillary thyroid microcarcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27930579\n",
      "BRAF mutation and DNA mutation was associated with serrated polyps and hyperplastic polyps in the carcinogenesis of colorectal cancers.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27928645\n",
      "Our data demonstrate that starvation-trigged autophagy, which is BRAF V600E dependent, promotes cancer cell survival in uveal melanoma. Vemurafenib induces autophagic cell death rather than adaptive cell survival in BRAF V600E-mutant melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27923714\n",
      "Acquired BRAF V600E Mutation is associated with resistance to osimertinib in lung cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27923591\n",
      "Despite a high specificity for thyroid cancer, BRAF(V600E) mutation has a low overall sensitivity and therefore has a limited diagnostic value as a single screening test.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27919446\n",
      "Immunohistochemistry is an accurate method to evaluate BRAF proto-oncogene is papillary thyroid cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27916952\n",
      "multiregion analysis was performed in 60 spatially separated tumor areas according to the pathological tumor node metastasis (pTNM) staging and KRAS, NRAS and BRAF mutations were tested using pyrosequencing.these results suggest the need for multiple RAS testing in different parts of the same tumor and/or more sensitive techniques.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27912827\n",
      "This review highlights treatment options, including clinical trials for ROS1 rearrangement, RET fusions, NTRK1 fusions, MET exon skipping, BRAF mutations, and KRAS mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27911979\n",
      "our studies show that BRAFNon-V600 mutations are not prognostic for stage IV melanoma patients, and this information will augment the design and interpretation of current and future clinical trials in this patient population.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27911794\n",
      "RAS-ERK signaling in BRAF mutant melanomas is critical for regulating active chromatin state and recruitment of RNA polymerase II at mutant TERT promoters. Our study provides evidence that the mutant TERT promoter is a key substrate downstream of the RAS-ERK pathway.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27911099\n",
      "Morphometric variables are predictive markers for papillary thyroid carcinoma cases with positivity for BRAF V600 mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27888823\n",
      "No relation between oropharyngeal squamous cell carcinomas and BRAF gene mutations\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27875244\n",
      "This multicenter data analysis establishes a six-genotype genetic prognostic model for poor outcomes of papillary thyroid cancer with a risk order of genetic duet of BRAF V600E/RAS mutation and TERT mutation >>>>BRAF V600E = TERT mutation alone >RAS mutation alone = wild-type genes.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27870159\n",
      "ndings indicate that BRAF V600E is not a consistent squarending in myopericytoma and does not serve as a useful diagnostic immunohistochemistry marker\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27866718\n",
      "BRAF protein mutation in metastatic lymph nodes maybe responsible for the recurrence of papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27865374\n",
      "A high extent more than 25% of BRAF(V600E) alleles may be associated with disease outcome in PTC patients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27864876\n",
      "ARMC10-BRAF fusion is associated with melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27864688\n",
      "genome analysis of wild-type gastrointestinal stromal tumors for mutations should include the BRAF gene in patients with KIT and PDGFRA wild-type gastrointestinal stromal tumors\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27863476\n",
      "Data indicate the role of immunohistochemical BRAF V600E expression in patients at the time of progression.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27863429\n",
      "the present study identifies the WIPF1 gene as having novel oncogenic functions and playing an important role in the invasiveness and aggressiveness of thyroid cancer when aberrantly up-regulated by the BRAF V600E/MAPK pathway through its promoter demethylation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27863426\n",
      "CSF tumor-derived cell-free DNA has the potential to serve as a diagnostic tool in patients with BRAFV600 mutated malignancies.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27863403\n",
      "Report targeted analysis of KRAS, BRAF and PIK3CA mutations in circulating tumor cells captured by a label-free platform and compare to expression in primary tumor tissue and metastases.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27860480\n",
      "BRAF gene mutation is confirmed by several studies found in malignant melanoma of the skin. The histopathology findings in our group did not confirmed our theory, that since the uveal melanoma itself has the similar origin as skin melanoma, should also contain a BRAF mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27860162\n",
      "Desmoplastic infantile astrocytoma/ganglioglioma with rare BRAF V600D mutation\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27835901\n",
      "Mutational activation of BRAF confers sensitivity to TGFBR1 inhibitors in human melanoma cells.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27815357\n",
      "KRAS mutations were rarely found together and those in codons 12 and 13 conferred poor prognosis. For BRAF, more c.1781A>G (p.D594G) colorectal cancers (CRC)carried RAS mutations [14% (3/21)] compared with c.1799T>A (p.V600E) CRCs.For NRAS, 5% (3/60) of codon 61 mutant colorectal cancers had KRAS mutations compared with 44% (10/23) of codons 12 and 13 mutant colorectal cancers\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27813079\n",
      "Increased plasma membrane abundance of PMCA4b in vemurafenib-treated BRAF mutant cells is associated with enhanced Ca2+ clearance.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27792249\n",
      "Results indicate that in addition to being present in established BRAF-associated gliomas, BRAF mutations might be associated with epithelial features in high-grade gliomas, including sheet-like arrangement of polygonal tumor cells with a plump cytoplasm and astroblastic rosettes, and thus could potentially serve as a genetic marker for these features.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27791198\n",
      "A rapid monophyletic evolution of melanoma subpopulations in response to targeted therapy that was not observed in non-targeted therapy was observed. NRAS mutations in BRAF mutated patient treated with a BRAF inhibitor were identified post-resistant samples. Sequence analysis showed that NRAS mutations co-occur with BRAF mutations in single cells, and are not mutually exclusive.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27776007\n",
      "Spitzoid neoplasms with BRAF fusion cases were most likely to have high-grade nuclear atypia, to be diagnosed as spitzoid melanoma, to have a positive result by melanoma fluorescence in situ hybridization assay, and to develop copy number gains in the kinase domain of the fusion protein.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27775691\n",
      "Data show that BRAF inhibitor (BRAFi) treatment failed to affect Nodal protein levels in melanoma tissues.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27775641\n",
      "Findings suggest that the association of HER2 amplification with BRAF(V600E) mutation and telomere shortening may represent a marker of tumor aggressiveness, and, in refractory thyroid cancer, may warrant exploration as a site for targeted therapy.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27771229\n",
      "BRAF V600E is the predominant mutation in Japanese non-chronically sun-damaged melanoma patients, and that both intra- and inter-tumor mutational heterogeneities exist in primary and metastatic melanomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27769870\n",
      "BRAF V600E mutations wereencountered in most metanephric stromal tumors, supporting a link with other metanephric tumors and suggesting a clonal event possibly affecting primordial renal cells.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27766572\n",
      "BRAF mutations were detected in 54 of 115 (47 %) including 51 of V600E and 3 of V600 K in Japanese melanoma cases.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27765849\n",
      "BRAF(V600E)-mediated MEK/ERK activation can upregulate MCL-1 by phosphorylation/stabilization to confer apoptosis resistance that can be reversed by MCL-1 antagonism combined with cobimetinib, suggesting a novel therapeutic strategy against BRAF(V600E)-mutant CRCs.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27764839\n",
      "Incidence of adverse events was similar regardless of RAS/BRAF status.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27760550\n",
      "BRAF(V600E) mutation is a common genetic change in isolated hypothalamic-pituitary Langerhans cell histiocytosis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27737711\n",
      "No significant impact on prognosis was observed for mutated KRAS, NRAS, and PIK3CA genes or combined RAS mutations\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27729324\n",
      "Alternative genetic mechanisms of BRAF activation in Langerhans cell histiocytosis\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27718322\n",
      "BRAF V600E mutation is associated with cerebellar pilocytic astrocytoma recurring as a ganglioglioma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27689252\n",
      "BRAF-positive thyroid cancers most often demonstrate worrisome sonographic features and are frequently associated with positive or suspicious Bethesda cytology.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27681305\n",
      "findings suggest an association of BRAF-V600E with parameters of a more aggressive behaviour of ameloblastoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27672042\n",
      "Japanese patients with sporadic colorectal cancer with BRAF V600E mutation exhibited a significantly shorter overall survival.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27671879\n",
      "In this report, we describe a 35-year-old female who presented with multifocal ganglioglioma, involving both the conus medullaris and filum terminale. The dominant lesion in the filum terminale was resected, which revealed World Health Organization I grade, p53 mutant, and BRAF wildtype status\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27666765\n",
      "BRAF V600E mutation in capsular nevi of sentinel lymph nodes may be useful as an adverse predictive biomarker in patients with melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27659822\n",
      "The V600E mutation is associated with a risk of transformation to high-grade glioma and poor response to chemoradiation approaches and outcome.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27634910\n",
      "Mutation analysis Iindicate NRAS as the most commonly mutated gene in myeloma patients followed by KRAS ( and BRAF.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27630332\n",
      "BRAF-mutant lesions are consistently associated with poor prognosis. Consequently, the indications of colorectal liver metastasis resection in this patient group should be reconsidered.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27620500\n",
      "The authors find that the interaction between sB-Raf and the Hsp90 chaperone system is based on contacts with the M domain of Hsp90, which contributes in forming the ternary complex with Cdc37 as long as the kinase is not stabilized by nucleotide.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27608415\n",
      "Study finds infrequent BRAF alterations but enriched FGFR alterations in adults as compared with that reported in pediatric pilocytic astrocytomas. In addition, coexistent BRAF and FGFR alterations and a significant association of FGFR alterations with age and tumor location were noted.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27600854\n",
      "BRAF mutations are closely associated with aggressive clinicopathological characteristics and poorer prognosis in papillary thyroid cancer. [meta-analysis]\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27599148\n",
      "Study found that BRAF alterations are frequent in dysembryoplastic neuroepithelial tumors (DNTs), particularly BRAF copy number gain which is being reported for the first time in these tumors. Evidence of activation of mTOR and MAPK pathways suggests a role for altered signalling in DNT pathogenesis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27597420\n",
      "The BRAF/MAP2K1-mut LCH cells had a more immature state than BRAF/MAP2K1-wt LCH cells. Authors also found the BRAFV600E and MAP2K1 mutations were significantly associated with pERK expression.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27571181\n",
      "r-BRAF are very uncommon in papillary thyroid carcinomas (PTC) and are found almost exclusively in PTC with low-risk clinicopathological features.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27568671\n",
      "Compared to some Asian populations, this study of Filipino papillary thyroid carcinoma patients shows a lower prevalence of BRAF V600E mutation\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27555670\n",
      "IFNgamma inhibits CXCL8 secretion and in turn the migration of a BRAF V600e mutated thyroid cell line\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27554081\n",
      "The BRAF V600E mutation is now recognized as the causal genetic event of hairy cell leukemia because it is somatic, present in the entire tumor clone, detectable in almost all cases at diagnosis (encompassing the whole disease spectrum), and stable at relapse.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27545333\n",
      "A report of BRAF mutations in acute myeloid leukemias (AML) found mutations only in de novo AML with monocytic differentiation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27542908\n",
      "(V600)BRAF switches on a metabolic reprogramming in melanoma cells, leading to a decreased OXPHOS activity and increased glycolytic ATP, lactate, HIF-1alpha and MCT4 levels.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27535135\n",
      "Point mutations of BRAF is associated with thyroid cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27532222\n",
      "A pointmutation located in exon 5 of the TP53 gene and a point mutation in exon 15 of the BRAF gene (c.1799T>A, V600E) were detected in an anaplastic thyroid carcinoma patient\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27503895\n",
      "miR-579-3p controls melanoma progression and resistance to target therapy by targeting the 3'UTR of two oncoproteins: BRAF and MDM2.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27480103\n",
      "BRAF(V600)-mutation is associated with melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27466810\n",
      "found that BRAF genotyping in weakly and moderately pigmented samples was more efficient when the sample was processed with BSA or purified with a NucleoSpin(R) gDNA Clean-up XS Kit prior to PCR amplification\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27460442\n",
      "BRAF(V600)-mutation is associated with papillary thyroid cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27458004\n",
      "Compared with newly diagnosed multiple myeloma, an increased prevalence of mutations in the Ras pathway genes KRAS, NRAS, and/or BRAF (72%), as well as TP53 (26%), CRBN (12%), and CRBN pathway genes (10%) was observed.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27454941\n",
      "Study of four cases confirms BRAF V600E mutation as a probable driver in a subset of ciliated muconodular papillary tumors (CMPT) of the lung, along with AKT1 mutation, which further supports that CMPT are indolent pulmonary neoplasms.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27449293\n",
      "Results show that promoter mutations render telomerase reverse transcriptase (TERT) expression dependent on MAPK signal pathway activation due to oncogenic BRAF or NRAS mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27442672\n",
      "A higher number of suspicious US features classified by the TIRADS, but not the BRAF mutation, are associated with lateral lymph node metastasis in patients with PTC, and can aid in the preoperative identification of patients at increased risk of lateral lymph node metastasis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27438990\n",
      "Results indicate that MLH1-hypermethylated BRAF wild-type colorectal carcinomas can harbor KRAS mutations and arise from precursor polyps resembling conventional tubular/tubulovillous adenomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27435270\n",
      "There is association between CpG island methylator phenotype and mutation of BRAF in patients with metastatic Colorectal cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27433783\n",
      "BRAFV600E mutations were associated with younger patient age and localization of melanoma on sun-protected areas of the skin.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27416954\n",
      "BRAFV600E mutation is associated with astroblastoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27404270\n",
      "colorectal cancers with BRAF D594G mutations are similar to those with BRAF wild-type with regard to clinicopathological features, microsatellite instability status, and prognosis. However, colorectal cancers with BRAF D594G mutations are rare.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27401113\n",
      "The results establish a link between BRAF(V600E) and NOX4, which is confirmed by a comparative analysis of NOX4 expression in human (TCGA) and mouse thyroid cancers.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27387551\n",
      "This study is the first to report BRAF mutations in a pure adult sample of differentiated thyroid cancer of Saudi Arabian ethnicity.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27382031\n",
      "The results demonstrated the lack of activity of anti-EGFRs in RAS(KRAS and NRAS) and BRAF wild-type, right-sided tumors, thus suggesting a potential role for primary tumor location in driving treatment choices\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27368419\n",
      "DiRas3 binds to KSR1 independently of its interaction with activated Ras and RAF.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27358379\n",
      "Mutations in KRAS and BRAF were associated with inferior PFS and OS of mCRC patients compared with patients with non-mutated tumors. KRAS exon 2 mutation variants were associated with heterogeneous outcome compared with unmutated tumors with KRAS G12C and G13D (trend) being associated with rather poor survival\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27354468\n",
      "We suggest that BRAF mutant patients should not be considered as having a unique biology and provide an in depth characterization of heterogeneous motifs that may be exploited for drug targeting.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27351224\n",
      "Using a panel of BRAF V600E and WT colorectal cancer cell lines and in vitro selected resistant culture, and xenograft models, authors demonstrate here that BRAFV600E confers resistance to mTOR inhibitors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27345584\n",
      "Here we review the current knowledge about the classification of this tumor subtype and its association with five key features: mutation status of the BRAF or KRAS genes, the CpG island methylation phenotype, microsatellite instability, immune cell infiltration, and overexpression of GTPase RAC1b\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27342756\n",
      "Studies indicate the clinical importance of BRAF-V600 mutations and BRAF inhibition in the progression to melanoma brain metastasis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27329244\n",
      "RNF43 germline and somatic mutation in Serrated Neoplasia pathway associated with BRAF mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27325282\n",
      "MET amplification is here identified-clinically and preclinically-as a new mechanism of resistance to EGFR and BRAF dual/triple block combinations in BRAF-mutated colorectal cancer. Switching from EGFR to MET inhibition, while maintaining BRAF inhibition, resulted in clinical benefit after the occurrence of MET-driven acquired resistance.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27314237\n",
      "Our study provides a rationale to strengthen NK cell immunotherapy through a combination with cetuximab for RAS and BRAF mutant mCRC patients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27296272\n",
      "Erdheim-Chester Disease With Cardiovascular Involvement and BRAF V600E Mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27283860\n",
      "BRAF(V600E)-mutation is associated with metastatic non-small cell lung cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27261210\n",
      "The association of BRAF mutations with clinical and pathological features was assessed next in a cohort of 840 KRAS exon 2 wild type CRC patients screened with the Real Time PCR assay.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27256275\n",
      "The BRAF(V)(600E) mutation is also seen in paediatric cytology and the morphological features showed a high accuracy as both predictive mutational parameters and a helpful aid in management mainly of the aggressive BRAF(V)(600E) mutated carcinomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27253461\n",
      "investigation of MGMT promoter methylation and in particular BRAF V600E mutations represent reliable additional tools to sustain differentiation of Giant Cell Glioblastoma (gcGBM) from Pleomorphic Xanthoastrocytoma (PXA) on a molecular basis. Based on these data specific BRAF kinase inhibitors could represent a promising agent in the therapy of PXA and their use should be emphasized.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27249714\n",
      "For patients with non-small cell lung cancer with a EGFR mutation and an anaplastic lymphoma kinase mutation(ALK) with brain metastases, several agents have shown intracranial activity. Lapatinib has been tested for patients with brain metastases from breast cancer harboring a HER2 mutation. molecular targeted therapies have shown efficacy in BRAF-positive melanoma brain metastasis\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27226552\n",
      "using a kinase-inactive mutant of CK2alpha, that RAF-MEK inhibitor resistance did not rely on CK2alpha kinase catalytic function, and both wild-type and kinase-inactive CK2alpha maintained ERK phosphorylation upon inhibition of BRAF or MEK.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27222248\n",
      "The B-Raf inhibitor PLX4032 induces DR5 upregulation exclusively in Ras-mutant cancer cells; this effect is dependent on Ras/c-Raf/MEK/ERK signaling activation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27220764\n",
      "p16 and BRAFV600E are useful to distinguish between sporadic and hereditary (Lynch syndrome-related) microsatellite instable colorectal carcinomas\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27210749\n",
      "These results provide support for the role of BRAF(V600E) in metastasis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27198569\n",
      "PD-L1 expression in colorectal cancer is associated with microsatellite instability and BRAF mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27197524\n",
      "BRAF IHC is strongly concordant with the BRAF mutation test.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27194447\n",
      "strong correlation between the presence of circulating V600 mutated DNA and overall survival of melanoma patients\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27180062\n",
      "Functional Na+/I- symporter activity was higher in BRAF(V600E) mutation-positive cases of classical variant papillary thyroid carcinoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27167340\n",
      "Data show that long noncoding RNA RMEL3 is required for MAPK and PI3K signaling, and its knockdown decrease BRAFV600E melanoma cell survival and proliferation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27165943\n",
      "BRAF mutation is associated with response to chemotherapy in lung cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27150060\n",
      "Data show that 514 of 1170 patients (44%) carried a BRAF mutation, and all models indicated age and histological subtype of melanoma as the two major predictive variables.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27147251\n",
      "BRAF mutation is correlated with response to therapy in melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27138882\n",
      "BRAF(V600E) in papillary thyroid cancer predicts an increased risk of lymph node metastasis, extra-thyroidal extension and reduced disease-free survival. It is an additional useful prognostic biomarker.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27138801\n",
      "BRAF mutation was significantly related with shorter DFS and OS among stage II/III CRC patients receiving adjuvant chemotherapy after curative resection\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27116958\n",
      "Braf and Kras genes mutation were reveled in gastritis and adenocarcinoma patients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27111917\n",
      "HRM appears the less sensitive assay for the detection of BRAF V600 mutations. The RT-ASA, IdyllaTM and IHC assays are suitable for routine molecular diagnostics aiming at the prescription of anti-BRAF therapies\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27105117\n",
      "Cdc37 performs a quality control of protein kinases, including b-raf, where induced conformational instability acts as a \"flag\" for Hsp90 dependence and stable cochaperone association.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27101548\n",
      "The BRAF was mutated in 55% (29/53) and NRAS in 11% (5/45) of the primary melanomas sequenced.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27098748\n",
      "BRAF mutations were not detected in any of the four IM cases examined. One patient with IM died from metastatic disease: this tumour was disomy 3 with 6p and 8q gains. All other patients were alive with no evidence of metastases at study closure.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27094161\n",
      "New and highly sensitive method to detect BRAF V600 mutations in Langerhans cell histiocytosis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27087167\n",
      "the BRAF pathway is activated in endometriotic cells from patients with endometriosis, and inhibition of the BRAF pathway can significantly decrease proliferation in both epithelial and stromal endometriotic cells in vitro and in vivo\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27085458\n",
      "BRAF mutations occur frequently in testicular germ cell tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27084044\n",
      "The BRAFV600E antibody (clone VE1) IHC may show non-specific staining, but molecular assays may be useful for the diagnosis of unicystic ameloblastoma, in conjunction with clinical, radiological and histopathological features.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27082577\n",
      "The BRAF-mutated Colorectal Cancers ,in comparison to KRAS-mutated ones, are associated with a much worse prognosis for the afflicted patients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27080216\n",
      "Dabrafenib showed clinical activity in BRAF(V600E)-positive NSCLC. Our findings suggest that dabrafenib could represent a treatment option for a population of patients with limited therapeutic options\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27064992\n",
      "the prevalence and clinicopathological associations of BRAF V600E and TERT promoter mutations in Chinese PTC patients\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27062580\n",
      "our results suggest that the mutational spectrum of pediatric AF is more complex than in adult AF, being rich in AKT1 and BRAF, as well as CTNNB1 gene mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27048246\n",
      "we identify recurrent somatic BRAF alterations in high-grade colorectal NET and demonstrate rapid clinical improvement and tumor responses with a combination of BRAF- and MEK-directed therapies.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27041569\n",
      "These findings identify a key mechanism of tolerance to Ras-Raf pathway inhibitors and suggest that blocking either AMPK or autophagy in combination with these targeted inhibitors could increase tumor regression and decrease the likelihood of eventual recurrence.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27036313\n",
      "Increased staining for phosphorylated ERK1/2 does not correlate to BRAF or KRAS mutations in colorectal neoplasms.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27034263\n",
      "BRAF mutation may have different prognostic implications in early- and late-stage colorectal cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27033063\n",
      "The prognostic role of BRAF, PIK3CA mutations and ploidy in advanced CRC.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27028853\n",
      "Data indicate that BRAF inhibitor (BRAFi) have unique paradoxical ERK activation profiles.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27009410\n",
      "The incidence of conjunctival melanoma increased in Denmark over 50 years. The proportion of BRAF-mutated conjunctival melanoma was constant. BRAF mutations were identified as early events in conjunctival melanoma, associated with a distinct clinicopathological profile.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/27000992\n",
      "The additive effects given by gamma-secretase inhibitor to BRAF inhibitor are due to enhancement of induction of the senescent-like arrest, which is associated with decreased RB phosphorylation and CDK6 expression.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26997442\n",
      "Low incidence of BRAF mutations in adenocarcinomas of the ampulla of Vater suggest no major role in tumorigenesis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26997441\n",
      "BRAF inhibitor therapy-associated melanocytic lesions lack the BRAF V600E mutation and show increased levels of cyclin D1 expression.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26996308\n",
      "beta3-alphaC deletions are activating mutations in BRAF. BRAF deltaNVTAP confers CRAF- and dimer-independent activity and is resistant to vemurafenib.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26994902\n",
      "Study provides evidence of BRAF-KIAA fusion in disseminated glioneuronal lesions occurring in childhood and the first report of a BRAF V600E mutation in children with this disease, representing a potential therapeutic target.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26991344\n",
      "Our findings indicate that BRAF and KRAS mutations as well as mutation heterogeneity predict poor outcome in CRC patients subsequent to liver resections and might help guide treatment decisions.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26989027\n",
      "Our data suggest that KRAS, NRAS, and BRAF mutations predict response to cetuximab treatment in metastatic colorectal cancer patients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26980024\n",
      "Mutant BRAF represses E-cadherin expression, implicating a catalytic role for BRAF in epithelial-mesenchymal transition.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26980021\n",
      "There was no statistically significant association between BRAF or MAP2K1 mutation and anatomic site, unifocal versus multifocal presentation, or clinical outcome in Langerhans cell histiocytosis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26974965\n",
      "Results indicate that MAPK pathway inhibition leads to changes in the immunological properties of mutant BRAF melanoma cells.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26969876\n",
      "The coexistence of BRAF or RAS mutations enhanced the prognostic effects of telomerase reverse transcriptase (TERT) promoter mutations. Furthermore, TERT promoter mutations strengthened the predictions of mortality and recurrence by the ATA and TNM staging systems, particularly for high-risk patients with differentiated thyroid cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26960768\n",
      "The diagnostic classifier based on profiling of 13 microRNAs was proposed, with total estimated accuracy varying from 82.7 to 99% for different nodule types. Relative expression of six microRNAs appeared significantly different in BRAF(V600E)-positive samples compared to BRAF(V600E)-negative papillary carcinoma samples\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26959890\n",
      "Growth arrest is accompanied by MAPK-mediated serine/threonine phosphorylation and suppression of a variety of oncogenic drivers that resist treatment by B-Raf(V600E) kinase inhibitors, including ErbB members, c-Met, IGFR, IRS, STAT3 and Akt.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26959608\n",
      "Thus ERK5 signaling is unlikely to play a role in tumor cell proliferation downstream of KRAS or BRAF or in tumor cells with ERK5 amplification. These results have important implications for the role of ERK5 as an anti-cancer drug target\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26951110\n",
      "The present cohort identifies that the classic architecture with multicentricity and local recurrence are correlates of BRAF (V600E) harboring pediatric papillary thyroid carcinomas\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26950846\n",
      "The BRAFV600E mutation was significantly associated with central lymph node metastases in patients undergoing prophylactic central neck dissection when specifically controlling for preoperatively available clinicopathologic variables in all papillary thyroid cancer subtypes.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26945035\n",
      "This study demonstrated that when whole chromosome 7 gain accompanies the KIAA1549-BRAF fusion, the fusion likely arises first.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26943032\n",
      "This study, the largest on TERT mutation so far, demonstrates a significant role of BRAF V600E and TERT promoter mutations in the aggressiveness of papillary thyroid carcinoma, which is particularly robust and cooperative when the two mutations coexist.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26932501\n",
      "Results are the first to describe the presence of Wnt signaling pathway abnormalities, manifested by nuclear beta-catenin, in a subset, as well as the lack of BRAF(V600E) mutation in gliosarcoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26927447\n",
      "Braf mutations were extremely rare in pancreatic cancer, suggesting that they play a limited role in PC development.[review]\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26927026\n",
      "BRAF V600E mutations were found in the papillary craniopharyngiomas subgroup and were not detectable in papillary craniopharyngiomas samples.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26925650\n",
      "KRAS mutations are not Associated with Metastatic Colorectal Cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26925640\n",
      "BRAF mutations are associated with poor response to chemptherapy in Colorectal Peritoneal Carcinomatosis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26924424\n",
      "BRAF-V600E expression in primary nodular melanoma is associated with aggressive tumour features.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26912807\n",
      "BRAF V600E mutation predisposes papillary thyroid carcinoma cells toward invasive phenotypes\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26910894\n",
      "Mutant BRAF may, in part, drive the histologic progression of colorectal adenomas toward serrated histology\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26910217\n",
      "The rate of the BRAF V600E mutation in the pediatric population with papillary thyroid carcinoma is significantly lower than that seen in the adult population\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26892442\n",
      "KRAS and, infrequently, BRAF mutations are observed in a subset of small intestinal adenocarcinomas, and are associated with higher pT classification and more frequent pancreatic invasion\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26889698\n",
      "The rate of the BRAFV600E mutation increased significantly in papillary thyroid cancer diagnosed in Poland from 2000-2013\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26871894\n",
      "Positive status of BRAF(V600E) mutation was a significant predictor of multifocality (OR = 1.23; 95%CI = 1.14-1.32), extrathyroidal extension (OR = 2.23; 95%CI = 1.90-2.63), TNM stage (OR = 1.67; 95%CI = 1.53-1.81), lymph node metastasis (OR = 1.67; 95%CI = 1.45-1.93), vascular invasion (OR = 1.47; 95%CI = 1.22-1.79) and recurrence/persistence (OR = 2.33; 95%CI = 1.71-3.18) of Papillary Thyroid Carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26871591\n",
      "Apart from BRAF V(600)E, no other recurrent somatic mutation was identified in these hairy cell leukaemia exomes, thereby excluding additional acquired mutations as also prevalent at a near-universal frequency in this form of the disease.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26857243\n",
      "TERT promoter mutation is an independent predictor for distant metastasis of thyroid neoplasms, but ALK testing is not useful for clinical decision-making in Korean patients with a high prevalence of the BRAF V600E mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26848795\n",
      "The BRAF V600 mutations were significantly associated with AQP1 expression (P=0.014). Long-term follow-up indicated a reduced progression-free survival (P=0.036) and overall survival (P=0.017) for the AQP1-positive cutaneous melanoma patients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26838744\n",
      "BRAF(V600E) mutation is correlated with a lower expression of Na(+)/I(-) symporter in papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26835544\n",
      "BRAF mutation subclonality was associated with earlier disease stage in Papillary Thyroid Carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26826419\n",
      "Colorectal poorly differentiated neuroendocrine carcinomas frequently harbor BRAF mutations and are associated with poor overall survival.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26825960\n",
      "Specific inhibition of BRAF oncogene, MEK or p38 signaling was associated with decreases in DIO3 expression in papillary thyroid cancer cells\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26825657\n",
      "One of the most cited proteins in melanoma is BRAF (about 50-60 % of melanomas harbors activating BRAF mutations), for these the most common is a substitution of valine to glutamic acid at codon 600 (p.V600E)[review]\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26823860\n",
      "We demonstrated that the BRAF (V600E) mutation slightly correlated with the clinicopathological characteristics of papillary thyroid cancer in the Han population\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26814611\n",
      "A BRAF mutation, p.Val600Ala, was identified in 1 of 8,000 peripheral blood lymphocytes and 1 of 6,000 T lymphocytes from rheumatoid arthritis patients and in 1 of 12,500 peripheral blood lymphocytes and 1 of 12,500 T lymphocytes from controls\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26810733\n",
      "Our findings present EBI-907 as a potent and promising BRAF inhibitor, which might be useful in broader indications.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26810070\n",
      "BRAF, FGFR1, and MYB mutations occur at high frequency and align with morphology of low-grade neuroepithelial tumors\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26808395\n",
      "Alternative pathways through mutations in BRAF gene are associated with the progression of Colorectal polyps to cancer and may provide insights into the genetic characteristics of skirts.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26807515\n",
      "MC1R status is associated with BRAF(V600E), BRAF(V600K), and NRAS mutations in cutaneous melanomas\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26802240\n",
      "BRAF mutation is playing an important role in the pathogenesis of pyogenic granuloma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26799289\n",
      "BRAF mutation is associated with colon cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26796506\n",
      "Letter: report frequent BRAF V600E mutations in metanephric stromal tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26790143\n",
      "Conclude that PRIMA-1(Met) through its ability to directly reactivate p53, sensitises (V600E/K)BRAF-positive melanoma cells to BRAF inhibitors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26787892\n",
      "results reveal a common BRAF(V600E)-directed transcriptional regulatory pathway that mediates epigenetic silencing in unrelated solid tumors and provide strong support for an instructive model of oncoprotein-directed epigenetic silencing\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26775732\n",
      "BRAF mutations are associated with response to therapy in metastatic colorectal cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26758762\n",
      "Findings suggested that BRAF-activated noncoding RNA may contribute to hepatocellular carcinoma initiation and progression.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26753950\n",
      "olfactory neuroepithelial progenitor cells with the genetic heritage of bipolar I disorder were more sensitive to glutamate induced apoptosis. Under expression of the BRAF gene and protein, which plays a role in regulating the pro-survival MEK/ERK signaling pathway, may contribute to this apoptotic sensitivity.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26750638\n",
      "BRAF V600E inhibition stimulates AMP-activated protein kinase-mediated autophagy in colorectal cancer cells.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26750533\n",
      "The significant association of SLP-2 overexpression with unfavorable clinicopathological characteristics and BRAFV600E mutation indicates that SLP-2 may have a role in aggressiveness of BRAF-mutated papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26749005\n",
      "BRAF mutation is associated with thyroid neoplasms.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26734696\n",
      "BRAF V600E mutation is associated with Langerhans cell histiocytosis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26733165\n",
      "study suggests an influence of overweight BMI on the status of BRAF (V600E) in patients with PTC, whereas the underlying mechanism need to be further investigated\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26732095\n",
      "This study discovered oncogenic BRAF deletions with a distinct activation mechanism dependent on the BRAF dimer formation in tumor cells.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26718898\n",
      "It was suggested that somatic point mutations in BRAF, CDKN2A and PI3KCA do not participate in the oncogenesis of Medullary thyroid carcinoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26718882\n",
      "four cases harbored the BRAF-V600E mutation, one case harbored the BRAF-G606R mutation, and three cases harbored deletions in exon 19 of EGFR\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26711930\n",
      "Clinical data suggest that BRAF mutations define specific subsets of patients with NSCLC; while their oncogenic nature is yet to be established in lung cancer, especially for non-V600E mutations, the value of BRAF mutations to predict the efficacy of targeted agents remains unclear.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26711586\n",
      "TERT promoter mutations have a limited role in pediatric thyroid carcinoma, but the BRAFV600E mutation may have a role in recurrence in pediatric patients\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26710756\n",
      "BRAF mutation is not associated with pheochromocytoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26695089\n",
      "BRAFV600E status during melanoma progression was evaluated in a cohort of 54 patients with at least paired-samples. These findings suggest that only VE1-negative tumours would be genotyped to detect other BRAFV600 mutations, and that either primary melanoma or metastasis can be tested using immunohistochemistry, according to the material available.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26691448\n",
      "These results revealed differences in the genetic profiles of KRAS, NRAS, PIK3CA and BRAF at mutation hotspots between Chinese CRC patients and those of Western countries.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26684240\n",
      "BRAF V600E mutation is associated with resistance to pazopanib in gastroenteropancreatic neuroendocrine tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26678033\n",
      "BRAF mutation is associated with melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26671072\n",
      "BRAF mutational status correlates with recurrence of papillary thyroid microcarcinoma [review; meta-analysis]\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26668268\n",
      "Actin remodeling confers BRAF inhibitor resistance to melanoma cells through YAP/TAZ activation\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26646323\n",
      "Data show that Griffipavixanthone (GPX), a dimeric xanthone isolated from Garcinia esculenta, is a B-RAF and C-RAF inhibitor against esophageal cancer cells.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26643848\n",
      "Twenty-three percent of patients with V600E- and 43% of patients with K601E-mutant melanomas presented with nodal disease at diagnosis compared to just 14% of patients with BRAF wild-type tumors (P = 0.001 and 0.006, respectively). Overall, these mutations represent a significant minority of BRAF mutations, but have distinct clinicopathological phenotypes and clinical behaviors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26632889\n",
      "The presence of the BRAFV600E mutation is independently associated with high F-18 FDG uptake on preoperative PET/CT in patients with overt papillary thyroid cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26630683\n",
      "BRAF-V600 mutation inconsistencies of up to 14.5% can be seen between the primary and metastatic foci in melanoma cases. These findings should be taken into account when planning targeted therapy and deciding on treatment responsiveness/unresponsiveness.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26625260\n",
      "identification of 7 BRAF-induced genes that are specific for BRAF V600E-driven papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26623721\n",
      "Data show that dasatinib induced DNA damage and activated DNA repair pathways leading to senescence only in the kinase-inactivating BRAF kinase (BRAF) mutations (KIBRAF) non-small cell lung cancer (NSCLC) cells.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26616508\n",
      "use of sorafenib has been ineffective in the management of advanced Colorectal cancer (CRC) patients with KRAS mutation, combination of selective BRAF inhibitors plus EGFR inhibitors may represent a good therapeutic strategy in BRAF-mutant CRC.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26616061\n",
      "Recent reports show a significant radiosensitization of the irradiated healthy tissue in patients with melanoma after the combination of radiotherapy and BRAF(V600) inhibitors, evoking concern in clinical practice\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26613644\n",
      "The findings suggest that the presence of the BRAFV600E mutation and loss of p16 expression accelerate the growth rate of melanomas in vivo leading to larger melanocytes that are more frequently arranged in nests.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26608120\n",
      "Report incidence and heterogeneity of genetic changes driving BRAF inhibitor resistance in melanomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26600545\n",
      "PIK3CA mutations were observed in 32% (8) of the 25 breast cancer tissues examined, Sequencing of exon 2 of KRAS suggested that 20% (5) of the 25 samples harbored a mutation and 16% (4) of BRAF harbored a mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26600396\n",
      "the V600E BRAF mutation occurred in about half of melanoma patients; it was associated with earlier manifestation of melanoma and likely with more aggressive clinical features.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26598713\n",
      "Chronic lymphocytic thyroiditis was an independent predictor for less aggressiveness in conventional papillary thyroid carcinoma patients regardless of BRAF mutation status.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26597176\n",
      "The patient's resected brain tumor is BRAF V600E mutated, NRAS wild type (WT), and TERT C250T mutated. The patient is a carrier of germline variants in immunomodulatory loci associated with prolonged survival.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26584635\n",
      "Data indicate that among classic and follicular variant papillary thyroid carcinomas (PTCs), mutation of proto-oncogene protein B-raf (BRAF(V600E)) was significantly associated with the smaller size.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26582795\n",
      "Characterization of TP53 as a downstream effector of miR-3151 provides evidence for a causal link between BRAF mutations and TP53 inactivation\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26582644\n",
      "Cooperation of BRAF(F595L) and mutant HRAS is associated with histiocytic sarcoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26575603\n",
      "In the validation-set (508 pts, RAS wt: 262 (51.6%), BRAFV600E mutated: 49 (9.6%)), right-sided primary, female gender and mucinous histology were confirmed as independent predictors of BRAFV600E mutation with high accuracy\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26575115\n",
      "NRAS codon 61 is the most frequent genetic alteration in this acromegaly series with Differentiated Thyroid Cancer . Since acromegalic patients have lower prevalance of BRAF V600E mutation, BRAF V600E mutation may not be a causative factor in development ofDifferentiated Thyroid Cancer in acromegaly.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26563980\n",
      "The vast majority of these tumors harbor the oncogenic BRAF V600E mutation. [review]\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26562024\n",
      "Case Report: BRAF kinase domains are a clinically important genomic alteration and therapeutic target.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26562020\n",
      "Data indicate that mutations in PTEN phosphatase A167T and NRAS protein Q61L, and proto-oncogene protein BRAF V600E were detected in melanoma cell line.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26541605\n",
      "Vitamin C is selectively toxic to cells with mutant KRAS or BRAF alleles.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26530529\n",
      "Data indicate that tumors with proto-oncogene proteins BRAF or KRAS mutations were in correlation with elevated serum level of carbohydrate antigen (CA19-9) and carcinoma embryonic antigen (CEA).\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26521469\n",
      "High frequency and specificity of the V600E BRAF mutation make it a useful biochemical marker for selecting the right surgical strategy for thyroidectomy.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26521063\n",
      "that BRAF sequencing has been used to discriminate between dedifferentiated papillary thyroid carcinoma and tumor to tumor metastasis\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26513490\n",
      "Both Glut1 and GLUT3 are strongly expressed by papillary thyroid carcinomas, and their expressions were significantly associated with the presence of the BRAF V600E mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26512781\n",
      "BRAF mutation is associated with poor response to cetuximab in colorectal carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26511315\n",
      "Apart from these distinct Cdc37/Hsp90 interfaces, binding of the B-Raf protein kinase to the cochaperone is conserved between mammals and nematodes.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26504080\n",
      "B-Raf(V600E) mutation in metastatic melanoma cells up-regulated tissue factor expression on cell membranes and promoted thrombin production\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26500331\n",
      "BRAF mutation is frequent in early-onset colorectal cancer in Taiwan and is associated with a poorly differentiated histology, a serrated precursor polyp, focal signet ring cell differentiation, lack of microsatellite instability and a poor prognosis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26498143\n",
      "BRAFV600 mutations are associated with response to BRAF inhibitors in metastatic melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26496853\n",
      "BRAF-mutated traditional serrated adenoma (TSA) is distinct from KRAS-mutated TSA in predisposing to the acquisition of subsequent serrated neoplasia\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26496026\n",
      "Monoclonal antibody VE1 immunohistochemistry predicts BRAF V600E mutation status and clinical outcome in colorectal cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26461266\n",
      "The presence or absence of the BRAF mutation and TERT promoter polymorphism was not significantly correlated with survival in Papillary thyroid carcinoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26460303\n",
      "BRAF V600-Mutation is associated with Colorectal Cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26457492\n",
      "The presence of BRAF mutation in fine-needle aspiration cytology specimens of nodular goitre may be useful in the assessment of oncological risk.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26454767\n",
      "PXA in adults PXA may present features distinct from pediatric PXA. Anaplastic features and BRAF mutation may potentially identify specific subgroups with distinct prognoses\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26454140\n",
      "Langerhans cell histiocytosis and Erdheim-Chester disease, both with cutaneous presentations, and papillary thyroid carcinoma all harboring the BRAF(V600E) mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26448939\n",
      "Patients with multifocal PTC whose largest tumor is BRAF-negative can have smaller tumors that are BRAF-positive.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26446943\n",
      "BRAF mutations in cfDNA are detectable in >75% of late-stage melanoma patients with BRAF mutation-positive tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26446234\n",
      "RAS and BRAF wild-type status could help select an elderly and unfit population that could benefit from anti-epidermal growth factor receptor single agent therapy.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26440707\n",
      "Levels of BRAF(mutant) and NRAS(mutant) ctDNA were determined using droplet digital PCR (ddPCR) assays. Among patients with samples available prior to treatment initiation ctDNA and LDH levels were elevated in 12/15 (80%) and 6/20 (30%) (p = 0.006) patients respectively\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26438153\n",
      "Among 33 BRAF wild-type colorectal carcinomas, 16 had no or weak staining, whereas 15 (45%) had heterogeneous staining. In contrast with colorectal carcinoma, Bond and Ventana VE1 IHC in melanoma and PTC were highly concordant with sequencing results\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26433819\n",
      "Combination of a BRAF inhibitor plus a MEK inhibitor adds a clear benefit over monotherapy with BRAF inhibitor in unresectable or metastatic cutaneous BRAF Val600-mutation-positive melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26426340\n",
      "BRAF Mutation is associated with response to therapy in Advanced Melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26425792\n",
      "BRAF-mutated conjunctival melanoma (CM) were frequent in younger patients and were rare in tumors involving the extrabulbar conjunctiva.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26422023\n",
      "BRAFK601E mutant thyroid tumors show better clinical outcomes than BRAFV600E positive tumors\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26414224\n",
      "Case Report: combined \"infiltrating astrocytoma/pleomorphic xanthoastrocytoma\" harboring IDH1 R132H and BRAF V600E mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26405815\n",
      "Systems Analysis of Adaptive Responses to MAP Kinase Pathway Blockade in BRAF Mutant Melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26403329\n",
      "consideration needs to put on multiple targets when deciding molecular target therapies for patients with BRAF V600E mutated thyroid carcinoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26399561\n",
      "Driver mutations are rare in mutational hotspots of BRAF, NRAS, KIT, and GNAQ/GNA11 in oral mucosal melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26392334\n",
      "A constitutive active MAPK/ERK pathway due to BRAFV600E mutation positively regulates aryl hydrocarbon receptor pathway in papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26392102\n",
      "BRAF V600-Mutation is associated with Colorectal Cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26384810\n",
      "BRAF V600E-mutation is associated with response to therapy in glioma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26384551\n",
      "Dual inhibition of BRAF(V600E) and MEK reduced but did not prevent SW1736 invasion.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26381028\n",
      "Case Report: erythematous rash as a result of BRAF inhibitor therapy in advance melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26376292\n",
      "BRAF and KRAS mutations show together a high prevalence in stage II and III MSI colon cancer and, when combined, are associated with poor survival compared to dWT cancers, which status confers an excellent cancer-specific survival.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26362194\n",
      "In three cases of papillary carcinoma arising in struma ovarii (PSCS), novel BRAF and KRAS mutations were identified in two of three tumors suggesting that mutations in PCSO may differ from those commonly identified in papillary carcinoma of the eutopic thyroid.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26359417\n",
      "BRAF V600E mutation in non-tumoral surrounding tissue in patients with colorectal cancer may be used as a valuable marker to foresee clinical outcome or a possible recurrence.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26353041\n",
      "BRAF mutation is associated with melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26351322\n",
      "combined pan-RAF and MEK inhibition can overcome intrinsic and acquired resistance to single-agent RAF/MEK inhibition, supporting dual pan-RAF and MEK inhibition as a novel therapeutic strategy for BRAF- and KRAS-mutant cancers\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26343583\n",
      "LY3009120 also inhibits various forms of RAF dimers including BRAF.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26343582\n",
      "Tumors with non-V600E BRAF mutants are insensitive to these drugs.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26339422\n",
      "Report BRAF V600 mutation detection in a large cohort of clinical samples of cutaneous melanoma metastases to the lymph nodes.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26321697\n",
      "no BRAF V600E mutations were found in PMSAs, but KIAA1549-BRAF fusion was identified in intermediate pilomyxoid tumors\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26319365\n",
      "The lesions designated as KAs and BRAF inhibitor-associated verrucous keratoses had a similar mutational profile.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26318033\n",
      "AKT3 has a role in prostate cancer proliferation through regulation of Akt, B-Raf, and TSC1/TSC2\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26314551\n",
      "BRAF fusions are rare driver alterations in a wide variety of malignant neoplasms, but enriched in Spitzoid melanoma, pilocytic astrocytomas, pancreatic acinar and papillary thyroid cancers.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26306423\n",
      "BRAF mutations seem to occur exclusively in the epithelial, but not in the stromal component\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26305188\n",
      "Report BRAF mutations in selected cohort of patients with pulmonary metastases of malignant melanoma and prognostic implications.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26299805\n",
      "KRAS and BRAF oncogenes have roles in colorectal cancer development and therapy resistance [review]\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26299074\n",
      "BRAF codon 600 mutations not found in Iranian prostate adenocarcinoma patients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26297254\n",
      "NRASQ61R and BRAFV600E immunohistochemistry coupled with next-generation sequencing allow detection of mutations in melanoma challenging samples.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26287849\n",
      "BRAF V600 appears to be a targetable oncogene in some, but not all, nonmelanoma cancers. Preliminary vemurafenib activity was observed in non-small-cell lung cancer and in Erdheim-Chester disease and Langerhans'-cell histiocytosis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26285159\n",
      "Data indicate that BRAFV600E, P-cadherin and cadherin 6 protein expressions were correlated with one another.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26284586\n",
      "Data suggest that combination of proto-oncogene protein B-raf (BRAF) and mTOR serine-threonine kinase (mTOR) inhibition forms the basis of a treatment regimen of thyroid cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26282084\n",
      "presence of BRAF mutations in melanoma associated with younger age\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26274032\n",
      "Letter/Case Report: BRAF mutations in metanephric adenofibroma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26271724\n",
      "BRAF V600E-mutated microcarcinomas represent a distinct biological subtype\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26269601\n",
      "neuregulin 1 promotes compensatory ErbB3 receptor signaling in mutant BRAF melanoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26268700\n",
      "the predictive value of BRAF mutation for central lymph node metastasis in papillary thyroid carcinoma was found to be related to the tumor size.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26259532\n",
      "BRAF mutations are associated with Papillary Thyroid Cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26258321\n",
      "Compared with RAS or PAX8/PPARG-positive TCs, BRAFV600E or RET/PTC-positive Thyroid cancers were more often associated with stage III/IV disease and recurrence.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26240026\n",
      "Combination of mutant-specific BRAF and CD117 ICC with cytopathology may facilitate the PTC-risk stratification in thyroid FNAB specimens.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26232865\n",
      "Despite its high specificity, our meta-analysis shows that BRAF(V600E) mutation analysis has a low sensitivity in diagnosing papillary thyroid cancer in thyroid nodules\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26230187\n",
      "BRAF mutations are associated with follicular variant of thyroid papillary carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26225944\n",
      "BRAF mutations are infrequent, whereas C-KIT and NRAS mutations are seen with higher frequency in vulvar melanomas than melanomas of other sites.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26223933\n",
      "Results revealed that in patients with papillary thyroid microcarcinoma (PTMC), BRAF mutation is associated with tumor size, multifocality and aggressive features and may be used as a predictive factor for prognosis of PTMC. [meta-analysis]\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26215382\n",
      "Data suggest that core-needle biopsy (CNB) + B-Raf proto-oncogene protein BRAF(V600E) mutation analysis can reduce rates of preventable diagnostic surgery.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26215201\n",
      "BRAFV600E Mutation Status in obese Patient is associated with Papillary Thyroid Cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26214416\n",
      "This study sought to investigate the correlations of V-raf murine sarcoma viral oncogene homolog B1 (BRAF) gene mutations with the clinicopathologic features of papillary thyroid carcinoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26208946\n",
      "BRAF (V600) -mutation is associated with metastatic melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26208478\n",
      "Findings suggest that triple therapy directed against BRAF/MEK/ErbB3 may be able to provide durable control of BRAF mutated metastatic melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26206478\n",
      "Study found that BRAF alterations do not appear to play a prominent role in pediatric oligodendroglioma, and lack of BRAF fusions or BRAF p.V600E separate these tumors from several other pediatric low-grade gliomas\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26202550\n",
      "BRAF Mutations are associated with Lung Adenocarcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26197238\n",
      "Studies indicate that more than half of all Erdheim-Chester disease (ECD) patients carry the proto-oncogene protein B-raf mutation BRAF(V600E) and treated with vemurafenib, a BRAF inhibitor, which has proven highly beneficial.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26191315\n",
      "Case Report: oncocytic papillary thyroid carcinoma with lymphoid stroma (Warthin-like tumor) with BRAF V600E and V600K mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26190162\n",
      "Data show that B-Raf proto-oncogene (BRAF) V600E mutation was identified in 4 of 27 thyroid nodule patients with isthmic lesion.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26189429\n",
      "Angiogenic/cachectic and pro-inflammatory/immune response factors could play a crucial role in BRAF(V600E)-positive human anaplastic thyroid carcinoma aggressiveness.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26187369\n",
      "Cytomorphologic features can help select nodules for the BRAF(V600E) mutation test among thyroid nodules read as \"suspicious for malignancy\" on cytology.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26182332\n",
      "Letter/Case Reports: BRAF-mutant colorectal cancers with axillary lymph node involvement.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26182194\n",
      "Report acute kidney injury in patients receiving BRAF inhibitors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26181555\n",
      "real-time PCR cycle threshold values for the BRAFV600E mutation obtained from fine needle aspirates can be associated with central lymph node metastasis in papillary thyroid microcarcinoma patients\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26181250\n",
      "Retrospective analysis suggesting that nivolumab has similar efficacy and safety outcomes in patients with wild-type or mutant BRAF, regardless of prior BRAF inhibitor or ipilimumab treatment.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26172302\n",
      "BRAF(V600E) mutation induces MGL ligand expression, thereby providing a direct link between oncogenic transformation and aberrant expression of immunosuppressive glycans in colorectal neoplasms.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26165597\n",
      "The RAS-binding domain of human BRAF protein exhibits allosteric conformational changes upon binding HRAS.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26160882\n",
      "Colon cancers from Asians have a lower rate of BRAF mutations than blacks or whites.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26154146\n",
      "BRAF mutation detection in cell block material is feasible and highly specific for papillary thyroid carcinoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26153495\n",
      "BRAF mutations are associated with metastatic colorectal cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26146664\n",
      "Report 3-fold increased risk of death for higher-risk melanomas harboring NRAS or BRAF mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26145760\n",
      "v-raf murine sarcoma viral oncogene homolog B (BRAF) is preferentially mutated in proximal colon cancers.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26145173\n",
      "Results show that active BRAF upregulates HMGCL via Oct-1 in cancer cells. HMGCL selectively promotes BRAF V600E-dependent phosphorylation and activation of MEK1 pathway by controlling intracellular levels of its product acetoacetate.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26143635\n",
      "Studies indicate that concurrent inhibition of proto-oncogene protein B-raf (BRAF) and Map kinase kinase (MEK) improved the most effective therapeutic modality as compared as single BRAF or MEK inhibition for patients with metastatic melanoma (MM).\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26143373\n",
      "Data suggest that the two strands of the BRAF promoter region, the G-rich strand and the C-rich strand, fold into a predominant antiparallel G-quadruplex and into an i-motif, respectively, and that they can coexist at nearly physiological conditions.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26138035\n",
      "BRAF mutation frequencies depended on histological subtype and localization of primary melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26125698\n",
      "BRAF overexpression is associated with BRAF V600E mutation in papillary thyroid carcinomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26125673\n",
      "In 19 cases of papillary tumor of the pineal region, there was a lack of BRAF-V600E mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26123241\n",
      "Case Report: melanoma with BRAF mutation in circulating cell-free DNA despite no detectable mutation in the primary lesion.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26122804\n",
      "We show for the first time that this important pediatric tumor may harbor the oncogenic BRAFV600E mutation, providing the first insights to their personalized treatment.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26121270\n",
      "Tissue micro array availability, BRAF mutation and KRAS mutation were all independent prognostic factors for colorectal cancer survival.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26120069\n",
      "The BRAF mutation is a possible indicator for determining the extent of thyroidectomy required but not for the extent of lymph node dissection and prognosis in patients with conventional papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26115961\n",
      "BRAF mutations were associated with central nervous system tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26110571\n",
      "Report BRAF mutations and PD-L1 expression in disseminated histiocytoses.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26105190\n",
      "Presence of BRAF V600E associated with aggressive tumor features in Papillary thyroid carcinoma, including invasion, metastasis, advanced TNM stage at presentation, low response to radioiodine treatment, recurrence, and tumor-related mortality.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26102513\n",
      "Given the high prevalence of lung cancer and the availability of targeted therapy, Chinese lung ADC patients without EGFR and KRAS mutations are recommended for HER2 and BRAF mutations detection, especially for those never smokers\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26090869\n",
      "BRAF, NRAS and KRAS gene mutations in plasma cell dyscrasias may have a role MEK-ERK pathway activation\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26084614\n",
      "LOH and TP53 mutations detected in lip squamous cell carcinoma and actinic cheilitis may be associated with tumorigenesis, whereas BRAF mutation does not seem to significantly contribute to LSCC pathogenesis\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26084290\n",
      "TRAP1 is a downstream effector of BRAF cytoprotective pathway in mitochondria and TRAP1 targeting may represent a novel strategy to improve the activity of proapoptotic agents in BRAF-driven CRC cells.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26083571\n",
      "This study confirmed the high frequency of KIAA1549:BRAF fusion in Pilocytic Astrocytomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26083553\n",
      "BRAFV600E expression is homogeneous in melanoma tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26080065\n",
      "BRAF protein immunohistochemistry on fine needle aspiration can be important in the diagnosis of papillary thyroid carcinoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26075701\n",
      "According to results, oral benign peripheral nerve sheath tumours have a low LOH rate, but P53 locus alteration is occasionally found. Additionally, BRAF V600E mutation is either not relevant to the molecular pathogenesis of this group of lesions of the oral cavity, or may occur at very low rates.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26071465\n",
      "detection of BRAF V600E by immunohistochemistry is useful in the distinction of hairy cell leukemias from other splenic-based lymphomas\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26066373\n",
      "BRAF-V600E mutations occur predominantly in female smokers with adenocarcinomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26055532\n",
      "Our data lead us to hypothesize that TERT promoter and BRAF mutations cooperate in cutaneous melanoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26045855\n",
      "Case Report: BRAFV600 mutant non-small-cell lung cancer which progressed on vemurafenib therapy.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26036358\n",
      "BRAFV600E expression in melanocytes induces Schwannian differentiation in vivo\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26032958\n",
      "BRAF protein play a role in the mitochondrial fragmentation in melanoma patients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/26014474\n",
      "BRAF V600E immunostaining is a helpful marker for pediatric metanephric adenoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25988212\n",
      "With respect to diagnostic potential, results obtained using the BRAF(V) (600E) mutation test combined with cytological examination were not significantly different from those obtained with cytological examination only.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25985019\n",
      "we identified a new SND1-BRAF fusion that appeared to be present in a subpopulation of tumor cells.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25975986\n",
      "reviews the current knowledge on the use and implications of BRAF mutational status in colorectal tumors, in order to define its present role in the clinical practice\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25970686\n",
      "KIT-mutated patients had a worse outcome than PDGFRA-mutated or triple-negative (KIT, PDGFRA, BRAF wild-type) cases\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25957797\n",
      "BRAF immunohistochemistry(IHC) was strongly concordant with BRAF mutation test and had high diagnostic accuracy in BRAF mutation analysis of Papillary thyroid carcinoma.[review; meta-analysis]\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25952101\n",
      "BRAF V600E Mutation is associated with Melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25950823\n",
      "Somatic BRAF mutation was found in a patient with syringocystadenoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25948295\n",
      "Data show that proto-oncogene protein B-raf (BRAF) inhibition reduces melanoma glucose uptake per cell, but that this change is no longer significant following normalization for cell volume changes\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25938346\n",
      "BRAF V600E mutation can be used as a supplementary molecular marker to aid in the diagnosis of Hairy cell leukaemia\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25937618\n",
      "BRAF V600E Mutation is associated with papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25937573\n",
      "The patient carrying a concomitant BRAF mutation in temporal gangliogliomas and focal cortical dysplasia fell into Engel Class II.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25929517\n",
      "The aim of this study was to evaluate the prognostic role of MMR status, BRAF mutations and specific KRAS point mutation in 762 patients in Chinese population, and several clinicopathologic features to better stratify colorectal cancer patients\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25922907\n",
      "RNA expression profiles were compared between conventional BRAFwild type and BRAFmutation papillary thyroid carcinomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25920006\n",
      "Studies suggest that the role of tumor biomarker V600E mutation of the BRAF proto-oncogene to detect or exclude cancers in patients with fine-needle aspiration (FNA) reports is marginal and should be reconsidered in guidelines.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25916409\n",
      "Results indicated that rs3748093*A single nucleotide polymorphisms (SNPs) of BRAF proto-oncogene (BRAF) was significantly correlated with an increased risk of papillary thyroid carcinoma (PTC) in a Chinese population.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25911848\n",
      "Report increased frequency of BRAF proto-oncogene hot spot mutation V600E in cohort of colorectal cancer patients from Ahvaz City, southwest Iran.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25908244\n",
      "Following B-RAF expression, MIR31HG is located mainly in the cytoplasm.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25900832\n",
      "BRAF-induced tumorigenesis is IKKalpha-dependent but NF-kappaB-independent\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25899783\n",
      "BRAF V600 mutation is associated with melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25899612\n",
      "This review will focus on the science and clinical findings related to targeted therapies that inhibit BRAF or MEK as well as the immunotherapies that block the CTLA-4 or PD-1 pathways\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25899003\n",
      "associate higher expression of the ligand-receptor axis of TFF2 and CXCR4 with BRAF V600E-mutant colon cancer (P = 3.0 x 10(-3) and 0.077, respectively for TCGA; P = 3.0 x 10(-8) and 5.1 x 10(-7) for CIT)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25890285\n",
      "A complex mechanism driven by mutation BRAF (V600E) on melanoma tumorigenesis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25888143\n",
      "Histopathological prognostic markers (Breslow thickness, mitotic index, ulceration, tumor infiltrating lymphocytes pattern) did not show any differences depending on BRAF V600E mutational status\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25886136\n",
      "Among 264 patients, mutations in KRAS exon 2, KRAS exons 3 or 4, NRAS, BRAF and PIK3CA were detected in 34.1%, 3.8%, 4.2%, 5.4% and 6.4%, respectively. Thus, a total of 12.1% of patients without KRAS exon 2 mutations had other RAS mutations\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25885250\n",
      "BRAF V600E mutation is associated with glioblastoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25884297\n",
      "Tumor dissemination in colon cancer patients is less likely to occur with the BRAF mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25870264\n",
      "Multifunctional bioscaffolds for 3D culture of melanoma cells reveal increased MMP activity and migration with BRAF kinase inhibition.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25870252\n",
      "The presence of TC was significantly associated with TERT promoter and BRAF mutations. BRAF did not influence patient outcome.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25868080\n",
      "The increased activity of the V600E mutant is twofold: increased flexibility of the A-loop which likely promotes the release of the products following phosphorylation of the substrate and an increased energy barrier between the active and inactive state.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25862899\n",
      "BRAF V600E mutation might be associated with right-sided tumors and subsequently related unexplained iron-deficiency anaemia (IDA) at presentation\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25854387\n",
      "The BRAFT1799A mutation was found in 38 cases (42.7%).\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25854168\n",
      "The SMOF412E mutation was not detected in ameloblastoma. The BRAFV600E-activating mutation is a common event in ameloblastomas, occurring regardless of site or histological type. This mutation is also detected in odontogenic carcinomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25851630\n",
      "BRAF mutations often affect a limited fraction of transformed metastatic colorectal cancer cells.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25843629\n",
      "Study reports that mice engineered to overexpress either the full-length murine B-Raf pseudogene Braf-rs1 and its human ortholog, BRAFP1, elicit their oncogenic activity, at least in part, as competitive endogenous RNAs (ceRNAs) that elevate BRAF expression and MAPK activation in vitro and in vivo.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25837167\n",
      "findings suggest that the BRAF(V600E) mutation can be detected using a PNA clamp real-time PCR in the blood of PTC[ papillary thyroid carcinoma ] patients with lung metastasis\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25832798\n",
      "these results may not only indicate some future applications of inhibitors targeting B-Raf(v600e), but also benefit B-Raf(v600e) harboring cancer patients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25820214\n",
      "BRAF V600E mutation is associated with differentiating Rathke's cleft cyst with squamous metaplasia from papillary craniopharyngioma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25819940\n",
      "BRAF mutation in cutaneous malignant melanoma plays an important role in the development of skin cancer in Asians. population.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25818616\n",
      "The most important implication of these findings is that we could begin to treat patients with the BRAF V600E and CDKN2A alteration differently when they are first diagnosed than those with a lower risk for secondary high-grade glioma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25817073\n",
      "This work supports the fact that BRAF V600 mutation is not implicated in meningioma tumorigenesis\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25815786\n",
      "No mutations in the BRAF gene were identified in patients with gastric cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25797743\n",
      "Preoperative targeted therapy of advanced BRAF-mutant melanoma is feasible, well tolerated, induces brisk tumor responses, and facilitates correlative science.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25795007\n",
      "oncogenic activation of BRAF allows tumor cells to co-opt an evolutionarily conserved MHC-I trafficking pathway as a strategy to facilitate immune evasion.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25794798\n",
      "Chitosan nanoparticle-mediated BRAF siRNA interference evidently reduced the invasion capacity of gastric cancers.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25794445\n",
      "Pediatric oligodendrogliomas (pODGs) can harbor the KIAA1549-BRAF fusion with aberrant MAPK/ERK signaling, and there exists an option of targeting these pathways in such patients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25794135\n",
      "By this integrated approach, we found that patients with BRAF V600E mutation responded very well to broad acting drugs and there was no relation to prognosis in early-stage myeloma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25784606\n",
      "Among the 779 cases, 150 cases were positive for BRAF (V600E) staining, including 38 (of 611, 6%) CRCs, 102 (of 127, 80%) PTCs and 10 (of 41, 24%) malignant melanomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25767210\n",
      "The study demonstrates the activating BRAF mutation (V600E), which is found in multiple human cancers, is a driver of canine invasive cell carcinoma of the bladder, and highlights a urine-based test for quick diagnosis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25767048\n",
      "BRAF mutation was frequently detected in younger patients, in thin melanomas, and in melanomas with less ulceration. As BRAF and NRAS mutations are rare in Taiwan, BRAF- or NRAS-targeted therapies may be effective only for selected Taiwanese melanoma patients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25766129\n",
      "Our results indicate that the mutations of BRAF and KIT exist in Japanese melanoma patients, however, the cell growth signaling may be regulated by not only these mutated genes, but by other unknown regulatory factors, which may affect the prognosis of melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25762352\n",
      "Radiotherapy with concomitant BRAF inhibitor therapy is feasible with an acceptable increase in toxicity. Vemurafenib is a more potent radiosensitizer than dabrafenib.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25755776\n",
      "No association was established between BRAF V600E mutation and regional lymph node metastasis in papillary thyroid carcinoma in Chinese patients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25752754\n",
      "These tumors showed a markedly better prognosis, with molecularly PXA-like tumors frequently harboring BRAF V600E mutations and 9p21 (CDKN2A) homozygous deletion.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25752325\n",
      "Results suggest that the presence of a BRAF mutation does not necessarily 'drive' more rapid tumour growth but is associated with poorer MSS in patients with early-stage disease\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25749811\n",
      "BRAF mutation is not associated response to chemotherapy in melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25746038\n",
      "genetic association studies in populations in Ireland and Belgium: Data suggest that frequency of mutations in BRAF (specifically the V600E mutation) vary by demographic location.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25736029\n",
      "No BRAF V600E mutations were seen in this cohort of non-infiltrative, non-invasive follicular variant of papillary thyroid carcinoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25735579\n",
      "A pathogenic BRAF(V600E) mutation was identified in a patient with Erdheim-Chester disease.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25729732\n",
      "Proto-Oncogene Proteins B-raf V600E mutation analysis is considered to be the most useful diagnostic tool for differentiating hairy cell leukemia from related lymphomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25724524\n",
      "These findings enhance our understanding of factors cooperating with BRAF inhibition that accelerate keratinocyte oncogenesis as well as broaden the knowledge base of multifactorial mediators of cancer in general.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25712893\n",
      "BRAF is minimally prognostic in papillary thyroid carcinoma. However, prevalence of the BRAF mutation is 70% in the general population, providing the opportunity for targeted therapy.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25710724\n",
      "Data show that licochalcone A (LicoA) suppresses solar UV-induced cyclooxygenase (COX-2) expression by acting as a potent inhibitor of enzymes PI3K, MEK1, and B-Raf.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25710585\n",
      "mutation is associated with distinct clinical and histopathologic features of colonic carcinomas\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25706985\n",
      "Trametinib alone caused upregulation of p-AKT in BRAF non-V600 mutated cells.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25704541\n",
      "Mutated BRAF mutant protein was detected in 53% of the bile duct adenomas and in none of the cases of bile duct hamartomas\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25702102\n",
      "All four tumors that recurred were LN+, with infiltrative borders, and lacked the BRAF mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25690538\n",
      "Suggest that continuing vemurafenib treatment beyond progression may be beneficial in BRAF V600 mutated advanced melanoma patients, who prior to progression responded to vemurafenib.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25689095\n",
      "BRAF mutations in Non-small cell lung cancer are more likely in Adenocarcinoma, and BRAF V600E mutations are more frequent in women and never smokers.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25688918\n",
      "mutated KRAS and mutated BRAF seem to be prognostic factors in patients with Colorectal cancer who undergo lung metastasectomy.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25685929\n",
      "analysis of BRAF 3'UTR isoforms in melanoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25674762\n",
      "Aberrant expression of A-, B-, and C-RAF, and COT is frequent in PTC; increased expression of COT is correlated with recurrence of PTC.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25673558\n",
      "Review/Meta-analysis: findings support BRAF mutation assessment before initiation of treatment with anti-EGFR monoclonal antibodies.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25667294\n",
      "analysis of BRAF mutation and CDKN2A deletions in childhood secondary high-grade glioma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25666295\n",
      "BRAF mutations are associated with Metastatic Colorectal Cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25663779\n",
      "Report low rates of BRAF mutations in Chinese colorectal carcinoma patients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25647260\n",
      "HPV presence was not associated with age, stage or grade of tumours, MSI or mutations in KRAS, TP53 or BRAF genes.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25646931\n",
      "These findings suggest that prenylation inhibition may be able to target melanoma cells with mutant NRAS or with mutant BRAF and PTEN.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25643238\n",
      "Case Report: successful (neo)adjuvant BRAF-targeted therapy in a patient with locally advanced BRAF V600E mutant melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25634750\n",
      "Report predictive value of immunohistochemistry in detecting BRAF mutations in neoplasms.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25632202\n",
      "KRAS and BRAF mutations are associated with inferior survival, independent of MSI status, in Japanese patients with curatively resected colorectal carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25628445\n",
      "BRAF mutations are associated with response to chemotherapy in colorectal cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25627962\n",
      "suggests that PIK3CA mutations account for a small fraction of PI3K pathway activation and have a limited impact in interfering with the BRAF/NRAS-driven growth in melanoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25618114\n",
      "BRAF overexpression could be an independent factor causing tumorigenesis in gliomas regardless of phospho-EGFR expression.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25616949\n",
      "In the management of thyroid nodules with benign cytology but positive BRAF(V600E) mutation, thyroidectomy should be considered in nodules which have 2 or more suspicious US features and are considered discordant on image-cytology correlation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25605225\n",
      "high-resolution melt and allele-specific PCR could detect as low as 1.25% KRAS- or BRAF-mutant alleles.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25602792\n",
      "Data support a role for BRAF V600E immunohistochemistry in diagnostically challenging cases of metanephric adenoma and expand the spectrum of BRAF exon 15 mutations in this uncommon but unique renal neoplasm.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25600339\n",
      "melanoma cell lines selected for resistance to BRAFi+MEKi, but not those to BRAFi alone, displayed robust drug addiction, providing a potentially exploitable therapeutic opportunity.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25593071\n",
      "BRAFV600E-mutation-positive papillary thyroid microcarcinoma are more likely to manifest with aggressive clinicopathological characteristics.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25588542\n",
      "BRAF V600E mutation is associated with Anaplastic thyroid cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25584719\n",
      "This is the largest study on the aggressive role of TERT promoter mutations in anaplastic thyroid cancer(ATC), demonstrating an association of TERT C228T with BRAF V600E, older patient age, and tumor distant metastasis in ATC.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25581727\n",
      "Report BRAF VE1 immunoreactivity patterns in epithelioid glioblastomas positive for BRAF V600E mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25576923\n",
      "Data suggest that Sema6A and Mical1 may represent new potential therapeutic targets in BRAFV600E melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25551625\n",
      "in different macroscopic subtypes of colorectal adenoma, BRAF mutation (V600E) was found in 2 of 36 lateral spreading tumors and 1 of 34 polypoid lesions; mutations in KRAS, BRAF or PIK3CA occurred in a mutually exclusive manner\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25543407\n",
      "To detect whether the V600E mutation is present or absent in the BRAF gene in melanoma patients is an important component in the evaluation of the biological behavior of tumor cells and their performance of biologically significant functions.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25537974\n",
      "The association between a host response and lymphovascular invasion and microvessel density in primary cutaneous melanoma with a BRAF mutation suggests that they exhibit potential for strategizing immunotherapies\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25527633\n",
      "IRS2 copy number gain, IGF-1R, IR-A, and IGFBP6 RNA expression levels, and KRAS and BRAF mutational status were identified as candidate predictive biomarkers for response to BMS-754807.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25526463\n",
      "BRAFV600E intratumor and intrapatient heterogeneity in melanoma is diminutive, nevertheless, the identified exceptions will have important implications for the clinical management of this disease.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25515853\n",
      "This is the first observation of a secondary BRAF mutation in a vemurafenib-resistant patient-derived melanoma sample, which confirms the potential importance of the BRAF L505H mutation in the development of therapy resistance.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25515650\n",
      "Missense mutations were identified in the BRAF and KRAS genes in cutaneous melanoma cell line.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25499274\n",
      "BRAF V600 mutation is associated with melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25499223\n",
      "These observations led us to conclude that increased TSH signaling overcomes OIS and is essential for B-RafV600E-induced papillary thyroid carcinogenesis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25491441\n",
      "The V600E BRAF mutation in a borderline serous tumour of the testis is genotypic evidence of similarity with its phenotypic ovarian counterpart.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25490969\n",
      "global miRNA expression profiles in fresh-frozen metastatic melanomas in relation to clinical outcome and BRAF mutation, were examined.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25490715\n",
      "BRAF V600E mutation affects patients with large/giant congenital melanocytic nevi, and with neurocutaneous melanocytosis, a novel finding.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25482468\n",
      "did not find a negative prognostic impact of a positive BRAF V600E mutation status on survival in papillary thyroid cancer\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25479927\n",
      "The combined BAP1-BRAFV600E+ immunoprofile appears to be a constant feature of BAP1 tumor syndrome-associated melanocytic lesions\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25473895\n",
      "truncated RAF1 and BRAF proteins, recently described as products of genomic rearrangements in gastric cancer and other malignancies, have the ability to render neoplastic cells resistant to RTK-targeted therapy\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25468810\n",
      "The BRAF(V600E) mutation was significantly associated with lymph node metastasis and poor prognosis in papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25463315\n",
      "We documented three novel mutations in the BRAF gene in cardio-facio-cutaneous syndrome patients and correlated clinical findings with causative mutations in the BRAF or MEK1/MEK2 genes\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25456393\n",
      "Lymph node specimens with low tumor cellularity due to numerous adjacent lymphocytes may pose a challenge to clinical detection of BRAF mutations of melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25450274\n",
      "The consistency of the BRAF gene mutation in peripheral blood and tissue is high.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25442675\n",
      "The determination of BRAF mutational status is recommended in any cystic sellar lesion and can in most cases be provided by VE1 immunohistochemistry even in specimens of low cellularity.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25442222\n",
      "BRAF V600E mutation status did not correlate with any clinicopathological parameters\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25437913\n",
      "Together, this work provides formal proof of an allosteric link between the RAF dimer interface, the activation segment and the catalytic infrastructure.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25437182\n",
      "Proteomic profile and in silico analysis in metastatic melanoma with and without BRAF mutation\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25430497\n",
      "Preanalytical workflow optimisation may reduce errors in down-stream sequencing in BRAF mutation detection.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25429742\n",
      "BRAF V600E mutation is related to lack of response and worse survival in wild-type KRAS metastatic colorectal cancer patients treated with anti-EGFR MoAbs.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25427581\n",
      "In this retrospective analysis, triplet chemotherapy with OCX was well tolerated and achieved encouraging efficacy in metastatic colorectal cancer irrespective of RAS/RAF mutation status.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25426645\n",
      "there is a lower incidence of brain metastases in patients with BRAF-mutated tumors who took vemurafenib before the diagnosis of brain metastases\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25404749\n",
      "The frequency of the BRAF mutation in cPTCs with suspicious US features was higher than that of cPTCs with negative US features regardless of the BSRTC.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25400776\n",
      "Concluded that the presence of BRAF(V600E) mutation in papillary thyroid carcinoma could be preoperatively predictive of extrathyroidal invasion in a Chinese population.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25389051\n",
      "we describe three interesting cases of paediatric glial and glioneuronal tumours harbouring both BRAF V600E and H3F3A K27M mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25385688\n",
      "Results demonstrate that mutated BRAF is associated with melanomas that are more aggressive.They are also associated with absence of solar elastosis and tumor epitheloid cells\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25378232\n",
      "BRAF V600E inhibited NIS expression by the upregulation of its promoter methylation.  Specific regions of CpG islands of NIS promoter in BRAF V600E harboring papillary thyroid carcinoma were highly methylated compared with surrounding normal tissue.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25376477\n",
      "discordancy of BRAF mutation status is not an infrequent finding between primary and metastatic melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25370533\n",
      "PD-L1 expression in melanocytic lesions does not correlate with the BRAF V600E mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25370473\n",
      "our data indicate that preexisting MEK1(P124) mutations are associated with a reduced response to BRAF inhibitor therapy and identify a subset of patients with BRAF-mutant melanoma likely to benefit from combination therapies\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25367198\n",
      "our study demonstrated the BRAF V600E mutation was an independent prognostic factor for colon cancer patients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25363723\n",
      "BRAF and NRAS alterations are preserved during in vitro culture in melanoma in a series of patients in which the c-KIT mutation was not detected\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25351955\n",
      "this study supports the idea that additional NK cell-based immunotherapy (by checkpoint blockade or agonists or cytokines) may combine well with BRAF(V600E) inhibitor therapy to promote more durable responses in melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25346165\n",
      "BRAF V600E mutations are frequent in dysembryoplastic neuroepithelial tumors and subependymal giant cell astrocytomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25337709\n",
      "The BRAF(V600E)mutation iss significantly associated with several poor clinicopathologic characteristics, but was not associated with sonographic features, regardless of thyroid tumor size.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25337237\n",
      "Report BRAF mutation status in colorectal neoplasms and neuroendocrine differentiation in primary/metastatic colorectal neoplasms.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25332244\n",
      "Data indicate an independent prognostic value of BRAF V600E mutation for papillary thyroid cancer (PTC) recurrence in various clinicopathologic categories.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25324352\n",
      "we identify that analysis of plasma and urinary cfDNA provides a reliable method to detect the BRAF(V600E) mutation and monitor response to therapy in these disorders.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25318602\n",
      "we detected 15 additional mutated melanoma samples and two additional BRAF V600E mutations in metastatic colorectal cancer samples by the LightMix assay compared to Sanger sequencing.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25314065\n",
      "B-RAF mutations were frequently detected in aberrant crypt foci.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25306614\n",
      "710 melanomas included in the study were located in sun non-exposed regions of the skin; this category of tumors was characterized by the highest occurrence of BRAF mutations\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25273224\n",
      "BRAF mutations occurred in 2.2% of advanced-stage lung adenocarcinomas, were most commonly V600E, and were associated with distinct clinicopathologic features in comparison with other genomic subtypes and with a high mutation rate in more than 1 gene.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25267307\n",
      "KRAS and BRAF mutation analysis could be used in the selection of patients for anti-EGFR therapy.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25266729\n",
      "BRAF V600E allele frequency is associated with papillary thyroid cancer progression.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25262966\n",
      "Overexpression of HO-1 in a subset of thyroid cancers is associated with tumour aggressiveness and BRAF V600E expression\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25262755\n",
      "BRAF mutation status was obtained for 146/160 cases. Overall mutation rate was 24/88 (27.3%) in primary and 25/58 (43.1%) in metastatic melanoma. V600E was the predominant mutation in 21/24 (87.5%) of primary and 23/25 (92%) of metastatic melanomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25244542\n",
      "The frequency of KRAS and BRAF mutations was low; KRAS mutations were detected in 1.6% and BRAF mutations in 4.7% of the biopsies for anal carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25242093\n",
      "Data suggest that proto-oncogene potein B-raf (BRAF) V600E mutations are present in rare cases of dendritic cell and histiocytic disorders, and their identifi cation off ers a potential therapeutic target for these neoplasms.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25239454\n",
      "dual HSP90/TRAP1 inhibitor HSP990 showed activity against the TRAP1 network and high cytostatic potential in BRAF-mutated colorectal carcinoma cells\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25236573\n",
      "A high discordant rate was found in Braf mutation statuses between primary and metastatic cutaneous melanoma lesions.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25219500\n",
      "Results reveal a BRAF(V600E)-directed pathway that mediates silencing of MLH1 and, more generally, is responsible for CpG Island Methylator phenotype.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25213729\n",
      "BRAF(V600E) status may help to predict clinical outcome of PTC.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25202140\n",
      "33% of Langerhans cell histiocytosis cases with wild-type BRAF and none with BRAFV600E harbored somatic mutations in MAP2K1 (6 in-frame deletions and 1 missense mutation) that induced extracellular signal-regulated kinase (ERK) phosphorylation in vitro.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25194980\n",
      "6 different BRAF missense mutations were found in 9 of 11 patients with cadiofaciocutaneous syndrome.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25188864\n",
      "this study sheds light on the pathogenesis of Serous borderline tumor ovarian tumors by showing that BRAF mutation is associated with cellular senescence\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25180764\n",
      "Targeted therapy in BRAF mutated melanoma; treatment with BRAF inhibitors and in combination with MEK inhibitors. [Review]\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25176643\n",
      "Methylation of MLH1 is strongly associated with BRAF mutations in sporadic colorectal cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25174651\n",
      "This study suggests that BRAF mutation-related specific transcripts associate with a poor phenotype in melanoma and provide a nest for further investigation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25165098\n",
      "PTEN loss was significantly associated with OS and time to MBM in patients with BRAF(V600) mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25164765\n",
      "Targeted sequencing on primary, metastatic, and normal tissue from colorectal cancer patients found a high degree of concordance for KRAS, NRAS, and BRAF mutations that were identical in both the primary and metastatic tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25156883\n",
      "BRAF(V600E) mutation is associated with papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25156525\n",
      "V600E BRAF mutation is associated with synchronous and metachronous thyroid cancer coexisting with Langerhans cell histiocytosis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25155755\n",
      "X-ray crystallography reveals a regulatory role for BRAF in the MAPK pathway independent of its kinase activity but dependent on interaction with MEK.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25154726\n",
      "combination of microsatellite instability and BRAF status serves as both a prognostic and predictive marker and may provide much-needed guidance during the planning of therapeutic strategies\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25153715\n",
      "The potential role of combined MMR and BRAF IHC as prognostic markers in CRC.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25148578\n",
      "Multiple potential therapeutic targets were identified in metastatic unknown primary and cutaneous melanomas that lacked BRAFV600 and NRAS mutations\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25139339\n",
      "Our data suggest that the poor prognosis of dMMR is driven by the BRAF(MT) status.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25120313\n",
      "The prevalence of rare BRAF mutations was 0.76% of all BRAF-positive thyroid cancers, and the rare mutations were associated with less aggressive pathologic features.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25118810\n",
      "activating V600E BRAF mutation can be frequently demonstrated in pediatric Langerhans cell histiocytosis\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25116269\n",
      "Next Generation Sequencing (NGS) assay revealed three genomic alterations: activating BRAF mutation (V600E), loss of CDKN2A/2B, and APC I1307K. After treatment with BRAF inhibitor (dabrafenib), the child's clinical condition improved progressively.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25109331\n",
      "loss of stem cell identity upon induction of BRAF/MAPK activity may represent a novel fail-safe mechanism protecting intestinal tissue from oncogene activation\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25104559\n",
      "It is a major negative mediator of the extracellular signal-related kinase (ERK)/mitogen-activated protein kinase and a substrate of cdk5 in neurons.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25085839\n",
      "The up-regulation of uPA mRNAs was correlated with high-risk clinicopathological features, including extrathyroid invasion, loss of cellular polarity/cohesiveness, and the BRAF(V600E) mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25076244\n",
      "Prevalence of BRAF mutations in CRC patients is not high but extremely correlated with MSI and risk categories as BG, whereas they are absent in LS patients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25073704\n",
      "ETV1 expression is a rare event in human melanoma and seems to be rather based on hyperactivation of MAPK signals, by BRAF (V600E) mutation, than on ETV1 gene amplification.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25073438\n",
      "KRAS, BRAF, and PIK3CA mutations were evaluated in 204 colorectal carcinoma samples; the frequency of KRAS, BRAF, and PIK3CA mutations was 23.5, 9.8, and 5.9 %, respectively.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25070294\n",
      "Data indicate that BRAF mutant status and number of positive lymph nodes as the only independent prognostic factors for recurrence-free (RFS) and disease-specific survival (DSS).\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25066317\n",
      "BRAF mutation in pilocytic astrocytoma is associated with a more diffuse growth pattern but does not confer a more aggressive clinical behavior\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25063807\n",
      "NRAS expression and increased MAPK activation drive vemurafenib resistance in V600E BRAF+ve melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25056119\n",
      "Enforced expression of RAC1 P29S in sensitive BRAF-mutant melanoma cell lines confers resistance manifested by increased viability.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25051202\n",
      "BRAF V600 mutations are associated with pathological features in Japanese melanoma patients\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25050586\n",
      "BRAF mutations were found in 8.7% of colorectal cancer precursor lesions, mainly associated with serrated polyps and absent in adenomas. In CRC cases, 6.5% exhibited BRAF mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25048604\n",
      "BRAF(V600E) mutations in primary cutaneous melanomas were associated with residence in locations with medium and high UV indices in mid-life.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25046227\n",
      "This study demonstrates that IHC analysis is a very sensitive test for evaluation of BRAF mutations in metastatic malignant melanoma and may be useful as an initial screening test.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25039399\n",
      "The adenocarcinoma showed expression of CK20 and p53, but CK7 in patches. The molecular profile of the adenocarcinoma showed a mutation in KRAS and wild-type BRAF, which might be associated with malignant transformation of intracranial mature teratomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25034364\n",
      "Common BRAF mutations are not present in systemic mastocytosis patients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25031736\n",
      "No BRAF mutations were detected in the lesions of 18 cases\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25029639\n",
      "Data indicate mutation in the proto-oncogene protein B-raf (BRAF) gene at the time of hairy cell leukemia (HCL) diagnosis in two cases.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25024077\n",
      "Coexisting BRAF V600E and TERT C228T mutations form a novel genetic background that defines PTC with the worst clinicopathologic outcomes, providing unique prognostic and therapeutic implications.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25015869\n",
      "document two rare cases of massively metastatic spinal cord GGs in adult patients who were negative for BRAF V600E mutations via multiple methods\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25013125\n",
      "In tDNA, 50 mutations (36 EGFR, 5 ERBB2, 4 KRAS, 3 BRAF, and 2 PIK3CA) were identified, of which 26 were detected in cfDNA. These data demonstrate the feasibility and potential utility of mutation screening in the detection of a range of tumor biomarkers\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25010701\n",
      "SOX2 expression is partly regulated by BRAF signalling, and an increased SOX2 expression may promote CRC metastasis and mediate a poor patient prognosis\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/25005754\n",
      "Our results highlight the low incidence of BRAF mutations and CIMP in CRC from Saudi Arabia.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24993163\n",
      "Activating FGFR2-RAS-BRAF mutations play a critical role in the pathogenesis of most cases of ameloblastoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24992171\n",
      "The absence of CXCR4 expression and BRAF mutation in cancers with a minor PD component underlined different pathogenic and metastatic processes in comparison with WDCs.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24989827\n",
      "BRAF testing is a useful adjunct to improve PPV for patients with \"suspicious for PTC\" cytology.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24979348\n",
      "BRAF mutations in NSCLC were significantly associated with adenocarcinomas .\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24978326\n",
      "BRAFV600E mutation in primary tumor might be a promising molecular marker to predict the status of 131I uptake in distal metastases.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24964857\n",
      "Results suggest tha tthe pathological progression from Serrated adenoma through colon carcinoma required the successive events: mutations in BRAF protein, hypermethylation of MLH1 then hypermethylation in AXIN2.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24964758\n",
      "MSI and the BRAF(V600E) mutation have a prognostic impact in colon cancer\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24958825\n",
      "BRAF(V600) mutation is associated with melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24958809\n",
      "Although there was large variability between patients, FDG uptake decreased with higher daily doses in patients with BRAFV600 mutation-positive melanoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24954313\n",
      "Considering the diagnostic performance and low reproducibility of US, the combination of FNA with BRAFV600E is the most reliable and objective method for diagnosing thyroid malignancy.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24950457\n",
      "amuvatinib has proapoptotic activity against melanoma cell lines, with selectivity observed for those harboring oncogenic NRAS but not BRAF\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24947927\n",
      "BRAF mutations are associated with response to chemotherapy in cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24942334\n",
      "The 5-year survival rate of colorectal cancer patients with BRAF mutations was significantly decreased.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24941944\n",
      "Although both, DTIC and TMZ act as alkylating agents through the same intermediate, NRAS and BRAF mutant cells responded differentially only to DTIC.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24936068\n",
      "a novel role for B-Raf in the selective regulation of alpha4beta1 integrin-mediated adhesion.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24926836\n",
      "Results show that BRAF-mutated patients were significantly younger at the time of primary melanoma and first diagnosis of metastasis than BRAF wild-type patients but BRAF mutation is not associated with a more aggressive illness.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24922189\n",
      "Using the PCR test with sense allele-specific primers, mutations in V600 were found in 33 of 51 Russian patients (64.7%) with cutaneous melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24921639\n",
      "BRAF V600E immunohistochemistry is reliable for the evaluation of mutational status in colorectal carcinoma regardless of site or prior treatment history, and staining shows a high degree of intratumoral homogeneity.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24918823\n",
      "BRAF and NRAS mutation status does not influence survival in metastatic melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24918610\n",
      "The results from this prospective cohort study further support an influence of sex and lifestyle factors on different pathways of colorectal carcinogenesis, defined by KRAS and BRAF mutation status of the tumours.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24909403\n",
      "BRAF was a significant parameter for predicting multifocality in follicular variant of papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24906137\n",
      "BET inhibition with I-BET151 appears independent of the BRAF and NRAS mutational status of melanoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24901049\n",
      "The B-Raf(V600E) inhibitor dabrafenib selectively inhibits RIP3 and alleviates acetaminophen-induced liver injury.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24897065\n",
      "suboptimal specificity and PPV limits the diagnostic utility of both antibodies to reliably detect BRAF p.V600E mutations in thyroid carcinoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24894769\n",
      "Findings suggest a link between Langerhans cell histiocytosis and Erdheim-Chester disease involving the BRAF(V600E) mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24893747\n",
      "Our results indicate a cross-talk between Braf and p300 in melanoma and demonstrate the importance Braf and p300 expression in the diagnosis and prognosis of melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24885690\n",
      "Genetic targeting of BRAF Valine600Aspartate drug resistance mutation identifies dabrafenib as a selective agent against BRAF-resistant colorectal cancer cells.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24885594\n",
      "While frequency rates of BRAF mutations were quite identical across the different MPM lesions, a significant increase of cKIT (p<0.001) and CyclinD1 (p=0.002) amplification rates was observed between first and subsequent primary melanomas\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24871132\n",
      "Treatment of HCL patients with vemurafenib, an inhibitor of mutated BRAF, resulted in normalization of HSPC frequencies and increased myeloid and erythroid output from HSPCs\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24866436\n",
      "BRAF mutation is associated with melanoma nodal metastases and an unknown primary site.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24863948\n",
      "Data indicate that BRAF protein overexpression was significantly associated with thyroid extracapsular extension (ECE) and lymph node metastasis (LNM) positive cases.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24862939\n",
      "BRAF mutation was not associated with negative prognostic indicators or adverse outcomes in PTC.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24861115\n",
      "12% of KRAS negative colorectal cancer showed BRAF gene mutation. Considering that 42% of samples have a KRAS mutation, 54% of patients should not respond to therapies with monoclonal antibodies directed against epidermic growth factor (EGFR) pathway.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24859998\n",
      "The high-resolution melting method developed was shown to be a reliable method for BRAF mutation detection\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24859340\n",
      "BRAF mutation is asociated with ameloblastoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24857351\n",
      "report of a new IDH1 mutation associated with BRAF mutation in a very unusual glial tumor.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24848709\n",
      "Overexpression of BRAF(V600E) in normal thyroid epithelial (H tori) cells also reduced the effects of Dkk-1 on cell survival.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24839220\n",
      "BRAF mutation cannot be regarded as a reliable marker of node metastases in patients with PTC.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24838814\n",
      "The BRAF mutation was significantly associated with persistence/recurrence and a potential predictor in patients with classical PTC >10 mm at a BRAF mutation prevalent area\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24833563\n",
      "RAC1b overexpression constitutes a marker of poor prognosis in KRAS/BRAF WT mCRC patients treated with first-line FOLFOX/XELOX therapy.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24832158\n",
      "Although VE1 antibody can be useful in the screening of colon carcinomas for BRAF V600E-mutant proteins, molecular genetic confirmation is always necessary for mutation diagnosis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24828987\n",
      "The present work discusses the most recent and controversial evidence on the BRAF V600E relevance in development and progression of thyroid tumors. [Review]\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24821886\n",
      "Case Report: KRAS mutated pancreatic adenocarcinoma developing on treatment with combined BRAF and MEK inhibition for metastatic melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24806883\n",
      "Characteristics and prognosis of colorectal cancer with NRAS mutations are different from those with KRAS or BRAF mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24798740\n",
      "analysis of RAS, RET/PTC, and BRAF mutations in advanced stage of papillary thyroid carcinoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24792487\n",
      "BRAF V600E mutation positive pediatric posterior fossa gangliogliomas exhibit no unique imaging features, are associated with shorter progression-free survival, and carry promising treatment implications by BRAF inhibitors\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24789721\n",
      "BRAF V600E mutation is associated with refractory hairy cell leukemia.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24787545\n",
      "BRAF(V600E) mutation is not a useful prognostic marker, though it does influence the short- and medium-term outcomes of classic papillary thyroid cancer\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24780046\n",
      "BRAF V600E is heterogeneously distributed in some papillary thyroid carcinomas(PTCs). The large BRAF V600E neoplastic cell subpopulations found in mutated cases is consistent with the view that the BRAF V600E is acquired early during PTC development.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24774510\n",
      "This study indicated that mutations of KRAS, PIK3CA and NRAS were rare in advanced gastric cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24770869\n",
      "Data demonstrate that the BRAF(V600E) cooperates with either PIK3CA(H1074R) or with silencing of the tumor-suppressor PTEN, to promote development of anaplastic thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24767862\n",
      "We conclude that a V600E BRAF mutation may not be helpful in distinguishing sporadic from MTS-associated sebaceous neoplasms\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24764675\n",
      "colorectal cancers with a BRAF mutation have distinct molecular features and resulted in a poor prognosis in Korean patients with advanced colorectal cancer\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24749938\n",
      "The presence of dermoscopic peppering and thicker Breslow index ulceration suggest a morphological consequence of immune behaviour in BRAF-mutated melanomas\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24748129\n",
      "The percentage of mutant BRAF alleles in papillary thyroid carcinoma is significantly associated with tumor burden and extrathyroidal invasion.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24746198\n",
      "discordant BRAF mutation status is rare when samples from individual PTCs are compared or when samples from individual PTCs and lymph node metastasis at thyroidectomy are compared but occurs more when primary and recurrent metastasis are compared\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24742923\n",
      "From a practical perspective, small biopsies may not adequately represent a tumor's full mutational profile, particularly for later arising but prognostically important mutations such as those in the KRAS and BRAF genes\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24737664\n",
      "BRAF-mutant mCRC is associated with worse clinical outcome. Patients with BRAF-mutant tumors develop peritoneal metastases, less frequently present with disease limited to the liver, and have shorter survival after metastasectomy.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24735930\n",
      "AKTi combined with BRAFi-based therapy may benefit patients with tumors harboring BRAF mutations and particularly PTEN deletions or AKT mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24733801\n",
      "Case Report: patient with V600E BRAF-mutant leptomeningeal melanoma who experienced a complete clinical and radiologic response after dabrafenib treatment.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24733413\n",
      "long-term treatment with BRAF inhibitors can affect the interaction between BRAF/MAPK and Wnt/beta-catenin signaling to affect patient outcomes\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24725538\n",
      "Response to this therapy suggests that BRAF inhibitors can affect primary CNS lesions when a documented and targetable mutation is present.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24721513\n",
      "analysis of pro-death autophagic processes responsible for sensitization of BRAF-V600E glioma cells toward UAI-201\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24721322\n",
      "BRAF(V600E) mutation demonstrated to be an adverse prognostic factor indicating aggressiveness of papillary thyroid carcinoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24720374\n",
      "the BRAF pathway may contribute to the pathogenesis or malignant transformation of histiocytic and dendritic cell neoplasms.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24717435\n",
      "decreasing the levels of CTR1 (Cu transporter 1), or mutations in MEK1 that disrupt Cu binding, decreased BRAF(V600E)-driven signalling and tumorigenesis in mice and human cell settings\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24715106\n",
      "Study found BRAF V600E mutations in 81 percent of papillary craniopharyngioma sampled\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24714776\n",
      "BRAF mutation is associated with melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24713734\n",
      "the homebrew dispensation sequence unambiguously identifies all known BRAF mutations in this region, whereas the kit-based dispensation sequence has one unresolvable degeneracy that could be solved with the addition of two injections\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24710085\n",
      "mutations in BRAF and NRAS are not mutually exclusive because they were simultaneously present in the same tumor specimens\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24709886\n",
      "A combined inhibition strategy targeting BRAF together with multiple erbB family kinases is potentially beneficial for treating BRAF V600E mutant melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24703243\n",
      "Near-genomewide RNAi screening for regulators of BRAF(V600E) -induced senescence identifies RASEF, a gene epigenetically silenced in melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24691006\n",
      "the outcome of 68 patients with advanced colorectal cancer and RAS, BRAF and PI3KCA status according to ALK gene status, is reported.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24684646\n",
      "analysis of a possible association between AID expression and BRAF mutation in melanoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24679337\n",
      "genetic association studies in a population in Iran: Data suggest that a mutation in BRAF (V600E) is associated with prognosis of paritents with papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24677749\n",
      "This analysis suggests that differences in disease course of PTC in children versus adults are not strongly dependent upon the presence of the BRAF(V600E) mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24673746\n",
      "Disruption of mutated BRAF signaling modulates thyroid cancer phenotype.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24671772\n",
      "Data support a central role of BRAF V600E mutation in Erdheim-Chester disease and suggest oncogene-induced senescense as a link to both inflammation and oncogenic mutation in histiocytes playing a role in the disease.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24666267\n",
      "Mutations in BRAF predict resistance to anti-EGFR therapies.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24664307\n",
      "Studies indicate that the role of proto-cncogene protein B-raf-MEK-ERK pathway in controlling cell fate as a primary target for deregulated activation in cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24659028\n",
      "Increased BRAF mutation is associated with colorectal cancer progression and poor response to therapy.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24651849\n",
      "BRAF mutant/microsatellite stable (MSS) (BRAFmut/MSS) cancers (n = 33) and BRAF mutant/microsatellite unstable (MSI) (BRAFmut/MSI) cancers (n = 30) were compared for presence of copy number aberrations (CNAs) indicative of chromosomal insatbility.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24642661\n",
      "KRAS and BRAF genes were wild-type in all squamous cell anal carcinoma cases.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24639117\n",
      "Although it has limitations, the VE1 antibody represents a feasible first-line approach for evaluating BRAF mutation status and may be a valid tool in the selection of samples for molecular analysis\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24638167\n",
      "BRAF-V600E expression in tissue dendritic cells did not define specific clinical risk groups but was associated with increased risk of recurrence.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24634053\n",
      "V600E mutations in 8/15 bile duct adenomas\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24625419\n",
      "We evaluated the BRAF V600E expression by immunohistochemistry in pulmonary and extrapulmonary Langerhans cell histiocytosis cases\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24619974\n",
      "findings suggest that subcategorization of AUS by cytomorphology and BRAF V600E mutation status is important for predicting the risk of malignancy\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24617711\n",
      "In this large cohort, we found TERT promoter mutations to be common, particularly in Follicular thyroid carcinoma and BRAF mutation-positive papillary thyroid carcinoma, and associated with aggressive clinicopathological characteristics.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24614711\n",
      "Melanomas with associated naevi have a higher frequency of BRAF(V600E) mutations than melanomas unassociated with naevi.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24612623\n",
      "Most of the Korean patients with multifocal papillary thyroid carcinoma (PTC) had the BRAF(V600E) mutation in one or more tumor foci, and all BRAF(V600E)-positive multifocal PTC showed more aggressive features.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24612059\n",
      "Serrated colorectal carcinoma as proposed to arise from serrated adenoma is characterized by mutation of BRAF.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24608435\n",
      "Anti-apoptotic BCL-2 proteins govern cellular outcome following B-RAF(V600E) inhibition and can be targeted to reduce resistance.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24604709\n",
      "BRAF V600E mutations may be more prevalent than previously thought in pediatric patients with papillary thyroid carcinoma, but do not correlate with aggressive disease characteristics\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24603591\n",
      "BRAF mutations are virtually absent in melanomas originating from the vulva or vagina\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24594804\n",
      "Meta-analysis demonstrated that the BRAF V600E mutation was significantly correlated with adverse pathological features of colorectal cancer and distinct clinical characteristics.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24591408\n",
      "BRAF mutation is associated with atypia of undetermined significance and papillary carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24588959\n",
      "analysis of BRAF mutation and DNA methylation markers on fine needle aspiration biopsy specimens may be a useful strategy to facilitate the diagnosis of malignant thyroid neoplasm\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24586605\n",
      "BRAF-V600 mutations are not associated with response to chemotherapy in stage IV melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24582505\n",
      "Report safety of vemurafenib in diverse population of patients with BRAF(V600) mutated metastatic melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24560515\n",
      "Although the sensitive pyrosequencing method was used, no EGFR, KRAS or BRAF mutations could be found\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24559116\n",
      "BRAF mutation was significantly associated with a larger tumor size, extrathyroidal invasion and lymph node metastasis in papillary thyroid cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24552757\n",
      "BRAF-mutation analysis should be part of the subtyping of non-squamous NSCLC.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24550319\n",
      "Nonsmall cell lung cancer cells with BRAF-V600E, but not other BRAF mutations, initially are sensitive to BRAF-inhibitor treatment, but rapidly acquire resistance to BRAF inhibition.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24548081\n",
      "BRAF mutation in FVPTC is associated with unfavourable clinicopathological characteristics and malignant features on ultrasonography and may be a potential prognostic factor as it is in classical PTC.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24535907\n",
      "Our results demonstrated that the BRAF V600E mutation is a common event in melanomas, representing an important molecular target for novel therapeutic approaches in such tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24532263\n",
      "we identify KIAA1549-BRAF gene fusions in 45 % of 82 low-grade glioma samples\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24529209\n",
      "Molecular genetic analysis revealed BRAF duplication and a KIAA1549-BRAF fusion gene in 82% of group II tumors, but in none of the group I tumors, and a BRAF:p.V600E mutation in 43% of group I tumors, but in none of the group II tumors\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24508103\n",
      "For the 598 (91%) patients with BRAF(V600E) disease, median overall survival in the vemurafenib group was 13.3 months (95% CI 11.9-14.9) compared with 10.0 months (8.0-14.0) in the dacarbazine group (HR 0.75 [95% CI 0.60-0.93]; p=0.0085)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24503706\n",
      "Two cases of classic HCL, 1 showing CD5 expression, were truly BRAF V600E-negative based on negative results by PCR and sequencing despite high-level leukemic involvement\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24497953\n",
      "B-cell receptor functions differ in hairy cell leukemia displying BRAF V(600)E and mutated IGHV.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24496868\n",
      "we sought to analyze the nature of IC and EC response and progression in patients with melanoma brain metastases treated with dabrafenib, and hypothesized that metastases respond and progress similarly to BRAF inhibitors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24493731\n",
      "The finding of BRAF mutations in meningeal melanocytomas points to a potential initiating role of BRAF in transformation toward malignancy and could have therapeutic implications in these specific melanocytomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24489105\n",
      "BRAF inhibition causes decreased CXCL8 secretion from melanoma cells and induce an immune response against the tumor associated with increased IFN-gamma, CCL4, and TNF-alpha.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24486585\n",
      "A novel mechanism for response was discovered whereby high expression level of CAV-1 at the plasma membrane disrupts the BRaf/CRaf heterodimer and thus inhibits the activation of MAPK pathway during dasatinib treatment.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24484235\n",
      "Suggest that some patients with advanced melanoma who are BRAF-mutation positive may benefit from ipilimumab as the first part of their sequential treatment schedule.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24475291\n",
      "B-RAF is a powerful regulator of hERG channel activity and cell surface hERG protein abundance.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24475086\n",
      "no significant survival differences were found according to BRAF-V600 tumor mutations in patients with primary melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24471909\n",
      "Data show that a high proportion of cases of non-pulmonary Langerhans cell histiocytosis (LCH) and pulmonary LCH (PLCH) expressed the proto-oncogene protein B-raf (BRAF) V600E mutant protein.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24471189\n",
      "results probably indicate that BRAF mutation may not be the only key factor in melanoma tumorigenesis, and that there should be multiple alternative genetic pathways related to melanoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24463458\n",
      "Resistance mechanisms were identified in 58% progressing tumors and BRAF alterations were common. Gene expression analysis revealed that mitogen-activated protein kinase (MAPK) activity remained inhibited in 21% of resistant tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24446311\n",
      "A subset of patients with RAS(wt) CMML harbors BRAF kinase domain mutations that are potentially capable of activating the MAPK signaling pathway.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24442520\n",
      "Mutational events as well as over-expression of BRAF gene are highly implicated, independently, in the pathogenesis of thyroid cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24440976\n",
      "The presence of BRAF mutations is positively associated with advanced tumor stage in African American colorectal cancer patients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24433452\n",
      "Two V600E-negative hairy-cell leukemias had new pote mutations in exon 11 (F468C and D449E). Another HCL was BRAF wild-type in exons 2-17. All non-HCL lymphomas lacked BRAF mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24425783\n",
      "Data reveal a mechanism by which BRAF(V600E) and PI3K signaling cooperate to regulate melanoma proliferation through AKT-independent effects on protein translation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24424406\n",
      "The B-RafV600E mutation detected in melanoma is not associated with a chronic exposure to the sun.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24417615\n",
      "BRAF mutational analysis by melt curve analysis is feasible in routine thyroid cytology, and in our series had a 100% specificity for PTC in subsequent histology. The application of BRAF analysis could be useful for indeterminate cytology\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24413733\n",
      "Targeted genotyping revealed BRAF p.Val600Glu in 95% of papillary craniopharyngiomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24410877\n",
      "Report detection of BRAF mutations eligible for therapy with vemurafenib in melanoma patients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24402044\n",
      "Despite being an independent predictor of central node metastasis in small papillary thyroid carcinoma, BRAF did not add substantially to the overall prediction of occult central node metastasis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24398428\n",
      "Data indicate that dual targeting of heat-shock proteins 90 (Hsp90) and BRAF(V600E) kinase provided combinatorial benefit in vemurafenib-sensitive melanoma cells in vitro and in vivo.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24397598\n",
      "the first BRAF V600/601 and KRAS G12-K16 screening study in primary mediastinal B-cell lymphoma that failed to identify hotspot mutations in this specific subtype\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24390240\n",
      "BRAF mutation decreases tumor response in first-line treatment whether cetuximab was given or not in patients with KRAS wild-type, and anti-EGFR MoAb produces a clear benefit in response rate in patients with BRAF and KRAS wild-type.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24389984\n",
      "meta-analysis suggested that extrathyroidal extension, lymph node metastasis, disease recurrence, and advanced TNM stage were associated with BRAF(V600E) mutation in papillary thyroid carcinoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24382015\n",
      "study found CYP24A1 expression was increased in papillary thyroid carcinoma compared to benign multinodular goitre; expression was further increased in stage III and IV tumours; a strong correlation found between CYP24A1 overexpression and BRAF(V600E) mutation\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24375920\n",
      "Response to vemurafenib suggests that BRAFV600 is an oncogenic driver in pediatric gliomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24374844\n",
      "Report clinical consequences of high frequency of BRAF mutations in ameloblastoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24372748\n",
      "correlation between KRAS or BRAF mutations and prognosis was not observed\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24367680\n",
      "BRAF V600E-mutation in metastatic colorectal cancer characterizes a subgroup of patients with distinct biologic, clinical and pathological features and is associated with very poor patients' prognosis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24366910\n",
      "The study identifies the BRAFV600E mutation as a significant molecular alteration in malignant peripheral nerve sheath tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24362353\n",
      "Braf(V600E)-driven tumors become addicted to autophagy as a means to preserve mitochondrial function and glutamine metabolism\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24356563\n",
      "The KRAS mutation is not present in about one-third of CRC patients, and therefore other gene mutations need to be investigated to better understand the molecular mechanisms of CRC and its treatment.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24354346\n",
      "there was no correlation between BRAF-positive primary focus of papillary microcarcinoma and more aggressive or recurrent disease\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24353007\n",
      "Molecular genetic tests revealed BRAF V600E mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24345920\n",
      "BRAF fusions define a new molecular subset of melanoma, potentially comprising 4% to 8% of \"pan-negative\" cases.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24345274\n",
      "This study demonstrated that temporal location, reticulin deposition and CD34 expression are associated with BRAF mutation in pleomorphic xanthoastrocytoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24335665\n",
      "Provided there is adequate quantity of viable tumor cells, immunohistochemical testing any melanoma sample from a patient with metastatic disease will accurately determine BRAF status.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24321241\n",
      "These cases further expand the range of glial neoplasia in which epithelioid morphology is encountered, and add to the growing list of biphasic tumors harboring the BRAF V600E mutation\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24311634\n",
      "BRAF-V600E mutation is associated with younger glioblastoma patients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24309328\n",
      "BRAF V600E mutation is a rare event in biliary tract cancer, accounting for only 1% of all subtypes, and is restricted to intrahepatic cholangiocarcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24301760\n",
      "We conclude that a high proportion of PTC cases likely harbors the BRAF V600E mutation. This mutation can be used as an independent factor for predicting the recurrence and distal metastasis of PTC tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24297085\n",
      "The overall survival rate was not significantly different between patients with wild-type BRAF and those with V600E or non-V600E BRAF mutations in an Asian cohort.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24295088\n",
      "genetic association study in population in Italy: Data suggest rare BRAF variants (found in 1.6% of all thyroid malignancies) cluster around codon V600 in binding pocket named A-loop of kinase domain leading to greater stability of BRAF conformation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24267957\n",
      "Detection of BRAF(V600E) in cytology specimens by pyrosequencing is a useful diagnostic adjunctive tool in the evaluation of thyroid nodules also in elderly subjects\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24265152\n",
      "A novel AKT1 mutant amplifies an adaptive melanoma response to BRAF inhibition.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24258620\n",
      "B-RAF increases the cell surface protein abundance and activity of the type II Na+-coupled phosphate transporters NaPi-IIa and NaPi-IIb.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24256466\n",
      "Frequency of somatic BRAF mutations in melanocytic lesions from patients in a CDK4 melanoma family.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24247620\n",
      "BRAF mutation in papillary thyroid carcinoma determined by IHC is associated with significantly increased risk of lymph node recurrence.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24244575\n",
      "BRAF p.V600E colon tumors showed significant MEIS1 promoter methylation, which was associated with decreased MEIS1 gene expression.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24242331\n",
      "associations were identified between miR-31, BRAF and prognosis in CRC\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24238398\n",
      "Rapidly metastasizing malignant melanoma characterized by a rare BRAF mutation not responding to vemurafenib\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24238153\n",
      "The study found a BRAF(V600E) mutation frequency of 54% (seven of 13) in brainstem gangliogliomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24228637\n",
      "BRAF(V600E) mutation is not associated with papillary thyroid microcarcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24196789\n",
      "As heterogeneity with respect to BRAF mutation status is detected in melanoma patients, subsequent testing of initially wild-type patients can yield different results and thus make BRAF inhibitor therapy accessible.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24183461\n",
      "Data indicate that the median time to progression (TTP) 8.9 months is close to the promising BRAF- and MEKi combination therapy with median progression-free survival (PFS) 9.4 months.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24178368\n",
      "study characterized the multiple-dose pharmacokinetics of vemurafenib 240-960 mg twice daily (bid) in BRAF(V600E) mutation-positive metastatic melanoma patients, using the commercial formulation\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24167125\n",
      "When supplemented with other noninvasive test methods, the B-RAF(V600E) test could be a powerful adjunct with extensive clinical applications for diagnosis of thyroid nodules. (review)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24166180\n",
      "Results sugggest that Cdx2 may play a role in the serrated pathway to colorectal cancer with BRAF(V600E), CpG Island Methylator Phenotype (CIMP)-high and mismatch repair (MMR)-deficiency.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24164374\n",
      "Based on this methodology and other published results for the BRAF mutation, we believe that it is now feasible and cost effective for the UK NHS to BRAF co-test all Thy4/Bethesda Class V thyroid FNAs.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24161954\n",
      "B-Raf mutations are associated with cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24152792\n",
      "results provide evidence that constitutively activated BRAF(V600E) drives aberrant proliferation of monocyte-lineage cells.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24139521\n",
      "When genotypes of BRAF/KRAS mutated s-BOTs and corresponding implants were compared, no patient presented with a fully matching mutation profile of s-BOT and all corresponding implants.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24139215\n",
      "Of 54 intrahepatic cholangiocarcinoma cases, 7.4% were mutant for KRAS, 7.4% were mutant for BRAF, and these were mutually exclusive. These cases were associated with a higher tumor stage and a greater likelihood of lymph node involvement.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24124924\n",
      "evaluated the potential role of XIAP expression as a novel prognostic marker to predict recurrence, in combination with the BRAF(V600E) mutational status in papillary thyroid cancer\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24123003\n",
      "HSP60 protein expression may inhibit lymph node metastasis in papillary thyroid carcinomas harboring the BRAF mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24122611\n",
      "No mutations were found in the BRAF gene in a cohort of 84 patients affected by squamous cell anal cancer\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24118207\n",
      "BRAF signalling increases Mcl-1 expression in cutaneous metastatic melanoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24117833\n",
      "BRAF mutational analysis was performed on tissue from 104 patients: 90 with sarcoma only and 14 with sarcoma and melanoma. In the sarcoma-melanoma group, three sarcomas showed BRAF mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24114843\n",
      "EGF, which signals through CRAF, and an activated BRAF mutant also activate PKC and stimulate cell migration through up-regulating RFFL expression.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24112705\n",
      "The kinase activity of BRAFV600E/L505H was higher than that of BRAFV600E, resulting in cross-resistance to a MEK inhibitor\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24112392\n",
      "BRAF mutation appears to be associated with distinct, unfavourable clinicopathological characteristics in colorectal cancer - systematic review and meta-analysis\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24104864\n",
      "The low incidence of BRAF mutation limited assessment of its prognostic impact.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24095280\n",
      "Data indicate that phosphorylation of BRAF by AMPK disrupts its association with KSR1.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24094449\n",
      "hypothesize that the level of SPRY2 expression contributes to MAPK/ERK pathway output and accounts for BRAF V600E+ and clinical heterogeneity in papillary thyroid cancer\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24073892\n",
      "The BRAF mutation represents an additional risk factor only in some subpopulations of colorectal cancers, in others having limited prognostic value.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24057326\n",
      "High rate of BRAF-KIAA1549 fusion is associated with pilocytic astrocytoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24052184\n",
      "The BRAF mutation was positive in 37 % of papillary thyroid carcinoma patients. It had no prognostic impact. Cause-specific survival of mutation-positive high-risk patients was poorer than CSS of mutation-negative high-risk patients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24039206\n",
      "BRAF protein mutation can be reliably detected in patients diagnosed with papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24030686\n",
      "There was no significant association between BRAF positivity and tumor multicentricity, lymphovascular invasion, extranodal extension, central neck involvement, advanced stage (stage III or IV), and distant metastasis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24026210\n",
      "We found BRAF mutations in 13/61 of the melanoma lesions and V600K predominated over V600E.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24024839\n",
      "BRAF mutations were associated with reduced overall survival among patients with cololectal cancer without KRAS mutations in exon 2 and among those with NRAS mutations in exon 3.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/24006859\n",
      "mutations in KRAS codon 61, KRAS codon 146, BRAF, NRAS, or PIK3CA detected in Asian patients were not predictive of clinical benefits from cetuximab treatment.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23996432\n",
      "Significant difference in Progression-free survival (PFS) and overall survival (OS)between patients with BRAF mutated and BRAF wild-type tumours was not detected\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23993026\n",
      "Mutation occurs at similar frequencies as NRAS in acral lentiginous melanoma of Swedish patients\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23987572\n",
      "Prevalence and distribution of pathogenetic mutations in BRAF and NRAS genes were evaluated in multiple melanoma lesions from patients with different geographical origin within the same Italian population.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23981603\n",
      "BRAF(V600E) mutation is predictive for distant metastasis in papillary thyroid carcinoma but not positively.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23972510\n",
      "BRAF mutations were detected in 2 amelanotic acral melanoma cases\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23969188\n",
      "the association between BRAF V600E mutation and aggressive features of papillary thyroid cancer\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23965740\n",
      "This study demonstrated the absence of consistent recurrent chromosomal alterations in desmoplastic infantile astrocytomas and desmoplastic infantile gangliogliomas and overall rarity of the BRAF mutation in these tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23963522\n",
      "detection of BRAF V600E in colorectal cancer specimens by immunohistochemistry is sensitive and specific and may help to identify Lynch syndrome patients\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23960272\n",
      "BRAF mutation is associated with the serrated morphology of traditional serrated adenoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23959801\n",
      "Mortalin mediates a switch in tumor-suppressive signaling of Raf/MEK/extracellular signal-regulated kinase.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23941441\n",
      "BRAF V600E-mutated protein may be valuable in the diagnostic evaluation of these glioneuronal lesions and the observed association with mTOR activation may aid in the development of targeted treatment involving specific pathogenic pathways\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23938765\n",
      "Report relatively high frequency of BRAF(V600E) and KIT mutations in amelanotic melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23931769\n",
      "used a mutation-specific antibody for immunohistochemical detection of the BRAF V600E mutation and correlated expression with clinicopathologic features in papillary thyroid carcinoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23930206\n",
      "The frequencies of EGFR, KRAS, BRAF, and HER-2 mutations in BM-NSCLC were 2.6, 38.5, 0, and 0% respectively.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23922205\n",
      "These findings demonstrate the presence of mutation-specific clinical differences between different BRAF genotypes in patients with melanoma, and support the incorporation of this information in patient evaluation and clinical trial design.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23908594\n",
      "Findings support the development of CDK and Raf co-targeting strategies in EGFR/HER-2-overexpressing or RAS/RAF mutant breast cancer (BC).\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23907581\n",
      "Our studies have identified a previously unrecognized regulatory role of Lys63-linked polyubiquitination in BRAF-mediated normal and oncogenic signalings.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23906414\n",
      "In our Near Eastern cohort, the BRAF mutation rate varied significantly by geographic location. In patients with multiple dysplastic nevi examined, discordant BRAF mutation status potentially negates an underlying constitutional predilection\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23903755\n",
      "Suppression of TORC1 activity in response to RAF or MEK inhibitors, as measured by decreased phosphorylation of ribosomal protein S6 (P-S6), effectively predicted induction of cell death by the inhibitor in BRAF-mutant melanoma cell lines.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23893412\n",
      "Ras-mutant cancer cells display B-Raf binding to Ras that activates extracellular signal-regulated kinase and is inhibited by protein kinase A phosphorylation\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23893334\n",
      "TIMP-1 protein expression is a reliable surrogate marker for BRAF(V600E)-mutated status in papillary thyroid carcinoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23887306\n",
      "Classification of serrated lesions using immunohistochemical evaluation of BRAF V600E mutation may identify lesions with higher potential to progression into sessile serrated adenoma/polyp, and further to BRAF V600E-mutated colorectal cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23883275\n",
      "Shifted termination assay fragment analysis can detect BRAF V600 mutations in formalin-fixed paraffin-embedded papillary thyroid carcinoma samples.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23880961\n",
      "BRAF V600E mutations occurs infrequently in endometrial cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23878352\n",
      "No evidence existed for a differential prognostic role of BRAF mutation by MSI status (P(interaction) > .50). Combined BRAF/MSI status in colorectal cancer is a tumor molecular biomarker for prognosic risk stratification.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23861977\n",
      "the presence of a BRAF- or NRAS mutation in a nevus was not associated with the risk of malignant transformation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23860532\n",
      "Findings show that KIT and BRAF mutations are only rarely present in SNMMs, whereas NRAS mutations seem to be relatively more frequent.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23855428\n",
      "The study found a high concordance of BRAF mutation status between paired metastases diagnosed at different time points.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23852164\n",
      "Patient-derived tumor xenografts provides 'real-time' results in an animal that phenocopies the biology and expected vemurafenib responses of the tumor in a patient with BRAF V600E melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23849768\n",
      "Summing up the results about the KRAS and the BRAF mutation carriers from our study, the portion of potentially non responsive colorectal cancer patients for the anti-EGFR treatment is 28.26%.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23845441\n",
      "demonstrate dose-dependent effects of oncogenic signaling, with physiologic Braf(V600E) expression being sufficient for hyperplasia induction\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23845288\n",
      "Although BRAF mutation appears to play a role in local tumour progression, it is not a risk factor for poor prognosis or tumour recurrence in papillary thyroid carcinoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23841470\n",
      "BRAF mutations are found in 2 to 4% of non-small cell lung cancers. The mutations harbor non-V600E mutations in 40 to 50% of cases. A phase 2 trial of dabrafenib described 8 responses of 20 patients with BRAF V600E mutant NSCLC\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23833303\n",
      "Melanomas arising in SSD skin have higher mutation loads and contain a spectrum of molecular subtypes compared with BRAF- and NRAS-mutant tumors indicating multigene screening approaches\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23833299\n",
      "Although no melanomas had high-level amplification of BRAF, the two patients with progressive disease as their best response had BRAF copy gain in their tumors\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23822828\n",
      "BRAF V600E mutated tumour cells was detected in the cortical tumour component, pronounced leptomeningeal tumoural stroma was predominantly negative for VE1 binding. BRAF V600E mutation affects a subset of desmoplastic infantile astrocytoma/ganglioglioma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23821376\n",
      "This study investigated the impact of KRAS, NRAS, BRAF, PI3KCA and TP53 status on outcome of elderly metastatic colorectal cancer patients\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23817662\n",
      "BRAF mutations are associated with lung cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23817129\n",
      "an unexpectedly higher frequency of BRAF mutations was observed in mucosal melanomas in Southern Italy.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23806056\n",
      "The present study demonstrates that concomitant BRAF mutation and RET/PTC rearrangement is a frequent event in papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23802768\n",
      "evaluated the survival impact of MET expression in patients with BRAF(V600E/K) advanced melanoma treated with vemurafenib\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23800934\n",
      "The findings support the hypothesis that BRAF-mutated cells may show resistance to the anticancer effects of aspirin in patients with colorectal cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23795354\n",
      "Co-amplification of these candidate genes or the CCND1 amplification along with either BRAF or NRAS mutations might be more important for prognosis than the presence of these alterations alone.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23791006\n",
      "Sinonasal intestinal-type adenocarcinomas share common alterations of the EGFR pathway with colorectal adenocarcinomas, except for a lower frequency of KRAS and BRAF mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23782679\n",
      "BRAF mutation rates varied by geographic location but not based on UV radiation\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23782496\n",
      "BRAF, NRAS, and c-Kit molecular analyses among patients affected by nail apparatus melanoma were investigated.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23776587\n",
      "The results indicate that BRAF mutant is a predictive biomarker for poor prognosis in mCRC patients undergoing anti-EGFR MoAbs therapy, especially in KRAS WT patients\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23775351\n",
      "demonstrating that the BRAF(T1799A) mutation is a clonal event in thyroid cancer\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23773459\n",
      "BRAF mutations are associated with colorectal neoplasms.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23771122\n",
      "We found that inherited variants of CDKN2A have no effect on the prevalence of BRAF/NRAS mutations in melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23763264\n",
      "Although moderate or strong cytoplasmic staining is specific for BRAF V600E mutations in colorectal adenocarcinoma, the VE1 monoclonal antibody is insufficiently sensitive to serve as an effective screening tool.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23755178\n",
      "Both the CRP single nucleotide polymorphism rs7553007 and KRAS/BRAF mutations were independent prognostic factors for colorectal cancer patients with synchronous liver metastasis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23752636\n",
      "BRAF mutation in the elderly is also exclusive of papillary carcinoma and is often significant. Furthermore, it is related to the classic variant and possibly to thyroid extravasation\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23744164\n",
      "The mutations of EGFR and BRAF genes were not found in HER2-mutated patients with brain metastasis from non-small cell lung cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23735514\n",
      "Selumetinib plus dacarbazine showed clinical activity in patients with BRAF-mutant cutaneous or unknown primary melanoma, reflected by a significant benefit in progression-free survival.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23726842\n",
      "report that Mps1/AKT and B-Raf(WT)/ERK signaling form an auto-regulatory negative feedback loop in melanoma cells\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23725167\n",
      "BRAF mutations are associated with papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23715079\n",
      "Case Report: BRAF mutation documented in folliculotropic metastatic melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23690527\n",
      "We found BRAF(V600E) mutations in the melanocytic nevi to be fully clonal, strongly suggesting that BRAF-activating mutations typically are early initiating events in melanocytic neoplasia.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23687957\n",
      "BRAFV600E mutation is not associated with papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23673558\n",
      "low BRAF as well as NRAS expression levels were associated with a longer progression-free survival in the total population\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23660947\n",
      "Establishment of molecular subgroups based on KRAS and BRAF mutation status is important and should be considered in future prognostic studies in colorectal carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23657789\n",
      "A BRAF mutation-specific (V600E) antibody detected tumors with BRAFV600E mutations and exhibited complete concordance with a DNA-based method.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23650027\n",
      "Detection of the BRAF V600E mutation in colorectal cancer by immunohistochemistry is a viable alternative to molecular methods\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23636013\n",
      "Braf mutations were not associated with the risk of lymph node metastasis in papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23633454\n",
      "The presence of NRAS or BRAF mutations in a mutually exclusive pattern in roughly half (47%) of conjunctival melanomas and the pattern of CNAs argue for conjunctival melanoma being closely related to cutaneous and mucosal melanoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23625203\n",
      "This study demonstrated that either BRAF or RAS mutations were present in two thirds of follicular variants of papillary thyroid carcinomas and these mutations were mutually exclusive.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23615046\n",
      "BRAF mutation is associated with poor response to anti-EGFR MoAbs and it is an adverse prognostic biomarker of the survival of patients with metastatic colorectal cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23613396\n",
      "K-RAS and B-RAF mutations do not seem to be predictive of treatment outcome as potential biomarkers for bevacizumab therapy in metastatic colorectal cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23612919\n",
      "BRAF alterations are associated with pediatric low grade gliomas and mixed neuronal-glial tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23603840\n",
      "We show that (V600E)BRAF upholds the activity of glycolysis and therefore the addiction to glycolysis de facto becomes an addiction to (V600E)BRAF.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23595630\n",
      "A combination of solid nodules, nodules with irregular contours, symptomatic nodules, and positive BRAF mutation has high predictive value for malignancy in patients with thyroid follicular lesion of undetermined signifi-cance.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23594689\n",
      "the clinical pathological relevance of BRAF mutation in cancer (Review)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23588369\n",
      "Our findings confirm that BRAF mutations originate in the serrated epithelium of colonic perineuriomas with crypt serration\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23584600\n",
      "and SSCA followed by Sanger sequencing are effective two-step strategies for the detection of BRAF mutations in the clinical setting.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23580256\n",
      "The overall BRAF V600E mutation rate was 70.4% and 100% in tall cell variant.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23579220\n",
      "Accurate diagnosis of rare BRAF mutations is crucial. Pyrosequencing is accurate, highly sensitive, reliable, and time saving to detect rare BRAF mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23571588\n",
      "In this retrospective multicenter study, the presence of the BRAF V600E mutation was significantly associated with increased cancer-related mortality among patients with papillary thyroid carcinom\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23569304\n",
      "Antitumor effects of vemurafenib are mediated by inhibiting oncogenic MAPK signaling in BRAF(V600)-mutant metastatic melanoma. Data suggest that inhibition downstream of BRAF should help to overcome acquired resistance.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23552385\n",
      "A high percentage of epithelioid giant cell glioblastoma multiformemanifest BRAF V600E mutation\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23549875\n",
      "Data indicate that concurrent BRAF and PI3K/mTOR blockade results in induction of apoptosis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23548132\n",
      "About one fourth of mCRC cases wild-type for KRAS codons 12 and 13 present other mutations either in KRAS, BRAF, or PIK3CA, many of which may explain the lack of response to anti-EGFR therapy observed in a significant proportion of these patients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23547069\n",
      "BRAF V600E mutation may identify a subset of grade 2 diffuse gliomas that have a distinct phenotype, incl. supratentorial location, chronic seizure disorder, and atypical radiographic and histologic features.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23544999\n",
      "In human BRAF papillary thyroid carcinomas, ERK kinase phosphorylation is decreased compared to normal thyroid glands.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23534744\n",
      "Molecular analysis of the BRAF T1799A mutation in fine needle aspiration biopsy specimens has high specificity and positive predictive value for papillary thyroid carcinoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23533272\n",
      "in cells expressing KIAA1549-BRAF, the fusion kinase functions as a homodimer that is resistant to PLX4720 and accordingly is associated with CRAF-independent paradoxical activation of MAPK signaling\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23533235\n",
      "genetic association studies in population in Italy: Data suggest that V600E mutation in BRAF in subjects with papillary thyroid carcinomas with/without lymph node metastases is not associated with disease progression.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23517740\n",
      "Aberrant BRAF splice variants with deletions in both kinase and RAS-binding domains in rheumatoid arthritis patients demonstrate that these BRAF splice variants constitutively activate MAPK through CRAF\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23511561\n",
      "A BRAF mutation was only detected in a single Japanese gastric cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23505540\n",
      "follow-up BRAFV600E mutation analysis may be helpful in the diagnosis of selected thyroid nodules negative for BRAFV600E mutation on initial analysis, which are assessed as suspicious malignant on ultrasonography.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23496275\n",
      "This study confirms that the BRAF mutation is differentially detected in each variant of papillary thyroid cancer and is strongly correlated with unfavorable clinicopathologic factors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23489693\n",
      "The novel melanoma cell lines were compared to metastatic cell lines (HBL, LND1), wild type (wt) for MC1R and BRAF genes.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23482591\n",
      "Results document the expression of RAC1b in normal thyroid cells as well as overexpression in a subset of PTCs. They suggest a possible interplay between BRAF V600E and RAC1b contributing to poor clinical outcome.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23482475\n",
      "BRAF mutation shows clinical significance in the prognosis of thyroid papillary cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23477830\n",
      "melanomas with activation of the BRAF/MAPK pathway have suppressed levels of MITF and PGC1alpha and decreased oxidative metabolism\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23476074\n",
      "BRAF V600E mutation testing modifies sensitivity or specificity of the Afirma Gene Expression Classifier in cytologically indeterminate thyroid nodules.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23463675\n",
      "V600R mutation and double (V600E -V600M) mutation were identified in two melanomas\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23463215\n",
      "In this manuscript, we provide an overview of the emerging scientific literature on dermatological adverse events arising out of BRAF inhibition.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23455323\n",
      "The Mcl-1 promoter is dependent on a STAT consensus-site for B-RAF-mediated activation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23448684\n",
      "An analysis of BRAF mutations in fast-growing melanomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23447565\n",
      "MITF-BCL2A1 as a lineage-specific oncogenic pathway in melanoma and underscore its role for improved response to BRAF-directed therapy.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23444215\n",
      "Data indicate that tumor regression was seen in three of five patients with BRAF-mutated, low pAKT melanomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23442159\n",
      "This study demonistrated that Dysembryoplastic neuroepithelial tumors share with pleomorphic xanthoastrocytomas and gangliogliomas BRAF(V600E) mutation and expression.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23435618\n",
      "BRAF V600E mutation was detected in 41/71 (58 %) gangliogliomas by immunohistochemistry, DNA sequencing was concordant in 60 of 62 analyzed cases, and BRAF V600E-mutated protein was localized predominantly to the neuronal compartment.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23435375\n",
      "BRAF(V600E) increases migration and invasion of thyroid cancer cells via upregulation of Snail with a concomitant decrease of its target E-cadherin.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23416953\n",
      "study identified two miRNAs (miR-21* and miR-203 that are differentially expressed in papillary thyroid carcinoma tissues with BRAF(V600E) and revealed their associations with clinicopathological features\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23416158\n",
      "AURKB and WEE1 are targets and biomarkers of therapeutic efficacy, lying downstream of (V600E)B-RAF in melanomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23412871\n",
      "The BRAF gene polymorphism (rs10487888) may not be a genetic determinant for increasing the risk of chronic periodontitis among the Iranian population\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23401454\n",
      "Studies identified 21 deleterious mutations MLH1, MSH2, MSH6 and BRAF.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23401445\n",
      "The role of BRAF V600E as targetable driver mutation in lung adenocarcinoma is strengthened by finding that in vivo expression of V600E in mice leads to development of invasive adenocarcinoma, a phenotype that is reversed when V600E expression is stopped.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23388101\n",
      "Report BRAF mutations in ovarian serous carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23374602\n",
      "BRAF and codon 12 KRAS mutations predict for adverse outcome of colorectal cancer patients receiving cetuximab.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23370668\n",
      "study suggests that highly aggressive papillary thyroid microcarcinoma may arise in a subset of patients with BRAF(V600E) mutation and tumors greater than 5 mm; multivariate analysis showed that tumor recurrence was not associated with BRAF(V600E)mutation\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23370429\n",
      "This is the first report of BRAF V600E mutation in endometrial cancer, indicating that it may contribute to tumorigenesis of endometrial cancer, although at a low frequency compared with KRAS mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23359496\n",
      "Kidins220 is a novel T-cell receptor (TCR)-interacting protein that couples B-Raf to the TCR. Kidins220 is mandatory for sustained Erk signaling and is crucial for TCR-mediated T cell activation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23355004\n",
      "The detected Merkel cell polyomavirus prevalence in non-small cell lung cancer in combination with the deregulated expression of BRAF and Bcl-2 genes suggests that these events are likely to contribute to the pathogenesis of non-small cell lung cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23354951\n",
      "Alternative splicing of exons 14, 15, 15b, 16b and 16c occurs in a considerable fraction of BRAF mRNA in normal colon and colorectal cancer cells and is independent of the V600E mutational status of the parental allele.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23352452\n",
      "Ras pathway activation via EGF treatment induced strong binding between B-Raf and C-Raf and a low level of binding between B-Raf and A-Raf.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23349307\n",
      "Data indicate that besides confirming the constant presence of BRAF-V600E in all patients with hairy cell leukemia, phospho-ERK1/ERK2 expression was observed.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23343956\n",
      "no association with BRAF-V600E mutation in gastroeosophageal tumors\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23334329\n",
      "Human neural crest progenitor cells are susceptible to BRAF(V600E)-induced transformation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23324583\n",
      "BRAF mutations is associated with colorectal cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23317446\n",
      "Results demonstrated the action of Dabrafenib and the inhibition of MAPK pathway in melanoma cell lines carrying BRAFV600D/R mutations; these results could be helpful to enlarge the number of patients who may benefit of a more effective targeted treatment\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23310942\n",
      "This study shows that BRAF mutation occurs in Nigerian colorectal cancers.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23307859\n",
      "High BRAF is associated with metastatic melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23297805\n",
      "No point mutations were identified in BRAF codon Val600Glu in the studied colorectal adenocarcinomas in the Turkish population.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23290787\n",
      "Studies indicate that BRAF mutations are identified in 40-50% of patients with melanoma, and treatment with either of two BRAF inhibitors (vemurafenib, dabrafenib) or the MEK inhibitor trametinib is associated with improved clinical benefit.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23287985\n",
      "Pulmonary Langerhans cell histiocytosis appears to be a clonal proliferation that may or may not have BRAF V600E mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23280049\n",
      "Preoperative mutation screening for BRAF(V600E) does not meaningfully improve risk stratification and is unlikely to alter the initial management of patients with indeterminate nodules.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23274581\n",
      "BRAF mutation is associated with esophageal squamous cell carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23263826\n",
      "we deduce that in the absence of mutation activation, B-Raf overexpression or downregulation is a protective event, since it delays the development of both malignant and benign thyroid tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23253715\n",
      "The status of BRAF(V600E) mutation was more frequent in multifocal PTC patients with lymph node metastasis and diagnosis at later age.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23246082\n",
      "the role of BRAF mutations in melanoma and colorectal cancer, focusing on similarities and differences of BRAF mutations (Review)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23242808\n",
      "Data indicate that BRAF and EGF receptor or SRC family kinase inhibition blocked proliferation and invasion of the resistant tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23237741\n",
      "Patients with V600R BRAF mutations can be treated successfully with oral BRAF inhibitors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23235345\n",
      "the BRAF V600E mutation is not pathobiologically relevant in primary central nervous system lymphoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23224067\n",
      "Mutations affecting BRAF, EGFR, PIK3CA, and KRAS are not associated with sporadic vestibular schwannomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23208503\n",
      "results suggest that mutant B-RAF signaling downregulates Tiam1/Rac activity resulting in an increase in N-cadherin levels and a decrease in E-cadherin levels and ultimately enhanced invasion\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23207070\n",
      "The present study revealed that ESCC of Brazilian patients do not present mutations in hot spots of EGFR, K-RAS and BRAF and only a minor proportion present overexpression of EGFR or HER2.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23203004\n",
      "BRAF (V600E) is non-associated with Gal-3 expression, whereas it is associated with cytoplasmatic localization of p27kip1 and higher CK19 expression in papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23192956\n",
      "BRAF (V600E) mutation is associated with papillary thyroid microcarcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23192464\n",
      "Aim of this work is to provide a detailed comparison of clinical-pathologic features between well-differentiated and poorly differentiated tumors according to their BRAF and RASSF1A status.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23190890\n",
      "Oncogenic B-RAF(V600E) signaling induces the T-Box3 transcriptional repressor to repress E-cadherin and enhance melanoma cell invasion.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23190154\n",
      "Our findings suggest that RAS pathway activation due to BRAF V600E and KRAS mutations is an important event in a subset of peripheral nerve sheath tumours not related to neurofibromatosis\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23188063\n",
      "BRAF mutations were correlated with poor overall survival in the full patient cohort\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23179992\n",
      "BRAF (V600E) mutation is associated with papillary thyroid carcinomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23163107\n",
      "The BRAF(V600E) mutation might be associated with a more aggressive phenotype and a poor prognosis in classic variant of papillary thyroid carcinomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23161722\n",
      "data confirm that among lymphoproliferative disorders, BRAF V600E mutation is restricted to hairy cell leukemia (HCL); no mutations were identified in variant HCL, NMZL, ENMZL, PTLD, PTCL, ALCL, or LGL proliferations\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23161556\n",
      "BRAF mutation as a new serum marker for papillary thyroid carcinomas were not detectable in patientts diagnosed with thyroid neoplasms.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23159116\n",
      "V600E point mutation was identified in the BRAF gene in 3 intramucosal nevi and in 2 melanomas. Only 1 blue nevus harbored the GNAQ209 mutation\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23158172\n",
      "BRAF mutational status is predictive of papillary thyroid carcinoma recurrence\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23157824\n",
      "Codon 12, 13 in KRAS gene and codon 600 in BRAF gene are the most common mutation points in Chinese colorectal cancer. KRAS and BRAF mutations are mutually exclusive. KRAS and BRAF gene mutation is higher in females than that in males.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23157823\n",
      "In Chinese colorectal carcinoma patients, BRAF mutation is associated with tumor differentiation and primary tumor sites.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23157614\n",
      "Data indicate that the presence of the BRAF V600E mutation was more frequent in women, but this gender difference was not statistically significant.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23153455\n",
      "These findings indicate that ABCG2 confers resistance to vemurafenib in A375 cells, suggesting involvement of this transporter in acquired resistance to vemurafenib.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23138171\n",
      "Clinical characteristics of colorectal cancer with the V600E BRAF mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23132792\n",
      "BRAFV600E mutation is associated with cervical lymph node metastasis and recurrence in papillary thyroid cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23125007\n",
      "One hundred and ten patients (51%) were identified who were potentially nonresponders to anti-EGFR therapy:  13/117 (11.1%) had the V600E BRAF mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23110075\n",
      "Study demonstrates that chromosomal instability commonly occurs in advanced BRAF mutant/MSS colorectal cancers where it may contribute to poorer survival, and further highlights molecular similarities occurring between these and BRAF wild type cancers.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23098991\n",
      "Studied differential miRNA expression in metastatic colorectal cancer by microarrays from primary tumors of 33 patients who had wild-type KRAS/BRAF and third- to sixth-line anti-EGFRmAb treatment, with/without irinotecan.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23096702\n",
      "We found that NRAS-mutant melanomas were significantly more likely from older patients and BRAF-mutant melanomas were more frequent in melanomas from the trunk.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23096133\n",
      "BRAF mutation is associated with pleomorphic xanthoastrocytomas with anaplastic features.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23095503\n",
      "Desmoplastic malignant melanoma: a study of ten cases and status of BRAF mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23088640\n",
      "analysis suggests that BRAF mutations occur at a low frequency in chronic lymphocytic leukemia\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23069257\n",
      "Histopathologic changes suggesting prolapsed rectal mucosa should take precedence over BRAF results in diagnosing sessile serrated adenomas in the rectum.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23066120\n",
      "The BRAF(V600E) mutation was demonstrated to be a poor prognostic factor for the persistence of the disease independent from other clinical-pathological features in low-risk intrathyroid papillary thyroid carcinoma patients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23062653\n",
      "BRAF mutation was not found to be significantly associated with lymph node metastasis in patients with papillary thyroid cancer\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23056577\n",
      "A systematic review and meta-analysis revealed that BRAF mutation is an absolute risk factor for patient survival in colorectal cancer and melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23055546\n",
      "BRAF mutation was associated with lymph node metastases (LNM), advanced stage, extrathyroidal extension, tumor size, male gender, multifocality, absence of capsule, classic PTC, and tall-cell variant papillary thyroid cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23055340\n",
      "KRAS and BRAF mutations are infrequent or absent, respectively in Intestinal-type sinonasal adenocarcinoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23051629\n",
      "Increased BRAF mutation with age along with the lack of a UVR magnitude-BRAF mutation association suggests that duration of exposure rather than UVR exposure dose is the more likely link to acquiring mutations in melanocytic nevi.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23041829\n",
      "Findings support the potential use of immunohistochemistry as an ancillary screening tool to assess the BRAFV600E mutation status in primary cutaneous melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23039341\n",
      "Studied the cytotoxicity and anti-tumour activity of novel MEK inhibitor, E6201, in a panel of melanoma cell lines. Most melanoma cell lines were sensitive or hypersensitive to E6201; the sensitivity correlated with wildtype PTEN and mutant BRAF status.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23036672\n",
      "We describe 3 patients with BRAF V600E mutation metastatic melanoma in whom treatment with vemurafenib resulted in prompt extracranial disease response but progression of metastatic disease in the brain.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23033302\n",
      "the spectrum and frequency distribution of the identified KRAS and BRAF mutations in Serbian patient with colorectal cancer are in good accordance with literature data.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23026937\n",
      "Immunohistochemistry is highly sensitive and specific for the detection of V600E BRAF mutation in melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23021375\n",
      "EGFR and downstream genetic alterations in KRAS/BRAF and PI3K/AKT pathways have roles in colorectal cancer and treatment [review]\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23014346\n",
      "Braf mutation status is not significantly associated with poor survival for melanoma in Koreans.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23010994\n",
      "BRAF mutation is suggested to be poor prognostic factors in CRLM.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23010278\n",
      "B-RAF upregulates SGLT1 activity, an effect requiring vesicle insertion into the cell membrane.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/23009221\n",
      "consistent with previous studies, it was concluded that the incidence of BRAF V600E mutation in adult acute lymphoblastic leukemia, if any, is extremely infrequent\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22996177\n",
      "This report is the first to identify the rare, variant BRAF V600D mutation in LCH, and provides support for constitutively activated BRAF oncogene-induced cell senescence as a mechanism of regression in congenital, benign LCH.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22973979\n",
      "found a significantly increased risk of papillary thyroid carcinoma attributed to the SNP variants rs17161747, rs1042179, and rs3748093 for those with a family history of cancer, for smokers, and for both those of age <45 years and nondrinkers\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22972589\n",
      "Higher response rates and longer time to progression were observed with selumetinib-containing regimens in patients who had melanoma that harbored a BRAF mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22946697\n",
      "Data indicate that of the 32 cardio-facio-cutaneous syndrome (CFC) patients, 28 (88%) had a known mutation in a gene that is causative for CFC, including BRAF (n = 21), MEK1 (n = 2), MEK2 (n = 4), and KRAS (n = 1).\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22941165\n",
      "The BRAF V600E mutation is the only independent predictor of compartment lymph node metastasis in papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22938585\n",
      "Data indicate that KRAS, BRAF, PIK3CA, and AKT1 mutations can be rapidly and accurately detected for cancer diagnosis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22932786\n",
      "Thus, in this meta-analysis, the BRAF mutation in PTC was significantly associated with PTC recurrence, lymph node metastasis, extrathyroidal extension, and advanced stage AJCC III/IV.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22931913\n",
      "We conclude that the presence of BRAF mutation, NRAS mutation, and the absence of an immune-related expressed gene profile predict poor outcome in melanoma patients with macroscopic stage III disease.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22930283\n",
      "BRAF mutation is associated with early stage disease and improved outcome in patients with low-grade serous ovarian cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22926515\n",
      "ARAF seems to stabilize BRAF:CRAF complexes in cells treated with RAF inhibitors and thereby regulate cell signaling in a subtle manner to ensure signaling efficiency\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22918165\n",
      "BRAF(V600E) mutation is an early event in thyroid carcinogenesis, and is associated with distinctive morphology and aggressive features even in papillary thyroid microcarcinomas\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22912864\n",
      "Data indicate that mutation frequency in malanoma patients was found witih BRAF(V600) in 51%, NRAS in 19%, PI3K pathway in 41% and PTEN in 22%.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22899730\n",
      "The presence of a BRAF c.1799T>A (p.V600E) mutation is associated with significantly poorer prognosis after colorectal cancer diagnosis among subgroups of patients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22898351\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "MSI status, KRAS and BRAF mutation rates varied remarkably among the colonic carcinoma subsites irrespective of right- and left-sided origin.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22892521\n",
      "The results of this study supported an important role for BRAF duplication and MAPK pathway activation in gliomas of the optic nerve proper.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22887810\n",
      "A K601E BRAF mutation is associated with papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22880048\n",
      "This study reveals a novel molecular mechanism underlying the regulation of feedback loops between the MAPK and AKT pathways.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22879539\n",
      "High prevalence of BRAF V600E mutations is associated with Erdheim-Chester disease but not in other non-Langerhans cell histiocytoses.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22876591\n",
      "Cardio-facio-cutaneous syndrome is caused by heterogeneous mutations in BRAF gene.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22870241\n",
      "High-throughput genotyping in metastatic esophageal squamous cell carcinoma identifies phosphoinositide-3-kinase and BRAF mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22863493\n",
      "The BRAFV600E occurs exclusively in papillary thyroid carcinoma and papillary carcinoma-derived anaplastic cancer, rising as a specific diagnostic marker for this tumor when identified in cytological / histological exams\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22859608\n",
      "BRAFV600E mutation is associated with Langerhans cell histiocytosis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22858857\n",
      "A review summarizes the role of the BRAF V600E mutation in the development and progression of thyroid cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22850568\n",
      "This study reveals a novel mechanism of immune suppression sensitive to BRAF(V600E) inhibition, and indicates that clinical blockade of IL-1 may benefit patients\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22833462\n",
      "Investigated BRAF and RAF1 alterations in Chinese prostate cancer.Found BRAF truncated in five of 200 informative Chinese cases & RAF1 was truncated in three of 204 informative cases and genomic rearrangements were correlated w/high Gleason scores.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22826437\n",
      "RAF1(D486N), as well as other kinase-impaired RAF1 mutants, showed increased heterodimerization with BRAF, which was necessary and sufficient to promote increased MEK/ERK activation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22826122\n",
      "It was concluded that extracellular kinase-mediated up-regulation of c-myc by K-Ras or B-Raf oncogenes disrupts the establishment of apical/basolateral polarity in colon epithelial cells independently of its effect on proliferation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22824468\n",
      "Single Nucleotide Polymorphisms in BRAF gene is associated with diseases.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22820660\n",
      "No BRAF V600E mutations were detected in nonserous epithelial ovarian tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22820187\n",
      "these results link epigenetic genes to methylation and suppression of tumor suppressor genes as a mechanism involved in BRAFV600E-promoted melanoma tumorigenesis and uncover a novel molecular signature that predicts a poor prognosis of melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22814862\n",
      "we found no cases of Rosette-forming glioneuronal tumors of the fourth ventricle showing KIAA1549-BRAF gene fusion or BRAF (V600E) mutation\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22809251\n",
      "As has been reported in other common types of melanoma, V600 BRAF mutation is the most common mutation of those tested in spindle cell melanoma. NRAS or KIT mutation appears to be rare, if not completely absent.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22799316\n",
      "Preoperative BRAF mutation was a predictive factor for occult contralateral papillary thyroid microcarcinoma presence.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22798500\n",
      "In CRC patients treated with cetuximab, activating mutation signatures for BRAF (58 genes) were developed.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22798288\n",
      "Data show clinical significance to BRAF(L597) mutations in melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22797077\n",
      "RSK regulates activated BRAF signalling to mTORC1 and promotes melanoma growth\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22773810\n",
      "Lung cancers with acquired resistance to EGFR inhibitors occasionally harbor BRAF gene mutations but lack mutations in KRAS, NRAS, or MEK1.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22772867\n",
      "BRAF (V600) mutations are are associated with melanomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22770943\n",
      "BRAF mRNA expression may help to identify PTC among thyroid nodules independently of the presence of BRAFV600E mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22767446\n",
      "study found a relatively higher B-Raf serine/threonine-protein kinase (BRAF)(V600E) mutation rate in classical type papillary thyroid carcinomas than in other similar studies\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22752848\n",
      "study reports a novel complex BRAF mutation identified in 4/492 Japanese papillary thyroid carcinoma(PTC) cases; findings suggest the BRAF(V600delinsYM)mutation, is a gain-of-function mutation and plays an important role in PTC development\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22751131\n",
      "B-Raf/MKK/ERK controls key aspects of cancer cell behavior and gene expression by modulating a network of miRNAs with cross-regulatory functions.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22743296\n",
      "BRAF V600E mutation is associated with response to vemurafenib in lung adenocarcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22742884\n",
      "Vemurafenib is effective for advanced melanomas expressing the BRAF V600E mutations [review]\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22740704\n",
      "These results clearly prove that the BRAFV600E mutation is not associated with the development of distant metastases or fatal outcome in papillary thyroid carcinoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22732794\n",
      "BRAF V600E mutation revealed a strong association with specific histological variants of papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22730329\n",
      "Reactivation of mitogen-activated protein kinase (MAPK) pathway by FGF receptor 3 (FGFR3)/Ras mediates resistance to vemurafenib in human B-RAF V600E mutant melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22727996\n",
      "BRAF V600E mutations are present in approximately 90% of all kidney metanephric adenoma cases, serving as a potential valuable diagnostic tool in the differential diagnosis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22706026\n",
      "The combined effects of EGFR downregulation, ligand competition, and immune effector function conspire to inhibit tumor growth in xenograft models of cetuximab-resistant BRAF and KRAS mutant cancers.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22705994\n",
      "Hairy cell leukemia cell lines expressing annexin A1 and displaying B-cell receptor signals characteristic of primary tumor cells lack the signature BRAF mutation to reveal unrepresentative origins.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22702340\n",
      "In papillary thyroid carcinoma BRAFV600E is associated with increased expression of the urokinase plasminogen activator and its cognate receptor, but not with disease-free interval.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22699145\n",
      "Data indicate that 14% with pancreatic ductal adenocarcinomas (PDACs) and 7% ampullary adenocarcinomas (A-ACs) had mutations in both KRAS and BRAF.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22694820\n",
      "In papillary thyroid cancer, significant correlations between the methylation status of four genes (TIMP3, RASSF1A, RARbeta2 and DCC) and the V600E BRAF mutation were found.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22684223\n",
      "The presence of BRAF mutations in these adenomatous precursors to colon cancer suggests that they represent sessile serrated adenomas with complete cytologic dysplasia.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22681706\n",
      "BRAFV600E mutation is associated with lymph node metastasis in multiple papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22649091\n",
      "Patient's BRAF mutation was likely responsible for his tumor's marked response to dasatinib, suggesting that tumors bearing kinase-impaired BRAF mutations may be exquisitely sensitive to dasatinib.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22639828\n",
      "Data suggest that BRAF V600E mutation may not be widespread in hematologic malignancies, excluding hairy-cell leukemia (HCL).\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22628551\n",
      "Data show that RNF149 (RING finger protein 149) interacts with wild-type BRAF.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22614978\n",
      "BRAF/NRAS mutations were identified in 58% of primary melanomas (43% BRAF; 15% NRAS)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22614711\n",
      "BRAF p.Val600Lys mutations were present at a relatively high frequency in the cohort of metastatic melanoma patients (27/183, 15%)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22592144\n",
      "Immunohistochemical detection of the mutated V600E BRAF protein in papillary thyroid carcinoma may facilitate mutational analysis in the clinical setting.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22591444\n",
      "Our results suggest that in a small fraction of diffuse gliomas, KIAA1549-BRAF fusion gene and BRAF(v600E) mutation may be responsible for deregulation of the Ras-RAF-ERK signaling pathway\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22586484\n",
      "In the present study, we did not find any significant correlations between KRAS, BRAF and PIK3CA mutations and the loss of PTEN expression and various clinicopathological features in Chinese patients with colorectal cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22581800\n",
      "BRAF regulates expression of long noncoding RNAs in melanocytes and melanoma cells\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22579930\n",
      "KRAS, BRAF, and PIK3CA mutations in colorectal cancer have sustained prevalence rate in the Taiwanese population.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22568401\n",
      "These results suggest that low-grade diffuse gliomas with 1p/19q loss have frequent BRAF gains\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22549934\n",
      "The mTOR pathway could be a good target to enhance therapy effects in certain types of thyroid carcinoma, namely in those harboring the BRAF(V600E) mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22549727\n",
      "abrogation of BRAFV600E-induced senescence contributes to melanomagenesis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22549559\n",
      "Recurrent/persistent PTC in the central compartment typically harbors the BRAF mutation\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22535974\n",
      "The diagnostic sensitivity for thyroid cancer is significantly increased by BRAF V600E mutation analysis, indicating that the screening for BRAF mutation in FNAB samples has a relevant diagnostic potential.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22535154\n",
      "study shows there are clinically and biologically distinct subtypes of BRAF-mutant metastatic melanoma, defined by genotype, with distinct etiology and behavior; cumulative sun-induced damage in primary cutaneous melanoma and older age are associated with V600K BRAF mutations;it establishes prevalence of the BRAF mutation by age-decade\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22534474\n",
      "BRAF and KIT mutations have been found in Japanese melanoma patients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22531170\n",
      "Demonstrate that BRAF V600E mutation-specific antibody can be used in immunohistochemical diagnosis of hairy cell leukemia.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22531127\n",
      "study concludes that generally, overweight increases the risk of colorectal cancer; taller individuals have an increased risk of developing a tumour with a BRAF mutation or microsatellite instability\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22522845\n",
      "In signet ring cell carcinoma, BRAF V600E mutation adversely affects survival in microsatellite-stable tumors, but not in high-level microsatellite-unstable tumor\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22516966\n",
      "Report upregulation of Bim and the splicing factor SRp55 in melanoma cells from patients treated with selective BRAF inhibitors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22515520\n",
      "Mutation BRAF transforms cells through cross talk with developmental pathways Hedgehog and Wnt, as well as by deregulation of colorectal cancer related kinase pathways.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22515292\n",
      "BRAF V600E is common in patients with low-risk papillary thyroid carcinoma but does not predict recurrence.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22514085\n",
      "The tumor with T1799A BRAF mutation and tumor sizes of 2 cm or more were clinicopathologic parameters associated with lower STAT1 activity.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22510884\n",
      "It was shown that the dimer interface within the kinase domain plays a pivotal role for the activity of B-Raf and several of its gain-of-function mutants.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22510757\n",
      "Patients with serrated polyposis syndrome referred to genetics clinics had a pan-colonic disease with a high polyp burden and a high rate of BRAF mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22508706\n",
      "The analysis of BRAF mutations by pyrosequencing is useful to refine the risk stratification of patients with papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22506009\n",
      "The (600DLAT)B-RAF and (V600E)B-RAF mutations were found enriched in DNA and mRNA from the CD1a+ fraction of granuloma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22500044\n",
      "Highly sensitive and specific molecular assays such as MEMO sequencing are optimal for detecting the BRAF mutations in thyroid FNAC because these techniques can detect PTC that might be missed by cytology or less sensitive molecular assays.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22498935\n",
      "No BRAF V600E mutations were indentified in this study of patients with endometrial cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22492957\n",
      "BRAF V600E is associated with gliomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22488961\n",
      "prevalence of the BRAF(V600E) mutation increased with increased tumor size\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22471666\n",
      "An update on malignancies displaying high frequencies of BRAF mutations and the mechanisms underlying the side effects and drug resistance phenomena associated with Raf inhibitors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22471241\n",
      "Out of 1041 Korean patients with papillary thyroid carcinoma, 0.4% had rare types of BRAF mutation and three new somatic mutations were identified\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22459936\n",
      "BRAF mutations play a limited role in the development of sinonasal cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22456166\n",
      "Report marked differences in the genetic pattern of the BRAF or NRAS mutated and wild-type melanoma subgroups.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22451557\n",
      "The BRAF(V600E) mutation analysis from FNA specimens for calcified thyroid nodules may be performed for a greater negative predictive value and unveil the malignancy in 25% of indeterminate or nondiagnostic cytology.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22435913\n",
      "analysis of a patient with pancreatic metastasis arising from a BRAF(V600E)-positive papillary thyroid cancer [case report]\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22431868\n",
      "EFVPTC 1 patient BRAFV600E mutation, NVPTC 2 patients, FVPTC 2 patients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22431777\n",
      "Effective use of PDT in the treatment of BRAF inhibitor-associated KAs and SCCs.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22430215\n",
      "expression of these oncogenes markedly stimulated ERK1/2 activities and morphologically transformed IECs. Importantly however\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22430208\n",
      "We propose that , and that persistent phosphorylation of Mps1 through BRAF(V600E) signaling is a key event in disrupting the control of centrosome duplication and chromosome stability that may contribute to tumorigenesis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22430133\n",
      "The prevalence of EGFR, KRAS, BRAF and PIK3CA somatic mutations in 861 randomly selected Chinese patients with non-small cell lung cancer\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22429583\n",
      "Article reviews the current understanding of BRAF gene, its structure, expression, and signal pathway in non-small cell lung cancer. [Review]\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22427190\n",
      "Investigation the prevalence of mutations in the BRAF gene and its correlation with demographic characteristics, tumor location and stage in 100 colorectal carcinoma patients from India.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22426956\n",
      "genetic association studies in population in Turkey: Data suggest that a mutation in BRAF (V600E; found in 39.45% of patients) is associated with aggressiveness of papillary thyroid neoplasms; lymph node metastasis increases when mutation is present.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22426079\n",
      "Data indicate that TaqMan(R) Mutation Detection assay is an important technology to consider in the field of mutation detection for KRAS, BRAF and EGFR point mutation screening.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22417847\n",
      "we have analyzed the prevalence of somatic mutations in the FGFR3, PIK3CA, AKT1, KRAS, HRAS, and BRAF genes in bladder cancers\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22398042\n",
      "In a cohort of Indian patients with ulcerative colitis, with or without neoplasia, none showed the BRAF mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22395615\n",
      "findings show (V600E)B-RAF copy-number gain as a mechanism of acquired B-RAF inhibitor resistance in 4 out of 20 patients treated with B-RAF inhibitor\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22393095\n",
      "Patient diagnosed with colon cancer shows poor prognosis with BRAF genetic mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22382362\n",
      "Eleven patients displayed Durable Disease Control (DDC) of which 55% had BRAF-V600E mutation positive tumors and 45% did not.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22376167\n",
      "The V600E BRAF mutation in papillary thyroid carcinomas may contribute to the initiation of the glycolytic phenotype and confers growth advantages in cancer\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22376079\n",
      "evidence presented that ERK activation occurs in a K-ras or B-raf -independent manner in the majority of primary colon cancer cases; B-raf mutations are not associated with mismatch-repair deficiency through loss of hMLH1 or hMSH2 expression\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22374786\n",
      "The presence of activating GNAS mutations, in association with KRAS or BRAF mutations, is a characteristic genetic feature of colorectal villous adenoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22368298\n",
      "review demonstrates that tumour BRAF V600E mutation, and MLH1 promoter 'C region' methylation specifically, are strong predictors of negative MMR mutation status[review]\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22367297\n",
      "A distinct subset of atypical Spitz tumors is characterized by BRAF mutation and loss of BAP1 expression.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22361037\n",
      "This is the first reported study of the relationship between CK20/CK7 immunophenotype, BRAF mutations and microsatellite status in colorectal carcinomas\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22358007\n",
      "(BRAF(V600E))detected in 141/170 malignant thyroid nodules (82.9%) (140 PTCs and one follicular variant of PTC). BRAF status not associated with US features with the exception of a negative relation between BRAF(V600E) and an irregular shape (p = 0.004).\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22339435\n",
      "Data suggest that the BRAF V600E mutation does not seem to play a role in myeloid malignant transformation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22335197\n",
      "BRAF V600E mutation-positive papillary thyroid carcinomas (PTCs) displayed infiltrative growth, stromal fibrosis, psammoma bodies, plump eosinophilic tumour cells, and classic fully developed nuclear features of PTC.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22331825\n",
      "BRAF mutation is an independent prognostic biomarker for colorectal liver metastasectomy.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22331186\n",
      "BRAFmut as a useful marker in hairy cell leukemia.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22317887\n",
      "Report of oncogenic BRAF/KRAS mutations in sporadic glomus tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22317764\n",
      "Data indicate that 266 (76.2%) tumors harbored EGFR mutations, 16 (4.6%) HER2 mutations, 15 (4.3%) EML4-ALK fusions, 7 (2.0%) KRAS mutations, and 2 (0.6%) BRAF mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22314188\n",
      "Colon adenocarcinomas with BRAF mutations have morphologic characteristics distinct from those with KRAS mutations and BRAF-mutated proximal colonic adenocarcinomas with proficient DNA mismatch repair have an aggressive clinical course.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22294102\n",
      "No hotspot mutations in Braf were found in oral squamous cell carcinoma in a Greek population.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22287190\n",
      "BRAF mutation is associated with colorectal serrated adenocarcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22282465\n",
      "In naive GISTs carrying activating mutations in KIT or PDGFRA a concomitant activating mutation was detected in KRAS (5%) or BRAF (about 2%) genes. I\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22258409\n",
      "Mutational activation of both BRAF and PIK3CA genes does contribute to hepatocellular tumorigenesis at somatic level in Southern Italian population.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22250191\n",
      "During therapy with selective BRAF inhibitors, panniculitis with arthralgia represents a new adverse effect that can require dose reduction.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22249628\n",
      "None of the molecular marker mutations that were analyzed in this study, including the BRAF mutation, predicted lymph node metastasis in classic papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22246856\n",
      "BRAF V600E mutation in low and intermediate grade lymphomas is associated with frequent occurrence in hairy cell leukaemia.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22245873\n",
      "No BRAF mutations were found in colon adenocarcinomas from renal transplant recipients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22235286\n",
      "evidence for heterogeneity of the BRAF(V600E) mutation within individual melanoma tumor specimens\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22233696\n",
      "Sessile serrated adenomas are precursors of sporadic colorectal cancers with microsatellite instability.Identified a novel surface microstructure, the Type II open-shape pit pattern (Type II-O), which was specific to SSAs with BRAF mutation and CIMP.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22230299\n",
      "One chronic lymphocytic leukaemia patient and one patient with B-prolymphocytic leukaemia were found to harbour the BRAF V600E mutation\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22228154\n",
      "In patients with colorectal adenocarcinoma, there were significant differences between BRAF wild-type and mutant tumors in age, female sex, proximal tumor location, frequency of microsatellite instability, and survival.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22227015\n",
      "The findings show mutant BRAF-induced oncogenic stress manifests itself by DNA damage and growth arrest by activating the pCHK2-p53-p21 pathway.It also confers tumor-promoting phenotypes such as the up-regulation of GLUT1 and enhances glucose metabolism.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22214007\n",
      "Although it constitutes a poor prognostic factor in colorectal cancer, it is not conclusive if it interferes with a poor therapeutic effect when cetuximab is used.[review]\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22210875\n",
      "Our results suggest that HCLv and IGHV4-34(+) HCLs have a different pathogenesis than HCLc and that a significant minority of other HCLc are also wild-type for BRAF V600.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22210186\n",
      "Patients with microsatellite instability tumor phenotype had favorable prognosis, but in those with the V600E BRAF mutation higher recurrence rate was observed.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22203991\n",
      "These results provide a functional link between oncogenic BRAF and angiogenesis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22199339\n",
      "analysis of BRAF gene mutations in non-small cell lung cancer\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22199277\n",
      "RET mutations may have a role in medullary thyroid carcinoma, while BRAF, AKT1, and CTNNB1 do not; the role of HRAS, KRAS, and NRAS mutations are not determined\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22194995\n",
      "These data support a model where the continuous regenerative process initiated by oncogenic B-RAF-driven alveolar disruption provides a tumor-promoting environment associated with chronic inflammation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22190283\n",
      "B-Raf gene mutation primarily occurs at two loci--the exon 11 glycine loop and the activation area of exon 15--in surgically resected specimens of hepatocellular carcinoma patients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22190222\n",
      "The BRAF(V600E) mutation was associated with high-risk clinicopathologic characteristics in patients with papillary thyroid cancer (PTC). The BRAF(V600E) mutation may be a potential prognostic factor in PTC patients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22189819\n",
      "Aberrant gene methylation driven by BRAF(V600E) altered expression of the DNA methyltransferase 1 and histone methyltransferase EZH2 profoundly.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22180495\n",
      "Findings suggest that the BRAF inhibitor vemurafenib in combination with standard-of-care or novel targeted therapies may lead to enhanced and sustained clinical antitumor efficacy in CRCs harboring the BRAF(V600E) mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22178589\n",
      "Report mutations in KRAS, EGFR, and BRAF in cholangiocarcinoma and identify therapeutic targets for tyrosine kinase inhibitors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22174938\n",
      "The antibody response against the catalytic domain of BRAF is not specific for rheumatoid arthritis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22170714\n",
      "BRAF mutation in papillary thyroid carcinoma is a later subclonal event, its intratumoral heterogeneity may hamper the efficacy of targeted pharmacotherapy, and its association with a more aggressive disease should be reevaluated.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22157687\n",
      "BRAF and KRAS mutations were observed in six (46.2%) and four (30.3%) filiform serrated adenomaS, respectively.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22156468\n",
      "BRAF mutations enhance the predictability of malignancy in thyroid follicular lesions of undetermined significance.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22156467\n",
      "The BRAF V600E mutation is associated with a higher pathological stage at surgery and a higher rate of recurrence.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22150560\n",
      "papillary thyroid cancers in young patients display a low prevalence of the already identified oncogenic alterations; the increasing prevalence with age is mainly due to V600E BRAF mutation\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22147942\n",
      "BRAF mutation is associated with inferior survival in stage III colon cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22147429\n",
      "V600E mutation of the BRAF gene reported to be associated with poor prognosis of germ cell tumors in adults prognostic biomarkers cannot necessarily be transferred from one age group to the other.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22145942\n",
      "Pyrosequencing of BRAF V600E in routine samples of hairy cell leukaemia identifies CD5+ variant hairy cell leukaemia that lacks V600E.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22137342\n",
      "thieno[2,3-d]pyrimidines are B-Raf inhibitors\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22136270\n",
      "Case Report: describe case of follicular thyroid carcinoma with BRAF mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22133769\n",
      "BRAF mutations are associated with hairy cell leukemia and related lymphoproliferative disorders.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22114137\n",
      "Overall, no difference existed in microsatellite instability or BRAF mutation frequencies between African Americans and Caucasians with colorectal neoplasms.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22105775\n",
      "BRAF (V600E) is a prevalent genetic alteration in adult sporadic papillary thyroid carcinoma in Indian cohort and it may be responsible for the progression of its classic variant.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22105174\n",
      "Murine thyroid tumors carrying the human BRAF(V600E) mutations are exquisitely dependent on the oncoprotein for viability.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22072743\n",
      "BAG3 protein sustains anaplastic thyroid tumor growth in vitro and in vivo. The underlying molecular mechanism appears to rely on BAG3 binding to BRAF, thus protecting it from proteasome-dependent degradation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22072557\n",
      "BRAF V600E mutation is associated with hairy cell leukemia and other mature B-cell neoplasms\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22065586\n",
      "Ras induces DR5 expression through co-activation of ERK/RSK and JNK signaling pathways\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22043994\n",
      "This article reviewes the spectrum of KRAS/BRAF genotype and the impact of KRAS/BRAF mutations on the clinicopathological features and prognosis of patients with colorectal cancer. [review]\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22039425\n",
      "study examined the clinical characteristics and outcomes of patients with mutant BRAF advanced cancer; conclude that BRAF appears to be a druggable mutation that also defines subgroups of patients with phenotypic overlap, albeit with differences that correlate with histology or site of mutation\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22038996\n",
      "Results support evaluation of BRAF(V600E)-specific inhibitors for treating BRAF(V600E) malignant astrocytomas (MA) patients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22033631\n",
      "high prevalence of BRAF (V600E) mutation is associated with synchronous bilateral papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22028477\n",
      "BRAF V600E mutation is associated with hairy cell leukemia and B-cell neoplasms\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22027477\n",
      "Postmenopausal hormone therapy was associated with borderline statistically significant risk reductions for BRAF-wildtype tumours among women with prolonged exposure to Postmenopausal hormone therapy.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22012135\n",
      "An integrated approach combining both VE1 mutant protein immunohistochemistry and genetic analysis may increase the diagnostic accuracy of BRAF mutation analysis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/22006538\n",
      "DNA methylation of each marker was quantified using combined bisulfite restriction analysis (COBRA) and analyzed along with various genetic factors associated with CRC [the BRAF and KRAS mutations, MLH1 methylation and microsatellite instability\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21948220\n",
      "In malignant FNABs in papillary thyroid carcinoma, BRAF(V600E) mutation was significantly associated with presence of extra-thyroidal extension and metastases after surgery.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21943101\n",
      "BRAF mutation V600E significantly induces cell migration and invasion properties in vitro in colon cancer cells\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21937738\n",
      "A prominent epigenetic mechanism through which BRAF V600E can promote papillary thyroid cancer tumorigenesis by altering the methylation and hence the expression of numerous important genes.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21936566\n",
      "this novel B-Raf fusion protein (SND-1 was identified as the B-Raf fusion partner) presents a novel target with potential clinical implications in the treatment of patients resistant to c-Met inhibitors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21915661\n",
      "Aberrant CIMP was detected in 16% of chromosomal instable tumors and in 44% of both microsatellite instable and microsatellite and chromosomally stable carcinomas\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21909080\n",
      "CXCR4 expression and BRAF mutation status could cooperatively induce and promote a more aggressive phenotype in papillary thyroid carcinoma through several pathways and specifically increase the tumors' spread outside of the thyroid gland.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21906875\n",
      "BRAF mutations are of pathogenetic significance in wild type gastrointestinal stromal tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21903858\n",
      "BRAF(V600E) causes upregulation of TIMP-1 via NF-kappaB. TIMP-1 binds then its surface receptor CD63, leading eventually to Akt activation, which in turn confers antiapoptotic behavior and promotion of cell invasion.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21901162\n",
      "In sporadic colorectal tumourspatients, the most frequently mutated gene was APC (68.9% of tumours), followed by KRAS (31.1%), TP53 (27.2%), BRAF (8.7%) and CTNNB1 (1.9%).\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21900390\n",
      "Studies indicate that BRAF V600E mutation initiates follicular cell transformation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21882184\n",
      "the BRAF(V600E) mutation should be considered as a poor prognostic marker in papillary thyroid cancer (Meta-Analysis)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21875464\n",
      "BRAF V600E mutation has a significant correlation with papillary thyroid carcinomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21871821\n",
      "Genetic analysis revealed individual heterozygous mutations in the KRAS (phenotype of CFC/Noonan syndrome) and BRAF genes (phenotype of CFC syndrome)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21863388\n",
      "Braf mutation in metastatic melanoma treated with BRAF inhibitor vemurafenib.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21835307\n",
      "The BRAF/MEK/ERK pathway is upregulated in progressive retinal arterial macroaneurysm patients, caused by mutation in IGFBP7.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21826673\n",
      "BRAF mutations and llelic loss of susceptibility loci are associated with familial non-medullary thyroid cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21825258\n",
      "study reports that V600E and non-V600E BRAF mutations affect different patients with non-small-cell lung cancer; V600E mutations are significantly associated with female sex and represent a negative prognostic factor\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21803329\n",
      "BRAF mutation is not indicative for predicting papillary thyroid cancer prognosis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21796448\n",
      "Importance of infiltrative growth pattern and invasiveness over presence of BRAF mutation in classic and follicular variant papillary thyroid carcinoma for development of nodal metastases.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21788131\n",
      "Patients with mutations in BRAF or NRAS gene are frequently present with ulceration, and mutation in BRAF or NRAS gene is indicator for poor prognosis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21774961\n",
      "BRAF(V600E) mutation analysis using residual liquid-based preparation cytologic samples is, therefore, a powerful additional diagnostic tool for diagnosis of papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21750338\n",
      "BRAF mutation of papillary thyroid carcinoma may have differential predictive values for LN metastasis, according to tumor size.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21725359\n",
      "identified concurrent mutational inactivation of the PTEN and RB1 tumor suppressors as a mechanism for loss of BRAF/MEK dependence in melanomas harboring (V600E)BRAF mutations\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21716161\n",
      "We describe a new mutation of BRAF, T599dup, in a case of anaplastic thyroid carcinoma with tall cell papillary thyroid carcinomas component.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21707687\n",
      "The application of BRAF(V600E) mutation analysis in US-guided FNAB can improve the diagnostic accuracy of thyroid nodules.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21705440\n",
      "MEK1(F129L) mutation also strengthened binding to c-Raf, suggesting an underlying mechanism of higher intrinsic kinase activity\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21696415\n",
      "The frequency of BRAF-KIAA1549 fusion transcripts is significantly lower in adult patients with pilocytic astrocytoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21693616\n",
      "Eight of 16 primary tumor samples and 4 of 6 metastatic samples showed BRAF V600E gene mutations and no copy number changes were associated exclusively with metastatic cancer\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21681432\n",
      "The BRAF V600E mutation did not show association with clinical or molecular characteristics of colorectal cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21663470\n",
      "The BRAF V600E mutation was present in all patients with hairy-cell leukemia who were evaluated.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21653734\n",
      "Compared with BRAF-wt papillary thyroid cancer, those harboring BRAF(V600E) exhibit downregulated VEGFA, VEGFR, and PDGFRbeta expression, suggesting presence of BRAF mutation does not imply stronger response to drugs targeting VEGF and PDGFB signal pathways.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21636552\n",
      "introduction of constitutively active BRAF V600E into human cortical stem and progenitor cells initially promotes clonogenic growth in soft agar but ultimately results in dramatically reduced proliferation and arrested growth of the culture.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21594703\n",
      "BRAF V600E mutation is associated with recurrent papillary thyroid cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21587258\n",
      "Wnt5a methylation was strongly associated with tumour microsatellite instability tumours after adjustment for age, sex, and tumour location and with BRAF V600E mutation, a marker of CpG island methylator phenotype\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21577205\n",
      "Studies indicate that Raf kinases are excellent molecular targets for anticancer therapy.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21570823\n",
      "Analysis showed that blood samples with PCR evidence for CMC were heterogeneous for BRAF status under limiting-dilution conditions, suggestive of heterogeneity of CMC\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21557216\n",
      "MSS/BRAF mutant cancers were more commonly proximal (38/54, 70.3%).\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21553007\n",
      "BRAF mutations, but not KRAS mutations, were associated with a worse outcome in Chinese colorectal cancer patients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21514245\n",
      "Ablation of B-Raf had no significant effect on development of K-Ras oncogene-driven non-small cell lung carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21512141\n",
      "Mutated BRAF is detected in approximately 45% of papillary thyroid carcinomas (PTC).\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21498916\n",
      "findings support the notion that BRAF(V600E), which can be detected preoperatively in papillary thyroid carcinoma fine-needle aspiration biopsy material, has a potential to contribute to patients stratification into high- and low-risk groups.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21483104\n",
      "Heterogeneity of KRAS and BRAF mutation status intra-tumorally in colorectal cancer was assessed.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21479234\n",
      "BRAF V600E mutations are common in the majority of pleomorphic xanthoastrocytoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21457162\n",
      "BRAF mutations are specific for serrated adenocarcinoma and identify a subset of serrated adenocarcinomas with gene methylation and a tendency for MSI-H\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21456008\n",
      "the impact of BRAF mutation and microsatellite instability on prognosis in metastatic colorectal cancer\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21455633\n",
      "No V600E mutation was identified in the BRAF gene in any sample.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21451543\n",
      "Activated BRAF promotes melanoma cell growth by matrix metalloproteinase-1\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21447798\n",
      "Amplification of the driving oncogene, KRAS or BRAF, underpins acquired resistance to MEK1/2 inhibitors in colorectal cancer cells.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21441910\n",
      "KSR interacts with a regulatory Raf molecule in cis to induce a conformational switch of MEK, facilitating MEK's phosphorylation by a separate catalytic Raf molecule in trans\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21441079\n",
      "In papilary thyroid carcinoma, the BRAFT1799A mutation is associated with age over 60 & a tumor size of 1cm or greater, but not with other clinicopathological characteristics, tumor recurrence or persistence.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21431280\n",
      "BRAF T1799A mutation may be an early and essential carcinogenic event in nearly all Korean papillary thyroid carcinomas\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21430505\n",
      "The presence of the BRAF(V600E) mutation may play different roles between medium and giant CMNs in melanocytic tumorigenesis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21427714\n",
      "There were no significant differences in the frequency of BRAF mutations among lesions exhibiting the hyperplastic, adenomatous, or mixed patterns.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21426297\n",
      "Mutations at the position V600 of BRAF were described in approximately 8% of all solid tumors, including 50% of melanomas, 30 to 70% of papillary thyroid carcinomas and 5 to 8% of colorectal adenocarcinomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21424530\n",
      "This study demonistrated that the role of RAF kinase fusions as a central oncogenic mechanism in the development of pilocytic astrocytoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21424126\n",
      "study suggested that both KRAS and BRAF mutations are exclusive, but KRAS and PIK3CA mutations are coexistent\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21412762\n",
      "BRAF mutation is associated with papillary thyroid cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21408138\n",
      "Allele-specific qPCR assays for the most frequent activating mutations in EGFR, KRAS, BRAF and PIK3CA in tumor-positive fine needle cytological aspirates were compared against histological material of primary tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21390154\n",
      "K-ras gene mutation is a common event in Chinese colorectal cancer (CRC) patients, but may not be a prognostic factor in CRC , while BRAF is rarely mutated in Chinese CRC patients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21383698\n",
      "tumor initiation by oncogenic BRAF renders thyroid cells susceptible to TGFbeta-induced epithelial-mesenchymal transition, through a MAPK-dependent process\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21383288\n",
      "Thus, MEK1(C121S) or functionally similar mutations are predicted to confer drug resistance of neoplasms to combined MEK/RAF inhibition.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21383284\n",
      "BRAF mutational status yielded no useful prognostic information in predicting recurrence and benefits from adjuvant chemotherapy in colorectal cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21362156\n",
      "Regulation of NR4A nuclear receptor expression by oncogenic BRAF in melanoma cells.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21356389\n",
      "IDH1 mutation works with other oncogenic mutations and could contribute to the metastasis in melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21351275\n",
      "BRAF mutation is associated with selective inhibition of thyroid cancer cells by the novel MEK inhibitor RDEA119 and genetic-potentiated synergism with the mTOR inhibitor temsirolimus\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21345796\n",
      "B-Raf associates with and stimulates NHE1 activity and that B-Raf(V600E) also increases NHE1 activity that raises intracellular pH.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21343559\n",
      "The presence of mutant BRAF had no impact on the disease-free interval from diagnosis of first-ever melanoma to first distant metastasis; however, it may have impacted survival thereafter.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21332555\n",
      "BRAF mutations were rare in colorectal laterally-spreading tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21326296\n",
      "BRAF mutations have a smaller role in the carcinogenesis of malignant melanoma in Chinese Han than in Western patients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21324100\n",
      "Data show that BRAF-mutated melanomas occur in a younger age group on skin without marked solar elastosis and less frequently affect the head and neck area, compared to melanomas without BRAF mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21321384\n",
      "identifying downstream events from the BRAFV600E/ERK1/2 pathway will eventually identify novel biomarkers that can be used to correlate with disease outcome and overall survival.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21317286\n",
      "identified BAD serine 134 to be strongly involved in survival signaling of B-RAF-V600E-containing tumor cells and found that phosphorylation of BAD at this residue is critical for efficient proliferation in these cells.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21317224\n",
      "Studies showed that siRNA knockdown of BIM significantly blunted the apoptotic response in PTEN+ melanoma cells.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21317202\n",
      "Findings suggest that inhibition of Raf-MEK-Erk pathway might offer a novel therapeutic strategy in neuroendocrine tumors\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21307665\n",
      "analysis of gallbladder carcinomas, gallbladder adenomas, and high-grade dysplastic lesions for the BRAF and the KRAS mutations\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21305640\n",
      "78 colorectal tumor samples were mutant for BRAF.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21303778\n",
      "Ras/Raf/MAPK and RhoA/ROCKII signalling pathways are abnormally activated in eutopic endometrial stromal cells of patients with endometriosis\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21289333\n",
      "803 metastatic colorectal cancer samples studied for KRAS exon 2 and BRAF exon 15 mutations; BRAF mutated samples were characterized for mismatch repair function; 344 tumours were mutated -34 involving BRAF mutations (8 of microsatellite instability type)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21285991\n",
      "Presence of mutated BRAF is one of the most powerful prognostic factors for advanced and recurrent CRC\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21274720\n",
      "The analysis of BRAF V600E mutation in 1,320 nervous system tumors reveals high mutation frequencies in pleomorphic xanthoastrocytoma, ganglioglioma and extra-cerebellar pilocytic astrocytoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21274671\n",
      "B-Raf mutations, microsatellite instability and p53 protein expression is not associated with sporadic basal cell carcinomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21270111\n",
      "Findings suggest inhibition of autophagy in combination with ER stress-inducing agents may represent a means by which to harness autophagy for the therapeutic benefit of B-RAF wild-type melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21263251\n",
      "These findings suggest that BRAF mutations may be associated with the pathogenesis of sessile serrated colorectal adenomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21249150\n",
      "the oncogenic effect of BRAF(V600E) is associated with the inhibition of MST1 tumor suppressor pathways, and the activity of RASSF1A-MST1-FoxO3 pathways determines the phenotypes of BRAF(V600E) tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21239517\n",
      "We found that performing BRAF(V600E) mutation analysis on the fine-needle aspiration biopsy specimens was of great help to make a therapeutic decision for thyroid nodules when the fine-needle aspiration biopsy results were equivocal\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21224857\n",
      "Acquisition of a BRAF mutation is not a founder event, but may be one of the multiple clonal events in melanoma development, which is selected for during the progression.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21223812\n",
      "The high expression of activated ERK is not caused by BRAF gene mutation in nasal mucosa malignant melanomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21223556\n",
      "B-Raf signaling has a key function in the altered expression of contractile receptors in the cerebrovasculature.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21215707\n",
      "In melanoma cells, oncogenic (V600E) BRAF signaling downregulates PDE5A through the transcription factor BRN2, leading to increased cGMP and Ca2+ and the induction of invasion through increased cell contractility.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21203559\n",
      "BRAF alternative splicing is differentially regulated in human and mouse. BRAF exon 9b is required for learning and memory associated with the hippocampus.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21190184\n",
      "B-Raf(insT) and B-Raf(V600E) , but not B-Raf(wt) , provoke drastic morphological alterations in human astrocytes.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21185263\n",
      "this study has confirmed that the BRAF(T1799A) mutation confers cancer cells sensitivity to PLX4032 and demonstrated its specific potential as an effective and BRAF(T1799A) mutation-selective therapeutic agent for thyroid cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21176117\n",
      "These results show that melanoma cell phenotype is an important factor in MAPK pathway inhibition response, as invasive phenotype cell response is dependent on BRAF mutation status.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21167555\n",
      "concluded that follicular variant of papillary thyroid carcinoma differs from conventional papillary thyroid carcinoma in the rate of BRAF mutation\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21166657\n",
      "The BRAF mutation was frequently detected in patients with superficial spreading melanoma (OR=2.021; P<0.001) and in melanomas arising in nonchronic sun-damaged skin (OR=2.043; P=0.001).\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21161938\n",
      "KRAS mutations arise more frequently than BRAF mutations in Moroccan patients with colorectal carcinomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21134562\n",
      "BRAF mutations activate the mitogen-activated protein kinase pathway and confer an aggressive thyroid cancer phenotype.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21134544\n",
      "BRAF mutation in papillary thyroid carcinoma is associated with an increased risk of palpable nodal recurrence and the need for reoperative surgery.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21131919\n",
      "Primary esophageal melanomas of Caucasian patients harbor mutations of c-Kit, KRAS and BRAF in varied frequencies.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21129611\n",
      "It therefore appears that BRAF mutations may play a strong negative prognostic role and only a slight role in resistance to anti-EGFR Abs.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21107323\n",
      "melanomas escape B-RAF(V600E) targeting not through secondary B-RAF(V600E) mutations but via receptor tyrosine kinase (RTK)-mediated activation of alternative survival pathway(s) or activated RAS-mediated reactivation of the MAPK pathway\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21107320\n",
      "identification of MAP3K8 (the gene encoding COT/Tpl2) as a MAPK pathway agonist that drives resistance to RAF inhibition in B-RAF(V600E) cell lines\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21103049\n",
      "Data show that among 181 CRC patients, stratified by microsatellite instability status, DNA sequence changes were identified in KRAS (32%), BRAF (16%), PIK3CA (4%), PTEN (14%) and TP53 (51%).\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21102416\n",
      "We show a strong association between concordant methylation of >/= 3 of five 3p22 genes with the CpG island methylator phenotype and the BRAF V600E mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21102258\n",
      "Mutations of EGFR, BRAF, and KRAS in adenocarcinoma were mutually exclusive and inversely correlated with RASSF1A methylation\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21098728\n",
      "BRAF gene amplification can promote acquired resistance to MEK inhibitors in cancer cells harboring the BRAF V600E mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21076620\n",
      "Data show that BRAF knockdown led to suppression of the expression of the GABPbeta, which involved in regulating HPR1 promoter activity.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21068756\n",
      "The dermoscopical and histopathological patterns of nevi correlate with the frequency of BRAF mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21051183\n",
      "findings indicate that somatic mutations in KRAS and PIK3CA but not BRAF oncogenes are closely associated with the development of cholangiocarcinoma in Chinese population\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21051183\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21049459\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21049459\n",
      "Although many studies document BRAF mutation as a prognostic factor in PTC our results underline that it is too early to consider it as a routine clinical predictive factor.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/21048031\n",
      "Observational study of gene-disease association and gene-environment interaction. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20979647\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20975100\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20962618\n",
      "Describe benign serrated colorectal fibroblastic polyps/intramucosal perineuriomas are true mixed epithelial-stromal polyps (hybrid hyperplastic polyp/mucosal perineurioma) with frequent BRAF mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20959481\n",
      "Braf mutation is associated with basal and treatment-induced regulation of the PI3K-AKT pathway as a critical regulator of AZD6244 sensitivity in cutaneous melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20955560\n",
      "Anti-BRAF autoantibodies from RA patients preferentially recognize one BRAF peptide: P2\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20953721\n",
      "BRAF mutation is associated with papillary thyroid microcarcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20950194\n",
      "BRAF is mutated in a low percentage of follicular variant of papillary thyroid carcinoma, and most of these mutated cases are suspicious or positive on fine-needle aspiration.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20947270\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20947270\n",
      "In the present series, no BRAF mutation was detected. The presence of KRAS mutations and loss of PTEN expression were not associated with impaired response to cetuximab-based chemoradiotherapy and 3-year disease free survival.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20945104\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20945104\n",
      "BRAF(V600E) mutation is associated with thyroid nodules.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20944096\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20944096\n",
      "Determination of the BRAF mutation and the growth fraction of melanomas may add a prognostic value.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20881644\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20860430\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20857202\n",
      "BRAF V600E mutation is associated with lack of response in wild-type KRAS metastatic colorectal cancer treated with anti-EGFR monoclonal antibodies.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20853079\n",
      "reduced RKIP mRNA levels and the elevated levels of B-RAF in pT1, grade III tumors vs. normal tissue, corroborate that these genes are involved in the pathogenesis of urinary bladder cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20843808\n",
      "A BRAF aberrant splice variant with an intact kinase domain and partial loss of the N-terminal autoinhibitory domain was identified in fibroblasts from an additional patient, and fibroblast proliferation was inhibited by BRAF-specific siRNA.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20840674\n",
      "RET rearrangements and BRAF mutation in undifferentiated thyroid carcinomas having papillary carcinoma components\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20840674\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20837233\n",
      "BRAF mutation detection in fine needle biopsy may be an adjunct tool for preoperative didagnosis of papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20813562\n",
      "first report implicating BRAF mutation in OSCC. study supports that mutations in the BRAF gene makes at least a minor contribution to OSCC tumorigenesis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20813562\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20807807\n",
      "Mutant protein kinase elicits significant therapeutic responses in mutant BRAF-driven human melanoma xenografts.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20802181\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20802181\n",
      "BRAF mutation is rare in advanced-stage low-grade ovarian serous carcinomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20736745\n",
      "Observational study of gene-disease association and gene-gene interaction. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20720566\n",
      "association between MC1 receptor germline variation and BRAF/NRAS mutations in melanoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20720566\n",
      "Observational study of gene-disease association and gene-gene interaction. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20703476\n",
      "Observational study of genetic testing. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20702649\n",
      "Observational study of gene-disease association and gene-gene interaction. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20689758\n",
      "PLX4032 has robust activity in BRAF mutated melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20679909\n",
      "Mutant Braf can be detected in RNA from mixed populations with as few as 0.1% Braf(V600E) mutant cells.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20670148\n",
      "Traditional DNA sequencing and the somewhat more-sensitive pyrosequencing method can detect multiple alternative BRAF mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20652941\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20647317\n",
      "Findings delineate how mutant B-RAF protects melanoma cells from apoptosis and provide insight into possible resistance mechanisms to B-RAF inhibitors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20647301\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20645028\n",
      "samples of metastatic colorectal cancer were tested for the presence of the seven most common mutations in the KRAS gene and the V600E mutation in the BRAF gene\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20645028\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20640859\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20635392\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20631031\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20631031\n",
      "No significant difference in BRAF alterations was found between pT1 tumors and thyroid capsule invasion and pT3 tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20627194\n",
      "PCR is practically applicable to KRAS/BRAF genotyping using small amounts of biopsied colorectal tumor cells.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20619739\n",
      "if KRAS is not mutated, assessing BRAF, NRAS, and PIK3CA exon 20 mutations (in that order) gives additional information about the efficacy of cetuximab plus chemotherapy in metastatic colorectal cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20616366\n",
      "Using traditional PCR and direct sequencing, we found KRAS mutations in 47 (40%) patients and BRAF(V600E) in 10 (8.5%)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20607849\n",
      "V600E BRAF mutation is not associated with seminoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20605766\n",
      "in melanomas activation of the MAPK pathway can occur through signaling pathways operating independently of BRAF T1799A\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20591910\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20576522\n",
      "allele specific Taqman-based real-time PCR assay allows the sensitive, accurate and reliable measurement of BRAF(V600E) mutated DNA in plasma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20573852\n",
      "BRAF mutational status of metastases is not required when the primary tumour is BRAF wild type.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20571907\n",
      "PIK3CA mutations may have a role in KRAS and BRAF wild type colorectal cancer\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20571907\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20570909\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20570909\n",
      "Incidence of cancer in FDRs of index CRC patients with the p.V600E BRAF mutation may be explained by a genetic predisposition to develop cancer through the serrated pathway of colorectal carcinogenesis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20569675\n",
      "reports the low frequency of PIK3CA and B-RAF mutations in astrocytomas, despite the presence of activated ERK and AKT proteins\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20569675\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20563851\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20563851\n",
      "HER2, but not EGFR gene amplification, is frequently observed in KRAS and BRAF wild type colorectal cancer patients\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20543023\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20526288\n",
      "The BRAF 1799T>A mutation was found in 5 of 19 (26%) of infiltrative follicular variant of papillary thyroid carcinomas and in none of the encapsulated carcinomas\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20526288\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20519626\n",
      "Studies identified the oncogenic BRAF V600E mutation in 35 of 61 archived specimens (57%).\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20514492\n",
      "Meta-analysis of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20514492\n",
      "BRAF mutation may be used a biomarker for the selection of patients with colorectal cancer patients who might benefit from anti-egf receptor monoclonal antibodies.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20501689\n",
      "Observational study of gene-disease association and genetic testing. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20501503\n",
      "The V600E BRAF mutation confers a worse prognosis to stage II and stage III colon cancer patients independently of disease stage and therapy.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20501503\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20498063\n",
      "Knockdown of B-Raf(V600E) resulted in thrombospondin-1 down-regulation and a reduction of adhesion and migration/invasion of human thyroid cancer cells.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20496269\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20495538\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20489114\n",
      "Observational study of genetic testing. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20485284\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20485284\n",
      "BRAF V600E mutations are associated with MSI-H status and cyclin D1 overexpression and characterize a subgroup of patients with poor prognosis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20478260\n",
      "Study concludes that the secreted protein IGFBP7 is dispensable for B-RAF(V600E)-induced senescence in human melanocytes.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20473281\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20473281\n",
      "Hypoxia-inducible factor-1alpha is expressed in papillary thyroid carcinomas and is regulated not only by hypoxia but also by BRAF(V600E)-mediated signaling pathway.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20460314\n",
      "These data demonstrate a high prevalence of B-RAF mutations in the present study population, underscoring the possibility of strong regional differences.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20460314\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20454969\n",
      "This study identified an exceptionally high frequency of KIAA1549-BRAF fusions in pilocytic astrocytoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20453000\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20445557\n",
      "B-RAF(V600E) can protect melanocytes from anoikis independently of cell cycle inhibition\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20444249\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20413299\n",
      "Observational study of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20410389\n",
      "thyroid carcinoma with the BRAF(V600E) mutation tends to be taller than wide and is not associated with the presence of calcifications on ultrasound.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20407018\n",
      "Activated Raf-1 induces focal adhesion kinase expression and regulates neuroendocrine and metastatic phenotypes in gastrointestinal carcinoid cell line BON.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20406109\n",
      "The miR-146b expression levels in papillary thyroid carcinoma with BRAF mutation were significantly higher than those without this mutation\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20381121\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20379614\n",
      "Clinical trial of gene-disease association and gene-environment interaction. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20351680\n",
      "Mutated in melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20332228\n",
      "Studies show FOXD3 is suppressed by B-RAF, uncover a novel role and mechanism for FOXD3 as a negative cell cycle regulator, and have implications for the repression of melanocytic lineage cells.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20305537\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20303012\n",
      "Our study suggests that mutations of KRAS, not BRAF, may play a role in the pathogenesis of prostate carcinoma in Chinese patients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20303012\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20302979\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20300843\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20300843\n",
      "BRAF mutation is not associated with interval cancers but is a marker of poor prognosis, particularly in microsatellite stable cancers.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20234366\n",
      "Observational study of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20233436\n",
      "data support the model of BRAF and K-ras mutations arising in distinct colorectal cancer subsets associated with different clinicopathological and dietary factors, acting as mutually exclusive mechanisms of activation of the same signalling pathway\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20230995\n",
      "pathogenesis of papillary thyroid cancer , and the clinical implications of BRAF(V600E) mutation in the diagnosis, prognosis and potential targeted therapeutic strategies for thyroid cancer [review]\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20200438\n",
      "we measured the prevalence and epidemiologic correlates of the BRAF V600E somatic mutation in cases collected as a part of a population-based case-control study of colorectal cancer in northern Israel.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20200438\n",
      "Observational study of gene-disease association and gene-environment interaction. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20187782\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20186801\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20182446\n",
      "High oncogenic BRAF levels trigger autophagy, which may have a role in melanoma tumor progression.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20177422\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20162668\n",
      "With MSI, specific KRAS and BRAF mutations, 3 distinct prognostic subgroups were observed: patients with (i) KRAS mutation G12D, G12V or BRAFmutation, (ii) KRAS/BRAFwild-type or KRAS G13D mutations in MSS/MSI-L and (iii) MSI-H and KRAS G13D mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20162668\n",
      "Observational study of gene-disease association and gene-gene interaction. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20156809\n",
      "BRAF activating mutations are a major genetic alteration in this histologic group of pediatric low-grade brain tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20146801\n",
      "Data demonstrate a signaling loop between B-Raf activation and p73 function, and suggest that low expression of TAp73 in colorectal cancer cell lines with mutated B-Raf may lead to lack of response to oxaliplatin/cetuximab.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20140953\n",
      "Formalin-fixed primary melanomas from relapsed and nonrelapsed patients were sequenced for common BRAF and NRAS mutations. BRAF/NRAS mutations were detected in 77% of relapsers and 58% of nonrelapsers and did not predict ulceration or mitotic rate.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20118768\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20098682\n",
      "Observational study of genetic testing. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20068183\n",
      "BRAF(V600E) mutation seems to define a subset of malignant astrocytomas in children, in which there is frequent concomitant homozygous deletion of CDKN2A (five of seven cases).\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20051945\n",
      "Observational study of genetic testing. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20049644\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20049644\n",
      "BRAF mutations only in metastases is not associated with resistance to anti-EGFR treatment in primary colorectal tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20044755\n",
      "BRAF gene rearrangements were more common in cerebellar pilocytic astrocytoma than non-cerebellar tumors; clinical outcome was independent of BRAF status\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20043015\n",
      "no support for MC1R variants with BRAF mutation for melanoma risk\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20043015\n",
      "Observational study of gene-disease association and gene-gene interaction. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20027224\n",
      "CpG island methylator phenotype (CIMP)-specific inactivation of BRAF(V600E)-induced senescence and apoptosis pathways by IGFBP7 DNA hypermethylation might create a favorable context for the acquisition of BRAF(V600E) in CIMP+ colorectal cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20023270\n",
      "BRAF V600E detection in the tumor does not induce a higher expression of the B-raf protein or the preferential activation of the p42/44 mitogen-activated protein kinase (MAPK) signaling pathway compared with GISTs without the BRAF mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20012784\n",
      "Screening for BRAF, RET, KRAS, NRAS, and HRAS mutations, as well as RET-PTC1 and RET-PTC3 rearrangements, was performed on cases of Hashimoto thyroiditis with a dominant nodule\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20009493\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20009493\n",
      "BRAFV600E mutation is associated with high-risk clinicopathological characteristics of papillary thyroid carcinoma and worse prognosis of patients\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/20008640\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19960590\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19960590\n",
      "BRAF T1796A mutation was identified in 27% of papillary thyroid cancer samples and its identification may be used to determine this risk factor of the development of papillary thyroid cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19959686\n",
      "2-fold increased risk of BRAF V600E colonic tumor mutation was observed in current and former cigarette smokers homozygous for the OGG1 polymorphism\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19958951\n",
      "clinical, cytologic, and pathologic parameters of 106 consecutive surgically treated patients with BRAF-positive PTC were compared with a concurrent cohort of 100 patients with BRAF-negative PTC (papillary thyroid carcinoma)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19956635\n",
      "Uncategorized study of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19955937\n",
      "v-Raf murine sarcoma viral oncogene mutations are common in ovarian serous bordeline tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19955937\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19935791\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19919912\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19919630\n",
      "The BRAF V600E mutational status appears to be of limited diagnostic utility in distinguishing genital naevi that exhibit atypia from those that do not.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19917255\n",
      "Data show that melanoma cells expressing B-Raf(V600E) display a reduced C-Raf:B-Raf ratio, and further suppression of C-Raf increases MAPK activation and proliferation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19913317\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19913317\n",
      "BRAF mutations are not relevant for rectal carcinogenesis\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19908233\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19908233\n",
      "BRAF gene mutation is associated with colorectal cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19903786\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19893451\n",
      "Study identified the previously reported pathogenic mutation of NTRK3 in a KRAS/BRAF wild-type tumor and 2 somatic mutations in the Src family of kinases (YES1 and LYN) that would be expected to cause structural changes.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19884556\n",
      "Observational study of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19884556\n",
      "BRAF status, EGFR amplification, and cytoplasmic expression of PTEN were associated with outcome measures in KRAS wild-type patients treated with a cetuximab-based regimen.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19884549\n",
      "KRAS and BRAF mutations in advanced colorectal cancer are associated with poor prognosis but do not preclude benefit from oxaliplatin or irinotecan.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19884549\n",
      "Clinical trial of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19883729\n",
      "The knowledge of BRAF mutation status can facilitate more accurate risk stratification and better decision making at various steps in the management of papillary thyroid cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19881948\n",
      "BRAF and KRAS oncogenes have different transforming capability in colon cancer\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19880519\n",
      "Hyperactivation of BRAF-MEK signaling activates MAP2 expression in melanoma cells by two independent mechanisms, promoter demethylation or down-regulation of neuronal transcription repressor HES1.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19878585\n",
      "Suppression of BRAF gene expression inhibited cell proliferation in cells with BRAF(V600E) mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19861964\n",
      "These data demonstrate the feasibility of BRAF mutation detection in cfDNA of patients with advanced melanoma. Future studies should aim to incorporate BRAF mutation testing in cfDNA to further validate this biomarker for patient selection.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19861964\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19861538\n",
      "BRAFV600E oncogene induces transforming growth factor beta secretion leading to sodium iodide symporter repression and increased malignancy in thyroid cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19855373\n",
      "BRAF V600E mutations were seen in 83% of proximal and 74% of distal hyperplastic colonic polyps\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19850689\n",
      "Observational study of genetic testing. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19850689\n",
      "BRAF(T1799A) can be detected in the blood of papillary thyroid carcinoma patients with residual or metastatic disease and may provide diagnostic information\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19829302\n",
      "data argues against obligatory downregulation in IGFBP7 expression in BRAF mutated melanoma cells\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19826477\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19794125\n",
      "As predicted from the genomic organization at this locus, 22 of 36 patients with sporadic pilocytic astrocytomas and B-Raf gene rearrangement also exhibit corresponding homeodomain interacting protein kinase-2 (HIPK2) gene amplification.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19765726\n",
      "Observational study of gene-disease association and gene-gene interaction. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19759551\n",
      "analysis of coexisting NRAS and BRAF mutations in primary familial melanomas with specific CDKN2A germline alterations\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19752400\n",
      "The polyclonality of BRAF mutations in acquired melanocytic nevi suggests that mutation of BRAF may not be an initial event in melanocyte transformation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19745699\n",
      "Beta-catenin nuclear labeling is a common feature of sessile serrated adenomas and correlates with early neoplastic progression after BRAF activation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19738460\n",
      "Papillary carcinomas of the thyroid with papillary growth and areas of follicular growth have a high frequency of BRAF mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19738388\n",
      "Observational study of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19735675\n",
      "Insights into the molecular function of the inactivating mutations of B-Raf involving the DFG motif.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19725049\n",
      "EPAC-mediated cellular effects require activation of the B-Raf/ERK and mTOR signaling cascades\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19724843\n",
      "This article focuses on reviewing the impact of the BRAFV600E mutation in the tumorigenesis of Papillary thyroid carcinoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19718661\n",
      "analysis of the effect on the Ras/Raf signaling pathway of post-translational modifications of neurofibromin\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19710016\n",
      "DGKeta acts as a novel critical regulatory component of the Ras/B-Raf/C-Raf/MEK/ERK signaling cascade via a previously unidentified mechanism.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19710001\n",
      "The BRAF(V600E) mutation can be used as a potential prognostic factor in PTMC patients in a BRAF(V600E)-prevalent area.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19704056\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19693938\n",
      "Whenever necessary BRAF testing may be performed on the residual samples of thyroid nodules, without interfering with routine cytology.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19690147\n",
      "a dual mechanism that affects the Sprouty2/B-Raf interaction: Sprouty phosphorylation and B-Raf conformation\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19686742\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19682280\n",
      "This study provides a basis for understanding the molecular processes that are regulated by (V600E)BRAF/MEK signalling in melanoma cells.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19681119\n",
      "Investigated the prevalence of PTPN11, HRAS, KRAS, NRAS, BRAF, MEK1, and MEK2 mutations in a relatively large cohort of primary embryonal Rhabdomyosarcoma (RMS) tumors. No mutation was observed in BRAF and MEK genes.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19679059\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19679059\n",
      "Mutations in BRAF protein is associated with Colorectal Carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19679016\n",
      "Studies indicate that drugs are effective in targeting essential molecular pathways of BRAF, PTEN, Akt and mammalian target of rapamycin.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19669908\n",
      "Observational study of gene-disease association and DATA ERROR. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19667985\n",
      "Studies indicate that in pilocytic astrocytomas, the BRAF fusion gene has been identified as a specific and frequent event leading to potentially targetable mitogen-activated protein kinase pathway activation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19659611\n",
      "simultaneous depletion of both MITF and BRAF(V600E) significantly inhibited melanoma growth even for the melanoma cell lines resistant to MITF depletion\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19652585\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19644722\n",
      "BRAFV600E mutation is associated with papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19638574\n",
      "Sorafenib inhibits NSCLC cell growth by targeting B-RAF in cells with wild-type KRAS and C-RAF in those with mutant KRAS.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19637313\n",
      "strong inter-relation between DR4 AND DR5 overexpression and presence of oncogenic KRAS/ BRAF mutations in colon cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19633643\n",
      "Characterization of candidate gene copy number alterations in the 11q13 region along with BRAF and NRAS mutations in human melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19628078\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19626635\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19626635\n",
      "In this study, 28 matched tumor and serum samples obtained from patients with both benign and malignant thyroid disorders were analyzed for BRAF mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19624312\n",
      "Mutated BRAF is a target in metastatic melanomas\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19603024\n",
      "Observational study of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19603024\n",
      "BRAF (P=0.01) mutations predicted reduced progress free survival in response to cetuximab salvage therapy in patients with metastatic colorectal cancer .\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19603018\n",
      "Observational study of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19603018\n",
      "Assessing KRAS and BRAF mutations might help optimising the selection of the candidate metastatic colorectal cancer patients to receive anti-EGFR moAbs.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19584155\n",
      "Results suggest that the mutations of EGFR, KRAS, BRAF between primary tumors and corresponding lymph node metastases should be considered whenever mutations are used for the selection of patients for EGFR-directed tyrosine kinase inhibitor therapy.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19584155\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19574281\n",
      "BRAF V600E mutation analysis can significantly improve FNAB diagnostic accuracy.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19571821\n",
      "We observed no association between germline MC1R status and somatic BRAF mutations in melanomas\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19571709\n",
      "BRAF mutated tumors occurred with a much greater frequency in proximal colon tumors than in either distal colon or rectal tumors\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19571295\n",
      "study concludes that a BRAF mutation is a negative prognostic marker in patients with metastatic colorectal cancer\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19571295\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19561230\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19561230\n",
      "BRAF mutations represent an alternative molecular pathway in the early tumorigenesis of a subset of KIT/PDGFRA wild-type GISTs and are per se not associated with a high risk of malignancy.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19551857\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19547661\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19543740\n",
      "Pilocytic astrocytomas had BRAF fusions in 70% of cases but not IDH1 or IDH2 mutations. Diffuse astrocytomas had IDH1 mutations in 76% of cases but not IDH2 mutations or BRAF fusions. Analysis of BRAF and IDH1 separates pilocytic from diffuse astrocytoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19534623\n",
      "BRAF V600E may have a role in development of papillary thyroid carcinoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19534622\n",
      "CTNNB1 and BRAF mutations may have roles in the cribriform-morular variant of papillary thyroid carcinoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19504446\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19498322\n",
      "Results show that activating BRAF somatic mutations may be occasionally found in advanced adrenocortical carcinomas, while CTNNB1 activating mutations are early and common events in adrenal tumorigenesis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19498322\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19492075\n",
      "Targeting NRAS alone or both BRAF and CRAF in combination or both BRAF and PIK3CA together showed delay in tumor growth.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19487299\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19487299\n",
      "If BRAF is mutated in the primary thyroid neoplasm, it is likely that the metastases will harbor the defect.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19483722\n",
      "B-Raf/MKK/ERK provides a permissive environment for melanoma genesis by modulating plexin B1.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19474002\n",
      "data confirm that KRAS and BRAF mutations do occur in the same cell and that BRAF V600E mutation is associated with CIMP+ status.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19464601\n",
      "The RAS/RAF/MEK/ERK signaling pathway has emerged as a major player in the induction and maintenance of melanoma, particularly the protein kinase BRAF, mutated in approximately 44% of melanoma cases. Review.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19461239\n",
      "mismatch repair deficiency is not a crucial event for BRAF mutation in melanocytic tumors\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19440799\n",
      "oncogenic properties of KRAS and BRAF but not NRAS, HRAS, and PIK3CA contribute to the tumorigenesis of periampullary and ampullary tumors\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19430562\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19430562\n",
      "Mutations in BRAF were found 10% patients in the low-grade carcinoma group, however, they were not found in the high-grade carcinoma group. KRAS and BRAF mutations were mutually exclusive, and both mutations were observed in 40%.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19424639\n",
      "Report efficient molecular screening of Lynch syndrome by specific 3' promoter methylation of the MLH1 or BRAF mutation in colorectal cancer with high-frequency microsatellite instability.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19424571\n",
      "BRAF V600E mutation is not the target gene for abnormal DNA mismatch repair in patients with sporadic endometrial cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19416762\n",
      "Novel BRAF mutation in a patient with LEOPARD syndrome and normal intelligence is reported.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19415957\n",
      "The T1799A BRAF mutation does not appear to play a role in the tumorigenesis of the cribriform-morular variant of papillary carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19414674\n",
      "Observational study of gene-disease association and genetic testing. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19404918\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19404918\n",
      "Investigated BRAF mutations in 30 bladder tumors. Detected two tumor specimens bearing two different mutations, both of which were found in exon 15. One sample showed the T1799A (V600E) and the other the G1798T (V600L) mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19404844\n",
      "elevated pERK expression occurs in urothelial carcinoma in the absence of B-Raf mutations and is not correlated with FGFR3 over-expression\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19404844\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19398955\n",
      "The murine model of mutant BRAF-induced melanoma formation provides an important tool for identifying further genetic alterations that cooperates with BRAF and that may be useful in enhancing susceptibility to BRAF-targeted therapeutics in melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19393416\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19393416\n",
      "B-RAF mutation was found to be significantly higher in papillary carcinomas when compared to follicular variant of papillary thyroid carcinomas (55.6% vs 14.3%, P = 0.05).\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19389934\n",
      "a subpopulation of melanocytes possesses the ability to survive BRAF(V600E)-induced senescence\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19383316\n",
      "The genes whose expression is associated with BRAF mutations are not simply restricted to the MAPK/ERK signaling but also converge to enhanced immune responsiveness, cell motility and melanosomes processing involved in the adaptative UV response\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19383313\n",
      "REVIEW summarizes the literature on NRAS and BRAF activating mutations in melanoma tumors with respect to available data on histogenetic classification as well as body site and presumed UV-exposure.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19378335\n",
      "proliferation of cells harboring mutations in B-Raf, but not K-Ras, is exquisitely sensitive inhibition of the MAPK pathway\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19372556\n",
      "Mutation in BRAF is associated with ERK1/2 activation and MEK1/2 inhibitor therapy in colorectal cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19370505\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19370505\n",
      "BRAF V600E mutation was significantly found in papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19369630\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19369630\n",
      "K-ras, EGFR, and BRAF mutations are disproportionately seen in adenocarcinomas of lung with a dominant micropapillary growth pattern compared with conventional adenocarcinoma in our institutional experience.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19362540\n",
      "Targets of phosphorylation by B-Raf signaling are investigated in melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19358278\n",
      "Observational study of gene-disease association and gene-environment interaction. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19355825\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19355825\n",
      "BRAF(V600E) is associated some of the aggressive clinicopathological features of papillary thyroid carcinoma including younger age at diagnosis, larger tumor size, and classic histological type, as well as also extrathyroidal invasion.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19351817\n",
      "Observational study of gene-disease association and gene-environment interaction. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19344998\n",
      "In BRAF mutated colorectal carcinoma cells quercetin, luteolin and ursolic acid decreased Akt phosphorylation\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19342899\n",
      "Both BRAF and RKIP expression levels exhibit a decrease from normal skin tissue and actinic keratosis, going to squamous cell carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19289622\n",
      "a correlation between a gene mutation--BRAF V600E--and cisplatin resistance in nonseminomatous germ cell tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19289622\n",
      "Observational study of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19282104\n",
      "study of KRAS/BRAF mutation status in a large and well-documented cohort of primary and metastatic renal cell carcinoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19276360\n",
      "GDC-0879-mediated efficacy was associated strictly with BRAF(V600E) status, MEK inhibition also attenuated proliferation and tumor growth of cell lines expressing wild-type BRAF.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19274086\n",
      "oncogenic BRAF(V600E) induces the uncoupling of LKB1-AMPKalpha complexes providing at the same time a possible mechanism in cell proliferation that engages cell growth and cell division in response to mitogenic stimuli\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19255327\n",
      "Clinical trial of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19240718\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19237633\n",
      "Observational study of gene-disease association and gene-gene interaction. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19226609\n",
      "BRAF* melanomas appear to be associated with a specific profile of DNA copy number aberrations that is distinct from those found in NRAS* and BRAF/NRAS(wt/wt) tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19208736\n",
      "BRAFT1799A mutation or RET/PTC rearrangement, mainly corresponding to follicular variants, maintain a thyroid differentiation expression level close to that of normal tissue.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19207009\n",
      "the presence of the braf protein mutation increases prohibitin promoter activity and therefore potentially mediates effects of this mutation on the behavior of BRAF protein\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19206169\n",
      "Findings provide evidence for a wide phenotypic diversity associated with mutations affecting BRAF, and occurrence of a clinical continuum associated with these molecular lesions.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19200582\n",
      "(novel) mutation in the activation kinase domain of the BRAF (A598V), this mutation led to the up-regulation of the BRAF kinase activity and its downstream signaling factors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19194051\n",
      "Expression levels of fibronectin, vimentin and CITED1 were positively correlated with those of BRAFV600E, suggesting pathophysiological links between activated BRAF and overexpression of these genes.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19190129\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19190129\n",
      "Distinct BRAF (V600E) and KRAS mutations in high microsatellite instability sporadic colorectal cancer in African Americans.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19190105\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19190079\n",
      "Mutation in BRAF is associated with adrenocortical carcinomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19178815\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19178815\n",
      "Mutations are absent or rare in the kinase domain of B-RAF in Japanese head and neck squamous cell carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19164452\n",
      "MLH1-hypermethylated tumors harbor fewer APC and KRAS mutations and more BRAF mutations, suggesting that they develop distinctly from an MGMT methylator pathway.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19159571\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19152441\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19147753\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19147753\n",
      "BRAF and RET/PTC dual mutations are associated with recurrent papillary thyroid carcinoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19142971\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19133693\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19127559\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19126563\n",
      "Sessile serrated adenomas are encountered commonly in routine endoscopy practice and the histological diagnosis correlates strongly with the presence of BRAF mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19107232\n",
      "BRAF pseudogene activation may play a role in thyroid tumor development.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19098310\n",
      "ERK activation was induced by PKD2 overexpression via B-Raf signaling, providing a possible molecular mechanism of cystogenesis\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19087308\n",
      "G12D mutation may be more likely selected in a BRAF mutated context\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19079609\n",
      "Genetic extinction of BRAF(V600E) in established prostate tumors did not lead to tumor regression, indicating that while sufficient to initiate development of invasive prostate adenocarcinoma, BRAF(V600E) is not required for its maintenance.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19064572\n",
      "Observational study and meta-analysis of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19037234\n",
      "NRAS and BRAF mutations increase from the radial to the vertical growth phase in cutaneous melanoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19034577\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19034577\n",
      "BRAF(V600E) mutation is assocciated with aggressive papillary thyroid microcarcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19033861\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19026650\n",
      "Observational study of genetic testing. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19018267\n",
      "ovarian cancer patients with KRAS or BRAF mutations may benefit from CI-1040 treatment\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19018267\n",
      "Observational study of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19016743\n",
      "Reverse transcription polymerase chain reaction-based sequencing revealed a fusion product between KIAA1549 and BRAF in pediatric low-grade astrocytomas\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19014278\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19014278\n",
      "In Korean patients with papillary thyroid carcinoma, the BRAFV600E mutation is associated with a lower frequency of background Hashimoto thyroiditis and a high frequency of lymph node metastasis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19012001\n",
      "The result showed that the mutation rate of PIK3CA in nasopharyngeal carcinomas (n = 73) was 9.6%, whereas both BRAF (n = 65) and RAS (n = 45) were wild type in every specimen with adequate DNA for analysis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19012001\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19003996\n",
      "BRAF-V600E mutation is uncommon in endocrine tumors other than thyroid papillary carcinomas\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19001320\n",
      "Wild-type BRAF is required for response to panitumumab or cetuximab in metastatic colorectal cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/19001320\n",
      "Observational study of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18992635\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18992635\n",
      "8% of sporadic colorectal tumors in this study harbor mutation in the BRAF gene.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18987552\n",
      "BRAF mutations may not play an important role in the oncogenesis or therapy of prostate adenocarcinoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18985043\n",
      "the T1799A BRAF mutation is present in a proportion of posterior uveal melanomas but within these tumours the distribution of the mutation is heterogeneous.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18980976\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18974108\n",
      "rearrangement, which was not observed in a series of 244 higher-grade astrocytomas, results in an in-frame fusion gene incorporating the kinase domain of the BRAF oncogene\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18953432\n",
      "study shows high expression of p16(INK4a) or the absence of activated B-RAF correlates with in vivo response of melanoma to cytotoxic drugs\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18946221\n",
      "Hereditary pancreatitis patients with PRSS1 mutations also had mutations in BRAF and KRAS2.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18945298\n",
      "BRAF V600E appeared to be the most commonly mutated gene in both the melanocytic aggregate (seven of 18, 39%) and the melanoma (four of 18, 22%)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18840924\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18840924\n",
      "BRAF(V600E) mutation may play some roles in local carcinoma development, there is no evidence that BRAF(V600E) mutation significantly reflects the aggressive characteristics and poor prognosis of patients with papillary carcinoma in Japan.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18834226\n",
      "With at least 3 markers methylated, new CIMP-positive colorectal cancers were closely associated with proximal tumor location, low frequency of KRAS mutation, and high frequency of BRAF mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18832519\n",
      "CIMP-high appears to be an independent predictor of a low colon cancer-specific mortality, while BRAF mutation is associated with a high colon cancer-specific mortality.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18806830\n",
      "study concludes a single endogenous BRAF(V600E) allele is sufficient to repress BIM & prevent death from growth factor withdrawal; colorectal cancer cells with V600E mutations are addicted to the ERK1/2 pathway for repression of BIM\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18798261\n",
      "BRAF mutation occurs independently of CpG island methylator phenotype and MSI in all types of serrated polyps and may serve as a marker of serrated pathway of colorectal carcinogenesis\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18794803\n",
      "study identified a group of melanomas with low-activity BRAF mutations (G469E- and D594G) that are reliant upon CRAF-mediated survival activity\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18794094\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18787396\n",
      "These data implicates a mitotic role for B-Raf in regulating spindle formation and the spindle checkpoint in human somatic cells.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18782444\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18782444\n",
      "BRAF, KRAS and PIK3CA mutations occur prior to malignant transformation demonstrating that these oncogenic alterations are primary genetic events in colorectal carcinogenesis\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18778891\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18778891\n",
      "BRAF mutation is associated with the CpG island methylator phenotype in colorectal cancer from young patients\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18759827\n",
      "Observational study of genetic testing. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18757433\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18757341\n",
      "KRAS and BRAF mutations can impair response to anti-EGFR therapy for colorectal neoplasms\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18718023\n",
      "presence of the BRAF (V600E) mutation,the incidence of microsatellite instability high colorectal cancer in populations based study.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18716556\n",
      "focal gains at chromosome 7q34 and increased BRAF-MEK-ERK signaling are common findings in sporadic pilocytic astrocytomas\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18715233\n",
      "These data suggest that regulation of BIM expression by BRAF-->MEK-->ERK signaling is one mechanism by which oncogenic BRAF(V600E) can influence the aberrant physiology of melanoma cells.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18710471\n",
      "There is a higher frequency of the BRAF(V600E) mutation in papillary thyroid carcinomas than in normal thyroid tissue.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18697864\n",
      "Identification and functional characterization of a novel T599I-VKSR(600-603)del BRAF mutation in a patient with follicular variant papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18682506\n",
      "The BRAF(V600E) mutation was demonstrated to be a poor prognostic factor independent from other clinicopathological features.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18682506\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18676756\n",
      "Observational study of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18676742\n",
      "CST6, CXCL14, DHRS3, and SPP1 are regulated by BRAF signaling and may play a role in papillary thyroid carcinoma pathogenesis\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18669866\n",
      "Observational study of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18668139\n",
      "N-RAS(Q61K) and B-RAF(V600E) contribute to melanoma's resistance to apoptosis in part by downregulating Bim expression\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18650848\n",
      "hyperactivation of the MAPK pathway following activation of an inducible form of oncogenic C-Raf induces a senescence-like proliferation arrest in B-Raf mutant melanoma cells\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18636014\n",
      "lung adenocarcinoma of mixed type with a high incidence of papillary and lepidic growth may be worthwhile investigating for BRAF-V600E mutation as more genetically oriented drug therapies emerge.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18632627\n",
      "co-overexpression of KIT/CDK4 is a potential mechanism of oncogenic transformation in some BRAF/NRAS wild-type melanomas\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18628967\n",
      "BRAF regulates melanoma proliferation through the lineage specific factor MITF\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18628431\n",
      "People of southern European origin had lower risk of colorectal cancers with CIMP and BRAF mutation than people of Anglo-Celtic origin, which may in part be due to genetic factors that are less common in people of southern European origin.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18628356\n",
      "The frequencies of LOHs of 17q21, 17p13, 10q23, and 22q13 were higher in tumors with lymph node metastasis, suggesting that these LOHs may be important in increased lymph node metastasis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18621636\n",
      "Observational study of gene-disease association, gene-environment interaction, and pharmacogenomic / toxicogenomic. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18615680\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18615680\n",
      "MLH1 methylation and BRAF mutations are associated with microsatellite unstable colon tumors\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18615679\n",
      "V600E BRAF mutation is associated with imatinib-resistant gastrointestinal stromal tumors\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18615679\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18602919\n",
      "Rac1b and B-Raf(V600E) functionally cooperate to sustain colorectal cell viability and suggest they constitute an alternative survival pathway to oncogenic K-Ras\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18594528\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18592405\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18567582\n",
      "the scaffold protein IQGAP1 couples Ca(2+) and calmodulin signaling to B-Raf function\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18532874\n",
      "Compared to melanomas without BRAF mutations, melanomas with BRAF mutations showed statistically significantly higher degrees of intraepidermal scatter of melanocytes, and a higher proportion of melanocytes arranged in nests.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18519771\n",
      "a significant relationship in overall survival in colon cancer patients with defective DNA mismatch repair and the presence of a specific mutation in BRAF (V600E)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18517279\n",
      "BRAF mutations in colorectal cancer microsatellite-stable cases are associated with high levels of chromosomal instability that are likely responsible for the adverse outcomes in these cases\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18509361\n",
      "Shorter overall survival in primary melanoma was associated with the presence of ulceration and BRAF exon 15 mutations, as well as the absence of nuclear activation of Akt and of cytoplasmic activation of ERK.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18509003\n",
      "study revealed a significant correlation of BRAFV600E mutation with a lower expression of both sodium iodide symporter and thyroperoxidase in papillary thyroid cancer\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18470905\n",
      "aberrant methylation of the hMLH1 gene may play a role in BRAF mutation-promoted thyroid tumorigenesis\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18458053\n",
      "oncogenic BRAF inhibition can have a different effect on cell fate depending on the cellular type\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18451171\n",
      "Akt3 and mutant V600E B-Raf cooperate to promote early melanoma development.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18435933\n",
      "CpG island methylator phenotype in colorectal neoplasms may result from activating mutations in either BRAF or KRAS.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18434602\n",
      "Cdk1/cyclin B has a role in regulating B-raf activation at mitosis\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18413255\n",
      "study describes the biochemical characterization of novel BRAF and MEK germline mutations in cardio-facio-cutaneous syndrome\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18408659\n",
      "in melanocytic lesions, BRAF(V600E) mutation can affect a subset of the cells and is associated with the type and quantity of sun exposure\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18402768\n",
      "Aberrant BRAF and INK4A functionally interact to promote growth and survival of melanoma cells.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18398503\n",
      "Results implicate aberrant activation of the MAPK pathway due to gene duplication or mutation of BRAF as a molecular mechanism of pathogenesis in low-grade astrocytomas and suggest inhibition of the MAPK pathway as a potential treatment.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18397470\n",
      "is commonly activated by somatic point mutation, it may provide possible diagnostic and therapeutic targets in human malignant tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18383861\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18383861\n",
      "K-RAS and BRAF mutations are a frequent genetic event in our samples of sporadic papillary and medullary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18382358\n",
      "Detecting BRAF mutation by pyrosequencing is more sensitive, faster, and less expensive than direct DNA sequencing.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18381570\n",
      "Thyroid cancers with BRAF mutation are preferentially sensitive to MEK inhibitors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18375819\n",
      "BRAF mutation is associated with disease stabilization in melanoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18368129\n",
      "This study confirms that the known MC1R-melanoma risk association is confined to subjects whose melanomas harbor BRAF mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18368129\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18343945\n",
      "Our data provide evidence that PIK3CA and BRAF contribute to the tumorigenesis of IPMN/IPMC, but at a lower frequency than KRAS.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18337114\n",
      "BRAF mutation testing of papillary thyroid carcinoma might improve the diagnosis, prognostic stratification and treatment of these tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18329792\n",
      "RKIP could play an important role in the down-regulation of wild-type BRAF, serving thus as an endogenous inhibitor of the MAPK pathway in nasal polyps and their adjacent turbinate mucosa.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18323787\n",
      "Mitogen-activated protein kinase (MAPK) activity is subject to regulation even in BRAF/NRAS mutant melanoma cells and that high MAPK pathway signaling may be important only in distinct subsets of tumor cells.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18310288\n",
      "BRAF-V600E mutation is associated with familial non-medullary thyroid carcinoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18310287\n",
      "BRAF(V600E) mutation is asscoiated with papillary thyroid cancer\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18310286\n",
      "BRAF T1799A mutation is associated with aggressive pathological outcomes of papillary thyroid cancer\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18267069\n",
      "A genome-wide RNA-interference screening to identify genes required for an activated BRAF oncogene to block proliferation of fibroblasts and melanocytes revealed that a IGFBP7, has a central role in BRAF-mediated senescence and apoptosis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18246127\n",
      "Mutant B-RAF mediates resistance to anoikis via Bad and Bim.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18235983\n",
      "Follicular histotypes of oncocytic thyroid carcinomas do not carry BRAF mutations\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18228248\n",
      "Important signalling role in T cell development.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18227705\n",
      "BRAF mutation is not associated with cutaneous melanoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18226854\n",
      "frequency of the occurrence of BRAF mutation and/or RET/PTC in H4-PTEN positive tumors was extremely high (75%) in papillary thyroid carcinoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18224685\n",
      "Observational study of gene-disease association and gene-gene interaction. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18199160\n",
      "A worse clinical outcome was found for CIMP-high, microsatellite stable colorectal cancer with KRAS/BRAF mutation but not for those lacking KRAS/BRAF mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18172070\n",
      "Because of the very sensitive pyrophosphorolysis-activated polymerization (PAP)technology, B-RAF mutations were found in cell lines and primary uveal melanomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18098337\n",
      "BRAF provides proliferation and survival signals in MSI colorectal carcinoma cells displaying BRAF(V600E) but not KRAS mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18071315\n",
      "B-Raf(V600E) signaling deregulates the mitotic spindle checkpoint through stabilizing Mps1 levels in melanoma cells.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18070147\n",
      "BRAF(V600E)'alone' does not represent a marker for poor outcome\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18061181\n",
      "Observational study of genetic testing. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18060073\n",
      "BRAF and MEK1/2 mutations may be more common than anticipated in ovarian cancer which could have important implications for treatment of patients with this disease and suggests potential new therapeutic avenues\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18045987\n",
      "These results identify Rnd3 as a regulator of cross talk between the RAF/MEK/ERK and Rho/ROCK signaling pathways, and a key contributor to oncogene-mediated reorganization of the actin cytoskeleton and focal adhesions.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18045960\n",
      "Detection of BRAF improves the diagnosis in fine-needle biopsy with cytological findings suspicious for papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18042262\n",
      "the results of HRAS, BRAF and MAP2K1/2 mutation screening in a large cohort of patients with CS and CFC\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18032947\n",
      "The BRAF mutation is common in melanomas, but variation in rates across melanoma subtypes points to a complex interplay between BRAF activation and other factors (eg, sun exposure).\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18024410\n",
      "no BRAF mutations identified in 65 screened JMML patients; this gene is unlikely to play a role in the pathogenesis of JMML.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18008004\n",
      "mutation of N-RAS or B-RAF, signature genetic lesions present in most MMs, potently induced the expression of cell-surface CD200, a repressor of DC function.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/18000091\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17972530\n",
      "These results suggest that papillary thyroid carcinomas with BRAF (V600E) mutation are more aggressive than those with wildtype BRAF.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17962436\n",
      "In this small study, the T1799A BRAF mutation was identified in almost half of the iris melanoma tissues samples examined. This finding suggests that there may be genetic as well as clinical differences between iris and posterior uveal melanomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17942568\n",
      "BRAF interacts with PLCepsilon1 in nephrotic syndrome type 3. Both proteins are coexpressed and colocalize in developing and mature glomerular podocytes.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17940185\n",
      "BRAF mutation represents a novel indicator of the progression and aggressiveness of papillary thyroid cancer (Review)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17924122\n",
      "Examined associations between BRAF mutations, morphology, and apoptosis in early colorectal cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17914558\n",
      "BRAF mutation is associated as early as the hyperplastic polyp stage followed by microsatellite instability at the carcinoma stage\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17911174\n",
      "effects of a MEK inhibitor, CI-1040, on thyroid cancer cells, some of which, particularly cell proliferation and tumor growth, seemed to be BRAF mutation or RAS mutation selective\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17878251\n",
      "MEK inhibition is cytostatic in papillary thyroid cancer and anaplastic thyroid cancer cells bearing a BRAF mutation\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17854396\n",
      "Papillary thyroid cancers with no 131I uptake had a high frequency of BRAF mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17786355\n",
      "BRAFV600E mutations were found in 41.2% of the papillary thyroid carcinomas\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17785355\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17785355\n",
      "BRAF V600E mutation is associated with high-risk papillary thyroid carcinoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17727338\n",
      "BRAF(V600E) mutation detected on fine-needle aspiration biopsy specimens, more than RET/PTC rearrangements, is highly specific for papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17721188\n",
      "Develompment of malignant strumo ovarii with papillary thyroid carcinoma features is associated with BRAF mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17717450\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17717450\n",
      "BRAF V600E mutation is primarily present in conventional papillary thyroid cancer; it is associated with an aggressive tumor phenotype and higher risk of recurrent and persistent disease in patients with conventional papillary thyroid cancer\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17714762\n",
      "diffuse expression of wild-type and/or mutant B-Raf may be involved in the tumorigenic process\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17704260\n",
      "5 unreported mutations (T241P, Q262R, G464R, E501V, N581K) were found in cardio-facio-cutaneous syndrome. A hotspot in exon 6 at Q257 was found.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17699719\n",
      "RNA interference and pharmacologic approaches were used to assess the role of B-Raf activation in the growth of human melanomas and additionally determined if a similar role for mutant B-Raf is seen for colorectal carcinoma cell lines.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17696195\n",
      "data showed differences in gene expression between nevi with and without the V600E BRAF mutation. Moreover, nevi with mutations showed over-expression of genes involved in melanocytic senescence and cell cycle inhibition\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17693984\n",
      "There was no coexistence of BRAF (V600E) mutation in papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17693984\n",
      "Observational study of genotype prevalence, gene-disease association, and genetic testing. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17685465\n",
      "BRAF V600E mutation in papillary carcinoma of the thyroid may facilitate tumor cell growth and progression once seeded in the lymph nodes.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17671688\n",
      "PPARbeta/delta has a role in growth of RAF-induced lung adenomas\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17663506\n",
      "KLF6 and p53 mutations are involved in the development of nonpolypoid colorectal carcinoma, whereas K-ras and B-raf mutations are not\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17635919\n",
      "In contrast to C-RAF that requires farnesylated H-Ras, cytosolic B-RAF associates effectively and with significantly higher affinity with both farnesylated and nonfarnesylated H-Ras.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17566669\n",
      "We conclude that screening for BRAF 15 exon mutation is an efficient tool in the diagnostic strategy for HNPCC\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17566669\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17548320\n",
      "influence of B-RAF-specific RNA interference on the proliferation and apoptosis of gastric cancer BGC823 cell line\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17542667\n",
      "Presence of BRAF V600E in very early stages of papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17535994\n",
      "The heterogeneous distribution of BRAF mutations suggests that discrete tumor foci in multifocal PTC may occur as independent tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17525723\n",
      "T1790A BRAF mutation (L597Q) in childhood acute lymphoblastic leukemia is a functional oncogene\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17520704\n",
      "frequency of the BRAF mutation and the associations between BRAF mutation and clinicopathologic parameters in papillary thyroid carcinoma were evaluated by meta-analysis\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17520704\n",
      "Meta-analysis of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17518771\n",
      "low rate of RAS-RAF mutations (2/22, 9.1%) observed in Spitz melanocytic nevi suggests that these lesions harbor as yet undetected activating mutations in other components of the RAS-RAF-MEK-ERK-MAPK pathway\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17516929\n",
      "analysis of a BRAF mutation-associated gene expression signature in melanoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17507627\n",
      "data indicate that both early-life UV exposure and nevus propensity contribute to occurrence of BRAF+ melanoma, whereas nevus propensity and later-life sun exposure influence the occurrence of NRAS+ melanoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17507627\n",
      "Observational study of gene-disease association and gene-environment interaction. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17488796\n",
      "BRAF V600E mutation in PTCs is associated with reduced expression of key genes involved in iodine metabolism\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17487504\n",
      "c-kit expression is not alternative to BRAF and/or KRAS activation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17487277\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17483702\n",
      "Molecular diagnosis and careful observations should be considered in children with Cardio-facio-cutaneous syndrome because they have germline mutations in BRAF and might develop malignancy.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17464312\n",
      "prevalence of BRAF mutation and RET/PTC were determined in diffuse sclerosing variant of papillary thyroid carcinoma; none of the cases showed a BRAF mutation\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17454879\n",
      "MSI is rare in UC-related neoplasia as well as non-neoplastic lesions, and does not contribute to the development of dysplasia.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17453358\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17453004\n",
      "BRAF V600E mutation was occasionally observed in anaplastic carcinomas with papillary carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17440063\n",
      "finding of a strong association between BRAF mutations and serrated histology in hyperplastic aberrant crypt foci supports the idea that these lesions are an early, sentinel, or a potentially initiating step on the serrated pathway to colorectal carcinoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17393356\n",
      "data suggest that BRAF mutations might be present less frequently than KRAS mutations in Greek patients with colorectal carcinomas\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17393356\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17387744\n",
      "BRAF(V600E) mutation is identified in a subset of cutaneous metastases from papillary thyroid carcinomas\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17366577\n",
      "mutational analysis of KRAS, BRAF, and MAP2K1/2 in 56 patients with CFC syndrome; comparison of the genotype-phenotype correlation of CFC with that of Costello syndrome suggest a significant clinical overlap but not genotype overlap.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17360030\n",
      "findings show that RASSF1A hypermethylation and KRAS mutations and BRAF mutations are inversely correlated and play an important role in the development of cervical adenocarcinomas\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17355635\n",
      "The aim of this study was to identify the effect that BRAF oncogene has on post-transcriptional regulation in papillary thyroid carcinoma by using microRNA analysis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17318013\n",
      "B-RAF mutations are a rare event in pituitary tumorigenesis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17315191\n",
      "BRAFV600E represents a detectable marker in the plasma/serum from melanoma patients for monitoring but not diagnostic purposes\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17312306\n",
      "Observational study of genetic testing. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17309670\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17309670\n",
      "BRAF gene plays a \"gatekeeper\" role but does not act as a predisposition gene in the development of low-grade ovarian serous carcinomas\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17302867\n",
      "Overexpression of B-Raf mRNA and protein may be a feature of nonfunctioning pituitary adenomas, highlighting overactivity of the Ras-B-Raf-MAP kinase pathway in these tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17297294\n",
      "characterization of the T1799-1801del and A1799-1816ins BRAF mutations in papillary thyroid cancer; the two new mutations resulted in constitutive activation of the BRAF kinase and caused NIH3T3 cell transformation\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17270239\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17227125\n",
      "Copy gain of PDGFB occurs in a subset of tumors showing no evidence of mutated BRAF or rearranged ret, suggesting that copy gain of PDGFB may underlie the increased expression of platelet-derived growth factor described recently in the literature.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17199737\n",
      "Absence of association between BRAF mutation and activation of MAPK pathway in papillary thyroid carcinoma suggests the presence of mechanisms that downregulate MAPK activation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17195912\n",
      "there is a subgroup of colorectal carcinomas which develop via the microsatellite instability pathway that carry an alteration of the BRAF gene\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17195912\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17186541\n",
      "Observational study of gene-disease association and gene-environment interaction. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17186541\n",
      "BRAF mutation is associated with thyroid carcinogenesis\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17179987\n",
      "The role for BRAF activation in thyroid cancer development and establishing the potential therapeutic efficacy of BRAF-targeted agents in patients with thyroid cancerwill be reviewed.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17170014\n",
      "RASSF1A methylation was observed in a high frequency in endometrioid endometrial carcinoma whereas K-ras and B-raf mutations were observed in a low frequency\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17159915\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17159915\n",
      "BRAF(T1799A) mutation is associated with a lower rate of tumor proliferation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17148775\n",
      "Previously identified associations between smoking and colon cancer, whether microsatellite unstable or stable, appear to be explained by the association of smoking with BRAF mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17148775\n",
      "Observational study of gene-disease association and gene-environment interaction. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17119447\n",
      "Association with preexisting nevi and pronounced infiltration of lymphocytes was significantly higher in BRAF mutated melanoma tumours\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17119056\n",
      "BRAF-V600E mutations are mainly involved in colorectal cancer families characterized by an increased risk of other common malignancies\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17097223\n",
      "data provide evidence that oncogenic properties of BRAF contribute to the tumorigenesis of intraductal papillary mucinous neoplasm/carcinoma (IPMN/IPMC), but at a lower frequency than KRAS\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17074813\n",
      "phosphorylation on both S365 and S429 participate in the differential regulation of B-Raf isoforms through distinct mechanisms\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17060774\n",
      "BRAF mutation remained a significant prognostic factor for lymph node metastasis (odds ratio = 10.8, 95% confidence interval, 3.5-34.0, P < 0.0001).\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17044028\n",
      "Activating BRAF mutation is associated with papillary thyroid carcinoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17018604\n",
      "Normally, BRAF alone is responsible for signaling to MEK. However, when RAS is mutated in melanoma, melanocytes switch their signaling from BRAF to CRAF.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17001349\n",
      "data support a model in which mutational activation of BRAF in human melanomas contributes to constitutive induction of NF-kappaB activity and to increased survival of melanoma cells\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16987295\n",
      "BRAF T1976A mutation is present at high frequency in benign naevi such as Spitz and Reed.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16973828\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16964379\n",
      "Extracellular signal-regulated kinase-3 (ERK3/MAPK6) is highly expressed in response to BRAF signaling.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16960555\n",
      "Expression of active mutants of B-Raf induces fibronectin.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16959844\n",
      "BRAFV600E activates not only MAPK but also NF-kappaB signaling pathway in human thyroid cancer cells, leading to an acquisition of apoptotic resistance and promotion of invasion.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16953233\n",
      "Concomitant KRAS and BRAF mutations increased along progression of MSS colorectal cancer, suggesting that activation of both genes is likely to harbour a synergistic effect\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16946010\n",
      "Braf mutations in thyroid tumorigenesis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16937524\n",
      "BRAF, K-ras and BAT26 are expressed in colorectal polyps and stool [BAT26]\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16937524\n",
      "BRAF, K-ras and BAT26 are expressed in colorectal polyps and stool\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16932278\n",
      "Single nucleotide polymorphism found exclusively in papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16924241\n",
      "Expression of p27Kip1 in melanoma is regulated by B-RAF at the mRNA level and via B-RAF control of Cks1/Skp2-mediated proteolysis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16918957\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16918136\n",
      "BRAF mutations are associated with colorectal cancers\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16912199\n",
      "B-RAF has been identified as the most mutated gene in invasive cells and therefore an attractive therapeutic target in melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16879389\n",
      "BRAF mutation was frequent in hyperplastic polyps (67%) and sessile serrated adenomas (81%).\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16858683\n",
      "Aberrant methylation and hence silencing of TIMP3, SLC5A8, DAPK and RARbeta2, in association with BRAF mutation, may be an important step in PTC tumorigenesis and progression.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16858395\n",
      "Thus, we propose that the hitherto unidentified function of the B-Raf amino-terminal region is to mediate calcium-dependent activation of B-Raf and the following MEK activation, which may occur in the absence of Ras activation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16845322\n",
      "BRAF mutation is associated with melanoma and melanocytic nevi.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16809487\n",
      "findings show that MC1R variants are strongly associated with BRAF mutations in non-chronic sun-induced damage melanomas; in this subtype, risk for melanoma associated with MC1R is due to increase in risk of developing melanomas with BRAF mutations\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16804544\n",
      "CpG island methylator phenotype-positive colorectal tumors represent a distinct subset, encompassing almost all cases of tumors with BRAF mutation\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16803888\n",
      "Rheb has a central role in the regulation of the Ras/B-Raf/C-Raf/MEK signaling network\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16799476\n",
      "A subset of Spitz nevi, some with atypical histologic features, possess BRAF mutations. The BRAF mutational status does not separate all Spitz nevi from spitzoid melanomas and non-Spitz types of melanocytic proliferations, contrary to previous reports.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16786134\n",
      "a BRAFT1799A mutation may have a role in poor differentiation of thyroid carcinoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16773193\n",
      "among 23 melanomas located at body sites with chronic UV exposure, only a single tumour harboured the B-raf V599E mutation which was a significantly lower frequency in comparison to melanomas from sun-protected body sites\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16728573\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16728573\n",
      "B-RAF (V600E) was confirmed to be associated with the papillary growth pattern, but not with poorer differentiated papillary thyroid carcinoma variants.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16721785\n",
      "BRAF mutations are as uncommon as KRAS mutations in prostate adenocarcinoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16691193\n",
      "UV light is not necessarily required for the acquisition of the BRAF(V600E) mutation, and non-mutagenic effects of UV light to melanocytes may be more important in the nevogenesis\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16691193\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16687919\n",
      "Observational study of genotype prevalence. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16618717\n",
      "Observational study of gene-environment interaction and pharmacogenomic / toxicogenomic. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16601293\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16601293\n",
      "BRAF V600E is associated with a high risk of recurrence and less differentiated papillary thyroid carcinoma due to the impairment of Na+/I- targeting to the membrane\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16547495\n",
      "Melanoma cells require either B-RAF or phosphoinositide-3 kinase activation for protection from anoikis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16537381\n",
      "Merlin and MLK3 can interact in situ and merlin can disrupt the interactions between B-Raf and Raf-1 or those between MLK3 and either B-Raf or Raf-1.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16487015\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16474404\n",
      "Cardio-facio-cutaneous (CFC) syndrome involves dysregulation of the RAS-RAF-ERK pathway.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16462768\n",
      "NRAS and BRAF activating mutations can coexist in the same melanoma, but are mutually exclusive at the single-cell level\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16452550\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16452469\n",
      "wild-type B-Raf-mediated ERK1/2 activation plays a major role in proliferation and transformation of uveal melanocytes; Raf-1 is not involved in this activation\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16439621\n",
      "findings demonstrate that heterogeneous de novo missense mutations in three genes within the mitogen-activated protein kinase pathway, BRAF, MEK1 and MEK2 cause cardio-facio-cutaneous syndrome\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16424035\n",
      "gain-of-function BRAF signaling is strongly associated with in vivo tumorigenicity\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16417232\n",
      "BRAF mutation does not seem to be sufficient to produce MAPK activation in melanocytic nevi.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16413100\n",
      "The most frequent B-RAF gene alterations are not involved in prostate carcinogenesis\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16397024\n",
      "Observational study of genotype prevalence. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16382052\n",
      "aberrant B-Raf activity in angiomyolipomas leads to abnormal cellular differentiation and migration [review]\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16376942\n",
      "V599E BRAF mutation was uncommon in Japanese lung cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16376942\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16373964\n",
      "activating mutations of PDGFR-alpha, c-kit and B-RAF are absent in gliosarcomas\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16371460\n",
      "V600E B-Raf requires the Hsp90 chaperone for stability and is degraded in response to Hsp90 inhibitors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16364920\n",
      "Data suggest that B-RAF activates C-RAF through a mechanism involving 14-3-3 mediated heterooligomerization and C-RAF transphosphorylation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16361694\n",
      "The authors have developed and run a high-throughput screen to find inhibitors of V600E BRAF using an enzyme cascade assay in which oncogenic BRAF activates MEK1, which in turn activates ERK2, which then phosphorylates the transcription factor ELK1.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16354586\n",
      "Mutation and elevated expression of BRAF is associated with the development of testicular germ cell tumors\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16354196\n",
      "The estimated proportion of attributable risk of melanoma due to variants in BRAF is 1.6%, but the burden of disease associated with this variant is greater than that associated with the major melanoma locus (CDKN2A) which has a risk of 0.2%.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16354196\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16268813\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16199894\n",
      "copy number gain may represent another mechanism of BRAF activation in thyroid tumors\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16181547\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16181240\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16179870\n",
      "The oncogenic B-raf mutations V599E and V599K, as early events in melanocyte transformation, persist throughout metastasis with important prognostic implications.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16179867\n",
      "As the BRAF oncogene is frequently found to be mutated in human cutaneous melanomas, it may constitute a risk factor for melanoma formation within CMN and DMN.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16174717\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16174717\n",
      "In patients with papillary thyroid cancer, BRAF mutation is associated with poorer clinicopathological outcomes and independently predicts recurrence.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16172610\n",
      "selective reduction in catalytic activity and expression of B-Raf but not Raf-1 suggest that B-Raf may be playing an important role in altered ERK signaling in brain of suicide subjects, and thus in the pathophysiology of suicide\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16144912\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16144912\n",
      "Mutations of the BRAF gene are partly involved in the malignant transformation of the endometrium.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16143028\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16129781\n",
      "These data suggest that MITF is an anti-proliferation factor that is down-regulated by B-RAF signaling and that this is a crucial event for the progression of melanomas that harbor oncogenic B-RAF.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16123397\n",
      "The results showed that conjunctival nevi, similar to skin nevi, have a high frequency of oncogenic BRAF mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16098042\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16098042\n",
      "Although BRAF and NRAS mutations are likely to be important for the initiation and maintenance of some melanomas, other factors might be more significant for proliferation and prognosis in subgroups of aggressive melanoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16096377\n",
      "BRAF mutation in melanoma is most likely to occur prior to the development of metastatic disease\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16079850\n",
      "sustained BRAF(V600E) expression in human melanocytes induces cell cycle arrest, which is accompanied by the induction of both p16(INK4a) and senescence-associated acidic beta-galactosidase (SA-beta-Gal) activity, a commonly used senescence marker\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16024606\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16015629\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16007203\n",
      "Single-cell clones with efficient knockdown of (V 600 E)B-RAF could be propagated in the presence of basic fibroblast growth factor but underwent apoptosis or senescence-like growth arrest upon withdrawal of this growth factor\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/16007166\n",
      "determination of mutation specific gene expression profiles in papillary thyroid carcinoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15998781\n",
      "Role of BRAF mutation in facilitating metastasis and progression of papillary thyroid cancer in lymph nodes.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15994075\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15980887\n",
      "BRAF mutation occurs later in thyroid tumor progression and is restricted mainly to papillary thyroid carcinoma and anaplastic thyroid carcinoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15968271\n",
      "The increasing frequency of BRAF mutations as a function of age could help account for the well documented but poorly understood observation that age is a relevant prognostic indicator for patients with papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15968271\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15935100\n",
      "B-raf V599E and V599K oncogenic mutations are likely to affect melanocyte-specific pathways controlling proliferation and differentiation\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15904951\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15880523\n",
      "Anaplastic thyroid carcinomas which are derived from papillary carcinomas are due to BRAF and p53 mutations\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15842051\n",
      "These results suggest that BRAF mutations do not have a role in tumorigenesis of neuroendocrine gastroenteropancreatic tumors.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15824163\n",
      "Observational study of gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15791648\n",
      "B-raf mutations surrounding Thr439 found in human cancers are unlikely to contribute to increased oncogenic properties of B-raf\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15791479\n",
      "The data of this study suggest that activating mutations of B-RAF are not a frequent event in gliomas; nevertheless, when present they are associated with high-grade malignant lesions.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15782118\n",
      "BRAF mutations proved to be absent in tumors from hereditary nonpolyposis colorectal cancer syndrome (HNPCC) families with germline mutations in the MMR genes MLH1 and MSH2.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15765445\n",
      "Mutations in the BRAF protooncogene (V599E)may be an alternative pathway of tumorigenesis of familial colorectal cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15710605\n",
      "autoinhibition was negatively regulated by acidic substitutions at phosphorylation sites within the activation loop\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15705790\n",
      "KSHV-infected cell lines expressed higher levels of B-Raf and VEGF-A; B-Raf-induced VEGF-A expression was demonstrated to be sufficient to enhance tubule formation in endothelial cells\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15702478\n",
      "We found mutations in p53, K-ras, and BRAF genes in 35%, 30%, and 4% of tumors, respectively, and observed a minimal or no co-presence of these gene alterations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15653554\n",
      "a novel Ras-independent ERK1/2 activation system in which p110gamma/Raf-1/MEK1/2 and PKA/B-Raf/MEK1/2 cooperate to activate ERK1/2.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15632082\n",
      "Data suggest that Rit is involved in a novel pathway of neuronal development and regeneration by coupling specific trophic factor signals to sustained activation of the B-Raf/ERK and p38 MAP kinase cascades.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15630448\n",
      "AKAP9-BRAF fusion was preferentially found in radiation-induced papillary carcinomas developing after a short latency, whereas BRAF point mutations were absent in this group\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15577314\n",
      "BRAF mutations are associated with conjunctival neoplasms\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15538400\n",
      "mutated in childhood acute lymphoblastic leukemia.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15489648\n",
      "Mutations of BRAF or KRAS oncogenes are early events in the serrated polyp neoplasia pathway. CpG island methylation plays a role in serrated polyp progression to colorectal carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15488754\n",
      "REVIEW: our understanding of B-RAF as an oncogene and of its role in cancer\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15373778\n",
      "BRAF(V599E) mutation is seven times higher in lesions with structural changes and 13 times higher in growing lesions as compared with lesions without changes\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15339934\n",
      "Data provide evidence that B-Raf is a positive regulator of T cell receptor-mediated sustained ERK activation, which is required for NFAT activation and the full production of IL-2.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15331929\n",
      "we found 19 cases (38%) to harbor somatic B-raf exon 15 mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15330192\n",
      "Mutations within the BRAF gene are useful markers for the differential diagnosis between Spitz nevus and malignant melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15313890\n",
      "Data suggest that SPRY2, an inhibitor of ERK signaling, may be bypassed in melanoma cells either by down-regulation of its expression in WT BRAF cells, or by the presence of the BRAF mutation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15277467\n",
      "In this study, this BRAF mutation was demonstrated in some conjunctival melanoma tissue samples, suggesting that some conjunctival melanomas may share biological features in common with cutaneous melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15273715\n",
      "mutated in papillary thyroid cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15263001\n",
      "B-Raf and ERK are activated by cyclic AMP after calcium restriction\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15191558\n",
      "activation of this gene may be one of the early events in the pathogenesis of some melanomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15186612\n",
      "BRAF mutations are rather rare in solitary cold adenomas and adenomatous nodules and do not explain the molecular etiology of ras mutation-negative cold thyroid nodules.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15179189\n",
      "in contrast to cutaneous melanoma, BRAF does not appear to be involved in the pathogenesis of uveal melanoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15161700\n",
      "mucosal melanomas of the head and neck do not frequently harbor an activating mutation of BRAF\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15150271\n",
      "B-Raf kinase activity regulation by tuberin and Rheb is mammalian target of rapamycin (mTOR)-independent\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15145515\n",
      "Radiation-induced tumors have a low prevalence of BRAF point mutations and high prevalence of RET/PTC rearrangements\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15140228\n",
      "The finding of tandem mutations in thin melanomas makes it more likely that they arise as a simultaneous rather than sequential event.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15126572\n",
      "BRAF(V599E) is more common genetic alteration found to date in adult sporadic papillary thyroid carcinomas (PTCs). It is unique for this thyroid cancer histotype, and it might drive the development of PTCs of classic papillary subtype.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15104286\n",
      "These results suggest that the BRAF mutation is unlikely to be involved in gastric carcinogenesis.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15077125\n",
      "ovarian serous cystadenomas do not contain mutations in either BRAF or KRAS genes\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15014028\n",
      "BRAF mutation may be acquired during development of metastasis but is not a significant factor for primary melanoma development and disease outcome.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15009715\n",
      "mutations in the BRAF gene and to some extent in the N-ras gene represent early somatic events that occur in melanocytic nevi\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15009714\n",
      "possible cooperation between BRAF activation and PTEN loss in melanoma development.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/15001635\n",
      "The lack or low prevalence of BRAF mutation in other thyroid neoplasms is consistent with the notion that other previously defined genetic alterations on the same signaling pathway are sufficient to cause tumorigenesis in most thyroid neoplasms.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/14966563\n",
      "These studies identify isoprenylcysteine carboxyl methyltransferase as a potential target for reducing the growth of K-Ras- and B-Raf-induced malignancies.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/14961576\n",
      "Mutations in BRAF gene is associated with malignant melanomas\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/14734469\n",
      "BRAF mutations are frequently present in sporadic colorectal cancer with methylated hMLH1\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/14724583\n",
      "RAS or BRAF mutations are detected in about 32% of all Barrett's adenocarcinomas; the disruption of the Raf/MEK/ERK (MAPK) kinase pathway is a frequent but also early event in the development of Barrett's adenocarcinoma\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/14722037\n",
      "Observational study of genotype prevalence and gene-disease association. (HuGE Navigator)\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/14719068\n",
      "New enriched PCR-RFLP assay for detecting mutations of BRAF codon 599 mutation in pleural mesotheliomas.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/14695993\n",
      "BRAF mutations are associated with proximal colon tumors with mismatch repair deficiency and MLH1 hypermethylation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/14695152\n",
      "NRAS and BRAF mutations arise early during melanoma pathogenesis and are preserved throughout tumor progression\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/14691295\n",
      "Our data indicate that BRAF gene mutations are rare to absent events in uveal melanoma of humans.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/14688025\n",
      "Mutations were found in exon 15 in colorectal adenocarcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/14668801\n",
      "Missense mutation is marker of colonic but not gastric cancer.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/14639609\n",
      "Mutations of BRAF are associated with extensive hMLH1 promoter methylation in sporadic colorectal carcinomas\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/14618633\n",
      "None of the cases of gastric cancer showed braf mutations\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/14612909\n",
      "BRAF is occasionally mutated in NHL, and BRAF mutation may contribute to tumor development in some NHLs\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/14602780\n",
      "BRAF mutations are restricted to papillary carcinomas and poorly differentiated and anaplastic carcinomas arising from papillary carcinomas\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/14534542\n",
      "BRAF mutations were seen in stomach neoplasms.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/14522897\n",
      "Uceal melanomas arise independent of oncogenic BRAF and NRAS mutations.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/14513361\n",
      "BRAF mutations, which are present in a variety of other human cancers, do not seem to be involved in gastric cancer development\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/14507635\n",
      "Both BRAF and FBXW7 mutations functionally activate kinase effectors important in pancreatic cancer and extend potential options for therapeutic targeting of kinases in treatment of phenotypically distinct pancreatic adenocarcinoma subsets.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/14501284\n",
      "Our findings of a high frequency of BRAF mutations at codon 599 in benign melanocytic lesions of the skin indicate that this mutation is not sufficient by itself for malignant transformation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/12970315\n",
      "mutation of BRAF gene could be a potentially useful marker of prognosis of patients with advanced thyroid cancers\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/12931219\n",
      "Mutations are not detectable in plasma cell leukemia and multiple myeloma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/12917419\n",
      "3 cell lines derived from human choroidal melanoma express B-Raf containing the V599E mutation and showed a 10-fold increase in endogenous B-RafV599E kinase activity and a constitutive activation of the MEK/ERK pathway that is independent of Ras\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/12893203\n",
      "Mucinous ovarian cancers without a KRAS mutation have not sustained alternative activation of this signaling pathway through mutation of the BRAF oncogene.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/12881714\n",
      "The BRAF(V599E) mutation appears to be an alternative event to RET/PTC rearrangement rather than to RAS mutations, which are rare in PTC. BRAF(V599E) may represent an alternative pathway to oncogenic MAPK activation in PTCs without RET/PTC activation.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/12879021\n",
      "BRAF has a role in in squamous cell carcinoma of the head and neck through uncommon mutations\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/12855697\n",
      "B-Raf has a role in extracellular signal-regulated kinase (ERK) signaling in T cells and prevents antigen-presenting cell-induced anergy\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/12824225\n",
      "Data suggest that BRAF T1796A activating mutation is not common in primary uveal melanoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/12821662\n",
      "B-raf is involved in adhesion-independent ERK1/2 signaling in melanocytes\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/12810628\n",
      "13 germline BRAF variants, 4 of which were silent mutations in coding regions & 9 nucleotide substitutions in introns, were found in melanoma patients and melanoma family, but none appeared statistically likely to be a melanoma susceptibility gene.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/12778069\n",
      "gene is mutated in skin melanoma, but not in uveal melanomas\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/12753285\n",
      "cAMP activates ERK and increases proliferation of autosomal dominant polycystic kindey epithelial cells through the sequential phosphorylation of PKA, B-Raf and MAPK in a pathway separate from the classical receptor tyrosine kinase cascade\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/12697856\n",
      "activating BRAF mutations may be an important event in the development of papillary thyroid cancer\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/12670889\n",
      "High prevalence of BRAF mutations in thyroid cancer is genetic evidence for constitutive activation of the RET/PTC-RAS-BRAF signaling pathway in papillary thyroid carcinoma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/12644542\n",
      "results demonstrate that the mutational status of BRAF and KRAS is distinctly different among histologic types of ovarian serous carcinoma, occurring most frequently in invasive micropapillary serous carcinomas and its precursors, serous borderline tumors\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/12619120\n",
      "The V599E BRAF mutation appears to be a somatic mutation associated with melanoma development and/or progression in a proportion of affected individuals.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/12447372\n",
      "High frequency of BRAF mutations in nevi\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/12198537\n",
      "BRAF mutations in colorectal cancers occur only in tumours that do not carry mutations in a RAS gene known as KRAS, and BRAF mutation is linked to the proficiency of these tumours in repairing mismatched bases in DNA\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/12068308\n",
      "somatic missense mutations in 66% of malignant melanomas and at lower frequency in a wide range of human cancers\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/8621729\n",
      "MEK1 interacts with B-Raf.\n"
     ]
    }
   ],
   "source": [
    "print_pubmeds_recent('BRAF')"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 44,
   "metadata": {},
   "outputs": [],
   "source": [
    "def print_pubmeds_most_recent(gene_name):\n",
    "    gene_info = gene_search(gene_name)\n",
    "    for reference in gene_info['generif'][:-10:-1]:\n",
    "        print('https://www.ncbi.nlm.nih.gov/pubmed/' + str(reference['pubmed']))\n",
    "        print(reference['text'])"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 45,
   "metadata": {},
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "https://www.ncbi.nlm.nih.gov/pubmed/30224486\n",
      "MET inactivation in the context of the BRAF-activating mutation is driven through a negative feedback loop involving inactivation of PP2A phosphatase, which in turn leads to phosphorylation on MET inhibitory Ser985.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/30220118\n",
      "The occurrence of BRAF V600E mutations in ganglioglioma is common, and their detection may be valuable for the diagnosis and treatment in ganglioglioma.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/30150413\n",
      "Data show that glycogen synthase kinase 3 (GSK3) and proto-oncogene proteins B-raf (BRAF)/MAPK signaling converges to control microphthalmia-associated transcription factor MITF (MITF) nuclear export.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/30010109\n",
      "these results indicated that STAT3-mediated downexpression of miR-579-3p caused resistance to vemurafenib. Our findings suggest novel approaches to overcome resistance to vemurafenib by combining vemurafenib with STAT3 sliencing or miR-579-3p overexpression.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29974407\n",
      "The frequency of BRAF mutations was significantly higher in Serrated Lesions subgroups with highly methylated epigenotype tumors and microsatellite instability.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29808165\n",
      "Studied frequency of BRAF 1799T>A mutation in Mexican Papillary Thyroid Cancer patients.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29767243\n",
      "The present findings suggested that miR9 may suppress the viability ofpapillary thyroid carcinoma (PTC) cells and inhibit tumor growth through directly targeting the expression of BRAF in PTC.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29762246\n",
      "The BRAFV600E mutation status may not impact the clinical response to radioiodine therapy for papillary thyroid carcinoma patients\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/29715113\n",
      "The present case series suggests that the incidence of concomitant KRAS/BRAF mutations in patients with surgically treated colorectal liver metastasis may be higher than previously hypothesized, and associated with more variable survival outcomes than expected.\n"
     ]
    }
   ],
   "source": [
    "print_pubmeds_most_recent('BRAF')"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 46,
   "metadata": {},
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "https://www.ncbi.nlm.nih.gov/pubmed/24084588\n",
      "The THO complex component Thp2 counteracts telomeric R-loops and telomere shortening.\n",
      "https://www.ncbi.nlm.nih.gov/pubmed/17960421\n",
      "Recombination and transcription analyses indicate that THO/TREX mutants share a moderate but significant effect on gene conversion and ectopic recombination, as well as transcription impairment of even short and low GC-content genes.\n"
     ]
    }
   ],
   "source": [
    "print_pubmeds_most_recent('THP2')"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {},
   "outputs": [],
   "source": []
  }
 ],
 "metadata": {
  "celltoolbar": "Slideshow",
  "kernelspec": {
   "display_name": "Python 3",
   "language": "python",
   "name": "python3"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 3
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython3",
   "version": "3.7.0"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 2
}
